import QtQuick 2.12
import "../"
// application-modal dialog
// Write sub-class with visual elements of dialog
// call show() to start modal
// call hide() to end
// call startTimeout(seconds) to start a timer which emits timedOut() signal
// Set dismissAnywhere and dismissable properties to allow dialog to be dismissed when touching screen anywhere.
// Derived elements may use dismissable property to emit dismissed() signal only in their own MouseArea handler.
// Set isTransparent property to allow passing mouse events to underlying controls

Item {
    id: root
    property bool isTop: true
    property bool isTransparent: false
    property bool dismissable: false
    property bool dismissAnywhere: false
    property alias isCounting:countDownTimer.running
    property bool blockKeys: false
    property alias backgroundColor: borderItem.color
    property alias border: borderItem.border

    signal timedOut()
    signal triggered()
    signal dismissed()
    signal noTime()
    signal hasTime()

    function startTimeout(seconds) {
        countDown = seconds
        countDownTimer.start()
    }

    function stopTimer() {
        countDownTimer.stop()
    }

    function show() {
        main._dialogShowing = true
        dialogManager.alertShown(root)
        visible = true
        if(countDown === 0) {
            noTime()
        } else {
            hasTime()
        }
    }

    function hide() {
        visible = false
        countDownTimer.stop()
        main._dialogShowing = false
        dialogManager.alertHidden(root)
        main.workoutKeysDisabled = false
    }

    onDismissed: hide()

    Component.onCompleted: {
        if(isTop)
            root.parent = main
    }

    property int countDown

    z: 99
    opacity: main.opacityDialog
    width: main.widthDialog
    height: main.heightDialog
    anchors.horizontalCenter: parent.horizontalCenter
    anchors.verticalCenter: parent.verticalCenter

    // blocking mouse area over entire root item
    Rectangle {   // pop-up dialog background
        id: borderItem
        anchors.fill: parent
        color: main.colorDialogBackground
        border.width: main.widthBorder
        border.color: main.colorUIBorder
        opacity: root.opacity
        z: root.z - 1 // don't cover our children

        MouseArea{
            anchors.fill: parent
            onClicked: {
                if(root.dismissable && root.dismissAnywhere) {
                    root.dismissed()
                }

                if(isTransparent){
                    mouse.accepted = false
                }
                buzzer.buttonPress()
            }

            Rectangle {
                anchors.fill: parent
                color: main.colorGenericStimulusArea
                opacity: 0.3
                visible: main.showStimulusArea && root.dismissAnywhere && root.dismissable
            }
        }
    }

    Timer {
        id: countDownTimer

        running: false
        interval: 1000
        repeat: true
        onTriggered: {
            countDown--
            if ( countDown <= 0 ) {
                running = false
                root.timedOut()
            }
            else
            {
                root.triggered()
            }
        }
    }
}
