import QtQuick 2.12
import "Globals.js" as Globals

Item {
    id: root

    property bool alpha: false
    property int value: defaultValue
    property string printedValue: zeroPadding > 0 ? Globals.padZeros(value, zeroPadding) : (alpha ? String.fromCharCode(value) : value)
    property int minValue: 1
    property int maxValue: Number.POSITIVE_INFINITY
    property int defaultValue: 1
    property bool valueWraps: false
    property int zeroPadding: 0
    property int columnSpacing: 0
    property bool showArrows: true
    property string labelColor: main.colorFontDark

    function valueUp() {
        if (root.value + 1 > maxValue) {
            if (valueWraps) {
                root.value = minValue
            } else {
            }
        } else {
            root.value ++
        }
    }

    function valueDown() {
        if (root.value - 1 < minValue) {
            if (valueWraps) {
                root.value = maxValue
            } else {
            }
        } else {
            root.value --
        }
    }

    height: 100 * main.vScaleFactor
    width: 100 * main.hScaleFactor
    anchors.verticalCenter: parent.verticalCenter

    onMaxValueChanged: {
        if (root.value > maxValue) {
            root.value = maxValue
        }
    }

    onMinValueChanged: {
        if (root.value < minValue) {
            root.value = minValue
        }
    }

    Column {
        height: parent.height
        width: parent.width
        spacing: root.columnSpacing

        Item {
            id: upControlItem
            opacity: root.showArrows ? 1.0 : 0.0
            height: (parent.height - middleLabel.height) / 2
            width: 0.9*parent.width
            anchors.horizontalCenter: parent.horizontalCenter

            ScalableImage {
                id: upControl
                width: parent.width
                anchors.fill: parent
                sourceName: "LowerControlBar/Control_Up_blue";
                fillMode: Image.PreserveAspectFit
            }

            MouseArea {
                anchors.fill: parent
                onClicked: {
                    root.valueUp()
                    buzzer.buttonPress()
                }

                Rectangle {
                    anchors.fill: parent
                    color: main.colorGenericStimulusArea
                    opacity: 0.3
                    visible: main.showStimulusArea
                }
            }
        }

        NumberLabel {
            id: middleLabel
            height: parent.height/4
            width: parent.width
            text: root.printedValue
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            font.pixelSize: height
            color: root.labelColor
        }

        Item {
            id: downControlItem
            opacity: root.showArrows ? 1.0 : 0.0
            height: (parent.height - middleLabel.height) / 2
            width: 0.9*parent.width
            anchors.horizontalCenter: parent.horizontalCenter

            ScalableImage {
                id: downControl
                width: parent.width
                anchors.fill: parent
                sourceName: "LowerControlBar/Control_Down_blue";
                fillMode: Image.PreserveAspectFit
            }

            MouseArea {
                anchors.fill: parent
                onClicked: {
                    root.valueDown()
                    buzzer.buttonPress()
                }

                Rectangle {
                    anchors.fill: parent
                    color: main.colorGenericStimulusArea
                    opacity: 0.3
                    visible: main.showStimulusArea
                }
            }
        }
    }

}
