import QtQuick 2.12

// Element which presents a list of strings which can be swiped and selected.
// The model element must be a ListModel, the items of which each have a "label" role
//   which is used as the text for each item.

Item {
    id: root

    // For this property, pass in the basename of the file where the model is defined.
    // E.g. if the model is defined in TelevisionRegionList.qml, pass in "TelevisionRegionList"
    property string modelTranslationContext

    property variant model
    property variant selectedData // provides access to the currently selected list item
    property alias currentIndex: pathview.currentIndex
    property int items_visible: 10
    property variant delegate: listDelegate
    property int selectedFontSize: 20
    property int unselectedFontSize: 18
    property PathView pathView: pathview
    property string fontColor: main.colorFontDark

    signal itemSelected(int index)

    function incrementCurrentIndex() {
        pathview.incrementCurrentIndex()
    }

    function decrementCurrentIndex() {
        pathview.decrementCurrentIndex()
    }

    Rectangle {
        id: sliderBar

        property double baseHeight: pathView.height

        anchors.left: parent.left
        anchors.leftMargin: -30* main.hScaleFactor
        width: 15 * main.hScaleFactor
        height: 0.2*baseHeight
        color: "darkgrey"
        radius: main.defaultRadius
        y: (baseHeight  - height) * pathview.currentIndex/pathView.model.count
    }

    PathView {
        id: pathview
        onModelChanged: if (model) root.selectedData = model.get(currentIndex)

        onCurrentIndexChanged: {
            if (!model)
                return

            root.selectedData = model.get(currentIndex)
        }
        anchors.fill: parent
        model: root.model
        pathItemCount: items_visible
        highlightMoveDuration: 100
        highlightRangeMode: PathView.StrictlyEnforceRange
        preferredHighlightBegin: 0.5
        preferredHighlightEnd: 0.5
        dragMargin: 500
        delegate: root.delegate

        path: Path {
            startX: width / 2
            startY: 0
            PathAttribute { name: "itemOpacity" ; value: 0.1 }
            PathLine { x: width / 2 ; y: height / 2 }
            PathAttribute { name: "itemOpacity" ; value: 1 }
            PathLine { x: width / 2 ; y: height }
            PathAttribute { name: "itemOpacity" ; value: 0.1 }
        }

    }

    Component {
        id: listDelegate

        Text {

            //anchors.fill: parent
            text: label ? (root.modelTranslationContext ? qsTranslate(root.modelTranslationContext, label) + application.emptyString : qsTr(label) + application.emptyString) : ""
            width: parent.width
            font.pointSize: pathview.currentIndex === index ? selectedFontSize: unselectedFontSize
            font.bold: pathview.currentIndex === index
            horizontalAlignment: Text.AlignLeft
            opacity: PathView.itemOpacity
            color: root.fontColor

            MouseArea { // this mouse area provides for clicking an item directly to select it
                anchors.fill: parent
                onClicked: {
                    pathview.currentIndex = index
                    root.itemSelected(index)
                    buzzer.buttonPress()
                }
                Rectangle {
                    anchors.fill: parent
                    color: main.colorGenericStimulusArea
                    opacity: 0.3
                    visible: main.showStimulusArea
                }
            }
        }
    }
}

