import QtQuick 2.12

/**
 * @brief Rectangle that is the basis of standardized buttons within the application.
 */
Rectangle {
    id: standardButton
    width: 188 * main.hScaleFactor
    height: 111 * main.vScaleFactor
    radius: main.defaultRadius
    border.color: main.colorUIBorder
    border.width: main.widthBorder
    color: selected ? main.colorSelected : main.state === "SetupWizardState" || main.state === "DiagnosticState" ? main.colorDialogBackground : main.colorButtonBackground
    opacity: enabled ? 1.0 : 0.5
    property bool beep: true
    property bool isNumberLabel: false
    
    property alias icon: standardButtonImage
    property alias label: standardButtonText

    /**
     * @brief type:string The relative path of the image to use in the button.
     */
    property alias sourceName: standardButtonImage.sourceName
    
    /**
     * @brief type:string The button's text.
     */
    property string buttonText: ""

    property bool noImage: !sourceName || sourceName.length == 0
    property bool noText: !buttonText || buttonText.length == 0

    /**
     * @brief type:color The color of the button's text.  Defaults to white.
     */
    property color textColor: main.colorFontLight

    /**
     * @brief type:bool Boolean to determine if the button is in a "selected" state.
     */
    property bool selected: false

    /**
     * @brief type:bool Boolean to toggle weather or not to show the image as bigger.
     */
    property bool wideImage: false

    /**
     * @brief Signal for when the button has been clicked.
     */
    signal clicked()

    /**
     * @brief Signal for when the button has been pressed and held.
     */
    signal pressAndHold()

    property alias buttonProperties: standardButtonImage

    ScalableImage {
        id: standardButtonImage
        anchors {
            horizontalCenter: parent.horizontalCenter
            top: parent.top
            topMargin: (wideImage ? 5 : 13) * main.vScaleFactor
            bottom: parent.bottom
            bottomMargin: standardButton.noText ? anchors.topMargin : (wideImage ? 32 : 40) * main.vScaleFactor
        }
        fillMode: Image.PreserveAspectFit
    }

    TextLabel {
        id: standardButtonText
        anchors {
            verticalCenter: parent.verticalCenter
            verticalCenterOffset: standardButton.noImage ? 0 : (0.26 * standardButton.height)
            left: parent.left
            leftMargin: 5 * main.hScaleFactor
            right: parent.right
            rightMargin: 5 * main.hScaleFactor
        }
        text: standardButton.buttonText
        font.pixelSize: 13 * main.vScaleFactor
        font.family: isNumberLabel ? "Free Sans" : "Montserrat"
        font.bold: isNumberLabel ? true : false
        color: standardButton.textColor
        horizontalAlignment: Text.AlignHCenter
        verticalAlignment: Text.AlignVCenter
        wrapMode: Text.WordWrap
    }

    MouseArea {
        anchors.fill: parent
        onClicked: standardButton.clicked()
        onReleased: {
            if(beep) {
                buzzer.buttonPress()
            }
        }
        onPressAndHold: standardButton.pressAndHold()

        Rectangle {
            anchors.fill: parent
            color: main.colorGenericStimulusArea
            opacity: 0.3
            visible: main.showStimulusArea
        }
    }
}
