import QtQuick 2.12

Item {
    id: page
    
    anchors.fill: parent
    
    /**
     * Title of the page
     */
    property alias title: page_title.text

    property bool fontDark: false
    
    property alias banner: page_runner_image
    
    /**
     * Width of image as a proportion of page width
     */
    property real image_width: 0.2
    /**
     * Offsets of the image for cropping
     */
    property alias image_offset_x: page_runner.x
    property alias image_offset_y: page_runner.y
    /**
     * Margins around page and spacing between major components on page
     */
    readonly property real page_spacing_proportion: 0.03
    readonly property real page_spacing: page_spacing_proportion*page.width
    /**
     * Set to true to disable the bottom margin
     */
    property bool no_bottom_margin: false
    /**
     * Set to false to disable the back button fucntionality of the banner
     */
    property bool banner_home_button: true
    /**
     * Content loaded below the title and to the right of the image
     */
    property alias content: page_content.sourceComponent
    property alias contentItem: page_content.item
    property alias contentSource: page_content.source
    /**
     * Dimensions of content, provided for convenience
     */
    readonly property alias page_content_width: page_content.width
    readonly property alias page_content_height: page_content.height

    readonly property real titleFontPixelSizeRatio: 25 / 768
    property bool showTitle: true

    property bool isSetupWizard: false
    property bool isDiagnostics: false

    property alias backState:backButton.backState
    property bool showBackButton: true
    
    onImage_widthChanged: {
        if(image_width < 0) {
            image_width = 0;
        } else if(image_width > (1-2*page_spacing_proportion)) {
            image_width = (1-2*page_spacing_proportion);
        }
    }
    
    signal backButtonClicked()

    Item {
        id: invisibleBackArea
        height: parent.height
        width: 120 * main.hScaleFactor
        anchors {
            left: parent.left
            top: parent.top
        }

        MouseArea {
            anchors.fill: parent
            onClicked: backButton.clicked()
            enabled: showBackButton

            Rectangle {
                anchors.fill: parent
                color: main.colorGenericStimulusArea
                opacity: 0.3
                visible: main.showStimulusArea
            }
        }
    }

    BackButton {
        id: backButton
        z: banner.z + 1
        backState: "HomeState"
        visible: showBackButton
        onBackButtonClicked:  {
            page.backButtonClicked()
        }
    }

    Row {
        anchors.fill: parent
        spacing: -1

        Item {
            id: page_runner
            width:page.isSetupWizard || page.isDiagnostics ? page.width*image_width : 0
            height: page.height
            clip: true

            ScalableImage {
                id: page_runner_image
                visible:  page.isSetupWizard || page.isDiagnostics
                anchors.fill: parent
                fillMode: Image.PreserveAspectCrop
                sourceName: "StandardPage/View_Background"
            }

            MouseArea {
                enabled: banner_home_button
                anchors.fill: parent
                onClicked: {
                    backButton.clicked()
                    buzzer.buttonPress()
                }

                Rectangle {
                    id: stimulus_highlighting
                    anchors.fill: parent
                    color: main.colorGenericStimulusArea
                    opacity: banner_home_button ? 0.3 : 0
                    visible: main.showStimulusArea
                }
            }

        }
        
        Column {
            y: page_spacing
            width: parent.width - page_runner.width
            height: parent.height-(no_bottom_margin ? 1 : 2)*page_spacing

            spacing: 0.03125*page.height

            TextLabel {
                id: page_title

                visible: page.showTitle
                anchors.left: parent.left
                anchors.leftMargin: page_spacing
                horizontalAlignment: Text.AlignLeft

                font.pixelSize: titleFontPixelSizeRatio * main.height
                text: ""
                color: fontDark ? main.colorFontDark : main.colorFontLight
            }

            Loader {
                id: page_content
                width: page.isSetupWizard ? page.width - page_runner.width : undefined
                height: parent.height - (page.showTitle ? page_title.height + parent.spacing : 0)
                anchors {
                    horizontalCenter: parent.horizontalCenter
//                    top: parent.top
                }
                clip: true
                onLoaded: {
                    if(item.hasOwnProperty("isSetupWizard")) {
                        item.isSetupWizard = page.isSetupWizard
                    }
                }
            }
        }
    }
}
