import QtQuick 2.12
import QtQuick.Controls 2.12
import QtQuick.Controls.Styles 1.4

/**
 * @brief Rectangle that is the basis of standardized spin boxes within the application.
 */
SpinBox {
    id: spinbox
    width: 70 * main.hScaleFactor
    height: 30 * main.vScaleFactor
    clip: false
    activeFocusOnPress: false
    selectByMouse: false
    menu: null
    horizontalAlignment: Qt.AlignRight

    
    function getValue() { return value; }

    style: SpinBoxStyle {
        textColor: main.colorFontDark
        horizontalAlignment: Qt.AlignRight
        padding.right: control.width/2
        font: Qt.font({ bold: true, pixelSize: 10 * main.vScaleFactor})
        
        background: Rectangle {
            width: control.width
            height: control.height
            color: "white"
            border.color: "transparent"
            border.width: main.widthBorder
        }
        
        incrementControl: ScalableImage {
            width:  padding.right/2
            height: background.height/2
            horizontalAlignment: Image.AlignHCenter
            verticalAlignment: Image.AlignVCenter
            fillMode: Image.Pad

            sourceName: "Components/sb_up";
            
            MouseArea {
                anchors.fill: parent
                anchors.topMargin: -10
                anchors.leftMargin: -10
                anchors.rightMargin: -10
                anchors.bottomMargin: 2
                onClicked: spinbox.__increment()
                Rectangle {
                    anchors.fill: parent
                    color: main.colorGenericStimulusArea
                    opacity: 0.3
                    visible: main.showStimulusArea
                }


            }
        }
        
        decrementControl: ScalableImage {
            width:  padding.right/2
            height: background.height/2
            horizontalAlignment: Image.AlignHCenter
            verticalAlignment: Image.AlignVCenter
            fillMode: Image.Pad

            sourceName: "Components/sb_dn";
            
            MouseArea {
                anchors.fill: parent
                anchors.topMargin: 2
                anchors.leftMargin: -10
                anchors.rightMargin: -10
                anchors.bottomMargin: -10
                onClicked: spinbox.__decrement()
                Rectangle {
                    anchors.fill: parent
                    color: main.colorGenericStimulusArea
                    opacity: 0.3
                    visible: main.showStimulusArea
                }


            }
        }
    }
    onValueChanged: buzzer.buttonPress()
}
