import QtQuick 2.7
import QtQuick.Controls 2.4
import QtQuick.Controls.Styles 1.4

/**
 * @brief Item that is the basis of standardized text fields within the application.
 */
TextField {
    id: stf
    width: 170 * main.hScaleFactor
    height: 30 * main.vScaleFactor
    
    property real font_pixelSize: 14 * main.vScaleFactor

    signal clicked()

    Rectangle {
        id: stimulus_highlighting
        anchors.fill: parent
        color: main.colorGenericStimulusArea
        opacity: 0.3
        visible: main.showStimulusArea
    }

    MouseArea {
        anchors.fill: parent
        enabled: stf.activeFocus
        onClicked: {
            stf.clicked()
        }
    }
    
    style: TextFieldStyle {
        textColor: "black"
        placeholderTextColor: "#808080"
        font.pixelSize: control.font_pixelSize
        background: Rectangle {
            width: control.width
            height: control.height
            color: "white"
            border.color: "transparent"
            border.width: main.widthBorder
        }
    }
    
    /**
     * @brief Gets the current text within the text field.
     * @return type:string Returns the text within the text field.
     */
    function getText() {
        return stf.text;
    }

    /**
     * @brief Clears the text within the text field.
     */
    function clear() {
        stf.text = "";
    }
    
}
