import QtQuick 2.12
import Process 0.1

Item {
    id: root
    state: "idle"

    signal discoveringChanged
    signal hrDisconnecting
    signal hrDisconnectingComplete
    signal scanned
    signal connected
    signal hrConnectionFailed
    signal hrTimeout

    signal bleReadHRTerminated()
    signal scanStopCompleted()

    signal haveHrServiceHandle ( string notice )
    signal haveConfigHandle (string notice )
    signal listening (string notice )
    property int heartrate: 0

    property bool scanning: false
    property bool scanHrHandle:false
    property bool readHR: false
    property bool waiting: false
    property string hr: "--"
    property string scriptsdir: "/usr/lib/trueui/scripts"
    property int devicesFound: 0
    property bool deviceListChanged: false
    property bool connecting: false
    property bool hrConnected: false
    property string nextHrAddress: ""
    property string nextHrAddressType: ""

    property string addrType: "public"
    property string deviceMAC: "NULL" //F6:94:92:22:03:5A" //ALPHA=F6:94:92:22:03:5A
    property string startHandle: "empty"
    property string hrHandle: "empty"
    property string hrUUID: "180d"
    property string configUUID: "2902"
    property string heartRateMeasurementUUID: "00002a37-0000-1000-8000-00805f9b34fb"

    function scan() {
        // scan for heart rate monitors and return List
        if(root.scanning == false){
            bluetoothAdapter.temporaryDisconnect()
            root.scanning = true
            console.debug("Process bleScan start")
            bleScan.start()
        }
    }

    function stopScan(result){
        if(root.scanning == true){
            root.scanning = false
            console.debug("Process bleStopScan start")
            bleStopScan.start()
            if(result == false){
                bluetoothAdapter.reconnect();
            }
        }
    }

    function buildArgs(deviceMAC,addrType) {
        var args = ["-b",deviceMAC, "-t",addrType]
        return args
    }

    function getHrServiceHandle(deviceMAC, addressType){

        root.connecting = true
        root.deviceMAC = deviceMAC
        root.addrType = addressType
        root.startHandle = "empty"
        var deviceArgs=buildArgs(root.deviceMAC,root.addrType)

        var args=deviceArgs.concat(["--primary","--uuid="+root.hrUUID]);
        bleGetHRServiceHandle.arguments = args
        console.debug("Process bleGetHRServiceHandle start")
        bleGetHRServiceHandle.start()
    }

    Timer{
        id: haveHrServiceHandleTimer
        interval: 3000
        running: false
        repeat: false
        onTriggered:
        {
            root.scanHrHandle=true
            console.debug("Process bleGetConfigHandle start")
            _hrMeasUUIDFound = false
            _hrMeasNotifHandleFound = false
            bleGetConfigHandle.start()
        }
    }


    onHaveHrServiceHandle: {
        var skip=new RegExp("empty")
        if(!skip.test(root.startHandle)){
            var deviceArgs=buildArgs(root.deviceMAC,root.addrType)
            var args=deviceArgs.concat(["--char-desc","-s",root.startHandle,root.hrUUID])
            bleGetConfigHandle.arguments = args
            haveHrServiceHandleTimer.start()
        }
    }

    Timer{
        id: haveConfigHandleTimer
        interval: 3000
        running: false
        repeat: false
        onTriggered: {
            root.readHR=true
            connected()
            console.debug("Process bleReadHR start")
            root.connecting = false
            bleReadHR.start()
            bluetoothAdapter.reconnect()
        }
    }

    onHaveConfigHandle:{
        if(root.hrHandle!="empty"){
            var preArgs=["gatttool"]
            var deviceArgs=buildArgs(root.deviceMAC,root.addrType)
            var args=preArgs.concat(deviceArgs,["--char-write-req","-a",root.hrHandle,"-n","0100","--listen"])
            bleReadHR.arguments=args
            root.waiting=false
            haveConfigHandleTimer.start()


        } else {
            console.debug("StartHandle not found..now exiting.")
            root.waiting=false
        }
    }

    property bool _hrMeasUUIDFound: false
    property bool _hrMeasNotifHandleFound: false

    Process {
        id: bleGetConfigHandle
        program: "gatttool"

        onReadyReadStandardOutput: {
            var output = String(readAllStandardOutput())
            output = output.trim()
            var items = output.split(/\r?\n/)
            var hrMeasUUID=new RegExp(root.heartRateMeasurementUUID)
            var UUID=new RegExp(root.configUUID)

            for(var j = 0; j < items.length; j++) {
                if(_hrMeasUUIDFound === false && hrMeasUUID.exec(items[j])) {
                    _hrMeasUUIDFound = true
                } else if(_hrMeasUUIDFound === true && _hrMeasNotifHandleFound === false && UUID.exec(items[j])) {
                    _hrMeasNotifHandleFound = true
                    var itemst = items[j].split(",")
                    root.hrHandle = itemst[0].split(" ")[2]
                    haveConfigHandle("emitted from bleGetConfig...")
                }
            }
        }

        onReadyReadStandardError: {
            console.debug("processing standard error in get handle")
            var output = String(readAllStandardError())
            output = output.trim()
            console.debug(output)
            if (output.indexOf("failed") >= 0 || output.indexOf("not connected") >= 0) {
                // It exits with status 0 in this case, so handle it specially
                root.connecting = false
                hrConnectionFailed()
            }
        }

        onFinished: {
            if (exitCode === 0) {
                console.debug("Process bleGetConfigHandle finished")
            } else {
                console.debug("bleGetConfigHandle process exited with code: " + exitCode)
                root.connecting = false
                hrConnectionFailed()
            }
        }


        function listargs(args){
            console.debug("in listargs")
            console.debug("args" + args)
        }
    }
    /*
    > gatttool -b $ALPHA --addr-type=random --char-write-req -a 0x22 -n 0100 --listen

        > Characteristic value was written successfully
        > Notification handle = 0x0021 value: 10 3d ef 03 
     */
    
     Timer{
        id: hrInterval
        interval: 10000
        running: false
        repeat: false
        onTriggered:
        {
            hrTimeout()
        }
    }

    Process {
        id: bleReadHR
        program: "unbuffer"

        onReadyReadStandardOutput: {
            var output = String(readAllStandardOutput())
            var hr = "--"
            // Expected response
            // Notification handle = 0x0021 value: 10 5c 9c 02
            var items = output.split(" ")
            if(items[0]==="Notification"){
                hr=parseInt(items[6],16)
                root.heartrate=hr
                hrInterval.restart()
            }
            console.debug("BPM: "+hr)
            if(killOnConnect && hr != "--"){
                disconnect()
                killOnConnect = false
            }
        }

        onReadyReadStandardError: {
            console.debug("processing standard error in bleReadHr")
            var output = String(readAllStandardError())
            output = output.trim()
        }

        onFinished: {
            console.debug("Process bleReadHR finished")
            bleReadHRTerminated()
        }
    }

    Process {
        id: bleGetHRServiceHandle

        program: "gatttool"


        onReadyReadStandardError: {
            console.debug("processing standard error in bleGetHRServiceHandle")
            var output = String(readAllStandardError())
            output = output.trim()
            console.debug(output)

        } // end onReadyReadStandardError:

        onReadyReadStandardOutput: {
            var output = String(readAllStandardOutput())
            output = output.trim()
            var handles = output.split(" ")

            for(var i=0 ; i < handles.length ; i++) {
                var handle=handles[i];
            }
            root.startHandle="0x"+handles[2];


        } // end onReadyReadStandardOutput

        onFinished: {
            root.scanning = false
            if(exitCode == 0){                
                console.debug("Process bleGetHRServiceHandle finished")

                if(root.startHandle === "empty"){
                    console.debug("startHandle not found")
                    root.connecting = false
                    hrConnectionFailed()
                    return
                }

                haveHrServiceHandle("emitted from bleGetHrServiceHandle\n")
            } else {
                console.debug("process exited with code: " + exitCode)
                root.connecting = false
                hrConnectionFailed()
            }
        }
        function listargs(args){
            console.debug("in listargs")
            console.debug("args" + args)
        }
    }

    Process {
        id: bleStopScan

        program: "bash"
        arguments: [root.scriptsdir + "/stopHeartrateScan.sh" ]
        onReadyReadStandardOutput: {
            var output = String(readAllStandardOutput())
            console.debug(output)
        }
        onFinished: {
            console.debug("Process bleStopScan finished")
            scanStopCompleted()
        }
    }
   

    Process {
        id: bleScan

        program: "bash"
        arguments: [root.scriptsdir + "/startHeartrateScan.sh" ]

        function isBluetoothDeviceString(address){
            if(address.length !== 17) return false
            if(address.charAt(2) !== ":") return false
            if(address.charAt(5) !== ":") return false
            if(address.charAt(8) !== ":") return false
            if(address.charAt(11) !== ":") return false
            if(address.charAt(14) !== ":") return false
            return true
        }



        onReadyReadStandardOutput: {
            var output = String(readAllStandardOutput())
            var item = output.split("\n")

            for(var i = 0; i<item.length; i++){
                /* device string returned from a noble scan do not
                  contain colons, so we insert them to be compatible
                  with the gatttool calls that follow */

                var scanLine=item[i]
                var parts = scanLine.split(";")
                var address = parts[0]
                address = address.replace(/(\S{2})/g,"$1:");
                address = address.replace(/:$/,"");
                var name = parts[1]
                var txPowerLevel = parts[2] // Not used
                var addressType = parts[3]
                if(isBluetoothDeviceString(address)) {
                    if(name === "(unknown)" || name === "undefined") continue

                    /* No need to do additional duplicate filtering because
                       heartRateManager will do the filtering for us */
                    heartRateManager.addBluetoothHeartRateDevice(name, address, addressType)
                }
            }
        }

        onReadyReadStandardError: {
            console.log("bleScan standard error:")
            var output = String(readAllStandardError())
            console.log(output)
        }

        onFinished: {
            console.debug("Process bleScan finished")
            scanned()
            root.scanning = false
        }

    }//bleScan

    onBleReadHRTerminated: {
        hrInterval.stop()
        root.heartrate=0
        bleReadHRTerminatedTimer.start()
    }

    Timer {
        id: bleReadHRTerminatedTimer
        interval: 4000
        running: false
        repeat: false
        onTriggered: {
            console.debug("Process bleHRdisconnect start")
            bleHRdisconnect.start()
        }
    }

    function abortConnections() {
        // End any in-progress connection attempts
        haveHrServiceHandleTimer.stop()
        haveConfigHandleTimer.stop()
        bleGetHRServiceHandle.terminate()
        bleGetConfigHandle.terminate()
        root.connecting = false
        root.nextHrAddress = ""
        root.nextHrAddressType = ""
    }

    function disconnect(deviceMAC,handle) {
        console.debug("Disconnect function launched")
        hrInterval.stop()
        hrDisconnecting()
        // Set up arguments for the bleHRdisconnect process
        var deviceArgs=buildArgs(root.deviceMAC,root.addrType)
        var args=deviceArgs.concat(["--char-write-req","-a",root.hrHandle,"-n","0000"])
        console.debug(args)
        bleHRdisconnect.arguments=args

        // Stop process that is reading HR
        bleReadHR.terminate()
    }

    Process {
        id: bleHRdisconnect

        program: "gatttool"

        onReadyReadStandardError: {
            console.debug("processing standard error in bleHRdisconnect")
            var output = String(readAllStandardError())
            output = output.trim()
            console.debug(output)
        } // end onReadyReadStandardError:

        onReadyReadStandardOutput: {
            //console.debug("processing standard output in bleHRdisconnect")
            var output = String(readAllStandardOutput())
            //console.debug( "scan output: " + output)
            output = output.trim()
        } // end onReadyReadStandardOutput

        onFinished: {
            root.heartrate = 0
            console.debug("Process bleHRdisconnect finished")
            hrDisconnectingComplete()
        }
        function listargs(args){
            console.debug("in listargs")
            console.debug("args" + args)
        }
    }
}

