import QtQuick 2.12
import "../MediaBrowser"
import "."
import Components 1.0
import Process 0.1

ModalDialog {
    id: root
    property variant list: bluetoothAdapter.scannedHeadSets
    isTop: false
    isTransparent: true
    visible: false
    state: "list"
    opacity: 1.0
    anchors.fill: parent
    backgroundColor: main.state == "HomeState" ? main.colorDialogBackground : main.colorButtonBackground
    border.color: main.state == "HomeState" ? main.colorUIBorder : "transparent"
    property bool isDiscovering: bluetoothAdapter.nonLeScan
    property bool isLowEnergy: false
    property bool pairingAllowed: true

    signal closed()
    signal deviceConnected()
    signal deviceDisconnected()
    signal headsetConnected()
    signal headsetDisconnected()

    onVisibleChanged: {
        state = "list"
        if(visible) {
            if(isLowEnergy == false){
                if(!bluetoothAdapter.discovering && bluetoothAdapter.connected === false && bluetoothAdapter.connectedHeadset === false){
                    bluetoothAdapter.startDiscovery(true)
                }
            } else {
                console.debug("Low Energy scan")
                bluetoothLEAdapter.scan()
            }
        } else {
            if(isLowEnergy == false){
                if(bluetoothAdapter.discovering){
                    bluetoothAdapter.stopDiscovery()
                }

                if(bluetoothAdapter.pairing == true){
                    bluetoothAdapter.cancelDeviceCreation()
                }
            }
        }
    }

    Connections{
        target: workoutScreen
        onWorkoutStopped: {
            hide()
            // Reset internal states before resetting at the system level
            if(bluetoothAdapter.connected) {
                bluetoothAdapter.disconnect()
            }
            if (bluetoothAdapter.connectedHeadset) {
                bluetoothAdapter.disconnectHeadset()
            }
            resetBluez.start()
        }
    }

    Process {
        id: resetBluez
        program: "scripts/resetBluez.sh"
        onReadyReadStandardOutput: {
            var output = String(readAllStandardOutput())
            output = output.trim()
            console.log("Bluetooth service succesfully restarted")
        }

        onReadyReadStandardError: {
            var output = String(readAllStandardError())
            output = output.trim()
            console.log( "Error restarting bluetooth service: " + output)
        }


    }

    Connections{
        target: bluetoothAdapter
        onPasskeyAvailable:{
            var text = passkey.toString()
            root.state = "pairing"
            btPairCodeKeyText.text = text
        }

        onNonLeScanChanged: {
            if(bluetoothAdapter.nonLeScan){
                root.state = "list"
            }
        }

        onPairingChanged: {
            if(pairing) {
                root.state = "gettingpairingcode"
            }
        }

        onPairingComplete: {
            if(result) {
                root.state = "connecting"
            } else {
                root.state = "list"
            }
        }

        onConnectingChanged: {
            if(connecting) {
                root.state = "connecting"
            }
        }

        onPairingHeadsetComplete:{
            if(result) {
                root.state = "connecting"
            } else {
                root.state = "list"
            }
        }

        onConnectionFailed: {
            root.state = "list"
            if(isLowEnergy == false){
                if(!bluetoothAdapter.discovering && bluetoothAdapter.connected === false && bluetoothAdapter.connectedHeadset === false){
                    bluetoothAdapter.startDiscovery(true)
                }
            }
        }

        onConnectedHeadsetChanged:{
            if(connected){
                headsetConnected()
            }
        }

        onDisconnectingHeadset:{
            root.state = "disconnecting"
        }

        onDisconnectingHeadsetComplete:{
            root.state = "list"
            headsetDisconnected()

            if(visible === true) {
                if(isLowEnergy == false){
                    if(!bluetoothAdapter.discovering && bluetoothAdapter.connected === false && bluetoothAdapter.connectedHeadset === false){
                        bluetoothAdapter.startDiscovery(true)
                    }
                } else {
                    console.debug("Low Energy scan")
                    bluetoothLEAdapter.scan()
                }
            }
        }

        onConnectedChanged:{
            if(connected){
                deviceConnected()
            }
        }

        onDisconnecting:{
            root.state = "disconnecting"
        }

        onDisconnectingComplete:{
            root.state = "list"
            deviceDisconnected()

            if(visible === true) {
                if(isLowEnergy == false){
                    if(!bluetoothAdapter.discovering && bluetoothAdapter.connected === false && bluetoothAdapter.connectedHeadset === false){
                        bluetoothAdapter.startDiscovery(true)
                    }
                } else {
                    console.debug("Low Energy scan")
                    bluetoothLEAdapter.scan()
                }
            }
        }

        onPairingCancelling:{
            root.state = "disconnecting"
        }

        onPairingCancelled:{
            if (root.state != "list") { // Avoid bug where discovery list becomes hidden
                root.state = "list"
            }
        }
    }

    Item {   // pop-up dialog background
        id: btStatusDialogborder

        anchors.fill: parent
        z: root.z + 1

        Item {
            id: btPairingItems
            visible: false
            anchors.fill: parent

            TextLabel {
                id: btPairCodeText
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.verticalCenter: parent.verticalCenter
                anchors.verticalCenterOffset: -implicitHeight / 2
                width: parent.width
                text: qsTr("CONFIRM ON DEVICE:") + application.emptyString
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                font.pixelSize: parent.height * 0.12
            }
            NumberLabel {
                id: btPairCodeKeyText
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.verticalCenter: parent.verticalCenter
                anchors.verticalCenterOffset: implicitHeight / 2
                width: parent.width
                text: ""
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                font.pixelSize: parent.height * 0.14
            }
        }

        TextLabel {
            id: btGettingPairingCodeText
            visible: false
            anchors.fill: parent
            text: qsTr("GETTING PAIRING CODE...") + application.emptyString
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            wrapMode: Text.WordWrap
            font.pixelSize: parent.height * 0.12
        }

        TextLabel {
            id: btConnectingText
            visible: false
            anchors.fill: parent
            text: qsTr("CONNECTING TO BLUETOOTH DEVICE...") + application.emptyString
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            wrapMode: Text.WordWrap
            font.pixelSize: parent.height * 0.12
        }

        TextLabel {
            id: btDisconnectingText
            visible: false
            anchors.fill: parent
            text: qsTr("DISCONNECTING FROM BLUETOOTH DEVICE...") + application.emptyString
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            wrapMode: Text.WordWrap
            font.pixelSize: parent.height * 0.12
        }

        // close button
        CloseButton {
            id: btExitButton

            z: 200

            anchors {
                left: parent.left
                leftMargin: 40 * main.hScaleFactor
                bottom: parent.bottom
                bottomMargin: 40 * main.vScaleFactor
            }

            onClicked: {
                if(bluetoothAdapter.pairing == true){
                    bluetoothAdapter.cancelDeviceCreation()
                }
                root.state = "list"
                root.closed()
            }
        }

        Component {
            id: menuButtonDelegate

            Item {
                height: 59 * main.vScaleFactor
                width: listArea.width

                Rectangle {
                    color: bluetoothDeviceListView.currentIndex === index ? main.colorHighlightBackground : main.colorButtonBackground
                    height: parent.height
                    width: parent.width * 0.9
                    radius: main.defaultRadius
                    border.color: main.colorUIBorder
                    border.width: main.widthBorder
                    anchors.horizontalCenter: parent.horizontalCenter

                    Text {
                        anchors {
                            verticalCenter: parent.verticalCenter
                            horizontalCenter: parent.horizontalCenter
                        }
                        anchors.fill: parent
                        anchors.margins: 10 * main.scaleFactor
                        horizontalAlignment: Text.AlignLeft
                        verticalAlignment: Text.AlignVCenter
                        text: name + application.emptyString
                        wrapMode: Text.WordWrap
                        clip: true
                        color: main.colorFontLight
                        font.pixelSize: parent.height * 0.25
                    }

                    MouseArea {
                        anchors.fill: parent
                        onClicked: {
                            bluetoothDeviceListView.currentIndex = index
                            buzzer.buttonPress()
                            //channelSelected(id)
                        }
                    }
                }
            }
        }

        Item {
            id: btDeviceListBox
            anchors.fill: parent

            DeviceListModel {
                id: deviceListModel
                base: root.list
            }

            Text {
                id: instructionalText
                height: parent.height * 0.725
                anchors.top: parent.top
                anchors.left: parent.left
                anchors.right: listArea.left
                anchors.rightMargin: 20 * main.hScaleFactor
                anchors.topMargin: 20 * main.vScaleFactor
                anchors.leftMargin: 20 * main.hScaleFactor
                text: qsTr("To connect:") + "<br />" +
                      qsTr("- Make sure your device is discoverable") + "<br />" +
                      qsTr("- Select your device") + "<br />" +
                      "<br />" +
                      qsTr("Your device will be disconnected at the end of each workout") + application.emptyString
                color: main.colorFontLight
                wrapMode: Text.WordWrap
            }

            Text {
                id: listHeading
                color: main.colorFontLight
                width: listArea.width
                height: parent.height * 0.087
                anchors.top: parent.top
                anchors.right: parent.right
                anchors.topMargin: 20 * main.vScaleFactor
                anchors.rightMargin: 20 * main.hScaleFactor
                text: qsTr("Select device from list:") + application.emptyString
                wrapMode: Text.WordWrap
            }

            Rectangle {
                id: listArea
                color: main.state == "HomeState" ? main.colorToolbarBackground : main.colorDialogBackground
                width: 268 * main.vScaleFactor
                height: parent.height * 0.638
                anchors.top: listHeading.bottom
                anchors.left: listHeading.left

                ListView {
                    id: bluetoothDeviceListView
                    anchors.fill: parent
                    model: deviceListModel.model
                    delegate: menuButtonDelegate
                    spacing: 2 * main.vScaleFactor
                    clip: true
                    visible: bluetoothDeviceListView.model.count > 0
                }
            }

            Text {
                id: emptyListText
                text: qsTr("No devices found") + application.emptyString
                anchors.fill: listArea
                anchors.horizontalCenter: listArea.horizontalCenter
                anchors.verticalCenter: listArea.verticalCenter
                horizontalAlignment: Text.AlignHCenter
                verticalAlignment: Text.AlignVCenter
                visible: bluetoothDeviceListView.visible === false
                color: main.colorFontLight
            }

            StandardButton {
                id: connectButton
                width: 138 * main.hScaleFactor
                height: 79 * main.vScaleFactor
                anchors.horizontalCenter: listArea.horizontalCenter
                anchors.top: listArea.bottom
                anchors.topMargin: 10 * main.vScaleFactor
                visible: true
                enabled: deviceListModel.model.count > 0

                sourceName: "Bluetooth/BluetoothIcon";
                buttonText: qsTr("CONNECT") + application.emptyString

                onClicked: {
                    if(root.pairingAllowed && bluetoothDeviceListView.model.count > 0 && bluetoothDeviceListView.currentIndex != -1) {
                        root.state = "gettingpairingcode"
                        bluetoothAdapter.connect(bluetoothDeviceListView.model.getItem(bluetoothDeviceListView.currentIndex))
                    }
                }
            }
        }
    }

    states: [
        State{
            name: "idle"
            PropertyChanges {target: btPairingItems; visible: false}
            PropertyChanges {target: btDeviceListBox; visible: false}
            PropertyChanges {target: btConnectingText; visible: false}
            PropertyChanges {target: btExitButton; visible: true}
            PropertyChanges {target: btDisconnectingText; visible: false}
            PropertyChanges {target: btGettingPairingCodeText; visible: false}

        },
        State{
            name: "list"
            PropertyChanges {target: btPairingItems; visible: false}
            PropertyChanges {target: btDeviceListBox; visible: true}
            PropertyChanges {target: btConnectingText; visible: false}
            PropertyChanges {target: btExitButton; visible: true}
            PropertyChanges {target: btDisconnectingText; visible: false}
            PropertyChanges {target: btGettingPairingCodeText; visible: false}
        },
        State{
            name: "pairing"
            PropertyChanges {target: btPairingItems; visible: true}
            PropertyChanges {target: btDeviceListBox; visible: false}
            PropertyChanges {target: btConnectingText; visible: false}
            PropertyChanges {target: btExitButton; visible: false}
            PropertyChanges {target: btDisconnectingText; visible: false}
            PropertyChanges {target: btGettingPairingCodeText; visible: false}
        },
        State{
            name: "connecting"
            PropertyChanges {target: btPairingItems; visible: false}
            PropertyChanges {target: btDeviceListBox; visible: false}
            PropertyChanges {target: btConnectingText; visible: true}
            PropertyChanges {target: btExitButton; visible: false}
            PropertyChanges {target: btDisconnectingText; visible: false}
            PropertyChanges {target: btGettingPairingCodeText; visible: false}
        },
        State{
            name: "disconnecting"
            PropertyChanges {target: btPairingItems; visible: false}
            PropertyChanges {target: btDeviceListBox; visible: false}
            PropertyChanges {target: btConnectingText; visible: false}
            PropertyChanges {target: btExitButton; visible: false}
            PropertyChanges {target: btDisconnectingText; visible: true}
            PropertyChanges {target: btGettingPairingCodeText; visible: false}
        },
        State{
            name: "gettingpairingcode"
            PropertyChanges {target: btPairingItems; visible: false}
            PropertyChanges {target: btDeviceListBox; visible: false}
            PropertyChanges {target: btConnectingText; visible: false}
            PropertyChanges {target: btExitButton; visible: false}
            PropertyChanges {target: btDisconnectingText; visible: false}
            PropertyChanges {target: btGettingPairingCodeText; visible: true}
        }
    ]

    function paddy(n, p, c){
        var pad_char = typeof c !== 'undefined' ? c : '0';
        var pad = new Array(1+p).join(pad_char);
        return (pad+n).slice(-pad.length);
    }
}
