import QtQuick 2.12

import "../string_format.js" as StrFormat
import Components 1.0

ModalDialog {
    id: bleDialog

    visible: dialogVisible
    opacity: 1
    isTop: true

    dismissable: true

    onVisibleChanged: {
        if (visible)
            idle_timer.restart()
    }

    onDismissed: disconnect()

    onTimedOut: {
        disconnect()
    }

    Item {
        z: bleDialog.z + 1
        anchors.fill: parent

        Text {
            id: dialogTitle

            width: parent.width * 0.8
            color: main.colorFontLight
            text: qsTr("Sending Data") + application.emptyString
            horizontalAlignment: Text.AlignHCenter
            wrapMode: Text.WordWrap

            font.bold: false
            font.pixelSize: 48 * main.vScaleFactor

            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: parent.top
            anchors.topMargin: 20 * main.vScaleFactor
        }

        Text {
            id: dialogInstruction

            color: main.colorFontLight
            text: qsTr("Open the TRUE Fitness App to log workout.") + application.emptyString
            anchors.horizontalCenter: dialogTitle.horizontalCenter
            anchors.top: dialogTitle.bottom
            anchors.topMargin: 10 * main.vScaleFactor
        }

        ScalableImage {
            id: _BlueToothLogo

            anchors.top: dialogInstruction.bottom
            anchors.topMargin: 12 * main.vScaleFactor
            anchors.horizontalCenter: dialogTitle.horizontalCenter
            sourceName: "Bluetooth/BluetoothIcon"
        }

        CloseButton {
            id: closeButton

            anchors {
                right: parent.right ; rightMargin: 80 * main.hScaleFactor
                top: parent.top ; topMargin: 40 * main.vScaleFactor
            }
            onClicked: bleDialog.dismissed()
        }

        Text {
            id: moreTimeText

            color: main.colorFontLight
            text: qsTr("Touch for more time") + application.emptyString
            font.pointSize: 15 * main.vScaleFactor
            anchors.top: _BlueToothLogo.bottom
            anchors.topMargin: 10 * main.vScaleFactor
            anchors.horizontalCenter: bleCounterDigits.horizontalCenter
            horizontalAlignment: Text.AlignHCenter
        }

        Text {
            id: bleCounterDigits

            color: main.colorFontLight
            text: StrFormat.formatTimeString(root.timeLeft)

            font.pixelSize: 34 * main.vScaleFactor
            horizontalAlignment: Text.AlignHCenter
            anchors {
                horizontalCenter: dialogTitle.horizontalCenter; horizontalCenterOffset: 0
                top: moreTimeText.bottom;  topMargin: 4 * main.vScaleFactor
            }
        }

        Text {
            id: dialogInstruction2

            color: main.colorFontLight
            text: qsTr("Select below workout in your App to complete:") + application.emptyString

            anchors.horizontalCenter: dialogTitle.horizontalCenter
            anchors.top: bleCounterDigits.bottom //moreTimeText.bottom
            anchors.topMargin: 10 * main.vScaleFactor
        }

        Text {
            id: dialogElapsed

            color: main.colorFontLight
            text: qsTr("Workout") + " " + StrFormat.formatTimeStringMinAndSec(root.workoutElapsed)  + application.emptyString
            font.bold: false
            font.pixelSize: 48 * main.vScaleFactor

            anchors.horizontalCenter: dialogTitle.horizontalCenter
            anchors.top: dialogInstruction2.bottom
            anchors.bottomMargin: 4 * main.vScaleFactor
        }

        ScalableImage{
            id: scanningBluetoothWave

            property int opacityInteger: 0

            width: 142 * main.hScaleFactor
            height: 58 * main.vScaleFactor
            anchors.topMargin: -10 * main.vScaleFactor
            anchors.bottomMargin: -10 * main.vScaleFactor
            anchors.rightMargin: -20 * main.hScaleFactor
            anchors.leftMargin: -20 * main.hScaleFactor
            anchors.verticalCenter: _BlueToothLogo.verticalCenter
            anchors.horizontalCenter: _BlueToothLogo.horizontalCenter
            sourceName: "Bluetooth/Bluetooth_waves_medium"
            sourceSize.width: 150 * main.hScaleFactor
            opacity: opacityInteger / 100.0

            NumberAnimation on opacityInteger {
                from: 0;
                to: 100;
                duration: 500
                running : scanningBluetoothWave.visible
                loops: Animation.Infinite
            }
        }
    }
}
