import QtQuick 2.12
import ".."
import Components 1.0

ModalDialog {
    id: root
    height: 1.3 * main.heightDialog
    opacity: 1
    dismissable: true
    blockKeys: true
    property string norm: normValue.totalValue
    property string frequency: Globals.stripLeadingZeros(frequencyRow.totalValue)
    property string network: networkRow.totalValue
    property string channelNumber: channelRow.totalValue
    property string navState: "norm"
    signal channelAdded(string norm, string freq, string network, string number)

    function submit() {
        root.channelAdded(root.norm, root.frequency, root.network, root.channelNumber)
    }

    Item {
        z: root.z + 1
        anchors.fill: parent

        TextLabel {
            id: headerText
            width: parent.width
            text: qsTr("ADD CHANNEL?") + application.emptyString
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: parent.top
            anchors.topMargin: 35 * main.vScaleFactor
            horizontalAlignment: Text.AlignHCenter
            wrapMode: Text.WordWrap
            font.pixelSize: 40 * main.vScaleFactor
        }

        Text {
            id: helpText
            anchors { left: parent.left; leftMargin: 30 * main.hScaleFactor; top: headerText.bottom; topMargin: 30 * main.vScaleFactor }
            text: qsTr("Add a Channel by Frequency") + application.emptyString
            font { pixelSize: 16 * main.vScaleFactor ; bold: true }
            color: main.colorFontLight
        }

        Text {
            id: stdHeader
            text: qsTr("Standard") + ":" + application.emptyString
            anchors { left: helpText.left; top: helpText.bottom; topMargin: 25 * main.vScaleFactor }
            font { pixelSize: 16 * main.vScaleFactor; bold: true }
            color: main.colorFontLight
        }

        Text {
            id: freqHeader
            text: qsTr("Frequency") + ":" + application.emptyString
            anchors { left: frequencyRow.left; top: helpText.bottom; topMargin: 25 * main.vScaleFactor}
            font { pixelSize: 16 * main.vScaleFactor; bold: true }
            color: main.colorFontLight
        }

        Text {
            id: netHeader
            text: qsTr("Network") + ":" + application.emptyString
            anchors { left: networkRow.left; top: helpText.bottom; topMargin: 25 * main.vScaleFactor}
            font { pixelSize: 16 * main.vScaleFactor; bold: true }
            color: main.colorFontLight
        }

        Text {
            id: chanHeader
            text: qsTr("Channel Number") + ":" + application.emptyString
            anchors { left: channelRow.left; top: helpText.bottom; topMargin: 25 * main.vScaleFactor}
            font { pixelSize: 16 * main.vScaleFactor; bold: true }
            color: main.colorFontLight
        }

        ValuePickerRow {
            id: normValue
            anchors.top: stdHeader.bottom
            anchors.topMargin: 15 * main.vScaleFactor
            anchors.left: helpText.left
            anchors.leftMargin: -3 * main.vScaleFactor
            numberOfItems: 1
            width: 100 * main.hScaleFactor
            height: 100 * main.vScaleFactor
            delegate: Component {
                NumberPicker {
                    id: picker
                    ListModel {
                        id: analogStandards
                        ListElement { label: "NTSC-M"; value: "NTSC-M" }
                        ListElement { label: "PAL-BG"; value: "PAL-BG" }
                        ListElement { label: "PAL-DK"; value: "PAL-DK" }
                        ListElement { label: "PAL-I"; value: "PAL-I" }
                        ListElement { label: "PAL-N"; value: "PAL-N" }
                        ListElement { label: "SECAM-L"; value: "SECAM-L" }
                        ListElement { label: "SECAM-B"; value: "SECAM-B" }
                        ListElement { label: "SECAM-DK"; value: "SECAM-DK" }
                    }
                    minValue: 0
                    maxValue: analogStandards.count - 1
                    printedValue: analogStandards.get(value).value
                    defaultValue: 0
                    valueWraps: true
                    columnSpacing: 5 * main.vScaleFactor
                    width:100 * main.hScaleFactor
                    height:90 * main.vScaleFactor
                    labelColor: main.colorFontLight
                }
            }
        }

        ValuePickerRow {
            id: frequencyRow
            anchors.top: freqHeader.bottom
            anchors.topMargin: 15 * main.vScaleFactor
            anchors.left: normValue.right
            anchors.leftMargin: 30 * main.hScaleFactor
            numberOfItems: 6
            width: 240 * main.hScaleFactor
            height: 100 * main.vScaleFactor
            delegate: Component {
                NumberPicker {
                    id: picker
                    minValue: 0
                    maxValue: 9
                    defaultValue: 0
                    valueWraps: true
                    columnSpacing: 5 * main.vScaleFactor
                    width:40 * main.hScaleFactor
                    height:90 * main.vScaleFactor
                    labelColor: main.colorFontLight
                }
            }
        }
        Text {
            // Wedge in a decimal point after the third frequency digit
            id: decimalPoint
            text: "."
            font.pixelSize: 50 * main.vScaleFactor
            x: 270 * main.hScaleFactor
            y: 200 * main.vScaleFactor
            color: main.colorFontLight
        }

        ValuePickerRow {
            id: networkRow
            anchors.top: netHeader.bottom
            anchors.topMargin: 15 * main.vScaleFactor
            anchors.left: frequencyRow.right
            anchors.leftMargin: 30 * main.hScaleFactor
            numberOfItems: 4
            width: 160 * main.hScaleFactor
            height: 100 * main.vScaleFactor
            delegate: Component {
                NumberPicker {
                    id: picker
                    minValue: "A".charCodeAt(0)
                    maxValue: "Z".charCodeAt(0)
                    defaultValue: minValue
                    alpha: true
                    valueWraps: true
                    columnSpacing: 5 * main.vScaleFactor
                    width:40 * main.hScaleFactor
                    height:90 * main.vScaleFactor
                    labelColor: main.colorFontLight
                }
            }
        }
        ValuePickerRow {
            id: channelRow
            anchors.top: chanHeader.bottom
            anchors.topMargin: 15 * main.vScaleFactor
            anchors.left: networkRow.right
            anchors.leftMargin: 30 * main.hScaleFactor
            numberOfItems: 2
            width: 80 * main.hScaleFactor
            height: 100 * main.vScaleFactor
            delegate: Component {
                NumberPicker {
                    id: picker
                    minValue: 0
                    maxValue: 9
                    defaultValue: 0
                    valueWraps: true
                    columnSpacing: 5 * main.vScaleFactor
                    width: 40 * main.hScaleFactor
                    height: 90 * main.vScaleFactor
                    labelColor: main.colorFontLight
                }
            }
        }
        Item {
            id: buttonRow
            anchors { bottom: parent.bottom; bottomMargin: 30 * main.vScaleFactor; right: parent.right; rightMargin: 50 * main.hScaleFactor}

            StandardKeyboardButton{
                id: okButton
                visible: true
                anchors.right: parent.right
                anchors.rightMargin: 40 * main.hScaleFactor
                anchors.bottom: parent.bottom
                buttonText: qsTr("OK") + application.emptyString
                fontsize: 20 * main.vScaleFactor
                textTopMargin: 10 * main.vScaleFactor
                onClicked: {
                    root.submit()
                }
                state:"double"
            }



            StandardKeyboardButton{
                id: cancelButton
                visible: true
                anchors.right: okButton.left
                anchors.rightMargin: 40 * main.hScaleFactor
                anchors.bottom: parent.bottom
                buttonText: qsTr("Cancel") + application.emptyString
                fontsize: 20 * main.vScaleFactor
                textTopMargin: 10 * main.vScaleFactor
                onClicked: {
                    root.dismissed()
                }
                state:"double"
            }
        }
    }

    Component.onCompleted: hide()
    onTimedOut: hide()
}
