
import QtQuick 2.12
import Process 0.1
import FileIO 1.0
import "../HomeScreen"
import "../string_format.js" as Format
import ".."
import Components 1.0
//import QtAV 1.6
import QtMultimedia 5.7

Item {
    id: root
    state: "NoUsbState"

    anchors.fill: parent

    property bool isUsbDeviceLoaded: storageMgr.usbDeviceLoaded
    property string cursorState: "controls" // controls is the only state currently

    onVisibleChanged: {
        if(visible === false && videoArtwork.playbackState === MediaPlayer.PlayingState) {
            videoArtwork.stopVideo()
        }
    }

    function doSave() {
        attractVideoManager.commitVideo()
        dialogText.text = qsTr("Banner content has been updated") + application.emptyString
        actionSuccessfulDialog.show()
        actionSuccessfulDialog.startTimeout(1)
    }

    function doClearVideos() {
        attractVideoManager.deleteCurrentVideos()
        dialogText.text = qsTr("Banner content has been cleared") + application.emptyString
        actionSuccessfulDialog.show()
        actionSuccessfulDialog.startTimeout(1)
    }

    function getFirstVideoFile(path) {
        var files = storageMgr.listFiles(path, ["*.mpg", "*.mpeg", "*.avi", "*.mp4"])
        if(files.length > 0) {
            return path + "/" + files[0]
        } else {
            return ""
        }
    }

    onStateChanged: {
        if (state === "FoundUsbState") {
            videoArtwork.source = getFirstVideoFile("/media/usb/attract")
            if(videoArtwork.source != "") {
                videoArtwork.startVideo()
            }
        }
    }

    onIsUsbDeviceLoadedChanged: {
        if (isUsbDeviceLoaded)
            state = "FoundUsbState"
        else
            state = "NoUsbState"
    }

    TextLabel {
        id: title
        text: qsTr("BANNER CONTENT")
        color: main.colorFontDark
        anchors.top: parent.top
        anchors.topMargin: 30 * main.vScaleFactor
        anchors.horizontalCenter: parent.horizontalCenter
        font.pixelSize: 24 * main.vScaleFactor
    }

    AttractVideoManager {
        id: attractVideoManager
        destination: "/data/video/attract/user"
        source: "/media/usb/attract"
    }

    Text {
        id: previewText
        font { pixelSize: 30 * main.vScaleFactor }
        text: qsTr("Preview") + application.emptyString
        anchors.top: title.bottom
        anchors.topMargin: 10 * main.vScaleFactor
        anchors.left: parent.left
        anchors.leftMargin: 50 * main.hScaleFactor
    }

    Rectangle {
        id: previewSlideshow
        width: parent.width * 0.5
        height: parent.height * 0.5
        anchors.top: previewText.bottom
        anchors.topMargin: 5 * main.vScaleFactor
        anchors.left: parent.left
        anchors.leftMargin: 50 * main.hScaleFactor
        clip: true
        color: main.colorDialogBackground
    }

    Video {
        id: videoArtwork
        fillMode: VideoOutput.PreserveAspectFit
        anchors.fill: previewSlideshow
        visible: previewSlideshow.visible
        source: ""

        function startVideo() {
            videoArtwork.seek(1)
            videoArtwork.play()
        }

        function stopVideo() {
            videoArtwork.stop()
            videoArtwork.source = ""
        }

//        backgroundColor: "transparent"
//        videoCodecPriority: ["FFmpeg"]

        loops: MediaPlayer.Infinite
//        onPositionChanged: {
//            if(position >= (duration - 500)) {
//                startVideo()
//            }
//        }
    }

    Text {
        id: slideshowCounter

        visible: previewSlideshow.imageIndex >= 0 && state === "FoundUsbState"
        anchors.horizontalCenter: previewSlideshow.horizontalCenter
        anchors.top: previewSlideshow.bottom
        font { pixelSize: 24 * main.vScaleFactor }
        text: qsTr("Image")// + " " + (1 + previewSlideshow.imageIndex) + " / " + previewSlideshow.imageList.count + application.emptyString
    }


    Text {
        id: insertUsbText
        anchors.top: title.bottom
        anchors.topMargin: 20 * main.vScaleFactor
        anchors.horizontalCenter: parent.horizontalCenter
        font { pixelSize: 24 * main.vScaleFactor }
        text: qsTr("INSERT USB KEY TO CHANGE CONTENT") + application.emptyString
    }

    Text {
        id: foundText
        anchors.top: previewSlideshow.top
        anchors.topMargin: 0
        anchors.left: previewSlideshow.right
        anchors.leftMargin: 50 * main.hScaleFactor
        font { pixelSize: 24 * main.vScaleFactor }
        text: qsTr("Content Found")// + ": " + numberOfImages + application.emptyString
    }

    StandardButton {
        id: saveButton

        buttonText: qsTr("SAVE?") + application.emptyString
        width: 120 * main.hScaleFactor
        height: 78 * main.vScaleFactor
        anchors.right: parent.right
        anchors.rightMargin: 20 * main.hScaleFactor
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 20 * main.vScaleFactor

        icon.anchors.topMargin: 5 * main.vScaleFactor
        icon.anchors.bottomMargin: 30 * main.vScaleFactor
        icon.sourceName: "WF/WF_Button_Saved_Workouts"
        onClicked: {
            root.doSave()
        }
    }

    ModalDialog {
        id: actionSuccessfulDialog

        Text {
            id: dialogText
            anchors.fill: parent
            anchors.verticalCenter: parent.verticalCenter
            color: main.colorFontLight
            anchors.horizontalCenter: parent.horizontalCenter
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            wrapMode: Text.WordWrap
            font.bold: false
            font.pixelSize: 50 * main.vScaleFactor
            z: parent.z + 1
        }
        Component.onCompleted: hide()
        onTimedOut: hide()
    }

    Item {
        id: missingFolderText
        anchors.top: foundText.bottom
        anchors.topMargin: 20 * main.vScaleFactor
        anchors.left: foundText.left
        visible: true

        Text {
            width: 250 * main.hScaleFactor
            text: qsTr("Create a folder on your USB thumb drive titled \"attract\" (case sensitive). Only one video file or image file in that folder can be uploaded here.Video should be in MPG, MPEG, AVI, or MP4 format") + application.emptyString
            font.pixelSize: 14 * main.vScaleFactor
            wrapMode: Text.WordWrap
        }
    }

    StandardButton {
        id: clearButton

        width: 100 * main.hScaleFactor
        height: 78 * main.vScaleFactor
        anchors.right: parent.right
        anchors.rightMargin: 20 * main.hScaleFactor
        anchors.bottom: saveButton.top
        anchors.bottomMargin: 20 * main.vScaleFactor

        buttonText: qsTr("Clear") + application.emptyString
        onClicked: root.doClearVideos()
    }

    FileIO {
        id: fileio
        onError: print("IO error: " + error)
    }

    states: [
        State {
            name: "NoUsbState"
            PropertyChanges { target: insertUsbText; visible: true }
            PropertyChanges { target: foundText; visible: false }
            PropertyChanges { target: previewText; visible: false }
            PropertyChanges { target: previewSlideshow; visible: false }
            PropertyChanges { target: saveButton; visible: false }
        },

        State {
            name: "FoundUsbState"
            PropertyChanges { target: insertUsbText; visible: false }
            PropertyChanges { target: foundText; visible: true }
            PropertyChanges { target: previewText; visible: true }
            PropertyChanges { target: previewSlideshow; visible: true }
            PropertyChanges { target: saveButton; visible: true }
        }
    ]

    transitions:  [
        Transition {
            from: "NoUsbState"
            to: "FoundUsbState"
        }
    ]
}
