import QtQuick 2.12
import Process 0.1
import Bluetooth 1.0
import Components 1.0

import ".."

Item {
    id: root
    anchors.fill: parent

    Component.onCompleted: {

    }

    Component.onDestruction: {
        scanButton.state = "idle"
    }

    Component{
        id: deviceInfoComponent
        Item {
            width: parent.width
            height: 60 * main.vScaleFactor
            anchors.left: parent.left
            anchors.leftMargin: 10 * main.hScaleFactor

            Text {
                height: parent.height/2
                width: parent.width * 0.8
                anchors.left: parent.left
                anchors.top: parent.top

                verticalAlignment: Text.AlignVCenter
                text: name
                font.pointSize: 16 * main.vScaleFactor
                color: main.colorFontLight
            }
            Text {
                height: parent.height/2
                width: parent.width * 0.8
                anchors.left: parent.left
                anchors.bottom: parent.bottom
                verticalAlignment: Text.AlignVCenter
                text: address
                font.pointSize: 16 * main.vScaleFactor
                color: main.colorFontLight
            }
            Text {
                height: parent.height
                width: parent.width * 0.2
                anchors.right: parent.right
                anchors.top: parent.top

                horizontalAlignment: Text.AlignHCenter
                verticalAlignment: Text.AlignVCenter
                text: rssi
                font.pointSize: 16 * main.vScaleFactor
                color:  main.colorFontLight
            }
        }
    }

    Row{
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.verticalCenter: parent.verticalCenter
        spacing: 20 * main.vScaleFactor


        Rectangle {
            id: bluetoothDeviceListBox
            color: main.colorDialogBackground
            radius: main.defaultRadius
            width: 350 * main.hScaleFactor
            height: 250 * main.vScaleFactor

            Text{
                anchors.bottom: parent.top
                anchors.horizontalCenter: parent.horizontalCenter
                horizontalAlignment: Text.AlignHCenter
                verticalAlignment: Text.AlignVCenter
                width: parent.width
                height: 60 * main.vScaleFactor
                text: qsTr("Bluetooth Audio Devices") + application.emptyString
            }

            ListView {
                id: bluetoothDeviceList

                clip: true
                anchors.fill: parent
                anchors.margins: 5 * main.scaleFactor
                model: bluetoothAdapter.scannedDevices
                highlight: Rectangle {
                    color: main.colorUIBorder
                    radius: 10 * main.scaleFactor
                    opacity: 0.7
                    width: parent.width}
                highlightMoveVelocity: 1500
                delegate: deviceInfoComponent
            }
        }

        Rectangle {
            id: bluetoothHeadsetListBox
            color: main.colorDialogBackground
            radius: main.defaultRadius
            width: 350 * main.hScaleFactor
            height: 250 * main.vScaleFactor

            Text{
                anchors.bottom: parent.top
                anchors.horizontalCenter: parent.horizontalCenter
                horizontalAlignment: Text.AlignHCenter
                verticalAlignment: Text.AlignVCenter
                width: parent.width
                height: 60 * main.vScaleFactor
                text: qsTr("Bluetooth Headsets") + application.emptyString
            }

            ListView {
                id: bluetoothHeadsetList

                clip: true
                anchors.fill: parent
                anchors.margins: 5
                model: bluetoothAdapter.scannedHeadSets
                highlight: Rectangle {
                    color: main.colorHighlightBackground
                    radius: 5 * main.scaleFactor
                    opacity: 0.7
                    width: parent.width
                }
                highlightMoveVelocity: 1500
                delegate: deviceInfoComponent
            }
        }

    }

    StandardButton {
        id: scanButton

        state: "idle"
        enabled: !bluetoothAdapter.connected

        width: 150 * main.hScaleFactor
        height: 78 * main.vScaleFactor
        anchors.right: parent.right
        anchors.rightMargin: 20 * main.hScaleFactor
        anchors.top: parent.top
        anchors.topMargin: 20 * main.vScaleFactor

        onClicked: state === "idle" ? state = "scanning" : state = "idle"

        onStateChanged: {
            if(state === "idle"){
                bluetoothAdapter.stopDiscovery()
            } else if(state === "scanning"){
                bluetoothAdapter.startDiscovery(false)
            }
        }

        states: [
            State {
                name: "idle"
                PropertyChanges { target: scanButton; buttonText: qsTr("Start Scan") + application.emptyString }
            },
            State {
                name: "scanning"
                PropertyChanges { target: scanButton; buttonText: qsTr("Stop Scan") + application.emptyString }
            }
        ]
    }
}



