import QtQuick 2.12
import Process 0.1
import "."
import "../Television"
import ".."
import "../Keypad"
import FileIO 1.0
import Components 1.0

Item {
    id: root
    property bool isActive: main.state === "DiagnosticState" && diagnosticsMain.currentSelectedIndex >= 0

    anchors.fill: parent


    ModalDialog {
        id: channelExistNotice
        dismissable: true
        blockKeys: true

        Item {
            z: channelExistNotice.z + 1
            anchors.fill: parent

            TextLabel {
                id: warningText
                width: parent.width
                text: qsTr("ReScan TV channels for C.A.B (Channel List should have only One Channel)") + application.emptyString
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.top: parent.top
                anchors.topMargin: 50 * main.vScaleFactor
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                font.pixelSize: 35 * main.vScaleFactor
            }

            Column {
                id: touchControls2
                width: 300 * main.hScaleFactor
                height: 200 * main.vScaleFactor
                spacing: 40 * main.vScaleFactor
                anchors {
                    top: warningText.bottom
                    topMargin: 40 * main.vScaleFactor
                    horizontalCenter: parent.horizontalCenter
                }

                StandardButton {
                    id: okBtn
                    width: 0.9 * parent.width
                    height: 50 * main.vScaleFactor

                    anchors.horizontalCenter: parent.horizontalCenter

                    onClicked: {
                        //cabEnabledToggle.value=false
                        channelExistNotice.hide()
                        startTv()
                    }
                    buttonText: qsTr("OK") + application.emptyString
                    label.font.pixelSize: 18 * main.vScaleFactor
                }

                }
        }
        Component.onCompleted: hide()
        onTimedOut: hide()
    }
Component.onDestruction: {
        if (root.isActive) {
            tv.on = false
            tv.currentChannel = -1
            tvRetryTimer.stop()
        }
    }

    onIsActiveChanged: {
        if (isActive){
                tvRetryTimer.start()
        } else {
            stopTv()
        }
    }


    Column {
        id: controlList
        spacing: 15 * main.vScaleFactor
        anchors.top: root.top
        anchors.topMargin: 20 * main.vScaleFactor
        anchors.left: root.left
        anchors.leftMargin: 20 * main.hScaleFactor
        width: root.width * 0.6
        height: root.height * 0.9

        Checkbox {
            id: cabEnabledToggle
            label: qsTr("C.A.B. Enabled?") + application.emptyString
            width: parent.width
            onPressed: {
                options.cabEnabled = value ? true : false
                if(value){
                    checkChannelList()
                   // startTv()
                } else {
                    stopTv()
                }
            }
            Component.onCompleted: value = options.cabEnabled
        }
       Rectangle {
                id: previewTv
                color: "black"

                width: parent.width
                height:  width/(16.0/9.0)
                anchors.horizontalCenter: parent.horizontalCenter

                Component.onCompleted: {

                    tv.viewParent = previewTv
                    tv.changeParent(previewTv)
                    tv.on = true
                    // Disable CC and FullScreen



                }
            }
    }

    Rectangle {
        id: rightControlArea

        radius: 5 * main.scaleFactor
        width: root.width * 0.30
        height: 230 * main.vScaleFactor
        color: "darkgrey"
        anchors {
            top: controlList.top
            right: parent.right
            rightMargin: 30 * main.hScaleFactor
        }

        Column {
            spacing: 15 * main.vScaleFactor
            anchors.fill: parent
            anchors.topMargin: 25 * main.vScaleFactor


            StandardButton {
                id: channelUpButton

                width: 0.75 * parent.width
                height: 78 * main.vScaleFactor
                anchors.horizontalCenter: parent.horizontalCenter

                buttonText: qsTr("Channel Up") + application.emptyString
                onClicked: nucleus.cabChannelUp()
            }

            StandardButton {
                id: channelDownButton

                width: 0.75 * parent.width
                height: 78 * main.vScaleFactor
                anchors.horizontalCenter: parent.horizontalCenter

                buttonText: qsTr("Channel Down") + application.emptyString
                onClicked: nucleus.cabChannelDown()
            }
        }
    }

    Timer {
        id: tvRetryTimer
        interval: 1500
        running: true
        repeat: false
        onTriggered: {
            //if (tv.on === false) {
            if(options.cabEnabled)
            {
             startTv()
            }
        }
    }
    function checkChannelList()
    {
        var tvCount=tv.channelList.channels.count
        if(tvCount>1)
        {
            tv.on=false
            tvRetryTimer.stop()
            channelExistNotice.show()
        }
        else
            startTv()

    }

    function startTv() {
        /* Get the first item on the list */
        var item = tv.channelList.getChannelItem(0)

        /* Tune to preview item if valid */
        if(item !== null) {
            //tv.tuneChannelID(item.id)
            var mrl=tv.channelList.getMrl(item.id)
            tv.on = true
            tv.mrl = mrl
            tv.currentChannelID = item.id
            tv.playerOnly = true
        }
    }

    function stopTv() {
        tv.stop()
        tv.on=false
        tv.currentChannel = -1
    }
}
