import QtQuick 2.12
import Process 0.1
import Components 1.0
import ".."

Item {
    id: root

    property string scriptsdir: "scripts"
    property bool isSetupWizard: false
    property bool isActive: (main.state === "DiagnosticState" && diagnosticsMain.currentSelectedIndex >= 0) || isSetupWizard

    signal timeSet()

    function saveDateTime() {
        dateProcess.start()

    }

    anchors.fill: parent

    TextLabel {
        id: title
        text: qsTr("CLOCK SETUP")
        color: main.colorFontDark
        anchors.top: parent.top
        anchors.topMargin: 30 * main.vScaleFactor
        anchors.horizontalCenter: parent.horizontalCenter
        font.pixelSize: 24 * main.vScaleFactor
    }

    DateTimePicker {
        id: datePicker
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: title.bottom
        anchors.topMargin: 30 * main.vScaleFactor
    }

    Text {
        id: selectTimezoneLabel
        anchors.horizontalCenter: parent.horizontalCenter
        text: qsTr("Select Timezone") + application.emptyString
        font.pixelSize: 24 * main.vScaleFactor
        anchors.top: datePicker.bottom
        anchors.topMargin: 80 * main.vScaleFactor
    }

    TimezoneSelection {
        id: timezoneSelection
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset: -100 * main.hScaleFactor
        anchors.top: selectTimezoneLabel.bottom
        anchors.topMargin: 20 * main.vScaleFactor
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 20 * main.vScaleFactor
        width: 400 * main.hScaleFactor
    }

    StandardButton {
        id: saveButton

        visible: !root.isSetupWizard
        width: 120 * main.hScaleFactor
        height: 78 * main.vScaleFactor
        anchors.right: parent.right
        anchors.rightMargin: 20 * main.hScaleFactor
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 20 * main.vScaleFactor

        icon.anchors.topMargin: 5 * main.vScaleFactor
        icon.anchors.bottomMargin: 30 * main.vScaleFactor
        icon.sourceName: "WF/WF_Button_Saved_Workouts"
        buttonText: qsTr("SAVE?") + application.emptyString
        onClicked: {
            if (isSetupWizard) {
                root.timeSet()
                return
            }

            root.saveDateTime()
            dialogText.text = qsTr("Date/Time has been updated") + application.emptyString
            actionSuccessfulDialog.show()
            actionSuccessfulDialog.startTimeout(1)
        }
    }

    ModalDialog {
        id: actionSuccessfulDialog

        Item {
            z: root.z + 1
            anchors.fill: parent

            Text {
                id: dialogText
                anchors.fill: parent
                anchors.verticalCenter: parent.verticalCenter
                color: "#ffffff"
                anchors.horizontalCenter: parent.horizontalCenter
                horizontalAlignment: Text.AlignHCenter
                verticalAlignment: Text.AlignVCenter
                wrapMode: Text.WordWrap
                font.bold: false
                font.pixelSize: 50 * main.vScaleFactor
            }
        }
        Component.onCompleted: hide()
        onTimedOut: hide()
    }

    Process {
        id: dateProcess
        program: root.scriptsdir + '/set_datetime.sh'
        arguments: [datePicker.getDateString(), timezoneSelection.selectedItem.LinuxID]
        onReadyReadStandardError: {
            var output = new String(readAllStandardError())
            console.log("output from stderr:", output)
        }

        onReadyReadStandardOutput: {
            var output = new String(readAllStandardOutput())
            console.log("output from stdout:", output)
        }
        onFinished: {
            Date.timeZoneUpdated()
        }
    }
}
