import QtQuick 2.12
import FileIO 1.0
import ".."
import Process 0.1
import "../string_format.js" as Format
import "../LanguageMenu/language.js" as LanguageJS
import Components 1.0


Item {
    id: root
    anchors.fill: parent
    state: ""

    property bool datadirty: false

    signal close()

    LayoutMirroring.enabled: main.rightToLeft
    LayoutMirroring.childrenInherit: true

    //    onDatadirtyChanged: {
    //        if(datadirty){
    //            options.sync();
    //            datadirty = false
    //        }
    //    }

    Component.onCompleted: {
        dataExport.getNetworkAddresses()
        simMode.value = options.simulationMode ? true : false
        pedalTimeout.value = options.disableNoPedalStop ? false : true
        showStimulusAreaMode.value = options.showStimulusArea ? true : false
        showCursorMode.value = options.showCursor ? true : false
        standAloneMode.value = options.ignoreFaults ? true: false
        enableHDTVDownscaling.value = options.downscaleHDTV
        tvAccelerationMode.value = options.tvHwAccel
        tvFrameDropMode.value = !options.tvNoFrameDrop
        erpEnabled.value = options.erpEnabled ? true: false
        diagnosticsUploadToggle.value = options.diagnosticsUploadEnabled
        disableBuzzerMode.value = options.disableBuzzer
        logginEnabledMode.value = options.loggingEnabled ? true : false
        usbLogginEnabledMode.value = options.usbLoggingEnabled ? true : false
        modestyModeSwitch.value = options.modestyMode
        enableAppleModeSwitch.value = options.enableNFC
        en957EnableControl.value = options.en957Enabled ? true : false
        manufacturingTestMode.value = options.manufacturingTestModeEnabled
        enableNavBarOn.value = options.navBarAlwaysOn
        enableProtoGraphs.value = options.enableProtoGraphs
        enableWifiMirroring.value= options.wifiMirroring
        enableAntPlus.value = options.enableAntPlus
        scrollLock.value = options.scrollLock

        // set developmentSoftware.value
        checkDailyRepo.start()
    }
    Flickable {
        id: scrollColumn
        clip: true
        flickableDirection: Flickable.VerticalFlick
        anchors.fill: parent
        contentHeight:controlList.height


        Column {
            id: controlList
            spacing: 5 * main.vScaleFactor
            width:root.width * 0.8

            //        spacing: 5 * main.vScaleFactor
            //        anchors.top: root.top
            //        anchors.topMargin: 20 * main.vScaleFactor
            //        anchors.horizontalCenter: parent.horizontalCenter
            //        width: root.width * 0.8
            //        height: root.height * 0.9

            Checkbox {
                id: simMode
                visible: diagnosticsMain.accessLevel >= 1
                label: qsTr("Enable Demo Run Screen") + application.emptyString
                width: parent.width
                onPressed: {
                    options.simulationMode = value ? true : false
                    datadirty = true
                }
            }

            Checkbox {
                id: pedalTimeout
                label: qsTr("Zero RPM Timeout") + application.emptyString
                width: parent.width
                onPressed: {
                    options.disableNoPedalStop = value ? false : true
                    datadirty = true
                }
            }

            Checkbox {
                id: showStimulusAreaMode
                label: qsTr("Stimulus Area Enabled") + application.emptyString
                width: parent.width
                onPressed: {
                    options.showStimulusArea = value ? true : false
                    datadirty = true
                }
            }

            Checkbox {
                id: showCursorMode
                label: qsTr("Show Cursor") + application.emptyString
                width: parent.width
                onPressed:{
                    options.showCursor = value ? true : false
                    datadirty = true
                }
            }

            Checkbox {
                id: standAloneMode
                visible: diagnosticsMain.accessLevel >= 1
                label: qsTr("Stand Alone Mode") + application.emptyString
                width: parent.width
                onPressed:{
                    options.ignoreFaults = value ? true : false
                    if(value == true) {
                        errorManager.fatalError = false
                        errorManager.preventUse = false
                        errorManager.degradedUse = false
                    }
                    datadirty = true
                }
            }

            Checkbox {
                id: manufacturingTestMode
                visible: diagnosticsMain.accessLevel >= 1
                label: qsTr("Manufacturing Test Mode") + application.emptyString
                width: parent.width
                onPressed:{
                    if (value) {
                        confirmPrompt.text = manufacturingTestMode.label
                        confirmPrompt.show()
                    } else {
                        options.manufacturingTestModeEnabled = false
                        standAloneMode.value = false
                    }
                }
            }

            Checkbox {
                id: developmentSoftware
                visible: diagnosticsMain.accessLevel >= 2
                label: qsTr("Enable beta software") + application.emptyString
                width: parent.width
                onPressed:{
                    if (value) {
                        enableDailyRepo.start()
                    } else {
                        disableDailyRepo.start()
                    }
                }
            }

            Checkbox {
                id: erpEnabled
                visible: diagnosticsMain.accessLevel >= 1
                label: qsTr("Energy Saving Timer Enabled") + application.emptyString
                width: parent.width
                value: options.erpEnabled
                onPressed: {
                    logger.logAlways("Diagnostics: ERP mode is being manually set to " + value)
                    if(options.manufacturingTestModeEnabled) {
                        options.erpEnabled = value
                        datadirty = true
                    } else {
                        /*
                     * options.erpEnabled is now bound to nucleus.erpIsSupported.
                     * See erpEnabled property in Options.qml
                     */
                        options.erpEnabled = value
                        datadirty = true
                        console.debug("setting ERP to "+value)
                        nucleus.setERPSupport(value)
                    }
                }
            }

            Checkbox {
                id: enableHDTVDownscaling
                label: qsTr("HDTV frame smoothing") + application.emptyString
                width: parent.width
                value: options.downscaleHDTV
                onPressed: {
                    options.downscaleHDTV = value ? true : false
                    datadirty = true
                }
            }

            Checkbox {
                id: tvFrameDropMode
                visible: diagnosticsMain.accessLevel >= 1
                label: qsTr("TV Drop Late Frames (restart needed)") + application.emptyString
                width: parent.width
                onPressed: {
                    options.tvNoFrameDrop = value ? false : true
                    datadirty = true
                }
            }

            Checkbox {
                id: tvAccelerationMode
                visible: diagnosticsMain.accessLevel >= 1
                label: qsTr("TV Acceleration (restart needed)") + application.emptyString
                width: parent.width
                onPressed: {
                    options.tvHwAccel = value ? true : false
                    datadirty = true
                }
            }

            Checkbox {
                id: remoteAccessToggle
                label: qsTr("Remote Access Enabled") + application.emptyString
                width: parent.width
                onPressed: {
                    remoteAccess.isEnabled = value
                    if (remoteAccess.isEnabled) {
                        accessConnecting.show()
                    } else {
                        // Hide in progress popup
                        accessConnecting.hide()
                    }
                }
            }

            Checkbox {
                id: diagnosticsUploadToggle
                label: qsTr("Send Diagnostics Reports to TRUE") + application.emptyString
                width: parent.width
                onPressed: {
                    options.diagnosticsUploadEnabled = value
                    datadirty = true
                }
            }

            Checkbox {
                id: disableBuzzerMode
                label: qsTr("Disable Buzzer") + application.emptyString
                width: parent.width
                onPressed: {
                    options.disableBuzzer = value
                    datadirty = true
                }
            }

            Checkbox {
                id: en957EnableControl
                visible: diagnosticsMain.accessLevel >= 1
                label: qsTr("EN957 Mode") + application.emptyString
                width: parent.width
                onPressed: {
                    options.en957Enabled = value ? true : false
                    datadirty = true
                }
            }

            Checkbox {
                id: logginEnabledMode
                label: qsTr("Logging Enabled") + application.emptyString
                width: parent.width
                onPressed: {
                    if(value == false){
                        console.debug("Logging Enabled is off");
                    }

                    options.loggingEnabled = value ? true : false
                    datadirty = true

                    if(value == true){
                        console.debug("Logging Enabled is on");
                    }

                    nucleus.setDiagnostics(options.loggingEnabled)
                }
            }
            Checkbox {
                id: usbLogginEnabledMode
                label: qsTr("USB Logging Enabled") + application.emptyString
                width: parent.width
                onPressed: {
                    if(value == false){
                        console.debug("Logging Enabled is off");
                    }

                    options.usbLoggingEnabled = value ? true : false
                    diagnostics.enableUsbLog(options.usbLoggingEnabled)
                    //datadirty = true

                    if(value == true){
                        console.debug("Logging Enabled is on");
                    }

                    // nucleus.setDiagnostics(options.loggingEnabled)
                }
            }

            Checkbox {
                id: modestyModeSwitch
                visible: diagnosticsMain.accessLevel >= 1
                label: qsTr("Display Images M.E.") + application.emptyString
                width: parent.width
                onPressed: {
                    options.modestyMode = value
                }
            }

            Checkbox {
                id: enableAppleModeSwitch
                visible: gem.nfc_Installed && diagnosticsMain.accessLevel >= 2
                label: qsTr("Enable NFC Connectivity") + application.emptyString
                width: parent.width
                onPressed: {
                    options.enableNFC = value
                }
            }

            Checkbox {
                id: enableNavBarOn
                visible: true
                label: qsTr("Always Show Navigation Bar") + application.emptyString
                width: parent.width
                onPressed: {
                    options.navBarAlwaysOn = value
                }
            }

            Checkbox {
                id: enableProtoGraphs
                visible: diagnosticsMain.accessLevel >= 2
                label: qsTr("Enable Prototype Graphs & HRC workout") + application.emptyString
                width: parent.width
                onPressed: {
                    options.enableProtoGraphs = value
                }
            }
            Checkbox {
                id: enableWifiMirroring
                visible: diagnosticsMain.accessLevel >= 2
                label: qsTr("Enable Wifi Mirroring") + application.emptyString
                width: parent.width
                onPressed: {
                    options.wifiMirroring = value
                }
            }

            Checkbox {
                id: enableAntPlus
                //            visible: diagnosticsMain.accessLevel >= 2
                label: qsTr("Enable Ant+") + application.emptyString
                width: parent.width
                onPressed: {
                    options.enableAntPlus = value
                }
            }

            Checkbox {
                id: scrollLock
                //            visible: diagnosticsMain.accessLevel >= 2
                label: qsTr("Scroll Lock on Line Graph") + application.emptyString
                width: parent.width
                onPressed: {
                    options.scrollLock = value
                }
            }
            // Hide button to convert between UIs for now
            /* StandardButton {
            id: convertUIButton
            visible: diagnosticsMain.accessLevel >= 2

            width: 300 * main.hScaleFactor
            height: 48 * main.vScaleFactor
            anchors.right: parent.right

            buttonText: qsTr("Convert to old Truetouch UI") + application.emptyString
            onClicked: confirmUIChangePrompt.show()
        }*/
        }
        Rectangle {
            id: sliderBar

            property double baseHeight: scrollColumn.height
            property double contentHeight: scrollColumn.contentHeight

            anchors.right: parent.right
            anchors.rightMargin: 2 * main.hScaleFactor
            width: 15 * main.hScaleFactor
            height: baseHeight * baseHeight/contentHeight
            visible: baseHeight < contentHeight
            color: "darkgrey"
            radius: main.defaultRadius
            y: scrollColumn.y + (baseHeight  - height) * scrollColumn.contentY / (contentHeight - baseHeight)
        }
    }

    StandardButton {
        id: networkExportButton

        enabled: logUploader.state !== "Terminating" && !logUploader.running
        visible: !storageMgr.usbDeviceLoaded && dataExport.ipAddress && !logUploader.uploading && !uploadTerminatingDialog.visible

        width: 150 * main.hScaleFactor
        height: 78 * main.vScaleFactor
        anchors.right: parent.right
        anchors.rightMargin: 20 * main.hScaleFactor
        anchors.top: parent.top
        anchors.topMargin: 20 * main.vScaleFactor

        buttonText: qsTr("Upload Diagnostics to TRUE Server") + application.emptyString
        onClicked: {
            // Start upload
            logUploader.start()
            connectingDialog.show()
        }
    }


    ModalDialog {
        id: uploadingDialog
        dismissable: true

        property string errorMessage: ""

        onDismissed: {
        }

        Item {
            z: uploadingDialog.z + 1
            anchors.fill: parent

            Text {
                id: warningText
                width: main.width
                height: 99 * main.vScaleFactor
                color: main.colorFontLight
                text: (logUploader.state === "Failed" ? uploadingDialog.errorMessage : qsTr("Uploading")) + application.emptyString
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.top: parent.top
                anchors.topMargin: 35 * main.vScaleFactor
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                font.bold: false
                font.pixelSize: 50 * main.vScaleFactor
            }

            ProgressBar {
                id: progressBar
                value: logUploader.percentComplete
                showLabel: true

                visible: logUploader.transferStarted
                opacity: logUploader.state === "Failed" ? 0.5 : 1.0

                anchors.top: warningText.bottom
                anchors.topMargin: 25 * main.vScaleFactor
                anchors.horizontalCenter: parent.horizontalCenter

                width: 0.5 * parent.width
                height: 0.3 * parent.height
            }
        }
        Component.onCompleted: hide()
        onTimedOut: hide()
    }
    ModalDialog {
        id: connectingDialog
        dismissable: true

        onDismissed: {
            logUploader.stop()
            connectingDialog.hide()
            uploadTerminatingDialog.show()
            uploadTerminatingDialog.startTimeout(2)
        }

        Item {
            z: connectingDialog.z + 1
            anchors.fill: parent

            TextLabel {
                width: parent.width
                height: 99 * main.vScaleFactor
                text: qsTr("Connecting") + application.emptyString
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.top: parent.top
                anchors.topMargin: 35 * main.vScaleFactor
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                font.pixelSize: 50 * main.vScaleFactor
            }

            StandardButton {
                id: cancelConnectButton

                visible: logUploader.state === "Connecting"
                width: 100 * main.hScaleFactor
                height: 78 * main.vScaleFactor
                anchors {
                    bottom: parent.bottom
                    bottomMargin: 50 * main.vScaleFactor
                    horizontalCenter: parent.horizontalCenter
                }

                buttonText: qsTr("Cancel") + application.emptyString
                onClicked: {
                    connectingDialog.dismissed()
                }
            }
        }
        Component.onCompleted: hide()
        onTimedOut: hide()
    }

    MessagePopup {
        id: accessConnecting
        message: qsTr("Connecting...") + application.emptyString
        isTransparent: true

        Component.onCompleted: hide()

        Connections {
            target: remoteAccess
            onSuccessChanged: {
                if (remoteAccess.success) {
                    accessConnecting.hide()
                }
            }
        }
    }
    MessagePopup {
        id: logUploadSuccessful
        dismissable: true
        dismissAnywhere: true
        isTransparent: true
        message: qsTr("Log Upload Successful") + application.emptyString
        Component.onCompleted: hide()
    }
    MessagePopup {
        id: connectionErrorDialog
        dismissable: true
        dismissAnywhere: true
        message: qsTr("Connection Error") + application.emptyString
        Component.onCompleted: hide()
    }
    MessagePopup {
        id: uploadTerminatingDialog
        dismissable: false
        message: qsTr("Stopping Upload") + application.emptyString
        Component.onCompleted: hide()
    }

    Connections {
        target: logUploader

        onTransferComplete: {
            buzzer.buttonPress()
            logUploadSuccessful.show()
            //logUploadSuccessful.startTimeout(5)
            uploadingDialog.hide()
        }

        onDataTransferStarted: {
            connectingDialog.hide()
            uploadingDialog.show()
        }

        onUploadFailed: {
            buzzer.buttonPress()
            uploadingDialog.errorMessage = qsTr("Log Upload Failed") + application.emptyString
        }

        onConnectionError: {
            buzzer.buttonPress()
            connectingDialog.hide()
            connectionErrorDialog.show()
        }

        onTerminated: {
        }
    }

    StandardButton {
        id: exportDiagButton

        property bool exportPending: false

        enabled: storageMgr.usbDeviceLoaded && !(diagExportProcess.processState != Process.NotRunning)
        visible: storageMgr.usbDeviceLoaded && !logUploader.uploading

        width: 150 * main.hScaleFactor
        height: 78 * main.vScaleFactor
        anchors.right: parent.right
        anchors.rightMargin: 20 * main.hScaleFactor
        anchors.top: parent.top
        anchors.topMargin: 20 * main.vScaleFactor

        buttonText: qsTr("Export Diagnostics") + application.emptyString
        onClicked: {
            if(main.lowerSystem === "NUCLEUS") {
                exportPending = true
                errorManager.retrieveFaultLogs()
            } else {
                diagExportProcess.startExport()
            }
        }
    }

    Connections {
        target: errorManager
        onRetrieveNucleusFaultLogComplete: {
            if(exportDiagButton.exportPending === true) {
                exportDiagButton.exportPending = false
                diagExportProcess.startExport()
            }
        }
    }

    Connections {
        target: language_menu
        onLanguageSelected: {
            if (languageDiagnosticMenu) {
                main.state = "DiagnosticState"
                if (lang)
                {
                    application.selectLanguage(lang)
                    options.defaultLanguage = lang
                    defaultLanguageText.text = LanguageJS.getLanguageName(options.defaultLanguage)
                    defaultLanguageIcon.sourceName = LanguageJS.getLanguageIcon(options.defaultLanguage)
                }
                languageDiagnosticMenu = false
            }
        }
    }

    FileIO {
        id: fileio
    }

    Process {
        id: diagExportProcess

        function startExport() {
            // Run export script
            var unixTime = (new Date).getTime()
            var dirName = main.serialNumber + "-diag-" + unixTime
            diagExportProcess.arguments = ["/media/usb/"+dirName]
            diagExportProcess.start()
        }

        program: "scripts/export-diagnostics/export_diag.sh"
    }

    Process {
        id: checkDailyRepo
        program: "scripts/toggleDailyRepo.sh"
        arguments: "2"
        onReadyReadStandardOutput: {
            var out = new String(readAllStandardOutput())
            if( out.match(/active/)){
                developmentSoftware.value =true
                console.log("checkDailyRepo: active"  + developmentSoftware.value)
            }else{
                developmentSoftware.value = false
                console.log("checkDailyRepo: disabled "  + developmentSoftware.value)
            }
        }

        onReadyReadStandardError: {
            var out=String(readAllStandardError())
            console.log("enableDailyRepo (error):" + out )
        }

    }

    Process {
        id: enableDailyRepo
        program: "scripts/toggleDailyRepo.sh"
        arguments: "1"
        onReadyReadStandardOutput: {
            var out=String(readAllStandardOutput())
            console.log("enableDailyRepo: " + out )
        }

        onReadyReadStandardError: {
            var out=String(readAllStandardError())
            console.log("enableDailyRepo (error):" + out )
        }

    }

    Process {
        id: disableDailyRepo
        program: "scripts/toggleDailyRepo.sh"
        arguments: "0"
        onReadyReadStandardOutput: {
            var out=String(readAllStandardOutput())
            console.log("disableDailyRepo: " + out )
        }

        onReadyReadStandardError: {
            var out=String(readAllStandardError())
            console.log("disableDailyRepo (error):" + out )
        }

    }

    // Hide button to convert between UIs for now
    /*Process {
        id: convertUIProcess

        program: "scripts/uiSelect.sh"
        arguments: "truetouch"

        onReadyReadStandardOutput: {
            var out=String(readAllStandardOutput())
            console.log("uiSelect.sh " + out )
        }

        onReadyReadStandardError: {
            var out=String(readAllStandardError())
            console.log("uiSelect.sh (error):" + out )
        }
    }

    ConfirmationPrompt {
        id: confirmUIChangePrompt
        x: 300  * main.hScaleFactor; y: 200 * main.vScaleFactor
        visible: false
        prompt: qsTr("Confirm that you want to downgrade to the older TrueTouch UI.")
        onNoClicked: {
            // Do nothing
            hide()
        }
        onYesClicked: {
            console.log("Starting uiSelect.sh truetouch" )
            convertUIProcess.start()
            main.rebootRequired = true
            hide()
        }
    }*/


    ConfirmationPrompt {
        id: confirmPrompt
        property string text: ""
        x: 300  * main.hScaleFactor; y: 200 * main.vScaleFactor
        visible: false
        prompt: qsTr("Enable") + " " + confirmPrompt.text + "?"
        onNoClicked: {
            manufacturingTestMode.value = false
            hide()
        }
        onYesClicked: {
            manufacturingTestMode.value = true
            options.manufacturingTestModeEnabled = true
            standAloneMode.value = true
            hide()
        }
    }

}
