import QtQuick 2.12

import ".."
import FileIO 1.0
import Components 1.0

Item {

    id: root
    property QtObject filteredCountryList
    property int tuner_id: 1
    property QtObject emptyModel
    property string cursorState: "log" // log, export, or clear
    property bool isNucleus: (machineinfo.systemConfig === "NUCLEUS" || machineinfo.systemConfig === "NUCBOOT")

    Component.onCompleted: {
        errorManager.retrieveFaultLogs()
    }

    Connections{
        target:errorManager
        onErrorListModelChanged: {
            var newModel = errorListModel
            errorList.model = newModel
        }
        onNucleusFaultListModelChanged: {
            var newModel = nucleusFaultListModel
            nucleusFaultList.model = newModel
        }
    }

    TextLabel {
        id:errorLabel
        anchors {
            top: parent.top
            topMargin: 10 * main.vScaleFactor
            left: parent.left
            leftMargin: 10 * main.hScaleFactor
        }

        text: (errorList.model.count === 0 ? qsTr("The Fault Log is empty") : qsTr("Console Errors")) + application.emptyString
        color: main.colorFontDark
    }

    Rectangle {
        id: sliderBar

        property double baseHeight: errorList.height //- 20 * main.vScaleFactor
        property double contentHeight: errorList.contentHeight

        anchors.right: parent.right
        anchors.rightMargin: 2 * main.hScaleFactor
        anchors.top: errorList.top
        width: 15 * main.hScaleFactor
        height: baseHeight * baseHeight/contentHeight
        visible: baseHeight < contentHeight
        color: "darkgrey"
        radius: main.defaultRadius
        y: (baseHeight  - height) * errorList.contentY / (contentHeight - baseHeight)
    }

    ListView {
        id: errorList

        anchors.top: errorLabel.bottom
        anchors.topMargin: 10 * main.vScaleFactor
        anchors.left: parent.left
        anchors.leftMargin: 10 * main.hScaleFactor
        anchors.right: parent.right
        anchors.rightMargin: 60 * main.hScaleFactor
        height: 0.25 * root.height
        clip: true

        visible: true
        model: root.emptyModel
        snapMode: ListView.SnapToItem
        highlightRangeMode: ListView.StrictlyEnforceRange
        preferredHighlightBegin: 0
        preferredHighlightEnd: 20
        highlightMoveVelocity: 2000

        delegate: Component {
            Row {
                spacing: 10 * main.hScaleFactor
                Text { text: ""+index; color: "gray"; width: 35 * main.hScaleFactor }
                Text {
                    property string odometer: options.metricUnits ? Globals.mileToKm(mileage) : mileage
                    property string odometer_units: (options.metricUnits ? qsTr("km") : qsTr("mi")) + application.emptyString

                    text: (odometer/100).toFixed(2) + (odometer_units) + " :  " +  timestamp
                }
                Text { text: errordescription }
            }
        }
    }

    TextLabel {
        id:nucleusFaultLabel
        anchors {
            top: errorList.bottom
            topMargin: 30 * main.vScaleFactor
            left: parent.left
            leftMargin: 10 * main.hScaleFactor
        }

        text: (nucleusFaultList.model.count === 0 ? qsTr("The Fault Log is empty") : qsTr("Nucleus Faults")) + application.emptyString
        color: main.colorFontDark
    }

    Rectangle {
        id: nucleusSliderBar

        property double baseHeight: nucleusFaultList.height //- 20 * main.vScaleFactor
        property double contentHeight: nucleusFaultList.contentHeight

        anchors.right: parent.right
        anchors.rightMargin: 2 * main.hScaleFactor
        anchors.top: nucleusFaultList.top
        width: 15 * main.hScaleFactor
        height: baseHeight * baseHeight/contentHeight
        visible: baseHeight < contentHeight
        color: "darkgrey"
        radius: main.defaultRadius
        y: (baseHeight  - height) * nucleusFaultList.contentY / (contentHeight - baseHeight)
    }

    ListView {
        id: nucleusFaultList

        anchors.top: nucleusFaultLabel.bottom
        anchors.topMargin: 10 * main.vScaleFactor
        anchors.left: parent.left
        anchors.leftMargin: 10 * main.hScaleFactor
        anchors.right: parent.right
        anchors.rightMargin: 60 * main.hScaleFactor
        height: 0.45 * root.height
        clip: true

        visible: true
        model: root.emptyModel
        snapMode: ListView.SnapToItem
        highlightRangeMode: ListView.StrictlyEnforceRange
        preferredHighlightBegin: 0
        preferredHighlightEnd: 20
        highlightMoveVelocity: 2000

        delegate: Component {
            Row {
                spacing: 10 * main.hScaleFactor
                Text { text: ""+index; color: "gray"; width: 35 * main.hScaleFactor }
                Text {
                    property string odometer: main.isTreadmill ? ((options.metricUnits ? Globals.mileToKm(mileage) : mileage)/100).toFixed(2) : mileage.toFixed(0)
                    property string odometer_units: (main.isTreadmill ? (options.metricUnits ? qsTr("km") : qsTr("mi")) : qsTr("revs")) + application.emptyString

                    text: odometer + (odometer_units) + " :  " +  timestamp
                }
                Text { text: errordescription }
            }
        }
    }

    Row {
        id: actionRow
        anchors.right: parent.right
        anchors.rightMargin: 20 * main.hScaleFactor
        anchors.bottom: root.bottom
        anchors.bottomMargin: 20 * main.vScaleFactor
        spacing: 10 * main.hScaleFactor

        StandardButton {
            id: exportButton

            enabled: (errorList.model.count > 0 || errorManager.nucleusFaultListModel.count > 0) && storageMgr.usbDeviceLoaded
            width: 100 * main.hScaleFactor
            height: 78 * main.vScaleFactor

            buttonText: qsTr("Export") + application.emptyString
            onClicked: {
                if(errorList.model.count > 0) {
                    exportErrorLog("/media/usb/")
                }

                console.debug("nucleus fault list count:" + errorManager.nucleusFaultListModel.count)
                if(isNucleus === true && errorManager.nucleusFaultListModel.count > 0) {
                    exportNucleusErrorLog("/media/usb/")
                }

                dialogText.text = qsTr("Error Log was exported") + application.emptyString
                actionSuccessfulDialog.show()
                actionSuccessfulDialog.startTimeout(1)
            }
        }

        StandardButton {
            id: clearButton

            width: 100 * main.hScaleFactor
            height: 78 * main.vScaleFactor

            buttonText: qsTr("Clear") + application.emptyString
            onClicked: {
                errorManager.clearAllError()

                dialogText.text = qsTr("Error Log was cleared") + application.emptyString
                actionSuccessfulDialog.show()
                actionSuccessfulDialog.startTimeout(1)
            }
        }
    }

    ModalDialog {
        id: actionSuccessfulDialog
        Text {
            id: dialogText
            anchors.fill: parent
            anchors.verticalCenter: parent.verticalCenter
            color: main.colorFontLight
            anchors.horizontalCenter: parent.horizontalCenter
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            wrapMode: Text.WordWrap
            font.bold: false
            font.pixelSize: 50 * main.vScaleFactor
            z: root.z + 1
        }
        Component.onCompleted: hide()
        onTimedOut: hide()
    }

    FileIO {
        id: fileio
    }

    function exportErrorLog(path) {
        var serialstring
        var datestring
        var filename

        if(path === "")
            return;

        if(main.serialNumber === undefined){
            serialstring = "unknown-serial"
        } else {
            serialstring = main.serialNumber
        }
        datestring = Qt.formatDateTime(new Date(),"yyyyMMdd")
        filename = "faults_" + serialstring + "_" + datestring + ".log"
        path = path + filename

        console.debug("Writing log file to: "+path)

        fileio.source = path
        fileio.fileMode = FileIO.READ_WRITE
        fileio.open()
        fileio.clear()
        for(var i=0 ; i < errorList.model.count ; i++) {
            var item = errorList.model.get(i)
            fileio.writeLine(item.timestamp + "," + item.mileage + "," + item.errordescription +"\r\n")
        }
        fileio.close()
        syncDisk.start()
    }

    function exportNucleusErrorLog(path) {
        var serialstring
        var datestring
        var filename

        if(path === "")
            return;

        if(main.serialNumber === undefined){
            serialstring = "unknown-serial"
        } else {
            serialstring = main.serialNumber
        }
        datestring = Qt.formatDateTime(new Date(),"yyyyMMdd")
        filename = "faults_nucleus_" + serialstring + "_" + datestring + ".log"
        path = path + filename

        console.debug("Writing log file to: "+path)

        fileio.source = path
        fileio.fileMode = FileIO.READ_WRITE
        fileio.open()
        fileio.clear()
        for(var i=0 ; i < nucleusFaultList.model.count ; i++) {
            var item = nucleusFaultList.model.get(i)
            fileio.writeLine((item.usageStamp/100).toFixed(2) + "," + item.categoryString + "," + item.codeString +"\r\n")
        }
        fileio.close()
        syncDisk.start()
    }
}
