/* @file workout_menus.js
    @brief Definitions of the workout program menu for all machine types.
*
*   Each menu_xxx array definition is a menu.  Each entry may be
*    either another menu by defining the "nextmenu" property, or
*   a workout program by definining the "program" property to the corresponding xml filename.
*/
var diagnosticsPageSummary = {label: QT_TRANSLATE_NOOP("Diagnostics", "Summary"),qmlSource:"DiagnosticsSummary.qml" }
var diagnosticsPageOptions = {label: QT_TRANSLATE_NOOP("Diagnostics", "Options"),qmlSource:"DiagnosticsOption.qml" }
var diagnosticsPageTimers = {label: QT_TRANSLATE_NOOP("Diagnostics", "Timers"),qmlSource:"DiagnosticsTimers.qml" }
var diagnosticsPageProgramStatistics = {label: QT_TRANSLATE_NOOP("Diagnostics", "Program Usage"),qmlSource:"DiagnosticsProgramStatistics.qml" }
var diagnosticsPageMiscStatistics = {label: QT_TRANSLATE_NOOP("Diagnostics", "Other Statistics"),qmlSource:"DiagnosticsMiscStatistics.qml" }
var diagnosticsPageStatisticsNucleus = {label: QT_TRANSLATE_NOOP("Diagnostics", "Summary"),qmlSource:"DiagnosticsStatisticsNucleus.qml" }
var diagnosticsPageProductSetupNucleus = {label: QT_TRANSLATE_NOOP("Diagnostics", "Product Setup"),qmlSource:"DiagnosticsSetupNucleus.qml" }
var diagnosticsPageClockSetup = {label: QT_TRANSLATE_NOOP("Diagnostics", "Clock"),qmlSource:"DiagnosticsClockSetup.qml" }
var diagnosticsPageSoftwareUpdate = {label: QT_TRANSLATE_NOOP("Diagnostics", "Software Update"),qmlSource:"DiagnosticsUpdate.qml" }
var diagnosticsPageNetworkSetup = {label: QT_TRANSLATE_NOOP("Diagnostics", "Network Setup"),qmlSource:"DiagnosticsNetwork.qml" }
var diagnosticsPageTVAdvanced = {label: QT_TRANSLATE_NOOP("Diagnostics", "TV Advanced"),qmlSource:"DiagnosticsTVAdvanced.qml" }
var diagnosticsPageTVRoot = {label: QT_TRANSLATE_NOOP("Diagnostics", "TV Setup"),qmlSource:"DiagnosticsTVRoot.qml" }
var diagnosticsPageTest = {label: QT_TRANSLATE_NOOP("Diagnostics", "Tests"),qmlSource:"DiagnosticsTests.qml" }
var diagnosticsPageTreadmillCalibrationTest = {label: QT_TRANSLATE_NOOP("Diagnostics", "Calibration"),qmlSource:"DiagnosticsTreadmillCalibration.qml" }
var diagnosticsPageStrideCalibration = {label: QT_TRANSLATE_NOOP("Diagnostics", "Calibration"),qmlSource:"DiagnosticsStrideEllipticalCalibration.qml" }
var diagnosticsPageErrorLog = {label: QT_TRANSLATE_NOOP("Diagnostics", "Fault Log"),qmlSource:"DiagnosticsError.qml" }
var diagnosticsPageTouchCal = {label: QT_TRANSLATE_NOOP("Diagnostics", "Touch Screen"), qmlSource:"DiagnosticsTouchCalibration.qml"  }
var diagnosticsPageDevelop = {label: QT_TRANSLATE_NOOP("Diagnostics", "Advanced"), qmlSource:"DiagnosticsDevelop.qml"  }
var diagnosticsPageSlidesSetup = {label: QT_TRANSLATE_NOOP("Diagnostics", "Screen Saver"), qmlSource: "DiagnosticsSlides.qml"  }
var diagnosticsPageFacility = {label: QT_TRANSLATE_NOOP("Diagnostics", "Facility Images"), qmlSource: "DiagnosticsFacility.qml"  }
var diagnosticsPageAttractVideo = {label: QT_TRANSLATE_NOOP("Diagnostics", "Banner Content"), qmlSource: "DiagnosticsAttractVideo.qml"  }
var diagnosticsPageBluetooth = {label: QT_TRANSLATE_NOOP("Diagnostics", "Bluetooth"), qmlSource: "DiagnosticsBluetooth.qml" }
var diagnosticsPageCAB = {label: QT_TRANSLATE_NOOP("Diagnostics", "C.A.B. Setup"), qmlSource: "DiagnosticsCAB.qml" }
var diagnosticsPageSynchronize = {label: QT_TRANSLATE_NOOP("Diagnostics", "Synchronize Settings"), qmlSource: "DiagnosticsSaltSync.qml" }
var diagnosticsPageProductSelectNucleus = {label: QT_TRANSLATE_NOOP("Diagnostics", "Product Selection"),qmlSource:"DiagnosticsProductSelection.qml" }
var diagnosticsPageEGymTest = {label: QT_TRANSLATE_NOOP("Diagnostics", "EGym Test"),qmlSource:"EGymTest.qml" }
var diagnosticsPageEGymRegister = {label: QT_TRANSLATE_NOOP("Diagnostics", "EGym Registration"),qmlSource:"EGymRegister.qml" }

// ===== Menus =====

var diagnosticsMenuUtilities = function(level) {
    var child
    if (level >= 2) {
        child = [
                    diagnosticsPageProductSetupNucleus,
                    diagnosticsPageProductSelectNucleus,
                    diagnosticsPageTVRoot,
                    diagnosticsPageTVAdvanced,
                    diagnosticsPageNetworkSetup,
                    diagnosticsPageSlidesSetup,
                    diagnosticsPageFacility,
                    diagnosticsPageAttractVideo,
    //                diagnosticsPageSynchronize,
                    diagnosticsPageClockSetup,
                    diagnosticsPageCAB
                ]
    } else {
        child = [
                diagnosticsPageProductSetupNucleus,
                diagnosticsPageTVRoot,
                diagnosticsPageTVAdvanced,
                diagnosticsPageNetworkSetup,
                diagnosticsPageSlidesSetup,
                diagnosticsPageFacility,
                diagnosticsPageAttractVideo,
//            diagnosticsPageSynchronize,
                diagnosticsPageClockSetup,
                diagnosticsPageCAB
            ]
    }

    if(eGym.enabled)
        child.push(diagnosticsPageEGymRegister)

    return {
        label: QT_TRANSLATE_NOOP("Diagnostics", "Setup..."),
        children: child,
        qmlSource:"DiagnosticsSetupNucleus.qml"
    }
}

var diagnosticsMenuUtilitiesStride = function(level) {
    var child
    if (level >= 2) {
        child = [
                    diagnosticsPageProductSetupNucleus,
                    diagnosticsPageProductSelectNucleus,
                    diagnosticsPageStrideCalibration,
                    diagnosticsPageTVRoot,
                    diagnosticsPageTVAdvanced,
                    diagnosticsPageNetworkSetup,
                    diagnosticsPageSlidesSetup,
                    diagnosticsPageFacility,
                    diagnosticsPageAttractVideo,
                    //                diagnosticsPageSynchronize,
                    diagnosticsPageClockSetup,
                    diagnosticsPageCAB
                ]
    } else if (level === 1) {
        child = [
                    diagnosticsPageProductSetupNucleus,
                    diagnosticsPageStrideCalibration,
                    diagnosticsPageTVRoot,
                    diagnosticsPageTVAdvanced,
                    diagnosticsPageNetworkSetup,
                    diagnosticsPageSlidesSetup,
                    diagnosticsPageFacility,
                    diagnosticsPageAttractVideo,
                    //                diagnosticsPageSynchronize,
                    diagnosticsPageClockSetup,
                    diagnosticsPageCAB
                ]
    } else {
        child = [
                    diagnosticsPageProductSetupNucleus,
                    diagnosticsPageTVRoot,
                    diagnosticsPageTVAdvanced,
                    diagnosticsPageNetworkSetup,
                    diagnosticsPageSlidesSetup,
                    diagnosticsPageFacility,
                    diagnosticsPageAttractVideo,
                    //                diagnosticsPageSynchronize,
                    diagnosticsPageClockSetup,
                    diagnosticsPageCAB
                ]
    }
    if(eGym.enabled)
        child.push(diagnosticsPageEGymRegister)

    return {
        label: QT_TRANSLATE_NOOP("Diagnostics", "Setup..."),
        children: child,
        qmlSource:"DiagnosticsSetupNucleus.qml"
    }
}

var diagnosticsMenuUtilitiesTread = function(level) {
    var child
    if (level >= 2) {
        child = [
                    diagnosticsPageProductSetupNucleus,
                    diagnosticsPageProductSelectNucleus,
                    diagnosticsPageTreadmillCalibrationTest,
                    diagnosticsPageTVRoot,
                    diagnosticsPageTVAdvanced,
                    diagnosticsPageNetworkSetup,
                    diagnosticsPageSlidesSetup,
                    diagnosticsPageFacility,
                    diagnosticsPageAttractVideo,
                    //                diagnosticsPageSynchronize,
                    diagnosticsPageClockSetup,
                    diagnosticsPageCAB
                ]
    } else if (level === 1) {
        child = [
                    diagnosticsPageProductSetupNucleus,
                    diagnosticsPageTreadmillCalibrationTest,
                    diagnosticsPageTVRoot,
                    diagnosticsPageTVAdvanced,
                    diagnosticsPageNetworkSetup,
                    diagnosticsPageSlidesSetup,
                    diagnosticsPageFacility,
                    diagnosticsPageAttractVideo,
                    //                diagnosticsPageSynchronize,
                    diagnosticsPageClockSetup,
                    diagnosticsPageCAB
                ]
    } else {
        child = [
                    diagnosticsPageProductSetupNucleus,
                    diagnosticsPageTVRoot,
                    diagnosticsPageTVAdvanced,
                    diagnosticsPageNetworkSetup,
                    diagnosticsPageSlidesSetup,
                    diagnosticsPageFacility,
                    diagnosticsPageAttractVideo,
                    //                diagnosticsPageSynchronize,
                    diagnosticsPageClockSetup,
                    diagnosticsPageCAB
                ]
    }

    if(eGym.enabled)
        child.push(diagnosticsPageEGymRegister)

    return {
        label: QT_TRANSLATE_NOOP("Diagnostics", "Setup..."),
        children: child,
        qmlSource:"DiagnosticsSetupNucleus.qml"
    }
}

var diagnosticsMenuDiagnostics = function(level) {
    if (level >= 1) {
        return {
            label: QT_TRANSLATE_NOOP("Diagnostics", "Diagnostics..."),
            children: [
                diagnosticsPageTest,
                diagnosticsPageErrorLog,
                diagnosticsPageSoftwareUpdate,
                diagnosticsPageTouchCal,
                diagnosticsPageDevelop,
                diagnosticsPageBluetooth,
                diagnosticsPageEGymTest
            ],
            qmlSource:"DiagnosticsTests.qml"
        }
    } else {
        return {
            label: QT_TRANSLATE_NOOP("Diagnostics", "Diagnostics..."),
            children: [
                diagnosticsPageTest,
                diagnosticsPageSoftwareUpdate,
                diagnosticsPageTouchCal,
                diagnosticsPageDevelop
            ],
            qmlSource:"DiagnosticsTests.qml"
        }
    }
}

var diagnosticsMenuDiagnosticsStride = function(level) {
    if (level >= 1) {
        return {
            label: QT_TRANSLATE_NOOP("Diagnostics", "Diagnostics..."),
            children: [
                diagnosticsPageTest,
                diagnosticsPageErrorLog,
                diagnosticsPageSoftwareUpdate,
                diagnosticsPageTouchCal,
                diagnosticsPageDevelop,
                diagnosticsPageBluetooth,
                diagnosticsPageEGymTest
            ],
            qmlSource:"DiagnosticsTests.qml"
        }
    } else {
        return {
            label: QT_TRANSLATE_NOOP("Diagnostics", "Diagnostics..."),
            children: [
                diagnosticsPageTest,
                diagnosticsPageSoftwareUpdate,
                diagnosticsPageTouchCal,
                diagnosticsPageDevelop
            ],
            qmlSource:"DiagnosticsTests.qml"
        }
    }
}

var diagnosticsMenuStatistics = function(level) {
    if (level >= 2) {
        return {
            label: QT_TRANSLATE_NOOP("Diagnostics", "Statistics..."),
            children: [
                diagnosticsPageStatisticsNucleus,
                diagnosticsPageProgramStatistics,
                diagnosticsPageMiscStatistics
            ],
            qmlSource: "DiagnosticsStatisticsNucleus.qml"
        }
    } else if (level >= 1) {
        return {
            label: QT_TRANSLATE_NOOP("Diagnostics", "Statistics..."),
            children: [
                diagnosticsPageStatisticsNucleus,
                diagnosticsPageMiscStatistics
            ],
            qmlSource: "DiagnosticsStatisticsNucleus.qml"
        }
    } else  {
        return {
            label: QT_TRANSLATE_NOOP("Diagnostics", "Statistics..."),
            children: [
                diagnosticsPageStatisticsNucleus
            ],
            qmlSource: "DiagnosticsStatisticsNucleus.qml"
        }
    }
}

var diagnosticsMenuMain = function(level) {
    return {
        label: "",
        children: [
            diagnosticsPageSummary,
            diagnosticsMenuUtilities(level),
            diagnosticsPageOptions,
            diagnosticsPageTimers,
            diagnosticsMenuStatistics(level),
            diagnosticsMenuDiagnostics(level)
        ],
        qmlSource:"DiagnosticsSummary.qml"
    }
}

var diagnosticsMenuMainTread = function(level) {
    return {
        label: "",
        children: [
            diagnosticsPageSummary,
            diagnosticsMenuUtilitiesTread(level),
            diagnosticsPageOptions,
            diagnosticsPageTimers,
            diagnosticsMenuStatistics(level),
            diagnosticsMenuDiagnostics(level)
        ],
        qmlSource:"DiagnosticsSummary.qml"
    }
}

var diagnosticsMenuMainStride = function(level) {
    return {
        label: "",
        children: [
            diagnosticsPageSummary,
            diagnosticsMenuUtilitiesStride(level),
            diagnosticsPageOptions,
            diagnosticsPageTimers,
            diagnosticsMenuStatistics(level),
            diagnosticsMenuDiagnosticsStride(level)
        ],
        qmlSource:"DiagnosticsSummary.qml"
    }
}
