import QtQuick 2.12
import ".."
import StorageMgr 1.0
import FileIO 1.0
import Components 1.0
import "../string_format.js" as Format
import "../LanguageMenu/language.js" as LanguageJS
import "../LanguageMenu/"

Item {
    id: root
    width: main.width
    height: main.height
    anchors.fill: parent
    state: ""

    property int topOffset: 130 * main.vScaleFactor
    property int itemSpacing: 10 * main.vScaleFactor

    property int menuItemWidth: 150 * main.hScaleFactor
    property int menuItemHeight: 75 * main.vScaleFactor

    property bool languageDiagnosticMenu: false

    property bool datadirty: false

    signal close()

    function showLanguageMenu() {
        languageDiagnosticMenu = true
    }

    function deleteSavedWorkouts() {
        var storedFiles = storage.listFiles("/data/saved_programs", "*.xml")
        for (var i = 0; i < storedFiles.length; i++) {
            var filepath = "/data/saved_programs/"+storedFiles[i]
            console.log("Deleting file:", filepath)
            fileio.remove(filepath)
        }
    }

    function deleteEGymWorkouts() {
    // There shouldn't be any, but delete just in case
        var storedFiles = storage.listFiles("/data/egym_programs", "*.xml")
        for (var i = 0; i < storedFiles.length; i++) {
            var filepath = "/data/egym_programs/"+storedFiles[i]
            console.log("Deleting file:", filepath)
            fileio.remove(filepath)
        }
    }

    Component.onCompleted: {
        metricUnitsMode.value = options.metricUnits ? true : false
        saveWorkoutEnabledMode.value = options.saveWorkoutEnabled ? true : false
        contactHRPriorityMode.value = options.contactHRPriority ? true : false
        maxSpeedRegulatorToggle.value = options.maxSpeedRegulatorEnabled
        virtualVideoSpeedControlledPlaybackToggle.value = options.virtualVideoSpeedControlledPlaybackRate
    }

    StorageMgr {
        id: storage
    }

    FileIO {
        id: fileio
        onError: {
            console.log("**WARNING: FileIO error -", error)
        }
    }

    Column {
        id: controlList
        spacing: itemSpacing

        visible: !languageDiagnosticMenu
        anchors.horizontalCenter: root.horizontalCenter
        anchors.verticalCenter: root.verticalCenter
        width: root.width * 0.8
        height: root.height * 0.8

        Checkbox {
            id: metricUnitsMode
            label: qsTr("Metric Units") + application.emptyString
            width: parent.width
            value: options.metricUnits
            onPressed: {
                options.metricUnits = value ? true : false
                datadirty = true
            }
        }

        Checkbox {
            id: saveWorkoutEnabledMode
            label: qsTr("Save Workout Enabled") + application.emptyString
            width: parent.width
            value: options.saveWorkoutEnabled
            onPressed: {
                options.saveWorkoutEnabled = value ? true : false
                if (!options.saveWorkoutEnabled) {
                    deleteSavedWorkouts()
                }
                datadirty = true
            }
        }

        Checkbox {
            id: egymWorkoutEnabledMode
            label: qsTr("EGym Workouts Enabled") + application.emptyString
            width: parent.width
            value: eGym.enabled
            onPressed: {
                options.egymWorkoutEnabled = value
                eGym.enabled = value
                gem.reset()
                if (!eGym.enabled) {
                    deleteEGymWorkouts()
                }
                datadirty = true
            }

            Component.onCompleted: value = eGym.enabled
        }

        Checkbox {
            id: contactHRPriorityMode
            label: qsTr("Contact Heart Rate Has Priority") + application.emptyString
            width: parent.width
            value: options.contactHRPriority
            onPressed: {
                options.contactHRPriority = value ? true : false
                datadirty = true
            }
        }

        Checkbox {
            id: maxSpeedRegulatorToggle
            label: qsTr("Max Speed Regulator Enable") + application.emptyString
            width: parent.width
            value: options.maxSpeedRegulatorEnabled
            onPressed: {
                options.maxSpeedRegulatorEnabled = value ? true : false

                if(options.maxSpeedRegulatorEnabled === false) {
                    options.maxSpeedRegulatorValue = machineinfo.treadmillSpeedMaxMph
                    maxSpeedRegulator.value = options.maxSpeedRegulatorValue
                }
                machineinfo.updateSpeedTable()
                datadirty = true
            }
        }

        Checkbox {
            id: maxInclineRegulatorToggle
            label: qsTr("Max Incline Regulator Enable") + application.emptyString
            width: parent.width
            value: options.maxInclineRegulatorEnabled
            onPressed: {
                options.maxInclineRegulatorEnabled = value ? true : false

                if(options.maxInclineRegulatorEnabled === false) {
                    options.maxInclineRegulatorValue = machineinfo.treadmillInclineMaxPercentGrade
                    maxInclineRegulator.value = options.maxInclineRegulatorValue
                }
                machineinfo.updateInclineTable()
                datadirty = true
            }
            visible: main.isTreadmill
        }

        Checkbox {
            id: virtualVideoSpeedControlledPlaybackToggle
            label: qsTr("Virtual Video Speed Controlled Playback") + application.emptyString
            width: parent.width
            value: options.virtualVideoSpeedControlledPlaybackRate
            onPressed: {
                options.virtualVideoSpeedControlledPlaybackRate = value ? true : false
                datadirty = true
            }

            visible: false
        }

        SliderControlLabeled{
            id: maxSpeedRegulator
            headingString: qsTr("Max Speed") + application.emptyString
            value: options.maxSpeedRegulatorValue
            minValue: main.isStepmill ? 20 : 60
            maxValue: main.isStepmill ? machineinfo.stepmillSpeedMaxSpm : machineinfo.treadmillSpeedMaxMph
            displayValue: main.isStepmill ? value + qsTr("SPM") : value / 10.0 + qsTr("MPH")

            visible: options.maxSpeedRegulatorEnabled

            onValueChanged: {
                options.maxSpeedRegulatorValue = value
                machineinfo.updateSpeedTable()
                datadirty = true
            }

            Component.onCompleted: value = options.maxSpeedRegulatorValue
        }

        SliderControlLabeled{
            id: maxInclineRegulator
            headingString: qsTr("Max Incline") + application.emptyString
            value: options.maxInclineRegulatorValue
            minValue: 0
            maxValue: machineinfo.treadmillInclineMaxPercentGrade
            displayValue: (value-(value%5)) / 10.0 + qsTr(" % GRADE")
            visible: options.maxInclineRegulatorEnabled

            onValueChanged: {
                options.maxInclineRegulatorValue = value - (value % 5)
                machineinfo.updateInclineTable()
                datadirty = true
            }

            Component.onCompleted: value = options.maxInclineRegulatorValue
        }

        SliderControlLabeled{
            id: lcdBrightnessControl
            headingString: qsTr("LCD Brightness") + application.emptyString
            value: options.lcdBrightness
            minValue: 10
            maxValue: 100
            displayValue: value + "%"

            onValueChanged: {
                datadirty = true
                options.lcdBrightness = value
            }
            Component.onCompleted: value = options.lcdBrightness
        }

        Item{
            id: defaultLanguageItem
            height: menuItemHeight
            width: root.width

            TextLabel{
                id: defaultLanguageLabel
                text: qsTr("Default Language") + application.emptyString
                anchors.left: parent.left
                anchors.verticalCenter: parent.verticalCenter
                color: main.colorFontDark
                width: 0.35 * parent.width
                font.pixelSize: 20* main.vScaleFactor
            }

            Text{
                id: defaultLanguageText
                text: LanguageJS.getLanguageName(options.defaultLanguage)

                font.pixelSize: 20* main.vScaleFactor
                anchors.left: defaultLanguageLabel.right
                anchors.verticalCenter: parent.verticalCenter
            }

            ScalableImage {
                id: defaultLanguageIcon

                sourceName: LanguageJS.getLanguageIcon(options.defaultLanguage);

                anchors.top: parent.top
                anchors.bottom: parent.bottom
                anchors.left: defaultLanguageText.right
                anchors.leftMargin: 30 * main.hScaleFactor

                height: parent.height
                fillMode: Image.PreserveAspectFit
            }

            MouseArea{
                anchors.fill: parent
                onClicked: {
                    root.showLanguageMenu()
                    buzzer.buttonPress()
                }

                Rectangle {
                    anchors.fill: parent
                    color: main.colorGenericStimulusArea
                    opacity: 0.3
                    visible: main.showStimulusArea
                }
            }
        }
    }

    /*Column {
        id: swipeArrows

        visible: mode.interactive
        anchors { left: mode.right ; leftMargin: 10 ; verticalCenter: mode.verticalCenter }
        spacing: 275
        ScalableImage {
            id: up
            
            sourceBase: "../graphics/"
            sourceName: "200/Swipe_Arrow_Down_Large";
        }

        ScalableImage {
            id: down
            
            sourceBase: "../graphics/"
            sourceName: "200/Swipe_Arrow_Down_Large";
        }

    }*/

    LanguageSelectionComponent {
        id: language_select_menu
        anchors.fill: controlList
        visible: languageDiagnosticMenu
        onLanguageSelected: {
            if (languageDiagnosticMenu) {
               if (lang)
               {
                   application.selectLanguage(lang)
                   options.defaultLanguage = lang
                   defaultLanguageText.text = LanguageJS.getLanguageName(options.defaultLanguage)
                   defaultLanguageIcon.sourceName = LanguageJS.getLanguageIcon(options.defaultLanguage)
               }
               languageDiagnosticMenu = false
            }
        }
    }
}
