import QtQuick 2.12
import ".."
import Components 1.0

Item{
    id: root
    anchors.fill: parent

    property int fontSize: 16 * main.vScaleFactor
    property int subFontSize: 12 * main.vScaleFactor
    property int textWidth: 100 * main.hScaleFactor
    property bool isSetupWizard: false
    property string configFile: ""

    property int numCols: 4
    property int imageMargin: 10 * main.hScaleFactor
    property int colWidth: (productImagesGrid.width - (numCols-1)*imageMargin)/numCols

    property int selectedIndex: -1

    Component.onCompleted: {
        root.selectedIndex = getCurrentIndexFromModelString(machineinfo.modelString)
    }

    function getCurrentIndexFromModelString(modelStr)
    {
        var i
        for(i = 0; i < productListModel.count; i++) {
            var item = productListModel.get(i)
            if(item.name === modelStr) {
                return i;
            }
        }
        return -1;
    }

    Item{
        id: headingSection

        anchors.top: parent.top
        anchors.left: parent.left
        anchors.right: parent.right
        height: 100 * main.vScaleFactor

        TextLabel{
            id: heading
            text: qsTranslate("Diagnostics", "PRODUCT SELECTION") + application.emptyString
            font.pixelSize: 36 * main.vScaleFactor
            anchors.fill: parent
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignTop
            color: main.colorFontDark
        }

        NumberLabel{
            id:serialNumber
            font.pixelSize: subFontSize
            horizontalAlignment: Text.AlignHCenter
            color: main.colorFontDark

            anchors.horizontalCenter: parent.horizontalCenter
            anchors.bottom: modelLabel.top
            anchors.bottomMargin: 3 * main.vScaleFactor

            text:qsTr("Serial: ") + main.serialNumber + qsTr("Version: ") + application.appVersion.split(".g")[0] + " / " + main.productVersion + application.emptyString
        }

        TextLabel{
            id: modelLabel
            text: qsTr("Product Model: ") + (machineinfo.modelString + " " + machineinfo.productTypeString) + application.emptyString

            font.pixelSize: subFontSize
            horizontalAlignment: Text.AlignHCenter
            color: main.colorFontDark
//            isHairline: true

            anchors.horizontalCenter: parent.horizontalCenter
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 3 * main.vScaleFactor
        }

    }

    ListModel {
        id: productListModel

        ListElement {
            name: "TI1000"
            imageName: "../graphics/ui3_0/product_images/2018/TI1000.png"
        }
        ListElement {
            name: "TE900"
            imageName: "../graphics/ui3_0/product_images/2018/TE900.png"
        }
        ListElement {
            name: "TC400"
            imageName: "../graphics/ui3_0/product_images/2018/TC400.png"
        }
        ListElement {
            name: "TC650"
            imageName: "../graphics/ui3_0/product_images/2018/TC650.png"
        }
        ListElement {
            name: "TC900"
            imageName: "../graphics/ui3_0/product_images/2018/TC900.png"
        }
        ListElement {
            name: "XC400"
            imageName: "../graphics/ui3_0/product_images/2018/XC400.png"
        }
        ListElement {
            name: "XC900"
            imageName: "../graphics/ui3_0/product_images/2018/XC900.png"
        }
        ListElement {
            name: "XS1000"
            imageName: "../graphics/ui3_0/product_images/2018/XS1000.png"
        }
        ListElement {
            name: "XL1000"
            imageName: "../graphics/ui3_0/product_images/2018/XL1000.png"
        }
        ListElement {
            name: "RC400"
            imageName: "../graphics/ui3_0/product_images/2018/RC400.png"
        }
        ListElement {
            name: "RC900"
            imageName: "../graphics/ui3_0/product_images/2018/RC900.png"
        }
        ListElement {
            name: "UC400"
            imageName: "../graphics/ui3_0/product_images/2018/UC400.png"
        }
        ListElement {
            name: "UC900"
            imageName: "../graphics/ui3_0/product_images/2018/UC900.png"
        }
        ListElement {
            name: "UC920"
            imageName: "../graphics/ui3_0/product_images/2018/UC900.png"
        }
        ListElement {
            name: "VC900"
            imageName: "../graphics/ui3_0/product_images/2018/VC900.png"
        }
        ListElement {
            name: "ST1000"
            imageName: "../graphics/ui3_0/product_images/ST1000.png"
        }
    }

    Component {
        id: productComponent
        Item {
//            anchors.fill: parent

            width: colWidth
            height: colWidth + 30 * main.vScaleFactor

            Rectangle {
                anchors.fill: parent

                visible: root.selectedIndex === index
                color: main.colorHighlightBackground//"transparent"
                opacity: 0.7
                radius: main.defaultRadius
                border.color: main.colorUIBorder
                border.width: 2*main.widthBorder
            }

            Column {
                id: productImageArea
                height: parent.height - root.imageMargin
                width: parent.width - root.imageMargin
                anchors {
                    horizontalCenter: parent.horizontalCenter
                    verticalCenter: parent.verticalCenter
                }

                Image{
                    width: parent.width
                    height: width

                    fillMode: Image.PreserveAspectFit
                    smooth: true
                    source: imageName
                }

                TextLabel {
                    text: name
                    color: main.colorFontDark
                    font.pixelSize: root.fontSize
                    width: parent.width
                    horizontalAlignment: Text.AlignHCenter
                }
            }

            MouseArea {
                anchors.fill: parent
                onClicked: {
                    root.selectedIndex = index
                    root.configFile = "ProductConfig/" + name + ".npc"
                }

                Rectangle {
                    anchors.fill: parent
                    color: main.colorGenericStimulusArea
                    opacity: 0.3
                    visible: main.showStimulusArea
                }
            }
        }
    }

    GridView {
        id: productImagesGrid

        width: 0.9*parent.width
        anchors {
            horizontalCenter: root.horizontalCenter
//            horizontalCenterOffset: -width/6
            top: headingSection.bottom
            topMargin: 30 * main.vScaleFactor
            bottom: parent.bottom
            bottomMargin: 100 * main.vScaleFactor
        }

        cellWidth: colWidth
        cellHeight: colWidth + 30 * main.vScaleFactor
        clip:true

        model: productListModel
        delegate: productComponent
    }

    Rectangle {
        id: sliderBar

        anchors.right: parent.right
        anchors.rightMargin: 2 * main.hScaleFactor
        width: 15 * main.hScaleFactor
        height: productImagesGrid.height * productImagesGrid.height/productImagesGrid.contentHeight
        visible: productImagesGrid.height < productImagesGrid.contentHeight
        color: "darkgrey"
        radius: main.defaultRadius
        y: (parent.height - height) * productImagesGrid.contentY / (productImagesGrid.contentHeight - productImagesGrid.height)
    }

    Checkbox {
        id: staticBrakeCheckbox

        anchors {
            verticalCenter: selectionButton.verticalCenter
            horizontalCenter: parent.horizontalCenter
        }

        width: 400 * main.hScaleFactor
        visible: root.selectedIndex === 0 // Only show for TI1000
        label: qsTr("Static Brake Installed?") + application.emptyString
        value: false

        onPressed: {

        }

        onVisibleChanged: {
            value = true
        }
    }

    StandardButton {
        id: selectionButton

        height: 60 * main.vScaleFactor

        anchors.right: root.right
        anchors.rightMargin: 20 * main.hScaleFactor
        anchors.bottom: root.bottom
        anchors.bottomMargin: 20 * main.vScaleFactor
        buttonText: qsTr("Reconfigure Nucleus") + application.emptyString

        onClicked: {
            nucleus.reconfigureNucleus(root.configFile, staticBrakeCheckbox.value )
            nucleusUpdatingDialog.show()
            main.restartRequired = true
            main.rebootRequired = false
        }

    }

    ModalDialog{
        id: nucleusUpdatingDialog
        blockKeys: true

        Item {
            z: parent.z + 1
            anchors.fill: parent

            Text{
                id: reconfigureHeader
                text: "Reconfiguring Nucleus ..."
                wrapMode: Text.WordWrap
                color: main.colorFontLight
                font.bold: false
                font.pixelSize: 40 * main.vScaleFactor
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.top: parent.top
                anchors.topMargin: 15 * main.vScaleFactor
            }

            Text{
                id: reconfigureStatusText
                text: nucleus.writeProgressString
                wrapMode: Text.WordWrap
                color: main.colorFontLight
                font.bold: false
                font.pixelSize: 30 * main.vScaleFactor
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.bottom: reconfigureProgress.top
                anchors.bottomMargin: 5 * main.vScaleFactor
            }

            ProgressBar {
                id: reconfigureProgress
                width: 0.5 * parent.width
                height: 0.15 * parent.height
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.verticalCenter: parent.verticalCenter
                anchors.verticalCenterOffset: 0.75*reconfigureStatusText.height
                value: nucleus.writeProgressPercent * 100
            }

            CloseButton {
                anchors {
                    right: parent.right
                    rightMargin: 10 * main.hScaleFactor
                    top: parent.top
                    topMargin: 10 * main.vScaleFactor
                }
                width: 40 * main.hScaleFactor
                height: 40 * main.vScaleFactor
                z: parent.z + 5
                onClicked: nucleusUpdatingDialog.hide()
            }
        }

        Component.onCompleted: hide()
    }
}
