import QtQuick 2.12
import Components 1.0
import ".."
import Process 0.1

Item {
    id: root
    width: main.width
    height: main.height
    anchors.fill: parent

    state: "unset"

    property string argList: getArgList()
    property string minionIds

    function getArgList() {
        var args
        args = "-"
        args += (syncScreenSaverButton.value ? "s" : "" )
        args += (syncFacilityImageButton.value ? "f" : "")
        args += (syncTVConfButton.value ? "T" : "")
        args += (syncTimerButton.value ? "t" : "")
        args += (syncSoftwareUpdateButton.value ? "u" : "")
        args += (syncAttractVideoButton.value) ? "b" : ""
        console.log("getArgList: args=" + args )
        return args
    }

    function parseMinions(jsonObj) {
        minionList.clear()
        for(var sn in jsonObj) {
            minionList.append({"serial" : sn, "type": jsonObj[sn]})
        }
    }

    ListModel {
        id: minionList
    }

    TextLabel {
        id: title
        text: qsTr("SYNCHRONIZE SETTINGS")
        color: main.colorFontDark
        anchors.top: parent.top
        anchors.topMargin: 30 * main.vScaleFactor
        anchors.horizontalCenter: parent.horizontalCenter
        font.pixelSize: 24 * main.vScaleFactor
    }

    StandardButton {
        id: makePrimaryButton

        selected: main.isPrimary
        width: 150 * main.hScaleFactor
        height: 80 * main.vScaleFactor
        anchors {
            top: title.bottom
            topMargin: 50 * main.vScaleFactor
            horizontalCenter: parent.horizontalCenter
        }

        buttonText: qsTr("Prepare to Synchronize") + application.emptyString
        onClicked: {
            makePrimary.start()
        }
    }

    Item {
        id: syncOptionsView
        visible: false
        anchors {
            top: title.bottom
            topMargin: 20 * main.vScaleFactor
            bottom: parent.bottom
            horizontalCenter: parent.horizontalCenter
        }
        width: root.width * 0.8
        anchors {
            top: title.bottom
            topMargin: 50 * main.vScaleFactor
            horizontalCenter: parent.horizontalCenter
            bottom: parent.bottom
        }

        Column {
            id: syncOptions

//            visible: main.isPrimary
            anchors {
                top: parent.top
                horizontalCenter: parent.horizontalCenter
                bottom: syncSettingsButton.top
                bottomMargin: 20 * main.vScaleFactor
            }
            width: parent.width
            spacing: 20 * main.hScaleFactor

            Checkbox {
                id: syncAssetsButton
                label: qsTr("Sync All Settings") + application.emptyString
                width: parent.width
                onPressed: {
                    if(syncAssetsButton.value) {
                        syncScreenSaverButton.value = true
                        syncFacilityImageButton.value = true
                        syncTVConfButton.value = diagnosticsMain.accessLevel >= 1 ? true : false
                        syncTimerButton.value = true
                        syncSoftwareUpdateButton.value = true
                        syncAttractVideoButton.value = true
                    }
                    else {
                        syncScreenSaverButton.value = false
                        syncFacilityImageButton.value = false
                        syncTVConfButton.value = false
                        syncTimerButton.value = false
                        syncSoftwareUpdateButton.value = false
                        syncAttractVideoButton.value = false
                    }
                }
            }

            Checkbox {
                id: syncScreenSaverButton
                label: qsTr("Sync Screensaver Images") + application.emptyString
                width: parent.width
            }

            Checkbox {
                id: syncFacilityImageButton
                label: qsTr("Sync Facility Images") + application.emptyString
                width: parent.width
            }

            Checkbox {
                id: syncAttractVideoButton
                label: qsTr("Sync Banner (Attract) Video") + application.emptyString
                width: parent.width
            }
            Checkbox {
                id: syncTVConfButton
                visible: diagnosticsMain.accessLevel >= 1
                label: qsTr("Sync TV Configuration") + application.emptyString
                width: parent.width
            }

            Checkbox {
                id: syncTimerButton
                label: qsTr("Sync Timer Settings") + application.emptyString
                width: parent.width
            }

            Checkbox {
                id: syncSoftwareUpdateButton
                label: qsTr("Sync Software Update") + application.emptyString
                width: parent.width
            }
        }

        StandardButton {
            id: syncSettingsButton

//            visible: main.isPrimary
            width: 150 * main.hScaleFactor
            height: 80 * main.vScaleFactor
            anchors {
                bottom: parent.bottom
                bottomMargin: 20 * main.vScaleFactor
                horizontalCenter: parent.horizontalCenter
            }

            buttonText: qsTr("Synchronize Selected Settings") + application.emptyString
            onClicked: {
                syncAssets.start()
                root.state = "minionView"
            }
        }
    }

    Item {
        id: minionView
        visible: false
        z: parent.z + 1
        anchors {
            top: title.bottom
            topMargin: 10 * main.vScaleFactor
            bottom: parent.bottom
            horizontalCenter: parent.horizontalCenter
        }
        width: parent.width * 0.9

        property int messageType: 0

        function getMinionTitle() {
            switch (messageType) {
            case 0:
                return qsTr("Consoles Found:") + application.emptyString
            case 1:
                return qsTr("Synchronizing Items to ...") + application.emptyString
            case 2:
                main.rebootRequired = true
                return qsTr("Synchronization Complete.") + application.emptyString
            }
        }

        Text {
            id: minionTitle

            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: parent.top
            width: parent.width

            color: main.colorFontDark
            text: parent.getMinionTitle()
            horizontalAlignment: Text.AlignHCenter
            wrapMode: Text.WordWrap
            font.bold: true
            font.pixelSize: 40 * main.vScaleFactor
        }

        Text {
            id: minionSubTitle

            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: minionTitle.bottom
            width: parent.width
            height: minionView.messageType === 2 ? 90 * main.vScaleFactor : 0

            visible: minionView.messageType === 2
            color: "red"
            text: qsTr("Power cycle required on ALL synchronized machines:") + application.emptyString
            horizontalAlignment: Text.AlignHCenter
            wrapMode: Text.WordWrap
            font.bold: true
            font.pixelSize: 32 * main.vScaleFactor
        }

        Row {
            id:minionInfoTitle
            anchors {
                horizontalCenter: parent.horizontalCenter
                top: minionSubTitle.bottom
                topMargin: 20 * main.vScaleFactor
            }

            width: parent.width*0.8
            spacing: 0.1 * parent.width

            Text {
                id: snText
                anchors {
                    top: parent.top
                }
                width: parent.width * 0.6

                text: qsTr("Serial Number:") + application.emptyString
                color: main.colorFontDark
                horizontalAlignment: Text.AlignRight
                wrapMode: Text.WordWrap
                font.bold: false
                font.pixelSize: 30 * main.vScaleFactor
            }

            Text {
                id: typeText
                anchors {
                    top: parent.top
                }
                width: parent.width * 0.3

                text: qsTr("Type:") + application.emptyString
                color: main.colorFontDark
                horizontalAlignment: Text.AlignLeft
                wrapMode: Text.WordWrap
                font.bold: false
                font.pixelSize: 30 * main.vScaleFactor
            }
        }

        ScrollBox {
            anchors {
                top: minionInfoTitle.bottom
                bottom: continueButton.top
                bottomMargin: 20 * main.vScaleFactor
                horizontalCenter: minionInfoTitle.horizontalCenter
            }
            width: minionInfoTitle.width
            color: "white"//"lightgrey"

            model: minionList
            delegate:  Row {
                width: parent.width
                spacing: 0.1 * parent.width

                Text {
                    width: parent.width * 0.6
                    color: main.colorFontDark
                    text: model.serial
                    horizontalAlignment: Text.AlignRight
                    wrapMode: Text.WordWrap
                    font.bold: false
                    font.pixelSize: 30 * main.vScaleFactor
                }

                Text {
                    width: parent.width * 0.3
                    color: main.colorFontDark
                    text: model.type
                    horizontalAlignment: Text.AlignLeft
                    wrapMode: Text.WordWrap
                    font.bold: false
                    font.pixelSize: 30 * main.vScaleFactor
                }
            }
        }

        StandardButton {
            id: continueButton
            visible: parent.messageType !== 1
            width: 150 * main.hScaleFactor
            height: 80 * main.vScaleFactor
            anchors {
                bottom: parent.bottom
                bottomMargin: 40 * main.vScaleFactor
                horizontalCenter: parent.horizontalCenter
            }
            buttonText: qsTr("Continue") + application.emptyString
            onClicked: { main.isPrimary ? root.state = "optionsView" : root.state = "unset" }
        }
    }

    Process {
        id: makePrimary
        program: "bash"
        arguments: "scripts/salt/makePrimary.sh"
        onReadyReadStandardError: {
            var stdErr = makePrimary.readAllStandardError()
            console.log("makePrimary stderr:",stdErr)
        }
        onReadyReadStandardOutput: {
            var stdOut = makePrimary.readAllStandardOutput()
            console.log("makePrimary stdout:", stdOut)
            var logs = JSON.parse(stdOut);
            minionIds  = JSON.stringify(logs)
            console.log("minionIds: " + minionIds );

            parseMinions(logs)
        }
        onStarted: {
            makePrimaryDialog.show()
            console.log("Configuring this console as 'Primary'...")
        }
        onFinished: {
            print("Diagnostics Update: This console is configured as Primary")
            main.isPrimary = true
            makePrimaryDialog.hide()
            minionView.messageType = 0
            root.state = "minionView"
        }
    }

    Process {
        id: syncAssets
        program: "bash"
        arguments: [ "scripts/salt/syncAssets.sh" , root.argList ]
        onReadyReadStandardError: {
            var stdErr = syncAssets.readAllStandardError()
            console.log("syncAssets stderr:",stdErr)
        }
        onReadyReadStandardOutput: {
            var stdOut = syncAssets.readAllStandardOutput()
            console.log("syncAssets stdout:", stdOut)
        }
        onStarted: {
            console.log("Synchronizing settings...")
            minionView.messageType = 1
        }
        onFinished: {
            print("Diagnostics Update: All Settings sync'ed")
            minionView.messageType = 2
        }
    }

    ModalDialog {
        id: makePrimaryDialog
        blockKeys: true
        visible: false  // shown when update process starts
        opacity: 1

        Item {
            z: parent.z + 1
            anchors.fill: parent

            Text {
                id: dialogText3
                width: parent.width * 0.8
                color: main.colorFontLight
                text: qsTr("Preparing to Synchronize ...") + application.emptyString
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.verticalCenter: parent.verticalCenter
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                font.pixelSize: 40 * main.vScaleFactor
            }
        }
    }

    states: [
        State {
            name: "unset"
            PropertyChanges { target: makePrimaryButton; visible: true }
            PropertyChanges { target: syncOptionsView; visible: false }
            PropertyChanges { target: minionView; visible: false }
        },
        State {
            name: "optionsView"
            PropertyChanges { target: makePrimaryButton; visible: false }
            PropertyChanges { target: syncOptionsView; visible: true }
            PropertyChanges { target: minionView; visible: false }
        },
        State {
            name: "minionView"
            PropertyChanges { target: makePrimaryButton; visible: false }
            PropertyChanges { target: syncOptionsView; visible: false }
            PropertyChanges { target: minionView; visible: true }
        }
    ]
}
