import QtQuick 2.12
import ".."
//import ConfigurationData 1.0
import Components 1.0


Item {
    id: root
    anchors.fill: parent
    state: ""

    property bool isSetupWizard: false
    property bool isActive: (main.state === "DiagnosticState" && diagnosticsMain.currentSelectedIndex >= 0) || isSetupWizard

    property string calibratingMessageString: qsTr("Waiting...")

    signal close()

    TextLabel {
        id: title
        text:  qsTr("ADJUSTIBLE STRIDE CALIBRATION")
        color: main.colorFontDark
        anchors.top: parent.top
        anchors.topMargin: 30 * main.vScaleFactor
        anchors.horizontalCenter: parent.horizontalCenter
        font.pixelSize: 24 * main.vScaleFactor
    }

    Grid {
        id: infoBlock

        property int fontSize: 14 * main.vScaleFactor
        property int colWidth: (parent.width - columnSpacing)/2

        rowSpacing: 20 * main.vScaleFactor
        columnSpacing : 40 * main.hScaleFactor
        columns: 2
        rows: 5
        verticalItemAlignment: Grid.AlignVCenter

        width: parent.width
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: title.bottom
        anchors.topMargin: 50 * main.vScaleFactor

        TextLabel {
            text: qsTr("MODEL") + application.emptyString
            font.pixelSize: infoBlock.fontSize
            color: main.colorFontDark
            width: infoBlock.colWidth
            horizontalAlignment: Text.AlignRight
        }

        TextLabel {
            text: machineinfo.modelString
            font.pixelSize: infoBlock.fontSize
            color: main.colorFontDark
            width: infoBlock.colWidth
            horizontalAlignment: Text.AlignLeft
        }

        TextLabel {
            text: qsTr("STRIDE RANGE") + application.emptyString
            font.pixelSize: infoBlock.fontSize
            color: main.colorFontDark
            width: infoBlock.colWidth
            horizontalAlignment: Text.AlignRight
        }

        TextLabel {
            text: (machineinfo.adjustableStrideEllipticalMinStrideIn / 10).toFixed(1) + qsTr(" to ") + (machineinfo.adjustableStrideEllipticalMaxStrideIn / 10).toFixed(1) + qsTr(" Inches")
            font.pixelSize: infoBlock.fontSize
            color: main.colorFontDark
            width: infoBlock.colWidth
            horizontalAlignment: Text.AlignLeft
        }

        TextLabel {
            text: qsTr("STRIDE ADC RANGE") + application.emptyString
            font.pixelSize: infoBlock.fontSize
            color: main.colorFontDark
            width: infoBlock.colWidth
            horizontalAlignment: Text.AlignRight
        }

        TextLabel {
            text: machineinfo.adjustableStrideEllipticalCalibratedStrideMinAdc + qsTr(" to ") + machineinfo.adjustableStrideEllipticalCalibratedStrideMaxAdc
            font.pixelSize: infoBlock.fontSize
            color: main.colorFontDark
            width: infoBlock.colWidth
            horizontalAlignment: Text.AlignLeft
        }

        TextLabel {
            text: qsTr("ACTUAL STRIDE ADC") + application.emptyString
            font.pixelSize: infoBlock.fontSize
            color: main.colorFontDark
            width: infoBlock.colWidth
            horizontalAlignment: Text.AlignRight
        }

        TextLabel {
            text: machinecontrol.strideLengthAdcActual
            font.pixelSize: infoBlock.fontSize
            color: main.colorFontDark
            width: infoBlock.colWidth
            horizontalAlignment: Text.AlignLeft
        }

        TextLabel {
            text: qsTr("TEST RESULTS") + application.emptyString
            font.pixelSize: infoBlock.fontSize
            color: main.colorFontDark
            width: infoBlock.colWidth
            horizontalAlignment: Text.AlignRight
        }

        TextLabel {
            text: root.calibratingMessageString
            font.pixelSize: infoBlock.fontSize
            color: main.colorFontDark
            width: infoBlock.colWidth
            horizontalAlignment: Text.AlignLeft
        }
    }

    StandardButton{
        id: calibrateButton

        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: infoBlock.bottom
        anchors.topMargin: 50 * main.vScaleFactor
        width: 100 * main.hScaleFactor
        height: 50 * main.vScaleFactor

        buttonText: qsTr("RUN") + application.emptyString

        beep:false
        onClicked: startCalibrationTimer.start()
    }

    Connections {
        target: machinecontrol
        onIsCalibratingChanged: {
            if(isCalibrating) {
                calibratingMessageString = qsTr("CALIBRATING...")+application.emptyString
            }
            else {
                calibratingMessageString = qsTr("CANCELLED...") + application.emptyString
            }
        }
        onCalibrationComplete: {
            if(result){
                calibratingMessageString = qsTr("CALIBRATION SUCCESSFUL")+application.emptyString
            }
            else {
                calibratingMessageString = qsTr("CALIBRATION FAILED")+application.emptyString
            }
        }
    }


    MessagePopup{
        id:goingToCalibrateMessage
        dismissable: false

    }

    Timer{
        id: startCalibrationTimer
        interval: 1000
        repeat: true
        running: false

        property int counter: 3

        function updateGoingToCalibrateMessage(){
            goingToCalibrateMessage.message = qsTr("STARTING CALIBRATION IN ") +"<br>" + counter + application.emptyString
        }

        onRunningChanged: if(running) {
                              buzzer.warningBeep()
                              goingToCalibrateMessage.show();
                              updateGoingToCalibrateMessage()
                          }
        onTriggered: {
            counter--;
            if(counter == 0){
                counter = 3
                startCalibrationTimer.stop()
                machinecontrol.calibrationStart()
                goingToCalibrateMessage.hide()
            }
            else
            {
                buzzer.warningBeep()
                updateGoingToCalibrateMessage();
            }
        }

    }

}
