
import QtQuick 2.12
import QtQuick.Controls 2.12
import Process 0.1
import ".."
import FileIO 1.0
import Components 1.0

Item {
    id: root
    property string tuner_id: tv.tunerType
    property bool isSetupWizard: false
    property bool isActive: main.state === "DiagnosticState" && diagnosticsMain.currentSelectedIndex >= 0 || root.isSetupWizard
    property bool collectingData: false
    property string statusStr: ""
    property var signalStats: []
    property var snrStats: []
    property var berStats: []
    property var uncStats: []
    property string currentChannelName: ""
    property string signalProgram: ""

    function deleteAllChannels() {
        //tv.channelList.channels.clear()
        //tv.channelList.doSave()
        tv.channelList.clearChannels()
        tv.channelList.doSave()
        selectMultipleCheckbox.value = false
        channelListBox.multipleSelectEnabled = selectMultipleCheckbox.value
    }

    Component.onDestruction: {
        if (root.isActive) {
            tv.on = false
            tv.currentChannel = -1
        }
    }

    onIsActiveChanged: {
        if (isActive){
            if (channelListBox.channelListGrid.currentIndex >= 0)
                previewTv.previewChannel(channelListBox.channelListGrid.currentIndex)
        } else {
            tv.on = false
            tv.currentChannel = -1
        }
    }

    ChannelListBox {
        id: channelListBox

        width: 0.7 * root.width
        height: 0.65 * root.height
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset: -rightControlArea.width/2
        anchors.top: rightControlArea.top

        isSelectable: true

        onUpdatePreview: {
            if (selectedIndex >= 0){
                previewTimer.index = selectedIndex
                previewTimer.restart()
            }
            root.currentChannelName = tv.channelList.channels.get(selectedIndex).name
            var channelExtra = tv.channelList.channels.get(selectedIndex).extra
            var fields = channelExtra.split("|")
            if(fields[2] === "A")
                root.signalProgram = ""
            else if(fields[0] === "ATSC" || fields[0] === "QAM")
                root.signalProgram = "azap"
            else if(fields[0] === "DVB-T")
                root.signalProgram = "tzap"
            else if(fields[0] === "DVB-C")
                root.signalProgram = "czap"
            else
                root.signalProgram = ""

        }
    }

    ModalDialog {
        id: deletePopup
        dismissable: true
        blockKeys: true

        Item {
            z: deletePopup.z + 1
            anchors.fill: parent

            TextLabel {
                id: warningText
                width: parent.width
                text: qsTr("DELETE CHANNEL?") + application.emptyString
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.top: parent.top
                anchors.topMargin: 35 * main.vScaleFactor
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                font.pixelSize: 40 * main.vScaleFactor
            }

            Column {
                id: touchControls2
                width: 300 * main.hScaleFactor
                height: 200 * main.vScaleFactor
                spacing: 20 * main.vScaleFactor
                anchors {
                    top: warningText.bottom
                    topMargin: 20 * main.vScaleFactor
                    horizontalCenter: parent.horizontalCenter
                }

                StandardButton {
                    id: deleteBtn
                    width: 0.9 * parent.width
                    height: 50 * main.vScaleFactor

                    anchors.horizontalCenter: parent.horizontalCenter

                    onClicked: {
                        tv.channelList.removeAChannel(channelListBox.channelListGrid.currentIndex)
                        tv.channelList.doSave()
                       if(tv.channelList.channelCount === 0)
                        {
                            selectMultipleCheckbox.value = false
                            channelListBox.multipleSelectEnabled = selectMultipleCheckbox.value
                        }

                        deletePopup.hide()
                    }
                    buttonText: qsTr("Delete Channel") + application.emptyString
                    label.font.pixelSize: 18 * main.vScaleFactor
                }

                StandardButton {
                    id: cancelBtn
                    width: 0.9 * parent.width
                    height: 50 * main.vScaleFactor

                    anchors.horizontalCenter: parent.horizontalCenter

                    onClicked: {
                        deletePopup.dismissed()
                    }
                    buttonText: qsTr("Cancel") + application.emptyString
                    label.font.pixelSize: 18 * main.vScaleFactor
                }

                StandardButton {
                    id: deleteAllBtn
                    width: 0.9 * parent.width
                    height: 50 * main.vScaleFactor

                    anchors.horizontalCenter: parent.horizontalCenter

                    onClicked: {
                        deletePopup.hide()
                        deleteAllPopup.show()
                    }
                    buttonText: qsTr("Delete ALL Channels") + application.emptyString
                    label.font.pixelSize: 18 * main.vScaleFactor
                }
            }
        }
        Component.onCompleted: hide()
        onTimedOut: hide()
    }

    ModalDialog {
        id: deleteSelectedPopup
        dismissable: true
        blockKeys: true

        Item {
            z: parent.z + 1
            anchors.fill: parent

            TextLabel {
                id: warningText2
                width: parent.width
                text: qsTr("DELETE SELECTED CHANNELS?") + application.emptyString
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.top: parent.top
                anchors.topMargin: 35 * main.vScaleFactor
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                font.pixelSize: 40 * main.vScaleFactor
            }

            Column {
                width: 300 * main.hScaleFactor
                height: 200 * main.vScaleFactor
                spacing: 20 * main.vScaleFactor
                anchors {
                    top: warningText2.bottom
                    topMargin: 20 * main.vScaleFactor
                    horizontalCenter: parent.horizontalCenter
                }

                StandardButton {
                    id: deleteBtn2
                    width: 0.9 * parent.width
                    height: 50 * main.vScaleFactor

                    anchors.horizontalCenter: parent.horizontalCenter

                    onClicked: {
                        tv.channelList.removeSelectedChannels()
                        channelListBox.channelListGrid.currentIndex = -1
                        if(tv.channelList.channelCount === 0) {
                            selectMultipleCheckbox.value = false
                            channelListBox.multipleSelectEnabled = selectMultipleCheckbox.value
                        }

                        deleteSelectedPopup.hide()
                    }
                    buttonText: qsTr("Delete Selected Channels") + application.emptyString
                    label.font.pixelSize: 18 * main.vScaleFactor
                }

                StandardButton {
                    id: cancelBtn2
                    width: 0.9 * parent.width
                    height: 50 * main.vScaleFactor

                    anchors.horizontalCenter: parent.horizontalCenter

                    onClicked: {
                        deleteSelectedPopup.dismissed()
                    }
                    buttonText: qsTr("Cancel") + application.emptyString
                    label.font.pixelSize: 18 * main.vScaleFactor
                }

                StandardButton {
                    id: deleteAllBtn2
                    width: 0.9 * parent.width
                    height: 50 * main.vScaleFactor

                    anchors.horizontalCenter: parent.horizontalCenter

                    onClicked: {
                        deleteSelectedPopup.hide()
                        deleteAllPopup.show()
                    }
                    buttonText: qsTr("Delete ALL Channels") + application.emptyString
                    label.font.pixelSize: 18 * main.vScaleFactor
                }
            }
        }
        Component.onCompleted: hide()
        onTimedOut: hide()
    }

    Loader {
        id: addChannelLoader

        function loadItem() {
           sourceComponent = addChannelComponent
        }

        function destroyItem() {
            sourceComponent = null
        }

        onLoaded: addChannelLoader.item.show()

        Component {
            id: addChannelComponent
            AddChannelPopup {
                id: addChannelPopup
                onChannelAdded: {
                    console.log("channelAdded", norm, network, number, freq)
                    var item = {id: "A"+freq, number: number, freq: freq, name: network, enabled:"true", analog:true, norm: norm}
                    tv.channelList.addChannel(item)
                    tv.channelList.doSave()
                    var idx = tv.channelList.findChannel(item.id)
                    if (idx >= 0){
                        channelListBox.channelListGrid.currentIndex = idx
                    }
                    hide()
                    addChannelLoader.destroyItem()
                }
                onDismissed: {
                    addChannelLoader.destroyItem()
                }
            }
        }
    }

    ModalDialog {
        id: deleteAllPopup
        dismissable: true
        blockKeys: true

        Item {
            z: parent.z + 1
            anchors.fill: parent

            TextLabel {
                id: warningText3
                width: parent.width
                text: qsTr("DELETE ALL?") + application.emptyString
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.top: parent.top
                anchors.topMargin: 35 * main.vScaleFactor
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                font.pixelSize: 40 * main.vScaleFactor
            }

            Column {
                id: touchControls3
                width: 300 * main.hScaleFactor
                height: 200 * main.vScaleFactor
                spacing: 20 * main.vScaleFactor
                anchors {
                    top: warningText3.bottom
                    topMargin: 20 * main.vScaleFactor
                    horizontalCenter: parent.horizontalCenter
                }

                StandardButton {
                    id: deleteAllBtn3
                    width: 0.9 * parent.width
                    height: 50 * main.vScaleFactor

                    anchors.horizontalCenter: parent.horizontalCenter

                    onClicked: {
                        root.deleteAllChannels()
                        deleteAllPopup.hide()
                    }
                    buttonText: qsTr("Delete ALL Channels") + application.emptyString
                    label.font.pixelSize: 18 * main.vScaleFactor
                }

                StandardButton {
                    id: cancelBtn3
                    width: 0.9 * parent.width
                    height: 50 * main.vScaleFactor

                    anchors.horizontalCenter: parent.horizontalCenter

                    onClicked: {
                        deleteAllPopup.dismissed()
                    }
                    buttonText: qsTr("Cancel") + application.emptyString
                    label.font.pixelSize: 18 * main.vScaleFactor
                }
            }
        }
        Component.onCompleted: hide()
        onTimedOut: hide()
    }

    Timer {
        id: previewTimer
        property int index: 0

        interval: 500
        running: false
        repeat: false
        onTriggered: {
            previewTv.previewChannel(previewTimer.index)
        }
    }

    ModalDialog {
        id: signalDataPopup
        dismissable: true
        blockKeys: true

        Component.onCompleted: {
            hide()
        }

        onTimedOut: hide()

        onVisibleChanged: {
            if(visible) {
                previewTv.pausePreview()
                if(fileio.exists("/data/channels.conf"))
                    collectSignalData.start()
            } else {
                collectSignalData.kill()
                previewTv.resumePreview()
            }
        }

        Item {
            id: signalItem
            z: parent.z + 1
            anchors.fill: parent

            property alias statsGraph: signalStatsGraph

            CloseButton {
                id: exitButton

                z: 200

                anchors {
                    right: parent.right
                    rightMargin: 40 * main.hScaleFactor
                    top: parent.top
                    topMargin: 40 * main.vScaleFactor
                }

                onClicked: {
                    signalDataPopup.hide()
                }
            }

            TextLabel {
                id: signalTitle
                width: parent.width
                text: qsTr("SIGNAL DATA") + application.emptyString
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.top: parent.top
                anchors.topMargin: 35 * main.vScaleFactor
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                font.pixelSize: 40 * main.vScaleFactor
            }

            TextLabel {
                visible: root.collectingData
                anchors.centerIn: parent
                width: parent.width
                text: qsTr("COLLECTING DATA")
                horizontalAlignment: Text.AlignHCenter
                font.pixelSize: 40 * main.vScaleFactor
            }

            BusyIndicator {
                id: control
                z: parent.z + 1
                anchors {
                    horizontalCenter: parent.horizontalCenter
                    verticalCenter: parent.verticalCenter
                    verticalCenterOffset: parent.height/4
                }
                width: 65
                height: 65
                visible: root.collectingData

                running: parent.visible
                contentItem: Item {
                     implicitWidth: 64
                     implicitHeight: 64

                     Item {
                         id: item
                         x: parent.width / 2 - 32
                         y: parent.height / 2 - 32
                         width: 64
                         height: 64
                         opacity: control.running ? 1 : 0

                         Behavior on opacity {
                             OpacityAnimator {
                                 duration: 250
                             }
                         }

                         RotationAnimator {
                             target: item
                             running: control.visible && control.running
                             from: 0
                             to: 360
                             loops: Animation.Infinite
                             duration: 1250
                         }

                         Image {
                             visible: control.running
                             source: "../graphics/ui3_0/Components/busyIndicator.png"
                             fillMode: Image.PreserveAspectFit
                             RotationAnimator on rotation {
                                 running: control.running
                                 loops: Animation.Infinite
                                 duration: 2000
                                 from: 0
                                 to: 360
                             }
                         }
                     }
                 }
            }

            Canvas {
                id: signalStatsGraph
                visible: !root.collectingData
//                z: parent.z + 1

                anchors {
                    top: signalTitle.bottom
                    topMargin: 10 * main.vScaleFactor
                    left: parent.left
                    leftMargin: 10 * main.hScaleFactor
                    right: parent.right
                    rightMargin: 10 * main.hScaleFactor
                    bottom: parent.bottom
                    bottomMargin: 10 * main.vScaleFactor
                }

                property double lastX: 0
                property double currX: 0
                property double timeToPixels: signalStatsGraph.width/60 // 10 minutes on screen at a time

                property var sigColor: Qt.rgba(63/255,221/255,0/255, 1.0)
                property var snrColor: Qt.rgba(60/255,180/255,244/255, 1.0)
                property var berColor: Qt.rgba(0.925, 0.110, 0.141, 1.0)
                property var uncColor: Qt.rgba(160/255,80/255,244/255, 1.0)

                property int maxSig: 0xffff
                property int maxSnr: 0xfff
                property int maxBer: 0xffff
                property int maxUnc: 0xff

                function computeY(targetPercent) {
                    var y = targetPercent * 0.9*signalStatsGraph.height
                    return 0.95*signalStatsGraph.height - y // 0 is top left
                }

                function computeYinRange(target, max, min) {
                    var percent = (target - min) / (max - min)
                    var y = percent * signalStatsGraph.height
                     return signalStatsGraph.height - y // 0 is top left
                }

                function drawSeg(ctx, lastX, currX, lastY, currY, strokeColor) {
                    ctx.strokeStyle = strokeColor
                    ctx.lineWidth = 2*main.scaleFactor

                    ctx.beginPath()
                    ctx.moveTo(Math.round(lastX), Math.round(lastY))
                    ctx.lineTo(Math.round(currX), Math.round(currY))
                    ctx.stroke()
                }

                function drawLegendItem(ctx, legX, legY, strokeColor, textStr, legVal) {
                    ctx.fillStyle = strokeColor
                    ctx.font = 'bold 13px "FreeSans"'
                    if(legVal > 90)
                        ctx.textBaseline = "top"
                    else if(legVal < 10)
                        ctx.textBaseline = "bottom"
                    else
                        ctx.textBaseline = "center"

                    ctx.fillText(textStr + " " + legVal + "%", legX, legY)
//                    ctx.fillText(legVal + "%", legX, legY + 24)
                }

                function paintNextSeg() {
                    if(!signalStatsGraph.available)
                        return

                    var ctx = signalStatsGraph.getContext("2d")
                    ctx.clearRect(0, 0, signalStatsGraph.width, signalStatsGraph.height)


                    // Draw lines
                    var i
                    var avgSig=0, avgSnr=0, avgBer=0, avgUnc=0
                    var startX = 0.15 * signalStatsGraph.width
                    var lastX, currX
                    var len = Math.min(100, signalStats.length)
                    var minI = signalStats.length-len + 1
                    timeToPixels = (signalStatsGraph.width-startX)/len
                    for(i=0; i<len; i++) {
                        lastX = (i-1)*timeToPixels + startX
                        currX = i*timeToPixels + startX

                        drawSeg(ctx, lastX, currX, computeY(signalStats[i-1+minI]/maxSig), computeY(signalStats[i+minI]/maxSig), sigColor)
                        drawSeg(ctx, lastX, currX, computeY(snrStats[i-1+minI]/maxSnr), computeY(snrStats[i+minI]/maxSnr), snrColor)
                        drawSeg(ctx, lastX, currX, computeY(berStats[i-1+minI]/maxBer), computeY(berStats[i+minI]/maxBer), berColor)
                        drawSeg(ctx, lastX, currX, computeY(uncStats[i-1+minI]/maxUnc), computeY(uncStats[i+minI]/maxUnc), uncColor)

                        avgSig += signalStats[i]
                        avgSnr += snrStats[i]
                        avgBer += berStats[i]
                        avgUnc += uncStats[i]
                    }

                    // Calculate average and convert to percent
                    avgSig = Math.round(100*avgSig/len/maxSig)
                    avgSnr = Math.round(100*avgSnr/len/maxSnr)
                    avgBer = Math.round(100*avgBer/len/maxBer)
                    avgUnc = Math.round(100*avgUnc/len/maxUnc)

                    // Legend
                    var legX = 0
                    var sigStr = qsTr("SIGNAL STRENGTH") + application.emptyString
                    drawLegendItem(ctx, legX, computeY(avgSig/100), sigColor, sigStr, avgSig)
                    var snrStr = qsTr("SIGNAL TO NOISE") + application.emptyString
                    drawLegendItem(ctx, legX, computeY(avgSnr/100), snrColor, snrStr, avgSnr)
                    var berStr = qsTr("BIT ERROR RATE") + application.emptyString
                    drawLegendItem(ctx, legX, computeY(avgBer/100), berColor, berStr, avgBer)
                    var uncStr = qsTr("UNCORRECTED ERRORS") + application.emptyString
                    drawLegendItem(ctx, legX, computeY(avgUnc/100), uncColor, uncStr, avgUnc)
                }

                onPaint: {
                    paintNextSeg()
                }
            }
        }
    }

    Process {
        id: collectSignalData
        program: root.signalProgram
        arguments: ["-c","/data/channels.conf", root.currentChannelName]

        property string parseLine
        property string leftover

        onReadyReadStandardError: {
            var stdErr = collectSignalData.readAllStandardError()
            console.log("collectSignalData stderr:",stdErr)
        }

        onReadyReadStandardOutput: {
            parseLine += readAllStandardOutput()
            var isRemainder = false
            if(parseLine[parseLine.length-1] !== '\n'){
                print("leftovers: " )
                isRemainder = true
            }
            var lines = parseLine.split(/\n/)
            var linecount = lines.length
            if(isRemainder)
                linecount--

            // Parse each line
            for(var i=0 ; i < linecount ; i++) {
                var line = lines[i]

                print(line.length + " line:"+ line)
                if( line.length <= 0 )
                    continue

                //status 1f | signal ee13 | snr 0163 | ber ffffffff | unc 000000ff | FE_HAS_LOCK
                var parts = line.split(/\|/)
                if(parts.length <= 5)
                    continue // Not a status line

                root.statusStr = parts[5];
                var status = parts[0].split(" ")[1]
                if(status !== "1f")
                    continue // Hasn't tuned yet

                var sig = parseInt(parts[1].split(" ")[2],16)
                var snr = parseInt(parts[2].split(" ")[2],16)
                var ber = parseInt(parts[3].split(" ")[2].slice(0,4),16)
                var unc = parseInt(parts[4].split(" ")[2],16)

                signalStats.push(sig)
                snrStats.push(snr)
                berStats.push(ber)
                uncStats.push(unc)
            }

            // save remainder partial line for next i/o event
            parseLine = ""
            if(isRemainder) {
                print("remainder:" + lines[linecount])
                parseLine = lines[linecount]
            }

            if(signalStats.length > 1 && root.collectingData) {
                root.collectingData = false
                console.log("Finished collecting signal data")
            }

            signalStatsGraph.requestPaint()
        }

        onStarted: {
            console.log("Collecting signal data for channel: " + root.currentChannelName + " with args " + collectSignalData.arguments)
            root.collectingData = true
            signalStats = []
            snrStats = []
            berStats = []
            uncStats = []
        }

        onFinished: {
            root.collectingData = false
        }
    }

    Rectangle {
        id: rightControlArea

        width: 0.25 * root.width
        height: channelListBox.height
        color: "#7f8082"
        anchors { left: channelListBox.right; top: parent.top; topMargin: 80 * main.vScaleFactor }

        Item {
            id: previewTv

            width: 0.9 * parent.width
            height: width/tv.aspect
            anchors { top: parent.top; right: parent.right; margins: 0.05 * parent.width }
            anchors.topMargin: 0.05 * parent.width

            Component.onCompleted: {
                tv.viewParent = previewTv
                tv.changeParent(previewTv)

                // Disable CC and FullScreen
                tv.playerOnly = true
            }

            function previewChannel(index) {
                var mrl=tv.channelList.getMrl(index)
                tv.on = true
                tv.mrl = mrl
                tv.currentChannel = index
            }

            function pausePreview() {
                tv.on = false
            }

            function resumePreview() {
                tv.on = true
            }
        }

        Column {
            id: touchControls

            anchors {
                top: rightControlArea.top;
                topMargin: 125 * main.vScaleFactor
                left: rightControlArea.left
                leftMargin: 0.05 * width
            }
            width: rightControlArea.width
            height: rightControlArea.height
            spacing: 20 * main.vScaleFactor
            z: 1000//parent.z + 1

            StandardButton {
                id: deleteChannelButton
                visible: tv.channelList.channelCount > 0
                buttonText: qsTr("Delete Channel") + application.emptyString
                width: 0.9 * parent.width
                height: 51 * main.vScaleFactor
                label.font { pixelSize: 12 * main.vScaleFactor }
                onClicked: {
                    deletePopup.show()
                }
            }

            StandardButton {
                id: addChannelButton
                visible: !options.iptvEnabled
                buttonText: qsTr("Add Analog Channel") + application.emptyString
                width: 0.9 * parent.width
                height: 51 * main.vScaleFactor
                label.font { pixelSize: 12 * main.vScaleFactor }
                onClicked: {
                    addChannelLoader.loadItem()
                }
            }

            StandardButton {
                id: iptvAddButton
                visible: options.iptvEnabled
                buttonText: qsTr("Add Channel") + application.emptyString
                width: 0.9 * parent.width
                height: 51 * main.vScaleFactor
                label.font { pixelSize: 12 * main.vScaleFactor }
                onClicked: {
                }
            }

            StandardButton {
                id: signalButton
                buttonText: qsTr("Show Signal Data") + application.emptyString
                width: 0.9 * parent.width
                height: 51 * main.vScaleFactor
                enabled: root.signalProgram !== ""
                label.font { pixelSize: 12 * main.vScaleFactor }
                onClicked: {
                    signalDataPopup.show()
                }
            }

            Checkbox {
                id: selectMultipleCheckbox
                visible: tv.channelList.channelCount>0
                label: qsTr("Select Multiple Channels")
                width: 0.9 * parent.width
                height: 30 * main.vScaleFactor
                font.pixelSize: 12 * main.vScaleFactor
                onValueChanged: channelListBox.multipleSelectEnabled = value
            }

            StandardButton {
                id: deleteSelectedBtn
                width: 0.9 * parent.width
                height: 70* main.vScaleFactor
                visible: tv.channelList.channelCount > 0 && channelListBox.multipleSelectEnabled

                buttonText: qsTr("Delete Selected Channels") + application.emptyString
                label.font.pixelSize: 12 * main.vScaleFactor

                onClicked: {
                    deleteSelectedPopup.show()
                }
            }
        }
    }

    // When scan is complete, show how many services were found.
    Text {
        id: channelsFoundText
        text: {
            if (channelListBox.channelListGrid.count > 0)
                return qsTr("Number of Channels:") + " " + channelListBox.channelListGrid.count + application.emptyString
            else
                return qsTr("No Channels Configured") + application.emptyString
        }
        anchors.bottom: channelListBox.top
        anchors.bottomMargin: 15 * main.vScaleFactor
        anchors.left: channelListBox.left
        font { pixelSize: 18 * main.vScaleFactor; bold: true }
    }

    FileIO {
        id: fileio
    }
}
