import QtQuick 2.12
import Components 1.0
import "../string_format.js" as Format
import ".."


Item {
    id: root
    anchors.fill: parent
    state: ""

    property int itemSpacing: 10 * main.vScaleFactor

    property int cooltime
    property int workouttimemax
    property int workoutsetuptimeout
    property int workoutsummarytimeout
    property int personpresenttimeout
    property bool languageDiagnosticMenu: false
    property int nouserdetecteddialogtimeout
    property int resumeworkouttimeout
    property bool userPresentDetection
    property int erpTimeout

    property bool datadirty: false

    signal close()

    onCooltimeChanged:{coolTimeControl.value = cooltime}
    onWorkoutsetuptimeoutChanged: {workoutSetupTimeoutControl.value = workoutsetuptimeout}
    onWorkouttimemaxChanged: {workoutTimeMaxControl.value = workouttimemax}
    onWorkoutsummarytimeoutChanged: {workoutSummaryTimeoutControl.value = workoutsummarytimeout}
    onPersonpresenttimeoutChanged: {personPresentTimeoutControl.value = personpresenttimeout}
    onNouserdetecteddialogtimeoutChanged: {noUserDetectedDialogTimeoutControl.value = nouserdetecteddialogtimeout}
    onResumeworkouttimeoutChanged: {resumeWorkoutTimeoutControl.value = resumeworkouttimeout}
    onUserPresentDetectionChanged: {userPresentDetectionToggle.value = userPresentDetection}
    onErpTimeoutChanged: {erpTimeoutControl.value = erpTimeout}

    Component.onCompleted: {
        cooltime = options.cooldownTime
        workouttimemax = options.workoutTimeMax
        workoutsetuptimeout = options.workoutSetupTimeout
        workoutsummarytimeout = options.workoutSummaryTimeout
        personpresenttimeout = options.personPresentTimeout
        nouserdetecteddialogtimeout = options.noUserDetectedDialogTimeout
        resumeworkouttimeout = options.resumeWorkoutTimeout
        userPresentDetection = options.ppdEnabled
        erpTimeout = options.erpTimeout
    }

    Column {
        id: controlList
        spacing: itemSpacing

        anchors.horizontalCenter: root.horizontalCenter
        anchors.verticalCenter: root.verticalCenter
        width: root.width * 0.8
        height: root.height * 0.8

        SliderControlLabeled{
            id: coolTimeControl
            headingString: qsTr("Cooldown Time") + application.emptyString
            minValue: 0
            maxValue: 300
            stepValue: 60
            displayValue: Format.formatTimeStringMinAndSec(value)
            onValueChanged:
            {
                options.cooldownTime = value
                datadirty = true
            }
        }

        SliderControlLabeled{
            id: workoutTimeMaxControl
            headingString: qsTr("Maximum Workout Time") + application.emptyString
            minValue: 5
            maxValue: 99
            stepValue: 1
            displayValue: Format.formatTimeStringMinAndSec(value*60)
            onValueChanged:
            {
                options.workoutTimeMax = value
                datadirty = true
            }
        }

        SliderControlLabeled{
            id: workoutSetupTimeoutControl
            headingString: qsTr("Workout Setup Timeout") + application.emptyString
            minValue: 0
            maxValue: 120
            stepValue: 15
            displayValue: value ? Format.formatTimeStringMinAndSec(value) : qsTr("OFF") + application.emptyString
            onValueChanged:
            {
                options.workoutSetupTimeout = value
                datadirty = true
            }
        }

        SliderControlLabeled{
            id: workoutSummaryTimeoutControl
            headingString: qsTr("Workout Summary Timeout") + application.emptyString
            minValue: 0
            maxValue: 120
            stepValue: 15
            displayValue: value ? Format.formatTimeStringMinAndSec(value) : qsTr("OFF") + application.emptyString
            onValueChanged:
            {
                options.workoutSummaryTimeout = value
                datadirty = true
            }
        }

        SliderControlLabeled{
            id: resumeWorkoutTimeoutControl
            visible: true
            headingString: qsTr("Pause Timer") + application.emptyString
            minValue: 0
            maxValue: 60
            stepValue: 15
            displayValue: value ? Format.formatTimeStringMinAndSec(value) : qsTr("OFF") + application.emptyString
            onValueChanged:
            {
                options.resumeWorkoutTimeout = value
                datadirty = true
            }
        }

        SliderControlLabeled{
            id: erpTimeoutControl
            visible: options.erpEnabled && main.erpIsSupported
            height: visible ? 60 : 0
            headingString: qsTr("Energy Saving Timer") + application.emptyString
            minValue: 900    // 15mins
            maxValue: 7200   // 2hrs(120mins)
            stepValue: 900   // 15mins
            displayValue: value ? Format.formatTimeStringMinAndSec(value) : qsTr("OFF") + application.emptyString
            onValueChanged:
            {
                options.erpTimeout = value
                datadirty = true
            }
        }

        ButtonControlLabeled{
            id: erpTest
            opacity: diagnosticsMain.accessLevel >= 1 ? 1 : 0
            width: 0.8 * parent.width
            height: visible && opacity > 0 ? 60 * main.vScaleFactor : 0

            labelString: qsTr("ERP Test") + application.emptyString

            buttonEnabled: options.erpEnabled && main.erpIsSupported

            onButtonPressed: {
                console.debug("Sleep Test")
                nucleus.erpSleep()
            }
        }

        Checkbox {
            id: userPresentDetectionToggle
            visible: main.personPresentSupported()
            label: qsTr("User Present Detection") + application.emptyString
            width: parent.width
            value: options.ppdEnabled
            onPressed: {
                options.ppdEnabled = value ? true : false
                datadirty = true
            }
        }

        SliderControlLabeled{
            id: personPresentTimeoutControl
            visible: (main.personPresentSupported() && options.ppdEnabled === true)
            headingString: qsTr("User Present Detection TIMER 1") + application.emptyString
            minValue: 1
            maxValue: 300
            stepValue: 1
            displayValue: value ? Format.formatTimeStringMinAndSec(value + 10) : qsTr("OFF") + application.emptyString
            onValueChanged:
            {
                options.personPresentTimeout = value
                datadirty = true
            }
        }

        SliderControlLabeled{
            id: noUserDetectedDialogTimeoutControl
            visible: (main.personPresentSupported() && options.ppdEnabled === true)
            headingString: qsTr("User Present Detection TIMER 2") + application.emptyString
            minValue: 0
            maxValue: 60
            stepValue: 1
            displayValue: value ? Format.formatTimeStringMinAndSec(value) : qsTr("OFF") + application.emptyString
            onValueChanged:
            {
                options.noUserDetectedDialogTimeout = value
                datadirty = true
            }
        }

    }
}
