import QtQuick 2.12
import Components 1.0
import NetworkRequest 1.0
//import EGym 1.0
import "../Keypad"

Item {
    id: root

    anchors {
        fill: parent
        margins: 10  * main.hScaleFactor
    }

//    property string serverUrl: "https://partner.ed.ts.egym.coffee/api/v1/"
    property string serverUrl: "https://partner.api.egym.com/api/v1/"
    property alias rfidStr: rfidInput.text
    property alias resultsStr: results.text
    property int currCmd: 0
    property var trainingPlan
    property var locale: "en_US"

    ListModel {
        id: commands
        ListElement { cmd: 0; name: "Login RFID"; cmdUrl: "oauth/token" }
        ListElement { cmd: 1; name: "Login Password"; cmdUrl: "oauth/token" }
        ListElement { cmd: 2; name: "Get User Data"; cmdUrl: "users" }
        ListElement { cmd: 3; name: "Get Training Plans"; cmdUrl: "cardio/training-plans" }
        ListElement { cmd: 4; name: "Post Workout Data"; cmdUrl: "cardio/workouts" }
        ListElement { cmd: 5; name: "Get Points History"; cmdUrl: "points" }
        ListElement { cmd: 6; name: "Assign RFID"; cmdUrl: "oauth/token" }
        ListElement { cmd: 7; name: "Accept Terms & Conditions"; cmdUrl: "users/terms-and-conditions" }
        ListElement { cmd: 8; name: "Logout"; cmdUrl: "" }
    }

    function postData(cmd, cmdUrl) {
        var data = ""
        var jsonEncoded = false
        switch (cmd) {
        case 0:
            data += "grant_type=rfid"
            data += "&machine_type=" + machineinfo.productTypeString.toLocaleLowerCase()
            data += "&serial_number=" + main.serialNumber
            data += "&rfid=" + rfidStr
            data += "&rfid_format=" + "MIFARE"
            console.log("EGYM Test data: " + data + ", SN: " + main.serialNumber + ", Type: " + machineinfo.productTypeString.toLocaleLowerCase())
            break
        case 1:
            data += "grant_type=password"
            data += "&machine_type=" + machineinfo.productTypeString.toLocaleLowerCase()
            data += "&serial_number=" + main.serialNumber
            data += "&username=" + unameInput.text
            data += "&password=" + upassInput.text

            break
        case 4:
            var timestamp = Date.now()
            data += '{"exerciseName": "bike", "intervals": ['
            data += '{"distance": 354, "duration": 60000, "floors": 0, "heartRate": 95, "incline": 0, "kiloCalories": 6, "rampAngle": 0, "resistance": 1, "rotations": 52, "speed": 5.779816780090332, "stepHeight": 0, "steps": 0, "stepsPerMinute": 0, "strideLengthZone": 0, "watts": 69},'
            data += '{"distance": 257, "duration": 60000, "floors": 0, "heartRate": 115, "incline": 0, "kiloCalories": 3, "rampAngle": 0, "resistance": 1, "rotations": 51, "speed": 4.362502128601075, "stepHeight": 0, "steps": 0, "stepsPerMinute": 0, "strideLengthZone": 0, "watts": 20}],'
            data += '"startTimestamp": ' + timestamp + ', "trainingPlanExerciseId": 6362291329564672, "trainingPlanId": 4804910418231296, "uniqueExerciseId": "bike_interval1572968855638"}'
            jsonEncoded = true;
            break
        case 6:
            data += "{\"rfid\":\"" + rfidStr + "\",\"rfid_format\":\"MIFARE\"}"
            jsonEncoded = true;
            break
        default:
            return
        }

        netRequest.jsonEncoded = jsonEncoded
        netRequest.post(serverUrl + cmdUrl, data)
    }

    function fetchData(cmd, cmdUrl) {
        switch (cmd) {
        case 2:
            break
        case 3:
            break
        case 5:
            break
        default:
            return
        }

        netRequest.jsonEncoded = false
        netRequest.get(serverUrl + cmdUrl)
    }

    function putData(cmd, cmdUrl) {
        var data = ""
        if(cmd !== 7)
            return

        data += "locale=" + locale
        netRequest.jsonEncoded = false
        netRequest.put(serverUrl + cmdUrl, data)
    }

    function executeCmd(cmd, cmdUrl) {
        if(!eGym.enabled)
            return

        currCmd = cmd
        switch (cmd) {
        case 0:
        case 1:
        case 4:
        case 6:
            postData(cmd, cmdUrl)
            break
        case 2:
        case 3:
        case 5:
            fetchData(cmd, cmdUrl)
            break
        case 7:
            putData(cmd, cmdUrl)
            break
        case 8:
            netRequest.reset()
            break
        default:
            break
        }
    }

    NetworkRequest {
        id: netRequest
        trueUser: "true-fitness-demo"
        truePassword: "n2bRuoll4GF3wPmLhvU6IIyVuyQXUP35"
        onResponse: {
            netRequest.jsonEncoded = false
            if(data.length > 0) {
                var response = JSON.parse(data)
                resultsStr = JSON.stringify(response)
                console.log("Response", resultsStr)
                if(currCmd === 0 || currCmd === 1) {
                    netRequest.setAccessToken(response.access_token)
//                    netRequest.setAccessTokenType(response.token_type)
                    netRequest.setAccessTokenType("Bearer")
                } else if(currCmd === 2) {
                    locale = response.locale
                } else if(currCmd === 3)
                    trainingPlan = response.trainer
            } else {
                resultsStr = "No Response"
            }
        }
        onError: {
            console.log("Network error in netRequest. Error", errorCode)
            resultsStr = "Error: " + errorCode
        }
    }

    Column{
        id: headingSection

        anchors.top: parent.top
        anchors.left: parent.left
        anchors.right: parent.right
        height: 100 * main.vScaleFactor

        TextLabel{
            id: heading
            text: qsTranslate("Diagnostics", "EGym Test") + application.emptyString
            font.pixelSize: 36 * main.vScaleFactor
            anchors.horizontalCenter: parent.horizontalCenter
            color: main.colorFontDark
        }

        TextLabel{
            id:serialNumber
            font.pixelSize: 12 * main.vScaleFactor
            anchors.horizontalCenter: parent.horizontalCenter
            color: main.colorFontDark

            text:qsTr("Serial: ") + main.serialNumber + "   " + qsTr("Type: ") + machineinfo.productTypeString + application.emptyString
        }

        TextLabel {
            visible: !eGym.enabled
            font.pixelSize: 18 * main.vScaleFactor
            anchors.horizontalCenter: parent.horizontalCenter
            color: main.colorFontDark
            text: qsTr("EGym is disabled! Enable on Options Page.")
        }
    }

    ScrollBox {
        id: cmdList
        anchors {
            top: headingSection.bottom
            topMargin: 40 * main.vScaleFactor
            left: parent.left
            leftMargin: 40 * main.hScaleFactor
        }
        height: 0.25 * parent.height
        width: 0.5 * parent.width

        model: commands
        delegate: cmdDelegate

        Rectangle {
            color: "transparent"
            border.color: main.colorDiagnosticEdges
            anchors.fill: parent
            anchors.margins: -2*main.vScaleFactor
            z: parent.z-1
        }
    }

    Component {
        id: cmdDelegate
        Item {
            width: parent.width
            height: 25 * main.vScaleFactor

            Text {
                id: dataName
                width: 0.9 * parent.width
                height: parent.height
                anchors.left: parent.left
                anchors.leftMargin: 0.05 * parent.width
                text: model.name
                font.pixelSize: 14 * main.vScaleFactor
                color: main.colorFontDark
            }

            MouseArea {
                anchors.fill: parent
                onClicked: {
                    executeCmd(model.cmd, model.cmdUrl)
                }
            }
        }
    }

    Column {
        spacing: 10 * main.hScaleFactor
        anchors {
            top: cmdList.top
            left: cmdList.right
            leftMargin: 20 * main.hScaleFactor
            right: parent.right
            rightMargin: 40 * main.hScaleFactor
            bottom: cmdList.bottom
        }

        TextLabel {
            id: unameLabel

            width: parent.width
            font.pixelSize: 16 * main.vScaleFactor
            horizontalAlignment: Text.AlignLeft
            verticalAlignment: Text.AlignTop
            color: main.colorFontDark
            text: "Enter User Name:"
        }

        TextInput {
            id: unameInput

            width: parent.width
            text: "true-test2@egym.de"

            Rectangle {
                color: "transparent"
                border.color: main.colorDiagnosticEdges
                anchors.fill: parent
                anchors.margins: -2*main.vScaleFactor
                z: parent.z-1
            }
        }

        TextLabel {
            id: upassLabel

            width: parent.width
            font.pixelSize: 16 * main.vScaleFactor
            horizontalAlignment: Text.AlignLeft
            verticalAlignment: Text.AlignTop
            color: main.colorFontDark
            text: "Enter User Password:"
        }

        TextInput {
            id: upassInput
            width: parent.width
            text: "trueTest1234"

            Rectangle {
                color: "transparent"
                border.color: main.colorDiagnosticEdges
                anchors.fill: parent
                anchors.margins: -2*main.vScaleFactor
                z: parent.z-1
            }
        }

        TextLabel {
            id: rfidLabel

            width: parent.width
            font.pixelSize: 16 * main.vScaleFactor
            horizontalAlignment: Text.AlignLeft
            verticalAlignment: Text.AlignTop
            color: main.colorFontDark
            text: "Enter RFID in hex:"
        }

        TextInput {
            id: rfidInput
            width: parent.width
            text: "A2667D23"

            Rectangle {
                color: "transparent"
                border.color: main.colorDiagnosticEdges
                anchors.fill: parent
                anchors.margins: -2*main.vScaleFactor
                z: parent.z-1
            }
        }

    }

    TextLabel {
        id: resultsLabel
        text: qsTr("Results") + application.emptyString
        font.pixelSize: 24 * main.vScaleFactor
        anchors {
            top: cmdList.bottom
            topMargin: 20 * main.vScaleFactor
            left: parent.left
            leftMargin: 40 * main.hScaleFactor
            right: parent.right
            rightMargin: 40 * main.hScaleFactor
        }

        horizontalAlignment: Text.AlignHCenter
        verticalAlignment: Text.AlignVCenter
        color: main.colorFontDark
    }

    Rectangle {
        anchors {
            top: resultsLabel.bottom
            topMargin: 20 * main.vScaleFactor
            left: parent.left
            leftMargin: 40 * main.hScaleFactor
            right: parent.right
            rightMargin: 40 * main.hScaleFactor
            bottom: parent.bottom
            bottomMargin: 40 * main.vScaleFactor
        }
        color: "transparent"
        border.color: main.colorDiagnosticEdges

        ScrollBox {
            anchors.fill: parent
            anchors.margins: 2

            clip: true

            Text {
                id: results
                text: ""
                font.pixelSize: 14 * main.vScaleFactor
                anchors.top: parent.top
                anchors.left: parent.left
                anchors.right: parent.right
                color: main.colorFontDark
                wrapMode: Text.WrapAtWordBoundaryOrAnywhere
            }
        }
    }

    TrueKeyboard {
        id: keyboard
        width: root.width
        anchors.horizontalCenter: root.horizontalCenter
        z: 999999
        active: rfidInput.activeFocus || unameInput.activeFocus || upassInput.activeFocus
        useMain: false
    }
}
