import QtQuick 2.12
import Components 1.0
import ".."

Item{  // popup screen lock
    id: root

    property int timeLeft: 5
    property int lockTime: 20    // number of seconds for screen lock

    anchors.fill: parent
    visible: false
    z:99 // ensure that the screenlock is on top of everything else

    Rectangle {
        anchors { horizontalCenter: parent.horizontalCenter ; verticalCenter: parent.verticalCenter }
        width: 888 * main.hScaleFactor
        height: 653 * main.vScaleFactor
        color: main.colorDialogBackground
        border.color: main.colorUIBorder
        border.width: main.widthBorder

        TextLabel { // display screen lock message
            id: lock_message_text
            anchors { top: parent.top ; topMargin: 50 * main.vScaleFactor ; horizontalCenter: parent.horizontalCenter }
            text: qsTr("SCREEN LOCKED FOR CLEANING") + application.emptyString
            font.pixelSize: 40 * main.vScaleFactor
        }

        ScalableImage {
            id: lock_image
            anchors { verticalCenter: parent.verticalCenter ; left: parent.left ; leftMargin: -30 * main.hScaleFactor }
            width: sourceSize.width * main.hScaleFactor
            height: sourceSize.height * main.vScaleFactor
            sourceName: "HomeScreen/LOCK_ICON";
        }

        NumberLabel { // display of remaining lock seconds
            id: lock_countdown_text
            anchors { top: lock_message_text.bottom; topMargin: 150 * main.vScaleFactor; right: parent.right; rightMargin: 170 * main.hScaleFactor }
            text: ((root.timeLeft > 9)? ":":":0") + screen_lock_overlay.timeLeft  // display leading zero if val > 9
            font.pixelSize: 132 * main.vScaleFactor
        }
    }

    Timer { // count down every second while screen is locked
        id: lock_timer
        interval: 1000 ; repeat: true ; running: false
        onTriggered: {
            // timeLeft is displayed above
            screen_lock_overlay.timeLeft = screen_lock_overlay.timeLeft - 1
            if(screen_lock_overlay.timeLeft <= 0 ) {
                // close the screen lock overlay
                screen_lock_overlay.visible = false
                lock_timer.stop()
                keymapper.keysEnabled = true
            }
        }
    }

    MouseArea { // overlay a mouse area to prevent activating anything underneath
        id: lock_popup
        anchors.fill: parent
    }

    function open() {
        timeLeft = lockTime
        screen_lock_overlay.visible = true
        lock_timer.start()
        keymapper.keysEnabled = false
    }
}
