import QtQuick 2.12
import ".."
import Components 1.0

ModalDialog {
    id: root
    isTop: false
    isTransparent: true
    visible: true
    state: "idle"
    opacity: 1.0
    anchors.fill: parent
    backgroundColor: main.state == "HomeState" || main.state == "SetupState" ? main.colorDialogBackground : main.colorButtonBackground
    border.color: main.state == "HomeState"  || main.state == "SetupState" ? main.colorUIBorder : "transparent"
    property bool isDiscovering: bluetoothAdapter.nonLeScan
    property bool isLowEnergy: false

    signal closed()
    signal deviceConnected()
    signal deviceDisconnected()
    signal headsetConnected()
    signal headsetDisconnected()

    Component.onCompleted: {
        root.state = "list"
    }

    onVisibleChanged: {
        console.debug("Prev State: "+state)
        var prev_state = state
        state = "list"
        if(visible) {
            if(isLowEnergy == false){
                if(!bluetoothAdapter.discovering){
                    bluetoothAdapter.startDiscovery(true)
                }
            } else {
                console.debug("Low Energy scan")
                bluetoothLEAdapter.scan()
            }
        } else {
            if(isLowEnergy == false){
                if(bluetoothAdapter && bluetoothAdapter.discovering){
                    bluetoothAdapter.stopDiscovery()
                }
            } else { //Low Energy
                console.debug("onVisibleChanged: Stop Scan")
                bluetoothLEAdapter.stopScan(false)
                if(prev_state == "disconnecting"){
                 console.debug("onvisablechanged: caught disconnect case")
                 visible = true
                    state = "disconnecting"
                } else {
                    root.closed()
                }
            }
        }
    }

    Connections{
        target: heartRateManager
        onDeviceSelected: {
            hide();
            bluetoothAdapter.reconnect()
        }

        onNoneSelected: {
            bluetoothLEAdapter.abortConnections()
            if(bluetoothLEAdapter.hrConnected == true) {
                bluetoothLEAdapter.disconnect(bluetoothLEAdapter.deviceMAC,bluetoothLEAdapter.hrHandle)
            }
            bluetoothAdapter.reconnect()
        }
    }

    Connections{
        target: workoutScreen
        onWorkoutStopped: {
            if(bluetoothLEAdapter.scanning){
                bluetoothLEAdapter.stopScan(true)
            }

            bluetoothLEAdapter.abortConnections()

            if(heartRateManager.currentBtAddress !== ""){
                console.debug("Bluetooth HR disconnect")
                bluetoothLEAdapter.disconnect(bluetoothLEAdapter.deviceMAC,bluetoothLEAdapter.hrHandle)
            }
            hide();
        }
    }

    Connections{
        target: mainProgItem
        onOpacityChanged: {
            if(mainProgItem.opacity == 0){
                hide()
            }
        }
    }

    Connections{
        target: bluetoothLEAdapter

        onConnectingChanged: {
            console.debug("connecting changed: " + bluetoothLEAdapter.connecting)
            if(bluetoothLEAdapter.connecting) {
                root.state = "connecting"
            }
        }
        onReadHRChanged: {
        }

        onConnected: {
            bluetoothLEAdapter.hrConnected=true
        }
        onScanningChanged: {
            console.debug("scanning changed: " + bluetoothLEAdapter.scanning)
            if(bluetoothLEAdapter.scanning == false)
                if(heartRateManager.deviceCount === 0){
                    root.state = "notfound"
                } else {
                    root.state = "list"
                }
        }


        onHrDisconnecting:{
            console.debug("BLE disconnecting signal received, deviceMAC = " + bluetoothLEAdapter.deviceMAC)
            root.state = "disconnecting"
            disconnectionTimeoutTimer.start()
        }

        onHrDisconnectingComplete:{
            console.debug("disconnectingComplete signal received")
            bluetoothLEAdapter.hrConnected = false
            hide()
        }

        onHrConnectionFailed: {
            hide()
        }
    }

    Timer{
        id: disconnectionTimeoutTimer
        interval: 5000
        repeat: false
        onTriggered: {
            if(bluetoothLEAdapter.hrConnected == true)
                console.debug("disconnectionTimeoutTimer: Timeout triggered")
                bluetoothLEAdapter.hrDisconnectingComplete()
        }
    }

    Item {
//        id: btStatusDialogborder
        z: root.z + 1
        anchors.fill: parent

        Item {
            id: btPairingItems
            visible: false
            anchors.fill: parent

            TextLabel {
                id: btPairCodeText
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.verticalCenter: parent.verticalCenter
                anchors.verticalCenterOffset: -implicitHeight / 2
                width: parent.width

                text: qsTr("CONFIRM ON DEVICE:") + application.emptyString
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                font.pixelSize: parent.height * 0.10
            }
            NumberLabel {
                id: btPairCodeKeyText
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.verticalCenter: parent.verticalCenter
                anchors.verticalCenterOffset: implicitHeight / 2
                width: parent.width
                text: ""
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                font.pixelSize: parent.height * 0.10
            }
        }

        Item{
            id: btDeviceListBox
            visible: false
            anchors.fill: parent

            TextLabel{
                id: btSelectDeviceText
                text: qsTr("SELECT YOUR HEART RATE DEVICE:") + application.emptyString
                width: listArea.width
                height: parent.height * 0.1
                wrapMode: Text.WordWrap
                anchors.top: parent.top
                anchors.left: parent.left
                anchors.right: listArea.left
                anchors.rightMargin: 40 * main.hScaleFactor
                anchors.topMargin: 40 * main.vScaleFactor
                anchors.leftMargin: 40 * main.hScaleFactor

                font.pixelSize: height * 0.45
            }

            /*Item {
                id: scanningAnimation
                height: 58
                width: 108
                anchors.horizontalCenter: parent.left
                anchors.horizontalCenterOffset: 100
                anchors.verticalCenter: parent.verticalCenter

                ScalableImage{
                    id: scanningBluetoothWave
                    property int opacityInteger: 0
                    anchors.fill: parent
                    anchors.verticalCenter: parent.verticalCenter
                    anchors.horizontalCenter: parent.horizontalCenter
                    opacity: opacityInteger / 100.0
                    visible: waveAnimation.running
                    NumberAnimation on opacityInteger {
                        id: waveAnimation
                        from: 0;
                        to: 100;
                        duration: 500
                        running : bluetoothLEAdapter.scanning
                        loops: Animation.Infinite
                    }
                    
                    //source: "graphics/Bluetooth/Bluetooth_waves.png"
                    sourceBase: "graphics/"
                    sourceName: "Bluetooth/Bluetooth_waves"
                }
                ImageButton{
                    id: scanningBluetoothIcon
                    anchors.verticalCenter: parent.verticalCenter
                    anchors.horizontalCenter: parent.horizontalCenter
                    upimage: "graphics/Bluetooth/Bluetooth_icon_medium.png"
                    downimage: upimage
                }

            }*/

            Rectangle {
                id: listArea

                color: main.state == "HomeState" || main.state == "SetupState" ? main.colorToolbarBackground : main.colorDialogBackground
                width: 268 * main.vScaleFactor
                height: parent.height * 0.638
                anchors.top: parent.top
                anchors.topMargin: 40 * main.vScaleFactor
                anchors.right: parent.right
                anchors.rightMargin: 40 * main.hScaleFactor

                ListView {
                    id: bluetoothDeviceListView
                    spacing: 2 * main.vScaleFactor
                    anchors.fill: parent
                    anchors.margins: 10 * main.vScaleFactor
                    clip: true

                    interactive: true
                    model: heartRateManager.wirelessSourceList

                    property int _pendingIndex: -1

                    delegate: Component {
                        Item{
                            id: listItem
                            function pressed(index) {
                                console.debug("index pressed: " + index)
                                bluetoothDeviceListView.currentIndex = index
                                heartRateManager.selectIndex(index)
                            }
                            height: 40
                            width: parent.width

                            Connections {
                                target: bluetoothLEAdapter
                                onScanStopCompleted: {
                                    console.debug("index: "+bluetoothDeviceListView._pendingIndex +" " + index )
                                    if(bluetoothDeviceListView._pendingIndex === index) {
                                        listItem.pressed(index)
                                    }
                                }
                            }
                            Rectangle {
                                color: bluetoothDeviceListView.currentIndex === index ? main.colorHighlightBackground : main.colorButtonBackground
                                height: parent.height
                                width: parent.width * 0.9
                                radius: main.defaultRadius
                                border.color: main.colorUIBorder
                                border.width: main.widthBorder
                                anchors.horizontalCenter: parent.horizontalCenter
                                Text {
                                    text: modelData
                                    color: main.colorFontLight
                                    font.pixelSize: parent.height * 0.45
                                    verticalAlignment: Text.AlignVCenter
                                    anchors.left: parent.left
                                    anchors.leftMargin: 10 * main.scaleFactor
                                    anchors.verticalCenter: parent.verticalCenter
                                }
                                MouseArea {
                                    anchors.fill: parent
                                    onClicked: {
                                        bluetoothLEAdapter.stopScan(true)
                                        bluetoothDeviceListView._pendingIndex = index
                                        console.debug("Stop the Scan")
                                        buzzer.buttonPress()
                                    }
                                    Rectangle {
                                        anchors.fill: parent
                                        color: main.colorGenericStimulusArea
                                        opacity: 0.3
                                        visible: main.showStimulusArea
                                    }
                                }
                            }
                        }
                    }
                }

            }
            StandardButton {
                id: connectButton
                width: 138 * main.hScaleFactor
                height: 79 * main.vScaleFactor
                anchors.horizontalCenter: listArea.horizontalCenter
                anchors.top: listArea.bottom
                anchors.topMargin: 10 * main.vScaleFactor
                visible: root.pairingAllowed == true && bluetoothDeviceListView.model.count > 0 && bluetoothDeviceListView.currentIndex != -1

                sourceName: "Bluetooth/BluetoothIcon";
                buttonText: qsTr("CONNECT")

                onClicked: {
                    bluetoothLEAdapter.stopScan(true)
                    console.debug("Stop the Scan")
//                        root.state = "gettingpairingcode"
//                        bluetoothAdapter.connect(bluetoothDeviceListView.model.getItem(bluetoothDeviceListView.currentIndex))
                }
            }
            Item {
                id: btDeviceListArrows

                width: 40
                height: 160
                visible: true
                anchors {
                    left: listArea.right
                    verticalCenter: listArea.verticalCenter
                }

                ScalableImage {
                    id: dataUpArrow
                    visible: bluetoothDeviceListView.contentY > 30
                    rotation: 90
                    anchors.top: parent.top
                    sourceName: "Swipe_Arrows_Left";
                }
                ScalableImage {
                    id: dataDownArrow
                    visible: bluetoothDeviceListView.contentHeight - bluetoothDeviceListView.height - bluetoothDeviceListView.contentY > 10
                    rotation: -90
                    anchors.bottom: parent.bottom
                    anchors.bottomMargin: 20
                    sourceName: "Swipe_Arrows_Left";
                }
            }
        }

        TextLabel {
            id: btGettingPairingCodeText
            visible: false
            anchors.fill: parent
            text: qsTr("GETTING PAIRING CODE...") + application.emptyString
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            wrapMode: Text.WordWrap
            font.pixelSize: parent.height * 0.15
        }

        Item {
            id: btNoDeviceFoundItem
            visible: false
            anchors.fill: parent
            Text {
                id: btNoDeviceFoundText
                anchors.top: parent.top
                anchors.topMargin: parent.height * 0.08
                anchors.horizontalCenter: parent.horizontalCenter
                width: parent.width * 0.8
                color: "white"
                text: qsTr("No Heart Rate Device Found") + application.emptyString
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                font.bold: false
                font.pixelSize: parent.height * 0.10
            }

            StandardButton {
                id: scanButton
                width: 138 * main.hScaleFactor
                height: 79 * main.vScaleFactor
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.top: btNoDeviceFoundText.bottom
                anchors.topMargin: parent.height * 0.1
                visible: true
                buttonText: qsTr("Rescan") + application.emptyString
                onClicked: {
                    root.state = "list"
                    bluetoothLEAdapter.scan()
                }
                icon.sourceName: "Bluetooth/Bluetooth_waves_medium"
            }
        }



        TextLabel {
            id: btConnectingText
            visible: false
            anchors.fill: parent
            text: qsTr("CONNECTING TO BLUETOOTH DEVICE...") + application.emptyString
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            wrapMode: Text.WordWrap
            font.pixelSize: parent.height * 0.15
        }

        TextLabel {
            id: btDisconnectingText
            visible: false
            anchors.fill: parent
            text: qsTr("DISCONNECTING FROM BLUETOOTH DEVICE...") + application.emptyString
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            wrapMode: Text.WordWrap
            font.pixelSize: parent.height * 0.15
        }

        // close button
        CloseButton {
            id: btExitButton

            z: 200

            anchors {
                left: parent.left
                leftMargin: 40 * main.hScaleFactor
                bottom: parent.bottom
                bottomMargin: 40 * main.vScaleFactor
            }

            onClicked: {
                bluetoothDeviceListView._pendingIndex = -1
                if(bluetoothAdapter.pairing == true){
                    bluetoothAdapter.cancelDeviceCreation()
                }
                if(btConnectingText.visible){
                    console.debug("Kill on connected set")
                    killOnConnect = true
                    root.state = "disconnecting"
                }
                else{
                    root.state = "list"
                    root.closed()
                }

            }
        }
    }

    states: [
        State{
            name: "idle"
            PropertyChanges {target: btPairingItems; visible: false}
            PropertyChanges {target: btDeviceListBox; visible: false}
            PropertyChanges {target: btConnectingText; visible: false}
            PropertyChanges {target: btExitButton; visible: false}
            PropertyChanges {target: btDisconnectingText; visible: false}
            PropertyChanges {target: btGettingPairingCodeText; visible: false}            
            PropertyChanges {target: btNoDeviceFoundItem; visible: false}

        },
        State{
            name: "notfound"
            PropertyChanges {target: btPairingItems; visible: false}
            PropertyChanges {target: btDeviceListBox; visible: false}
            PropertyChanges {target: btConnectingText; visible: false}
            PropertyChanges {target: btExitButton; visible: true}
            PropertyChanges {target: btDisconnectingText; visible: false}
            PropertyChanges {target: btGettingPairingCodeText; visible: false}
            PropertyChanges {target: btNoDeviceFoundItem; visible: true}
        },
        State{
            name: "list"
            PropertyChanges {target: btPairingItems; visible: false}
            PropertyChanges {target: btDeviceListBox; visible: true}
            PropertyChanges {target: btConnectingText; visible: false}
            PropertyChanges {target: btExitButton; visible: true}
            PropertyChanges {target: btDisconnectingText; visible: false}
            PropertyChanges {target: btGettingPairingCodeText; visible: false}
            PropertyChanges {target: btNoDeviceFoundItem; visible: false}
        },
        State{
            name: "pairing"
            PropertyChanges {target: btPairingItems; visible: true}
            PropertyChanges {target: btDeviceListBox; visible: false}
            PropertyChanges {target: btConnectingText; visible: false}
            PropertyChanges {target: btExitButton; visible: true}
            PropertyChanges {target: btDisconnectingText; visible: false}
            PropertyChanges {target: btGettingPairingCodeText; visible: false}
            PropertyChanges {target: btNoDeviceFoundItem; visible: false}
        },
        State{
            name: "connecting"
            PropertyChanges {target: btPairingItems; visible: false}
            PropertyChanges {target: btDeviceListBox; visible: false}
            PropertyChanges {target: btConnectingText; visible: true}
            PropertyChanges {target: btExitButton; visible: true}
            PropertyChanges {target: btDisconnectingText; visible: false}
            PropertyChanges {target: btGettingPairingCodeText; visible: false}
            PropertyChanges {target: btNoDeviceFoundItem; visible: false}
        },
        State{
            name: "disconnecting"
            PropertyChanges {target: btPairingItems; visible: false}
            PropertyChanges {target: btDeviceListBox; visible: false}
            PropertyChanges {target: btConnectingText; visible: false}
            PropertyChanges {target: btExitButton; visible: false}
            PropertyChanges {target: btDisconnectingText; visible: true}
            PropertyChanges {target: btGettingPairingCodeText; visible: false}
            PropertyChanges {target: btNoDeviceFoundItem; visible: false}
        },
        State{
            name: "gettingpairingcode"
            PropertyChanges {target: btPairingItems; visible: false}
            PropertyChanges {target: btDeviceListBox; visible: false}
            PropertyChanges {target: btConnectingText; visible: false}
            PropertyChanges {target: btExitButton; visible: false}
            PropertyChanges {target: btDisconnectingText; visible: false}
            PropertyChanges {target: btGettingPairingCodeText; visible: true}
            PropertyChanges {target: btNoDeviceFoundItem; visible: false}
        }
    ]

    function paddy(n, p, c){
        var pad_char = typeof c !== 'undefined' ? c : '0';
        var pad = new Array(1+p).join(pad_char);
        return (pad+n).slice(-pad.length);
    }
}

