import QtQuick 2.12

//import VLCVideo 1.0
import Components 1.0
import "../BlueTooth"
import ".."

Item {

    id: root

    width: 907 * main.hScaleFactor
    height: 425 * main.vScaleFactor
    anchors.centerIn: parent

    // REQUIRED property: for translation to work (via qsTranslate), it must know where the external model is stored.
    // Without this you will likely see blank strings in your data table.
    property string sourceFile: "MediaBrowser"

    property int highlightedItem:1
    property bool isDialogVisible: false
    property bool isMenuVisible: bluetoothAdapter.currentConnectedDevice !== null && root.currentBtPlayer !== null ? !root.currentBtPlayer.isMenuItemAudio : true
    property variant menu
    property bool videoShown: false
    property bool viewShowing: false
    property bool allowFullscreen: false
    property variant currentBtPlayer: bluetoothAdapter.currentConnectedDevice !== null ? bluetoothAdapter.currentConnectedDevice.player : undefined
//    property bool ipodVideoShowing: false
    // possible dialogState values
    // - idle: mediaBrowserNoDeviceConnectedDialog is displayed
    // - connecting: btConnectionStatusDialog is displayed
    // - help: btHelpDialog is displayed
    // - connected: mediaBrowserNoDeviceConnectedDialog is displayed
    property string dialogState: ""
    property string baseState: main.state == "HomeState"  || main.state == "SetupState" ? "home" : "idle"
    property string connectionType: "none"
    property string deviceName: gem.advertisedName
    property bool isConnected: bluetoothAdapter.connected || bluetoothAdapter.connectedHeadset

    Component.onCompleted: {
        dialogState = bluetoothAdapter.currentConnectedDevice !== null ? (currentBtPlayer.isPlaying ? "connected" : baseState) : baseState
    }

    onDialogStateChanged: {
        if(dialogState === "home") {
            homeStatusDialog.visible=true
            btConnectionStatusDialog.hide()
            btHeadsetConnectionStatusDialog.hide()
            controlMenuItem.visible=false
            btHeartRateDialog.visible=false
        } else if(dialogState === "idle") {
            homeStatusDialog.visible=false
            btConnectionStatusDialog.show()
            btHeadsetConnectionStatusDialog.hide()
            controlMenuItem.visible=false
            btHeartRateDialog.visible=false
        } else if(dialogState === "ear") {
            homeStatusDialog.visible=false
            btConnectionStatusDialog.hide()
            btHeadsetConnectionStatusDialog.show()
            controlMenuItem.visible=false
            btHeartRateDialog.visible=false
        } else if(dialogState === "connecting") {
            homeStatusDialog.visible=false
            btConnectionStatusDialog.show()
            btHeadsetConnectionStatusDialog.hide()
            controlMenuItem.visible=false
            btHeartRateDialog.visible=false
        } else if(dialogState === "connected") {
            homeStatusDialog.visible=false
            btConnectionStatusDialog.hide()
            btHeadsetConnectionStatusDialog.hide()
            controlMenuItem.visible=true
            btHeartRateDialog.visible=false
        } else if(dialogState === "disconnecting") {
            homeStatusDialog.visible=false
            btConnectionStatusDialog.show()
            btHeadsetConnectionStatusDialog.hide()
            controlMenuItem.visible=false
            btHeartRateDialog.visible=false
        } else if(dialogState === "app") {
            homeStatusDialog.visible=true
            btConnectionStatusDialog.hide()
            btHeadsetConnectionStatusDialog.hide()
            controlMenuItem.visible=false
            btHeartRateDialog.visible=false
        } else if(dialogState === "hr") {
            homeStatusDialog.visible=false
            btConnectionStatusDialog.hide()
            btHeadsetConnectionStatusDialog.hide()
            controlMenuItem.visible=false
            btHeartRateDialog.visible=true
        }
    }

    function actionConnectionType(action)
    {
        switch (action) {
        case "audio":
            if(isConnected === false)
                dialogState = "idle"
            else
                dialogState = "connected"
            break;
        case "ear":
            if(isConnected === false)
                dialogState = "ear"
            else
                dialogState = "disconnecting"
            break;
        case "hr":
            dialogState = "hr"
            break;
        case"app":
            dialogState = "app"
            break;
        default:
            dialogState = baseState
            break;
        }
    }

    onConnectionTypeChanged: {
        actionConnectionType(connectionType)
    }

//    function toggleFullscreen() {
//        if (root.allowFullscreen) {
//            if (tv.player.fullscreen) {
//                fullscreenVideoFrame.endFullscreen()
//            } else {
//                fullscreenVideoFrame.showFullscreen(tv.player)
//            }
//        }
//    }

    function showVideo(show) {
        if(show) {
            tv.tuneChannelID("IPODINPUT")
            root.videoShown = true
        }
        else
            root.videoShown = false
    }

    function shown() {
        dialogState = baseState
        viewShowing = true
        if(audioManager.ipodPlaying)
            audioManager.ipodRequest()
        if(audioManager.ipodPlayingVideo) {
            // if an ipod video is already allowed and we're not showing it, show it.
            if(audioManager.ipodVideoAllowed) {
                root.showVideo(true)
            }
            else // request showing the videov
                audioManager.ipodVideoRequest()
        }
        if (audioManager.btconnected) {
            audioManager.btRequest()
        }

    }

    function hidden() {
        dialogState = baseState
        viewShowing = false
    }

    signal close()

    signal upPressed()
    signal downPressed()
    signal rightPressed()
    signal leftPressed()
    signal centerPressed()
    signal menuPressed()
    signal menuItemPressed(int index)
    signal playPausePressed()
    signal nextTrackPressed()
    signal previousTrackPressed()

    // mouse area to mask anything under this pop-up
    MouseArea {
        anchors.fill: parent
    }

    function getIndexFromMenuItem(i)
    {
        var item = ipodmenulistview.model.get(i)
        return item.index
    }

    Connections {
        target: root.viewShowing ? audioManager : null

        ignoreUnknownSignals: true

        onBtconnectedChanged: {
            if (audioManager.btconnected && viewShowing) {
                audioManager.btRequest()
            }
        }
    }

    function btControlsHandler(button){
        //root.currentBtPlayer.restartMenuTimer();
        if(root.currentBtPlayer.isMenu){
            switch(button){
            case "up":
                if(bt_menulistview.currentIndex > 0)
                    bt_menulistview.currentIndex--
                break;
            case "down":
                if(bt_menulistview.currentIndex + 1 < bt_menulistview.count)
                    bt_menulistview.currentIndex++
                break;
            case "left":
                root.currentBtPlayer.previousFolder()
                break;
            case "right":
                root.currentBtPlayer.selectItem(bt_menulistview.currentIndex)
                break;
            case "center":
                root.currentBtPlayer.selectItem(bt_menulistview.currentIndex)
                break;
            case "menu":
                root.currentBtPlayer.isMenu = false
                break;
            default:
                break;
            }
        } else {
            switch(button){
            case "up":
                root.currentBtPlayer.previousFolder()
                break;
            case "down":
                root.currentBtPlayer.selectItem(bt_menulistview.currentIndex)
                break;
            case "left":
                root.currentBtPlayer.previous()
                break;
            case "right":
                root.currentBtPlayer.next()
                break;
            case "center":
                if(root.currentBtPlayer.isPlaying){
                    root.currentBtPlayer.pause()
                }else{
                    root.currentBtPlayer.play()
                }
                break;
            case "menu":
                root.currentBtPlayer.isMenu = true
                break;
            default:
                break;
            }
        }
    }

    Rectangle {
        id: controlMenuItem
        visible: false
        anchors.fill: parent
        color: main.state == "HomeState" ? main.colorDialogBackground : main.colorButtonBackground
        border.color: main.state == "HomeState" ? main.colorUIBorder : "transparent"
        border.width: main.widthBorder

        // close button
        CloseButton {
            id: close_button

            z: 200

            anchors {
                left: parent.left
                leftMargin: 40 * main.hScaleFactor
                bottom: parent.bottom
                bottomMargin: 40 * main.vScaleFactor
            }

            onClicked: {
                if(bluetoothAdapter.connected === false) {
                    dialogState = "idle"
                } else {
                    dialogState = "connected"
                }

                root.close()
            }
        }

        Row {
            anchors.centerIn: parent
            anchors.margins: 40 * main.scaleFactor
            spacing: 20 * main.hScaleFactor

            StandardButton {
                id: up_button
                width: 80 * main.hScaleFactor
                height: 50 * main.vScaleFactor
                anchors.verticalCenter: parent.verticalCenter
                sourceName: "Media/Back_Triangle"
                onClicked: btControlsHandler("up")
            }

            ListModel {
                id: testModel
                ListElement {name: "ABBA"; type: "folder"}
                ListElement {name: "The Animals"; type: "folder"}
                ListElement {name: "Black Sabbath"; type: "folder"}
                ListElement {name: "The Black Keys"; type: "folder"}
                ListElement {name: "Bob Dylan"; type: "folder"}
                ListElement {name: "Corrosion of Conformity"; type: "folder"}
                ListElement {name: "The Cult"; type: "folder"}
                ListElement {name: "Song 1"; type: "folder"}
                ListElement {name: "Song 2"; type: ""}
                ListElement {name: "Song 3"; type: ""}
                ListElement {name: "Song 4"; type: ""}
                ListElement {name: "Song 5"; type: ""}

            }

            Item {
                id: new_bt_menu
                width: 280 * main.hScaleFactor
                height: root.height * 0.638

                Rectangle {
                    anchors.fill: parent
                    color: main.state == "HomeState" ? main.colorToolbarBackground : main.colorDialogBackground
                }

                TextLabel {
                    anchors.centerIn: parent
                    visible: root.currentBtPlayer !== undefined && bt_menulistview.model !== null && bt_menulistview.model.count === 0
                    text: qsTr("No Menu Available") + application.emptyString
                    wrapMode: Text.WordWrap
                }

                NowPlayingControl {
                    id: bt_now_playing
                    opacity: 1.0
                    anchors.fill: parent

                    visible: !isMenuVisible
                    // connect data model for song meta-data here (duration, title, etc.)
                    duration: root.currentBtPlayer ? root.currentBtPlayer.duration / 1000 : 0
                    //title: title
                    title: root.currentBtPlayer && root.currentBtPlayer.title !== "" ? root.currentBtPlayer.title : "Title info not available"
                    artist: root.currentBtPlayer && root.currentBtPlayer.artist !== "" ? root.currentBtPlayer.artist : "Artist info not available"
                    album: root.currentBtPlayer && root.currentBtPlayer.album !== "" ? root.currentBtPlayer.album : "Album info not available"
                    position: root.currentBtPlayer ? root.currentBtPlayer.position / 1000 : 0

                    //visible: false //bluetoothAdapter.connected && root.currentBtPlayer && root.currentBtPlayer.isPlaying
                }

                ListView {
                    id: bt_menulistview

                    anchors.fill: parent
                    anchors.margins: 10 * main.vScaleFactor
                    clip: true
                    onMovingChanged: root.upPressed()
                    currentIndex: 1
                    highlight: Rectangle {
                        color: "transparent"
                        radius: main.defaultRadius
                        border.width: main.widthBorder
                        border.color: main.colorUIBorder
                    }
                    pressDelay: 200
                    highlightMoveDuration: 1
                    //model: testModel
                    model: root.currentBtPlayer && root.currentBtPlayer.menu
                    visible: isMenuVisible && (root.currentBtPlayer ? root.currentBtPlayer.menuSize > 0 : false)
                    delegate: Component {
                        Text {
                            text: name
                            color: main.colorFontLight
                            width: bt_menulistview.width
                            height: name == "" ? 0 : 31 * main.vScaleFactor
                            verticalAlignment: Text.AlignVCenter
                            anchors.left: parent.left
                            anchors.leftMargin: 30 * main.hScaleFactor
                            MouseArea{
                                anchors.fill: parent
                                onClicked: {
                                    root.currentBtPlayer.selectItem(index)
                                    //menuItemPressed(index)
                                    buzzer.buttonPress()
                                }
                                onPressed: {
                                    bt_menulistview.currentIndex = index
                                    buzzer.buttonPress()
                                }
                                Rectangle {
                                    anchors.fill: parent
                                    color: main.colorGenericStimulusArea
                                    opacity: 0.3
                                    visible: main.showStimulusArea
                                }
                            }
                        }
                    }
                }

                Item {
                    id: new_bt_controls
                    width: new_bt_menu.width
                    height: 50 * main.vScaleFactor
                    anchors.horizontalCenter: new_bt_menu.horizontalCenter
                    anchors.top: new_bt_menu.bottom
                    anchors.topMargin: 10 * main.vScaleFactor

                    Row {
                        anchors.fill: parent
                        anchors.centerIn: parent
                        spacing: 20 * main.hScaleFactor

                        StandardButton {
                            width: 80 * main.hScaleFactor
                            height: parent.height

                                sourceName: "Bluetooth/RWD_Icon"

                            onClicked: {
                                btControlsHandler("left")
                            }
                        }

                        StandardButton {
                            width: 80 * main.hScaleFactor
                            height: parent.height
                                sourceName: {
                                    if(currentBtPlayer === undefined || currentBtPlayer === null) {
                                        return "Bluetooth/Play_Icon"
                                    } else {
                                        if(currentBtPlayer.isPlaying) {
                                            return "Bluetooth/Pause_Icon"
                                        } else {
                                            return "Bluetooth/Play_Icon"
                                        }
                                    }
                                }
                                onClicked: {
                                    btControlsHandler("center")
                                }
                        }

                        StandardButton {
                            width: 80 * main.hScaleFactor
                            height: parent.height
                                sourceName: "Bluetooth/FWD_Icon"
                                onClicked: {
                                    btControlsHandler("right")
                                }
                        }
                    }
                }
            }

            StandardButton {
                id: down_button
                width: 80 * main.hScaleFactor
                height: 50 * main.vScaleFactor
                anchors.verticalCenter: parent.verticalCenter
                sourceName: "Media/Forward_Triangle"
                onClicked: btControlsHandler("down")
            }
        }

        StandardButton {
            id: disconnect_button
            width:  139 * main.hScaleFactor
            height: 79 * main.vScaleFactor
            anchors {
                right: parent.right
                rightMargin: 60 * main.hScaleFactor
                bottom: parent.bottom
                bottomMargin: 20 * main.vScaleFactor
            }

            buttonText: qsTr("DISCONNECT") + application.emptyString
            sourceName: "Bluetooth/BluetoothIcon"
            onClicked: {
                if(bluetoothAdapter.connected) {
                    dialogState = "disconnecting"
                    bluetoothAdapter.disconnect()
                }
            }
        }

        VolumeControls {
            id: volume_controls

            z: 200
            opacity: audioManager.audioPlaying ? 1.0 : 0.0
            enabled: (visible && opacity > 0.0)

            anchors.top: parent.top
            anchors.topMargin: 20 * main.vScaleFactor
            anchors.right: parent.right
            anchors.rightMargin: 20 * main.hScaleFactor

            // synchronize the control display with actual volume if changed elsewhere
            Connections {
                target: audioManager
                onVolumeChanged: {
                    if(audioManager.volume != volume_controls.percent) {
                        volume_controls.vol_setting = audioManager.volume * (volume_controls.vol_max - volume_controls.vol_min) / 100;
                    }
                }
                onMuteChanged: volume_controls.muted = audioManager.mute
            }

            onMutedChanged: audioManager.setMute(muted)
            onPercentChanged: audioManager.setVolume(percent)

            Behavior on opacity { NumberAnimation { duration: 200; easing.type: Easing.InOutQuad } }
        }
    }

    BluetoothDeviceSelectionDialog{
        id: btConnectionStatusDialog
        list: bluetoothAdapter.scannedDevices
        pairingAllowed: !(bluetoothAdapter.pairing || bluetoothAdapter.connectingHeadset)
        opacity: 1.0

        onClosed: {
            actionConnectionType("none")
            root.close()
        }
        onDeviceConnected: dialogState = "connected"
        onDeviceDisconnected: dialogState = "idle"
    }

    BluetoothDeviceSelectionDialog{
        id: btHeadsetConnectionStatusDialog
        list: bluetoothAdapter.scannedHeadSets
        pairingAllowed: !(bluetoothAdapter.pairing || bluetoothAdapter.connectingHeadset)
        opacity: 1.0

        onClosed: {
            actionConnectionType("none")
            root.close()
        }
        onHeadsetConnected: {
            dialogState = "idle"
            root.close()
        }
        onHeadsetDisconnected:  {
            dialogState = "list"
            root.close()
        }
    }

    HeartRateDeviceSelectionDialog {
        id: btHeartRateDialog

        visible: false
        isLowEnergy: true
        onClosed: {
            actionConnectionType("none")
            root.close()
        }
    }

    Connections {
        target: bluetoothLEAdapter
        onConnected: {
            dialogState = "home"
        }
    }

    Rectangle {
        id: homeStatusDialog

        property string infoType: "audio"
        property bool isInfoShowing: false

        visible: false
        anchors.fill: parent
        color:main.colorDialogBackground
        border.color: main.colorUIBorder
        border.width: main.widthBorder

        // close button
        CloseButton {
            id: close_button_home

            visible: !homeStatusDialog.isInfoShowing
            z: 200

            anchors {
                left: parent.left
                leftMargin: 40 * main.hScaleFactor
                bottom: parent.bottom
                bottomMargin: 40 * main.vScaleFactor
            }

            onClicked: {
                if(bluetoothAdapter.connected === false) {
                    dialogState = "home"
                } else {
                    dialogState = "connected"
                }
                buttonsGrid.currentIndex = -1
                root.close()
                actionConnectionType("none")
            }
        }

        Column {
           id: buttonsGrid

           property int buttonWidth: 188 * main.hScaleFactor
           property int buttonHeight: 111 * main.hScaleFactor
           property alias currentIndex: infoButtonList.currentIndex

           anchors {
               horizontalCenter: parent.horizontalCenter
               top: parent.top
               topMargin: 25 * main.vScaleFactor
           }
           width: buttonModel.count * (buttonWidth + spacing) - spacing

           spacing: 25 * main.vScaleFactor

           ListModel {
               id: buttonModel
               ListElement {label: QT_TR_NOOP("AUDIO CONNECT"); icon: "Bluetooth/Bluetooth_Media_icon"; action: "audio"}
               ListElement {label: QT_TR_NOOP("TRACKING APP"); icon: "Bluetooth/Bluetooth_Media_icon"; action: "app"}
               ListElement {label: QT_TR_NOOP("HR CONNECT"); icon: "Bluetooth/Bluetooth_HRicon"; action: "hr"}
               ListElement {label: QT_TR_NOOP("EAR CONNECT"); icon: "Bluetooth/Bluetooth_Headphones_Icon"; action: "ear"}
           }

           ListView {
               id: connectButtonsList
               width: parent.width
               height:  parent.buttonHeight
               spacing: 25 * main.vScaleFactor
               currentIndex: -1
               orientation: ListView.Horizontal
               model: buttonModel
               delegate: Component {
                   StandardButton {
                       id: appButton

                       function getEnabled(action) {
                           if (action === "audio") {
                               if(bluetoothAdapter.connectedHeadset === true) {
                                   return false
                               } else {
                                   return true
                               }
                           } else if(action === "ear") {
                               if(bluetoothAdapter.connected === true) {
                                   return false
                               } else {
                                   return true
                               }
                           } else {
                               return true
                           }
                       }

                       width: buttonsGrid.buttonWidth
                       height: buttonsGrid.buttonHeight
                       selected: index === buttonsGrid.currentIndex || (index == 1 && dialogState === "app")
                       buttonText: qsTranslate(root.sourceFile, model.label)

                       icon.sourceName: model.icon
                       enabled: getEnabled(model.action)

                       onClicked: {
                           homeStatusDialog.isInfoShowing = false
                           root.connectionType = model.action
                           actionConnectionType(root.connectionType)
                       }

                       // re-translate the strings when the language changes
                       Connections {
                           target: application
                           onLanguageChanged: { appButton.buttonText = qsTranslate(root.sourceFile, model.label) }
                       }
                   }
               }
           }

           ListView {
               id: infoButtonList
               visible: dialogState !== "app"
               width: parent.width
               height: 34 * main.vScaleFactor
               spacing: 25 * main.vScaleFactor
               currentIndex: -1
               orientation: ListView.Horizontal
               model: buttonModel
               delegate: Component {
                   ScalableImage {
                       width: buttonsGrid.buttonWidth
                       height: 34 * main.vScaleFactor
                       sourceName: "Bluetooth/InfoIcon"
                       fillMode: Image.PreserveAspectFit

                       MouseArea {
                           anchors.fill: parent
                           onClicked: {
                               homeStatusDialog.isInfoShowing = true
                               homeStatusDialog.infoType = action
                               infoButtonList.currentIndex = index
                               console.debug("Clicked: "+action)
                               infoText.infoString = infoText.infoStringGet()
                               infoText.text = qsTranslate(root.sourceFile, infoText.infoString)
                           }
                       }
                   }
               }
           }
        }

        Rectangle {
            id: info_popup

            visible: homeStatusDialog.isInfoShowing
            color: main.colorDialogBackground
            border.color: main.colorUIBorder
            border.width: main.widthBorder
            width: 605 * main.hScaleFactor
            height: 403 * main.vScaleFactor

            anchors {
                right: parent.right
                rightMargin: 50 * main.hScaleFactor
                top: parent.top
                topMargin: buttonsGrid.buttonHeight + 2*buttonsGrid.spacing
            }

            // close button
            CloseButton {
                id: close_button_info

                anchors {
                    left: parent.left
                    leftMargin: 40 * main.hScaleFactor
                    bottom: parent.bottom
                    bottomMargin: 40 * main.vScaleFactor
                }

                onClicked: {
                    buttonsGrid.currentIndex = -1
                    homeStatusDialog.isInfoShowing = false
                }
            }

            Text {
                id: infoText
                anchors {
                    horizontalCenter: parent.horizontalCenter
                    top: parent.top
                    topMargin: 25 * main.vScaleFactor
                    bottom: close_button_info.top
                    bottomMargin: 10 * main.vScaleFactor
                }
                width: 0.8 * parent.width
                wrapMode: Text.WordWrap
                textFormat: Text.RichText
                color: main.colorFontLight

                function infoStringGet(){
                    switch(homeStatusDialog.infoType) {
                    case "audio":
                        return QT_TR_NOOP("<p><b>CONNECTING BLUETOOTH AUDIO DEVICES</b></p><p>You can stream music from you Bluetooth audio device through the headphone jack on this machine during your workout.</p><p>Make sure your Bluetooth audio device is discoverable, then touch the AUDIO CONNECT button. Complete pairing through the Bluetooth pairing menu on your audio device.</p>")
                    case "app":
                        return QT_TR_NOOP("<p><b>CONNECTING BLUETOOTH WORKOUT TRACKING APP</b></p><p>Workout data from this machine can be transfered via Bluetooth signal to compatible mobile workout tracking apps. Touch the TRACKING APP button and then complete pairing through the Bluetooth pairing menu on your mobile device's app.</p><p>Consult TRUEFITNESS.COM for current list of compatible mobile apps.</p>")
                    case "hr":
                        return QT_TR_NOOP("<p><b>CONNECTING BLUETOOTH HEART RATE DEVICES</b></p><p>Make sure your device is discoverable, then touch the HR CONNECT button. Select your Bluetooth heart rate monitor from the list.</p><p>NOTE: a Bluetooth HR monitor will not appear on this machine if it is already paired with a mobile device like a smart phone.</p><p>This machine will recognize both Bluetooth heart rate monitors and traditional 5kHz \"Polar compatible\" straps. Traditional Polar compatible devices will automatically display when in close proximity to this machine, but can be \"turned off\" by touching the HR CONNECT button, then touching DO NOT DISPLAY.</p>")
                    case "ear":
                        return QT_TR_NOOP("<p><b>CONNECTING BLUETOOTH EARBUD DEVICES</b></p><p>Audio from TV or web browser (if enabled by this facility), can be streamed to compatible Bluetooth earbud or headphone devices. Make sure your device is discoverable, then touch the EAR CONNECT button. Select your Bluetooth earbud or headphone device from the list.</p><p>NOTE: Bluetooth ear devices will not appear on this machine if it is already paried with a mobile device like a smart phone.</p>")
                    }
                }

                property string infoString: "error" //Show error if not updated on clicked

                text: qsTranslate(root.sourceFile, infoString)

                // re-translate the strings when the language changes
                Connections {
                    target: application
                    onLanguageChanged: { infoText.text = qsTranslate(root.sourceFile, infoText.infoString) }
                }
            }
        }

        ScalableImage{
            id: scanningBluetoothWave

            property int opacityInteger: 0

            visible: dialogState === "app"
            width: 80 * main.hScaleFactor
            height: buttonsGrid.buttonHeight/2
            anchors {
                verticalCenter: buttonsGrid.top
                verticalCenterOffset: 0.4 * buttonsGrid.buttonHeight
                horizontalCenter: buttonsGrid.left
                horizontalCenterOffset: buttonsGrid.buttonWidth * 1.5 + buttonsGrid.spacing
            }

            sourceName: "Bluetooth/Bluetooth_waves_medium"
            fillMode: Image.PreserveAspectFit
            opacity: opacityInteger / 100.0

            NumberAnimation on opacityInteger {
                from: 0;
                to: 100;
                duration: 500
                running : scanningBluetoothWave.visible
                loops: Animation.Infinite
            }
        }

        Text {
            id: appConnectionText
            visible: dialogState === "app"

            onVisibleChanged: {
                if(visible === true) {
                    gem.reset();
                    console.log("Calling  gem.startAdvertising()")
                    gem.startAdvertising()
                } else {
                    console.log("Calling  gem.stopAdvertising()")
                    gem.stopAdvertising()
                }
            }

            anchors {
                horizontalCenter: parent.horizontalCenter
                top: buttonsGrid.bottom
                topMargin: 25 * main.vScaleFactor
                bottom: parent.bottom
                bottomMargin: 10 * main.vScaleFactor
            }

            width: parent.width
            wrapMode: Text.WordWrap
            textFormat: Text.RichText
            color: main.colorFontLight
            horizontalAlignment: Text.AlignHCenter

            Timer{
                interval: 700
                repeat: true
                running: dialogState === "app" && gem.connected === 0 && root.deviceName == ""
                triggeredOnStart: false
                onTriggered: {
                    console.log("gem retry advertising")
                    gem.startAdvertising()
                }
            }

            text: {
                if(gem.connected === 0) {
                    return qsTr("<p><b>BLUETOOTH WORKOUT TRACKING APP<b></p><p>From your compatible fitness app, pair your device to:</p><p><h1>") + root.deviceName + qsTr("<br></h1></p><p>Consult TRUEFITNESS.COM for the current list of compatible mobile apps.</p>")
                } else {
                    return qsTr("<p><b>BLUETOOTH WORKOUT TRACKING APP<b></p><p>You are now connected to:</p><p><h1>") + root.deviceName + qsTr("<br></h1></p><p>Start a workout to begin tracking workout data.</p>")
                }
            }
        }
    }
}

