import QtQuick 2.12
import Process 0.1
import Components 1.0
import ".."

Item {
    id: root

    property int volume: vol_setting
    property int percent: 100 * (volume / (vol_max - vol_min))
    property int vol_setting: audioManager.vol_setting
    property int vol_max: audioManager.vol_max
    property int vol_min: audioManager.vol_min
    property alias muted: mute_button.selected
//    property bool showSourceButton: false
    property string volText: qsTr("VOL") + application.emptyString

//    signal sourceButtonClicked()
    signal action()

    width: 166 * main.hScaleFactor
    height: 166 * main.vScaleFactor

    Component.onCompleted:  {
        console.log("Intializing Volume to " + root.vol_setting + " (audioManager volume percent: " + audioManager.volume + ")")
        paVolControl.setVolume(root.vol_setting)
    }

    Connections {
        target: bluetoothAdapter
        onConnectedHeadsetChanged: {
            if(bluetoothAdapter.connectedHeadset) {
                if(muted) {
                    paVolControl.setVolume(0)
                } else {
                    paVolControl.setVolume(vol_setting)
                }
            }
        }
    }

    // re-translate the strings when the language changes
    Connections {
        target: application
        onLanguageChanged: {
            root.volText= qsTr("VOL") + application.emptyString
        }
    }

    onVol_settingChanged: paVolControl.setVolume(vol_setting)
    onMutedChanged: {
        if(muted) {
            paVolControl.setVolume(vol_min)
        } else {
            paVolControl.setVolume(vol_setting)
        }
    }

    function volumeUp() {
        if(mute_button.isDown) {
            mute_button.isDown = false;
        } else {
            if(root.volume < root.vol_max) {
                root.vol_setting++;
            }
        }
    }

    function volumeDown() {
        if(mute_button.isDown) {
            mute_button.isDown = false;
        } else {
            if(root.volume > root.vol_min) {
                root.vol_setting--;
            }
        }
    }

    function toggleMute() {
        mute_button.selected = !mute_button.selected
    }

    StandardButton {
        id: volume_down_button
//        repeat: true
        anchors.left: parent.left
        anchors.top: parent.top
        width: 76 * main.hScaleFactor
        height: 76 * main.vScaleFactor

        buttonText: root.volText
        sourceName: "Media/Media_Volume_Minus"
        color: selected ? main.colorSelected : main.colorDialogBackground

        onClicked: {
            root.action()
            volumeDown()
        }
    }

    StandardButton {
        id: volume_up_button
//        repeat: true
        anchors.right: parent.right
        anchors.top: parent.top
        width: 76 * main.hScaleFactor
        height: 76 * main.vScaleFactor

        buttonText: root.volText
        sourceName: "Media/Media_Volume_Plus"
        color: selected ? main.colorSelected : main.colorDialogBackground

        onClicked:{
            root.action()
            volumeUp()
        }
    }

    StandardButton {
        id: mute_button
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.bottom: parent.bottom
        width: 76 * main.hScaleFactor
        height: 76 * main.vScaleFactor

        sourceName: "Media/Media_Mute_Up"
        color: selected ? main.colorSelected : main.colorDialogBackground

        onClicked: {
            root.action()
            toggleMute()
        }
    }

/*
    ImageButton {
        id: source_button
        anchors.top: btHeadset_button.visible ? btHeadset_button.bottom : mute_button.bottom
        anchors.topMargin: 15
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset: 0
        downimage: muteButtonDownimage
        upimage: muteButtonUpimage
        icon: root.sourceIcon
        onClicked: root.sourceButtonClicked()
        reenableDelay: 200
        mouseAreaScale: 1.25
        visible: root.showSourceButton
    }

    Text {
        id: change_source_text
        text: qsTr("CHANGE AUDIO") + application.emptyString
        font.bold: false
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: source_button.bottom
        font.pixelSize: 12
        visible: source_button.visible
    }
    */
}
