import QtQuick 2.12
import Components 1.0
import ".."

Item {
    id: root

    property variant activeConnections: []
    property bool preventEthDisconnect: false

    signal disconnectRequest(string interfaceName)

    function refresh() {
        // Force re-selection of current item
        cnxList.currentIndex = -1
        cnxList.currentIndex = 0
    }

    width: childrenRect.width
    height: childrenRect.height

    Text {
        id: activeCnxText
        text: qsTr("Active Connections") + ":" + application.emptyString
        anchors {
            top: parent.top
            left: parent.left
        }
    }

    Rectangle {
        id: connectionsListBox
        color: main.colorDialogBackground
        width: 290 * main.hScaleFactor
        height: 310 * main.vScaleFactor
        border { width: main.widthBorder; color: main.colorUIBorder}
        anchors {
            left: parent.left
            top: activeCnxText.bottom
            topMargin: 5  * main.vScaleFactor
        }
        clip: true

        ListView {
            id: cnxList

            visible: !netConnections.isRefreshing
            anchors.fill: parent
            anchors.margins: 5 * main.scaleFactor
            model: netConnections.list
            delegate: connDelegate
            highlight: Component {
                Rectangle {
                    height: 44 * main.vScaleFactor
                    width: parent.width
                    color: main.colorHighlightBackground
                }
            }
        }

        Text {
            id: refreshingText
            visible: netConnections.isRefreshing
            text: qsTr("Refreshing...") + application.emptyString
            anchors {
                top: parent.top
                left: parent.left
                topMargin: 10 * main.vScaleFactor
                leftMargin: 10 * main.hScaleFactor
            }
        }
    }

    Component {
        id: connDelegate
        Row {
            height: 44 * main.vScaleFactor
            spacing: 10 * main.hScaleFactor

            Item {
                width: 1 * main.hScaleFactor
                height: 10 * main.vScaleFactor
            }

            ScalableImage {
                id: padlock
                anchors.verticalCenter: parent.verticalCenter
                sourceName: encrypted ? "HomeScreen/LOCK_ICON" : "Diagnostics/padlock-unlocked"
                Text {
                    id: problemX
                    visible: (intf === "enp2s0" && (!netConnections.wiredEnabled || netConnections.wireDisconnected)) || (intf === "wlp5s0" || intf === "wlp6s0") && !netConnections.wirelessEnabled
                    color: "#ff3300"
                    font.pixelSize: 18 * main.vScaleFactor
                    text: "X"
                    anchors {
                        horizontalCenter: parent.horizontalCenter;
                        verticalCenter: parent.verticalCenter
                    }
                }
            }

            Text {
                text: essid ? essid : ""
                font { pixelSize: 20 * main.vScaleFactor }
                width: 180 * main.hScaleFactor
                height: parent.height
                verticalAlignment: Text.AlignVCenter
                color: main.colorFontLight
                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        cnxList.currentIndex = index
                        buzzer.buttonPress()
                    }
                    Rectangle {
                        anchors.fill: parent
                        color: main.colorGenericStimulusArea
                        opacity: 0.3
                        visible: main.showStimulusArea
                    }
                }
            }

            Item {
                width: 1 * main.hScaleFactor
                height: 10 * main.vScaleFactor
            }

            CloseButton { // x
                anchors {
                    verticalCenter: parent.verticalCenter
                }
                width: 25 * main.hScaleFactor
                height: 25 * main.vScaleFactor
                enabled: !(intf === "enp2s0" && root.preventEthDisconnect)
                onClicked: disconnectRequest(intf)
            }

            Item {
                width: 1 * main.hScaleFactor
                height: 10 * main.vScaleFactor
            }
        }
    }

    Grid {
        id: ethInfo

        property int fontSize: 20 * main.vScaleFactor
        property int colWidth1: 0.60*width
        property int colWidth2: 0.40*width - columnSpacing
        visible: cnxList.currentIndex >= 0 && cnxList.model.get(cnxList.currentIndex).intf === "enp2s0"

        rowSpacing: 20 * main.vScaleFactor
        columnSpacing: 40 * main.hScaleFactor
        columns: 2
        rows: 6
        verticalItemAlignment: Grid.AlignVCenter

        width: 300 * main.hScaleFactor
        anchors {
            left: connectionsListBox.right
            leftMargin: 20 * main.hScaleFactor
            bottom: connectionsListBox.bottom
        }

        TextLabel {
            text: qsTr("Interface") + application.emptyString
            wrapMode: Text.WordWrap
            font.pixelSize: parent.fontSize
            color: main.colorFontDark
            width: parent.colWidth1
        }
        TextLabel {
            text: qsTr("Ethernet") + application.emptyString
            wrapMode: Text.WordWrap
            font.pixelSize: parent.fontSize
            color: main.colorFontDark
            width: parent.colWidth2
        }

        TextLabel {
            text: qsTr("Status") + application.emptyString;
            wrapMode: Text.WordWrap
            font.pixelSize: parent.fontSize
            color: main.colorFontDark
            width: parent.colWidth1
        }
        TextLabel {
            text: {
                if (netConnections.wireDisconnected) {
                    return qsTr("Wire Disconnected") + application.emptyString
                } else if (netConnections.wiredEnabled) {
                    return qsTr("Connected") + application.emptyString
                } else {
                    return qsTr("No Connection") + application.emptyString
                }
            }
            wrapMode: Text.WordWrap
            font.pixelSize: parent.fontSize
            color: netConnections.wireDisconnected ? "gray" : main.colorFontDark
            width: parent.colWidth2
        }

        TextLabel {
            text: qsTr("IP Address") + application.emptyString;
            wrapMode: Text.WordWrap
            font.pixelSize: parent.fontSize
            color: main.colorFontDark
            width: parent.colWidth1
            visible: !netConnections.wireDisconnected
        }
        NumberLabel {
            text: netConnections.wiredIp
            font.pixelSize: parent.fontSize
            color: main.colorFontDark
            width: parent.colWidth2
            visible: !netConnections.wireDisconnected
        }

        TextLabel {
            text: qsTr("Subnet Mask") + application.emptyString
            wrapMode: Text.WordWrap
            font.pixelSize: parent.fontSize
            color: main.colorFontDark
            width: parent.colWidth1
            visible: !netConnections.wireDisconnected
        }
        NumberLabel {
            text: netConnections.wiredNetmask
            font.pixelSize: parent.fontSize
            color: main.colorFontDark
            width: parent.colWidth2
            visible: !netConnections.wireDisconnected
        }

        TextLabel {
            text: qsTr("MAC Address") + application.emptyString
            wrapMode: Text.WordWrap
            font.pixelSize: parent.fontSize
            color: main.colorFontDark
            width: parent.colWidth1
        }
        TextLabel {
            text: netConnections.wiredMac
            font.pixelSize: parent.fontSize
            color: main.colorFontDark
            width: parent.colWidth2
        }

        TextLabel {
            text: qsTr("Wireless MAC Address") + application.emptyString
            wrapMode: Text.WordWrap
            font.pixelSize: parent.fontSize
            color: main.colorFontDark
            width: parent.colWidth1
            visible: netConnections.wireDisconnected
        }
        TextLabel {
            text: netConnections.wirelessMac
            font.pixelSize: parent.fontSize
            color: main.colorFontDark
            width: parent.colWidth2
            visible: netConnections.wireDisconnected
        }
    }

    Grid {
        id: wirelessInfo

        property int fontSize: 20 * main.vScaleFactor
        property int colWidth1: 0.60*width
        property int colWidth2: 0.40*width - columnSpacing

        rowSpacing: 20 * main.vScaleFactor
        columnSpacing: 40 * main.hScaleFactor
        columns: 2
        rows: 5
        verticalItemAlignment: Grid.AlignVCenter

        width: 300 * main.hScaleFactor

        visible: cnxList.currentIndex >= 0 && ( cnxList.model.get(cnxList.currentIndex).intf === "wlp5s0" || cnxList.model.get(cnxList.currentIndex).intf === "wlp6s0" )
        anchors {
            left: connectionsListBox.right
            leftMargin: 20 * main.hScaleFactor
            bottom: connectionsListBox.bottom
        }

        TextLabel {
            text: qsTr("Status") + application.emptyString
            wrapMode: Text.WordWrap
            font.pixelSize: parent.fontSize
            color: main.colorFontDark
            width: parent.colWidth1
        }
        TextLabel {
            text: {
                if (netConnections.wirelessEnabled) {
                    return qsTr("Connected") + application.emptyString
                } else {
                    return qsTr("No Connection") + application.emptyString
                }
            }
            wrapMode: Text.WordWrap
            font.pixelSize: parent.fontSize
            color: main.colorFontDark
            width: parent.colWidth2
        }

        TextLabel {
            text: qsTr("Signal Strength") + application.emptyString
            wrapMode: Text.WordWrap
            font.pixelSize: parent.fontSize
            color: main.colorFontDark
            width: parent.colWidth1
        }
        NumberLabel {
            text: netConnections.signalStrength
            font.pixelSize: parent.fontSize
            color: main.colorFontDark
            width: parent.colWidth2
        }

        TextLabel {
            text: qsTr("IP Address") + application.emptyString
            wrapMode: Text.WordWrap
            font.pixelSize: parent.fontSize
            color: main.colorFontDark
            width: parent.colWidth1
        }
        NumberLabel {
            text: netConnections.wirelessIp;
            font.pixelSize: parent.fontSize
            color: main.colorFontDark
            width: parent.colWidth2
        }

        TextLabel {
            text: qsTr("Subnet Mask") + application.emptyString
            wrapMode: Text.WordWrap
            font.pixelSize: parent.fontSize
            color: main.colorFontDark
            width: parent.colWidth1
        }
        NumberLabel {
            text: netConnections.wirelessNetmask
            font.pixelSize: parent.fontSize
            color: main.colorFontDark
            width: parent.colWidth2
        }

        TextLabel {
            text: qsTr("MAC Address") + application.emptyString
            wrapMode: Text.WordWrap
            font.pixelSize: parent.fontSize
            color: main.colorFontDark
            width: parent.colWidth1
        }
        TextLabel {
            text: netConnections.wirelessMac
            font.pixelSize: parent.fontSize
            color: main.colorFontDark
            width: parent.colWidth2
        }
    }
}
