import QtQuick 2.12
import Components 1.0
import ".."

// prompt user for ending the workout

ModalDialog {
    id: root

    property string prompt: qsTr("<b><font color='#cc3333'>NOTICE:</font> By pressing Accept below, the owner of this equipment acknowledges being made aware of their responsibilities when enabling access to the Internet.</b>\
<h2>Internet Service</h2>\
<p>The owner of this equipment and the facility in which it is installed is responsible for providing Internet service to this machine.\
This machine may receive network service by either WiFi or wired Ethernet connectivity.\
Performance of connectivity can vary greatly with the ISP and equipment (routers, switches, network load, etc.) used to provide access.\
The owner of this equipment and the facility in which it is installed is responsible for ensuring signal strength/bandwidth is sufficient for performance based on\
number of devices connected to the Internet and usage needs.</p>\
\
<p>Before contacting your True Fitness representative regarding Internet connectivity, please consult your ISP or IT department.\
</p>\
<h2>Filtering of Content and Security</h2>\
<p>True Fitness Technology, Inc. has no control or responsibility regarding the content and information users may access via the Internet.\
Filtering for appropriate content is the responsibility of the facility and equipment owner.\
It is recommended that filters and/or firewalls be installed externally to this equipment to regulate\
user access of content, and for protection against malicious or inappropriate websites and content.\
</p>\
<h2>Safety</h2>\
<p>Internet usage while exercising can pose risks to safety.   It is recommended that a facility institute guidelines for Internet interaction.\
Particular guidelines advising exercisers to disengage Internet interaction during intense exercise is highly recommended.\
Specifically for treadmill use, it is recommended that users be advised that interaction with the Internet should occur only at slow walking speeds and care should always\
be taken to ensure gait remains stable at the front/center of walking belt.\
</p>\
<h2>Formatting</h2>\
<p>Similar to other tablet and mobile devices with web-browsing capability, \
some websites may not function as designed on this device.</p>")

    property string yesText: qsTr("Accept") + application.emptyString
    property string noText: qsTr("No") + application.emptyString

    property int textXOffset: 149 * main.hScaleFactor
    property int textSize: 10 * main.vScaleFactor

    signal yesClicked()
    signal noClicked()

    width: main.widthDialog
    height: 0.7*main.screenHeight

    Item {
        id: scrollTextItem
        z: root.z + 1
        anchors.fill: parent

        Flickable {
            id: scrollText
            clip: true
            flickableDirection: Flickable.VerticalFlick

            anchors {
                fill: parent
                topMargin: 50 * main.vScaleFactor
                leftMargin: 50 * main.hScaleFactor
                rightMargin: 50 * main.hScaleFactor
                bottomMargin: noButton.height + (50 * main.vScaleFactor)
            }

            contentHeight: contentItem.childrenRect.height

            Text {
                id: promptText
                width: scrollText.width
                height: paintedHeight
                color: main.colorFontLight
                text: root.prompt
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.top: parent.top
                anchors.topMargin: 35 * main.vScaleFactor
                wrapMode: Text.WordWrap
                horizontalAlignment: main.rightToLeft ? Text.AlignRight : Text.AlignLeft
            }
        }

        Text {
            id: scrollForMore
            anchors.top: scrollText.bottom
            anchors.topMargin: 10 * main.vScaleFactor
            anchors.horizontalCenter: scrollText.horizontalCenter
            width: scrollText.width
            horizontalAlignment: Text.AlignHCenter
            color: main.colorFontLight

            text: qsTr("< scroll down for more >")
            visible: !scrollText.atYEnd
        }

        Rectangle {
            id: sliderBar

            property double baseHeight: scrollText.height
            property double contentHeight: scrollText.contentHeight

            anchors.right: parent.right
            anchors.rightMargin: 2 * main.hScaleFactor
            width: 15 * main.hScaleFactor
            height: baseHeight * baseHeight/contentHeight
            visible: baseHeight < contentHeight
            color: "darkgrey"
            radius: main.defaultRadius
            y: (baseHeight  - height) * scrollText.contentY / (contentHeight - baseHeight)
        }

        StandardButton {
            id: noButton
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 20 * main.vScaleFactor
            anchors.right: parent.right
            anchors.rightMargin: 50 * main.hScaleFactor

            buttonText: root.noText
            onClicked: noClicked()

            icon.sourceName: "stop_button_icon"
        }

        StandardButton {
            id: yesButton

            anchors.bottom: parent.bottom
            anchors.bottomMargin: 20 * main.vScaleFactor
            anchors.left: parent.left
            anchors.leftMargin: 50 * main.hScaleFactor

            buttonText: root.yesText
            onClicked: yesClicked()

            icon.sourceName: "HomeScreen/QuickStartIcon"
        }
    }
}

