import QtQuick 2.12
import Components 1.0
import "validator.js" as Validator

/**
 * @brief Item that contains the contents of the Create Profile page within the application.
 */
StandardPage {
    id: createAccountPage
    
    height: main.height
    width: main.width
    
    title: qsTr("CREATE PROFILE")  + application.emptyString
    image_width: 0.19
    no_bottom_margin: true

    property string gender: "male"

    content: create_profile_content

    signal clear()

    onVisibleChanged: {
        if (!visible) {
            createAccountPage.clear()
        }
    }


    Component {
        id: create_profile_content
        Item {
            id: create_profile_item

            width: 986 * main.hScaleFactor
            // Functions
            /**
             * @brief Gets the input from the fields within the Create Profile screen.
             * Prints all inputs from the fields for the create profile screen to a log.
             * @return type:string Returns a colon separated string of all the items of the Create Profile string.
             */
            function getInput() {
                console.log("Printing Create Profile Information:\n");

                var firstNameText = (firstNameTextField.acceptableInput) ? firstNameTextField.getText() : "NULL";
                console.log("First name field: " + firstNameText + "\n");

                var lastNameText = (lastNameTextField.acceptableInput) ? lastNameTextField.getText() : "NULL";
                console.log("Last name field: " + lastNameText + "\n");

                var dateText = "NULL";
                if(birthDateTextField.acceptableInput) {
                    var d = birthDateTextField.getText();
                    var dsplit = d.split("/", 3);
                    if(Validator.checkDate(Number(dsplit[2]), Number(dsplit[0]), Number(dsplit[1]))) {
                        dateText = d;
                    }
                }
                console.log("Birth Date Field: " + dateText + "\n");

                console.log("Gender selection: " + createAccountPage.gender + "\n");

                var heightInches = 12 * feetbox.getValue() + inchesbox.getValue();
                console.log("Height: " + heightInches + " inches\n");

                var emailText = (emailTextField.acceptableInput) ? emailTextField.getText() : "NULL";
                console.log("Email field: " + emailText + "\n");

                var passwordText = (passwordTextField.acceptableInput) ? passwordTextField.getText() : "NULL";
                console.log("Password field: " + passwordText + "\n");
                console.log("");
                return firstNameText + ":" + lastNameText + ":" + dateText + ":" + createAccountPage.gender + ":" + heightInches + ":" + emailText + ":" + passwordText;
            }

            /**
             * @brief Clears the input from all fields within the Create Profile screen.
             */

            onVisibleChanged: if (!visible) clear()

            function clear() {
                firstNameTextField.clear();
                lastNameTextField.clear();
                birthDateTextField.clear();
                maleButton.color = "white";
                femaleButton.color = "#7F8084";
                feetbox.value = 5;
                inchesbox.value = 6;
                emailTextField.clear();
                passwordTextField.clear();
            }

            Rectangle {
                id: mainArea
                anchors.left: parent.left
                anchors.top: parent.top
                anchors.topMargin: 30 * main.vScaleFactor
                anchors.right: parent.right
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 200 * main.vScaleFactor
                border.color: main.colorUIBorder
                border.width: main.widthBorder
                color: main.colorDialogBackground
                radius: main.defaultRadius

                Column {
                    /**
                     * @brief type:int Padding between components within this column layout.
                     */
                    property int padding: 30
                    anchors.fill: parent
                    anchors.leftMargin: 22 * main.hScaleFactor
                    anchors.rightMargin: 22 * main.hScaleFactor
                    anchors.topMargin: 18 * main.vScaleFactor
                    anchors.bottomMargin: 100 * main.vScaleFactor
                    spacing: padding * main.vScaleFactor

                    Text {
                        id: createProfileDescriptionText
                        width: parent.width
                        text: qsTr("Next we set up your profile information that doesn't change - it's important with your profile to enter all the biometric information as accurately as possible.  We use information like your age and gender to help determine your estimated max heart rate, projected walk and run speeds, etc.  This in turn helps to ensure you get the maximum results from your workout.") + application.emptyString
                        font.pixelSize: 15 * main.vScaleFactor
                        color: "white"
                        wrapMode: Text.Wrap
                    }

                    Grid {
                        /**
                         * @brief type:int Padding between components within this row layout.
                         */
                        property int padding: 18

                        columns: 3
                        rows: 3
                        spacing: padding * main.hScaleFactor

                        StandardTextField {
                            id: firstNameTextField
                            width: 290 * main.hScaleFactor
                            height: 42 * main.vScaleFactor
                            placeholderText: qsTr("FIRST NAME") + application.emptyString
                            validator: RegExpValidator { regExp: /^[^ 0-9±!@£$%^&*_+§¡€#¢§¶•ªº«\\/<>?:;|=.,\n][^±!@£$%^&*_+§¡€#¢§¶•ªº«\\/<>?:;|=.,\n]{0,31}$/ }
                        }
                        StandardTextField {
                            id: lastNameTextField
                            width: 290 * main.hScaleFactor
                            height: 42 * main.vScaleFactor
                            placeholderText: qsTr("LAST NAME") + application.emptyString
                            validator: RegExpValidator { regExp: /^[^ 0-9±!@£$%^&*_+§¡€#¢§¶•ªº«\\/<>?:;|=.,\n][^±!@£$%^&*_+§¡€#¢§¶•ªº«\\/<>?:;|=.,\n]{0,31}$/ }
                        }
                        StandardTextField {
                            id: birthDateTextField
                            width: 290 * main.hScaleFactor
                            height: 42 * main.vScaleFactor
                            placeholderText: qsTr("MM/DD/YYYY")
                            validator: RegExpValidator { regExp: /^(0[1-9]|1[012])[/](0[1-9]|[12][0-9]|3[01])[/](19|20)\d\d$/ }
                            inputMethodHints: Qt.ImhDigitsOnly

                            property int prevLength: 0
                            onLengthChanged: {
                                switch(length) {
                                case 2: // MM
                                case 5: // MM/DD
                                    if(prevLength < length) insert(length, "/");
                                    else if(prevLength > length) remove(length-2, length);
                                    break;
                                default:
                                    break;
                                }
                                prevLength = length;
                            }
                        }

                        Row {
                            width: 290 * main.hScaleFactor
                            height: 42 * main.vScaleFactor
                            /**
                             * @brief type:int Padding between components within this column layout.
                             */
                            property int padding: 16

                            spacing: padding

                            Rectangle {
                                id: maleButton
                                width: 137 * main.hScaleFactor
                                height: parent.height
                                color: "white"

                                Text {
                                    id: maleButtonText
                                    text: qsTr("MALE") + application.emptyString
                                    font.pixelSize: 14 * main.vScaleFactor
                                    anchors.centerIn: parent
                                }

                                MouseArea {
                                    anchors.fill: parent
                                    onClicked: {
                                        maleButton.color = "white"
                                        femaleButton.color = "#7F8084"
                                        createAccountPage.gender = maleButtonText.text
                                        buzzer.buttonPress()
                                    }
                                    Rectangle {
                                        anchors.fill: parent
                                        color: main.colorGenericStimulusArea
                                        opacity: 0.3
                                        visible: main.showStimulusArea
                                    }
                                }
                            }

                            Rectangle {
                                id: femaleButton
                                width: 137 * main.hScaleFactor
                                height: parent.height
                                color: "#7F8084"

                                Text {
                                    id: femaleButtonText
                                    text: qsTr("FEMALE") + application.emptyString
                                    font.pixelSize: 14 * main.vScaleFactor
                                    anchors.centerIn: parent
                                }

                                MouseArea {
                                    anchors.fill: parent
                                    onClicked: {
                                        maleButton.color = "#7F8084"
                                        femaleButton.color = "white"
                                        createAccountPage.gender = femaleButtonText.text
                                        buzzer.buttonPress()
                                    }
                                    Rectangle {
                                        anchors.fill: parent
                                        color: main.colorGenericStimulusArea
                                        opacity: 0.3
                                        visible: main.showStimulusArea
                                    }
                                }
                            }
                        }

                        Row {
                            id: heightArea
                            width: 290  * main.hScaleFactor
                            height: 42 * main.vScaleFactor
                            spacing: 20 * main.hScaleFactor

                            Text {
                                id: heightlabel
                                width: parent.width - 2 * (feetbox.width+parent.spacing)
                                height: parent.height
                                horizontalAlignment: Text.AlignLeft
                                verticalAlignment: Text.AlignVCenter
                                color: "white"
                                text: qsTr("HEIGHT") + application.emptyString
                                font.pixelSize: 14 * main.vScaleFactor
                            }

                            StandardSpinBox {
                                id: feetbox
                                width: 98 * main.hScaleFactor
                                height: parent.height
                                value: 5
                                minimumValue: 3
                                maximumValue: 7
                                suffix: " " + qsTr("FT") + application.emptyString
                            }

                            StandardSpinBox {
                                id: inchesbox
                                width: 98 * main.hScaleFactor
                                height: parent.height
                                value: 6
                                minimumValue: 0
                                maximumValue: 11
                                suffix: " " + qsTr("IN") + application.emptyString
                            }
                        }
                        StandardTextField {
                            id: emailTextField
                            width: 290 * main.hScaleFactor
                            height: 42 * main.vScaleFactor
                            placeholderText: qsTr("EMAIL") + application.emptyString
                            // E-mail validator using the RFC 5322 Official Standard
                            validator: RegExpValidator { regExp: /(?:[A-Za-z0-9!#$%&'*+/=?^_`{|}~-]+(?:\.[A-Za-z0-9!#$%&'*+/=?^_`{|}~-]+)*|"(?:[\x01-\x08\x0b\x0c\x0e-\x1f\x21\x23-\x5b\x5d-\x7f]|\\[\x01-\x09\x0b\x0c\x0e-\x7f])*")@(?:(?:[A-Za-z0-9](?:[A-Za-z0-9-]*[A-Za-z0-9])?\.)+[A-Za-z0-9](?:[a-z0-9-]*[A-Za-z0-9])?|\[(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?|[A-Za-z0-9-]*[A-Za-z0-9]:(?:[\x01-\x08\x0b\x0c\x0e-\x1f\x21-\x5a\x53-\x7f]|\\[\x01-\x09\x0b\x0c\x0e-\x7f])+)\])/ }
                        }
                        StandardTextField {
                            id: passwordTextField
                            width: 290 * main.hScaleFactor
                            height: 42 * main.vScaleFactor
                            placeholderText: qsTr("PASSWORD") + application.emptyString
                            inputMethodHints: Qt.ImhDigitsOnly
                            validator: RegExpValidator { regExp: /^\d{4,32}$/ }
                        }
                        Item { }
                        Item { }
                    }

                    Item {
                        id: bottomRectangle
                        anchors.left: parent.left
                        anchors.right: parent.right
                        height: 90 * main.vScaleFactor
                        StandardButton {
                            id: backButton
                            anchors.left: parent.left
                            anchors.verticalCenter: parent.verticalCenter
                            buttonText: qsTr("BACK") + application.emptyString
                            onClicked: {
                                create_profile_item.clear()
                                main.state = "LoginState"
                            }

                            icon.sourceName: "Components/ArrowLeftWhiteIcon"
                        }
                        StandardButton {
                            id: createButton
                            anchors.right: parent.right
                            buttonText: qsTr("CREATE") + application.emptyString
                            textColor: main.colorFontGreen
                            onClicked: {
                                create_profile_item.getInput();
                                create_profile_item.clear()
                                main.state = "HomeState"
                            }
                            icon.sourceName: "Components/ArrowRightGreenIcon"
                        }
                    }
                }
            }
        }
    }
}
