import QtQuick 2.12
import Components 1.0
import ".."

/**
 * @brief Item that is the basis of the Sign-In set of pages within the application.
 */
StandardPage {
    id: sipage
    anchors.fill: parent

    title: qsTr("WELCOME BACK!") + application.emptyString
    image_width: 0.19
    no_bottom_margin: true
    /**
     * @brief Boolean representing if the sign in button is selected (or Forgot Password).
     * @todo Determine how to remove this property from the SignIn.qml file.
     */
    property bool isSignIn: true

    content: sign_in_content
    Component {
        id: sign_in_content

        Item {
            id: sign_in_item
            anchors {
                horizontalCenter: parent.horizontalCenter
                top: parent.top
            }
            width: 986 * main.hScaleFactor
            height: 391 * main.vScaleFactor

            state: "SIGN_IN"

            onVisibleChanged: {
                if (!visible) {
                    clear()
                }
            }

            /**
             * @brief Clears the current item's text field and forces the page's state to SIGN_IN.
             */
            function clear() {
                if(content.item) content.item.clear();
                sign_in_item.state = "SIGN_IN";
            }

            /**
             * @brief Signal emitted when box_button is clicked.
             */
            Connections {
                target: centercontent.item
                ignoreUnknownSignals: true
                onSubmitClicked: {
                    if(target.isAcceptable()) {
                        var data = target.getInput().split(":", 2)

                        if(sign_in_item.state === "SIGN_IN") {
                            console.log("** Login ******************************")
                            console.log("Cell phone number: " + data[0])
                            console.log("         Passcode: " + data[1])
                            console.log("***************************************")
                        }
                        else if(sign_in_item.state === "REGISTER") {
                            console.log("** Register ***************************")
                            console.log("Cell phone number: " + data[0])
                            console.log("***************************************")
                            main.state = "RegisterState"
                        }
                        else if(sign_in_item.state === "FORGOT_PASSWORD") {
                            console.log("** Forgot Password ********************")
                            console.log("Cell phone number: " + data[0])
                            console.log("***************************************")
                            sign_in_item.state = "ENTER_CODE"
                        }
                        else if(sign_in_item.state === "ENTER_CODE") {
                            console.log("** Enter Code *************************")
                            console.log("Verification Code: " + data[0])
                            console.log("***************************************")
                            sign_in_item.state = "NEW_PASSWORD"
                        }
                        else if(sign_in_item.state === "NEW_PASSWORD") {
                            console.log("** New Password************************")
                            console.log("New Password: " + data[0])
                            console.log("***************************************")
                            sign_in_item.state = "SIGN_IN"
                            main.state = "HomeState"
                        }
                    } else {
                        // Warning / Mark bad field
                    }
                }
            }

            Row { // Holds left area of buttons, main center area and keypad
                id: signin_layout_b
                anchors {
                    horizontalCenter: parent.horizontalCenter
                    top: parent.top
                }
                width: 976 * main.hScaleFactor
                height: parent.height
                spacing: 80 * main.hScaleFactor

                Column { // Holds sign in, register and forgot password buttons
                    width: 182 * main.hScaleFactor
                    height: parent.height
                    spacing: 15 * main.vScaleFactor

                    StandardButton {
                        id: signInButton
                        anchors.horizontalCenter: parent.horizontalCenter
                        buttonText: qsTr("SIGN IN") + application.emptyString
                        textColor: main.colorFontLight
                        selected: (sign_in_item.state === "SIGN_IN")
                        onClicked: sign_in_item.state = "SIGN_IN"

                        icon.sourceName: "HomeScreen/SignInRegisterIcon"
                    }

                    StandardButton {
                        id: registerButton
                        anchors.horizontalCenter: parent.horizontalCenter
                        buttonText: qsTr("REGISTER") + application.emptyString
                        textColor: main.colorFontLight
                        selected: (sign_in_item.state === "REGISTER")
                        onClicked: sign_in_item.state = "REGISTER"

                        icon.sourceName: "SignIn/RegisterIcon"
                    }

                    Item {
                        width: 15 * main.hScaleFactor
                        height: 67 * main.vScaleFactor
                    }

                    Item {
                        id: lastItem
                        width: 182 * main.hScaleFactor
                        height: 93 * main.vScaleFactor
                        anchors.horizontalCenter: parent.horizontalCenter

                        StandardButton {
                            id: forgotPasswordButton
                            visible: (sipage.isSignIn)
                            anchors.horizontalCenter: parent.horizontalCenter
                            buttonText: qsTr("FORGOT PASSWORD") + application.emptyString
                            textColor: main.colorFontLight
                            selected: (sign_in_item.state === "FORGOT_PASSWORD")
                            onClicked: sign_in_item.state = "FORGOT_PASSWORD"
                            onVisibleChanged: console.log("The visibility of the FP button is: " + !sipage.isSignIn.toString() + "\nInfo on QR: " + (!(sipage.isSignIn)).toString() + " " + qrCodeToPortal.visible.toString())

                            icon.sourceName: "SignIn/ForgotPasswordIcon"
                            
                        }
                        ScalableImage {
                            id: qrCodeToPortal
                            visible: forgotPasswordButton.visible ? false : true
                            anchors.top: lastItem.top
                            anchors.horizontalCenter: parent.horizontalCenter
                            sourceName: "Bluetooth/TRUE_Portal_QR";
                            fillMode: Image.PreserveAspectFit
                            width: 76 * main.hScaleFactor
                            height: 76 * main.vScaleFactor
                            onVisibleChanged: console.log("The visibility of the QR code is: " + !sipage.isSignIn.toString())
                        }
                    }
                }

                Loader { // Main content
                    id: centercontent
                    width: 418 * main.hScaleFactor
                    height: 391 * main.vScaleFactor
                    source: "SignIn_SIBox.qml"
                }

                Keypad { // Keypad
                    id: keypad
                    width: 216 * main.hScaleFactor
                    height: parent.height
                    color: "transparent"
                    show_entry: false
                }
            }

            states: [
                State {
                    name: "SIGN_IN"

                    PropertyChanges { target: sipage; title: qsTr("WELCOME BACK!")  + application.emptyString; }
                    PropertyChanges { target: signInButton; selected: true }
                    PropertyChanges { target: registerButton; selected: false }
                    PropertyChanges { target: forgotPasswordButton; visible: true; selected: false }
                    PropertyChanges { target: centercontent; source: "SignIn_SIBox.qml" }
                },
                State {
                    name: "REGISTER"

                    PropertyChanges { target: sipage; title: qsTr("CREATE ACCOUNT") + application.emptyString; }
                    PropertyChanges { target: signInButton; selected: false }
                    PropertyChanges { target: registerButton; selected: true }
                    PropertyChanges { target: forgotPasswordButton; visible: false; selected: false }
                    PropertyChanges { target: centercontent; source: "SignIn_RegBox.qml" }
                },
                State {
                    name: "FORGOT_PASSWORD"

                    PropertyChanges { target: sipage; title: qsTr("FORGOT PASSWORD") + application.emptyString; }
                    PropertyChanges { target: signInButton; selected: false }
                    PropertyChanges { target: registerButton; selected: false }
                    PropertyChanges { target: forgotPasswordButton; visible: true; selected: true }
                    PropertyChanges { target: centercontent; source: "SignIn_FPBox.qml" }
                },
                State {
                    name: "ENTER_CODE"

                    PropertyChanges { target: sipage; title: qsTr("ENTER CODE") + application.emptyString; }
                    PropertyChanges { target: forgotPasswordButton; visible: true; }
                    PropertyChanges { target: centercontent; source: "SignIn_ECBox.qml" }
                },
                State {
                    name: "NEW_PASSWORD"

                    PropertyChanges { target: sipage; title: qsTr("NEW PASSWORD") + application.emptyString; }
                    PropertyChanges { target: forgotPasswordButton; visible: true; }
                    PropertyChanges { target: centercontent; source: "SignIn_NPBox.qml" }
                }
            ]
        }
    }
}
