
/**
 * @brief Checks that the date is valid.
 * @param type:int year The year value to check.
 * @param type:int month The month value to check.
 * @param type:int day The day value to check.
 * @return type:bool Returns true if the date is valid and false otherwise.
 */
function checkDate(year, month, day) {
    var valid = (year > 0) && (month > 0) && (day > 0);

    if(valid) {
        switch(month) {
            // 31-day months
        case 1:  // Jan
        case 3:  // Mar
        case 5:  // May
        case 7:  // Jul
        case 8:  // Aug
        case 10: // Oct
        case 12: // Dec
            valid = (day <= 31);
            break;

            // 30-day months
        case 4:  // Apr
        case 6:  // Jun
        case 9:  // Sep
        case 11: // Nov
            valid = (day <= 30);
            break;

            // February...
        case 2:  // Feb
            valid = (day <= 28);
            // Day = 29 is valid on a leap year
            if(!valid && (day === 29)) {
                // Leap years occur when:
                //   Year is divisible by 4
                //   Year is not divisible by 100
                //   Except when year is divisible by 400
                //   (e.g., 1800, 1900, 2100 are not leap years, but 2000 is)
                valid = (year%4 === 0) && (year%100 !== 0 || year%400 === 0);
            }
            break;
        default:
            valid = false;
            break;
        }
    }

    return valid;
}
