import QtQuick 2.12
import Process 0.1
import FileIO 1.0
import ".."
import Components 1.0
import Television 1.0


// This element represents the television tuner and its channel scan results.
Item {
    id: root
    visible: false

    anchors.fill: parent

    property bool on: false
    property string mrl
    property real aspect: videoPlayer.aspect > 0 ? videoPlayer.aspect : 1.333
    property alias playing: videoPlayer.playing
    property bool recording: tvRecordingManager.recording

    property alias player: videoPlayer
  //  property alias fullscreen: videoPlayer.fullscreen
    property bool fullscreen:false
    property alias playerOnly: videoPlayer.playerOnly
    property bool tuning: videoPlayer.tuning
    property bool muted: false
    property alias channelList: chanList
    property int currentChannel: -1
    property string currentChannelID: ""
    property string lastChannelID: ""
    property string tunerType
    property string scriptsdir: "scripts"
    property string channelFile: "/data/tv_conf.xml"
    property int numCaptionTracks: videoPlayer.numCaptionTracks
    property alias captionTrack: videoPlayer.captionTrack
    property alias lastCaptionTrack: videoPlayer.lastCaptionTrack
    property bool tuningTimedOut: false
//    property bool vlcErrorOccurred: videoPlayer.vlcErrorOccurred
    property bool isIpodInput: false
    property bool bcasCardPresent: false
    property bool proIdiomPresent: false
    property bool verbose: false
    property string audioDeviceNumber: "0"
    property string analogDeviceNumber: "1"
    property string tvAlsaDevice:"hw:" + (tunerType === "DVB-T2" && fileio.resolveSymlink("/dev/video2") === "/dev/video1" ? "2" : analogDeviceNumber) + ",0"
    property alias tuneTimes: tuneTimes
   // property alias firstTune: videoPlayer.firstTune
    property bool firstTune: false
    property variant viewParent
    property bool disconnectwifi:false
    property bool showclosecaption:false


    signal clicked()
    signal tuningTimeout()

    ChannelList {
        id: chanList
    }
    function showScreen()
    {
        fullscreenVideoFrame.showRect()
        tv.fullscreen=true
    }

    function restoreChannel() {
        console.log("Television: Restoring last channel: ", lastChannelID);

        if (lastChannelID !== "") {
            tuneChannelID(lastChannelID);
        }
    }
    function tuneLastChannel()
    {
       tuneChannelID(currentChannelID)
     }

    function tuneChannelID(id) {
        if (root.currentChannelID !== "") {
            lastChannelID = currentChannelID;
        }

        if(id === "IPODINPUT") {
            //special case for IPODINPUT - an AUX channel not in the channel list
            root.isIpodInput = true;
            root.currentChannel = -1;
            root.currentChannelID = "";
            root.mrl = chanList.getAuxMrl("NTSC_M");

            if (!bluetoothAdapter.connectedHeadset) {
                root.mrl += ":live-caching=15";
            }

            return;
        } else {
            root.isIpodInput = false;
            audioManager.tvRequest();
        }

        var idx = chanList.findChannel(id);

        if(idx >= 0) {
            root.currentChannel = idx;
            root.currentChannelID = id;
            root.on = true;
        } else {
            root.currentChannelID = "";
        }

        if (lastChannelID === "") {
            lastChannelID = currentChannelID;
        }
    }

    function channelUp() {
        var idx = root.currentChannel;

        if(idx < chanList.channels.count-1) {
            idx++;
        } else {
            idx = 0;
        }

        var chanid = chanList.channels.get(idx).id;

        if(chanid) {
            tuneChannelID(chanid);
        }
    }

    function channelDown() {
        var idx = root.currentChannel;
        if(idx > 0) {
            idx--;
        } else {
            idx = channelList.channels.count - 1;
        }

        var chanid = chanList.channels.get(idx).id;

        if(chanid) {
            root.on = true;
            tuneChannelID(chanid);
        }
    }

    // switch off the TV
    function stop() {
        root.on = false;
    }

    Component.onCompleted: {
        tunerDetect.start();
        bcasDetect.start();
        proIdiomDetect.start();
        chanList.readChannels(root.channelFile);
        audioDeviceNumberDetect.start();
    }
    onOnChanged: {
        console.log("TV " + (on ? "on" : "off"));

        if(on) {
            resetSize()
            root.mrl = getTVMrl();
            console.log("TV MRL:" + root.mrl)
           if(workoutScreen.showingMirror===true)
            {
                videoPlayer.mrl="rtp://@:1991"
            }
            else{
            videoPlayer.mrl = root.mrl
            }
            videoPlayer.play();
            if (tv.numCaptionTracks > 0) {
                console.log("TV on, caption track: " + root.captionTrack)
            } else {
                console.log("TV on, no captions.")
            }
        } else {
            tuningTimer.stop();
            videoPlayer.stop();
        }
    }

    onPlayingChanged: {
        if(playing)
        {
       if(root.firstTune && !workoutScreen.showingMirror)
        {
           root.on=false
            root.firstTune=false
           root.on=true
            console.log("first tuneeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeee")
        }
       }



       /* console.log("**********************************************************")
        if(root.firstTune) {
            if(playing) {
                // First tune or closed caption call on analog doesn't have sound, so retry
               // root.captionTrack = root.numCaptionTracks > 0 ? (root.captionTrack + 1) % root.numCaptionTracks : 0
               console.log("retrying first tune, muted===================================== " + tv.muted + ", captionTrack: " + root.captionTrack + ", lastCaptionTrack: " + root.lastCaptionTrack)
                root.on = false
            } else {
                root.firstTune = false
                root.on = true
            }
        }*/
    }

    function getChannelObject() {
        return root.channelList.channels.get(currentChannel);
    }

    // get the current channel mrl, given the selected channel number
    function getTVMrl() {
        var mrl;

        if(root.channelList.channels.get(currentChannel)) {
            mrl = chanList.getMrl(currentChannel);
            return mrl;
        } else {
            return "";
        }
    }

    function tunedToCab() {
        return currentChannel >= 0 && channelList.channels.count === 1;
    }

    function changeParent(p) {
        root.parent = p
        resetSize()
    }

    function resetSize() {
        if(parent) {
            root.anchors.left = parent.left
            root.anchors.top = parent.top
            root.width = parent.width
            root.height = parent.height
            videoPlayer.resetSize();
            console.log("Update TV size:" + root.x + ", " + root.y + ", " + root.width + ", " + root.height)
        }
    }

    onCurrentChannelChanged: {
        if(!on) {
            return
        }


        root.mrl = getTVMrl()
    }

    onMrlChanged: {
       workoutScreen.state=""
       videoPlayer.stop()
        print("TV MRL:" + mrl)
      videoPlayer.mrl = ""
        videoPlayer.mrl = mrl
        videoPlayer.play()
       // mrlTimer.start()
    }
   /* Timer {
        id: mrlTimer
        interval: 2000
        onTriggered: {
            console.log("&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&")
            mrlTimer.stop()
            videoPlayer.mrl = ""
            videoPlayer.mrl = mrl

        }
    }*/

    FileIO
    {
        id: fileio
    }

    onTuningChanged: {
        if(root.tuning) {
            if (tv.on) {
                tuningTimer.restart()
                root.tuningTimedOut = false
            }
        } else {
            tuningTimer.stop()
        }
    }

    Timer {
        id: tuningTimer
        interval: 7000
        onTriggered: {
            root.tuningTimedOut = true
            root.tuningTimeout()
            videoPlayer.stop()
//            videoPlayer.play()
        }
    }

    ListModel {
        id: tuneTimes
        property int numberTimesToStore: 8
        function appendTuneTime(timeMs) {
            if (tuneTimes.count >= numberTimesToStore) {
                tuneTimes.remove(0)
            }
            tuneTimes.append({"time": timeMs})
        }
    }

  /*  Timer
    {
        id:disableOverlay
        interval: 10000
        repeat: true
        onTriggered:
        {
            videoPlayer.setOverlayFlag(false)
            videoPlayer.disableOverlayText()

        }

    }*/
   /* function showOverlayOnFullscreen()
    {
        if(videoPlayer.fullscreen)
        {
            disableOverlay.stop()
            videoPlayer.overlayFlag=true
        }

    }*/

    VLCVideo {
        id: videoPlayer
        objectName: "television"
        anchors.fill: parent

      //  property string line1: main.isTreadmill ? qsTr("INCLINE") : qsTr("LEVEL") + application.emptyString
      //  property string line2: main.isTreadmill ? (workoutManager.treadInclineGUI/10.0).toFixed(1) : workoutManager.workloadLevel
        //property string line3: main.isTreadmill ? (qsTr("%") + application.emptyString) : ""
      //  property string leftText: line1 + "\n" + line2 + "\n"// + line3

      //  property string speedStr: workoutScreen.unitState === "ENGLISH" || main.isStepmill ? workoutManager.treadSpeedGUI : workoutManager.treadSpeedMetricGUI.toFixed(1)
       // property string speedUnits: main.isStepmill ? qsTr("SPM") : (workoutScreen.unitState === "ENGLISH" ? qsTr("MPH") : qsTr("KPH") ) + application.emptyString
       // property string line4: ((main.isTreadmill || main.isStepmill) ? qsTr("SPEED") : qsTr("RPM")) + application.emptyString
       // property string line5: (main.isTreadmill ? (speedStr/10.0).toFixed(1) :
                                                  // (main.isStepmill ? speedStr : machinecontrol.pedalRPM))  + application.emptyString
        //property string line6: ((root.isTreadmill || main.isStepmill) ? speedUnits : "" ) + application.emptyString
      //  property string rightText: line4 + "\n" + line5 + "\n" + line6

        //textOnLeft: true
        //overlayTextR: rightText
       // overlayTextL: leftText





        /*onOverlayFlagChanged:
        {
           // main.showRect()

           /* if(videoPlayer.overlayFlag===true)
            {

             overlayFlag=true
            disableOverlay.start()
            }*/

       // }


        scaleHDTV: options.downscaleHDTV
        commandLineArgs: {
            var args = ["--video-filter=deinterlace", "--deinterlace=-1"]//, "--v4l2-use-libv4l2"
            args = args.concat(["--avcodec-skiploopfilter=4"])
            //args = args.concat(["--dropped-frame-stats", "-vvv", "--ts-silent"])
            if (root.verbose) {
              args = args.concat(["-vvvv"])
            } else {
              //args = args.concat([ "--quiet", "--ts-silent" ])
            }

            if(options.tvHwAccel) {
                args = args.concat(["--avcodec-hw=vaapi"])
            } else {
                args = args.concat(["--avcodec-hw=none"])
            }

            if(options.tvNoFrameDrop) {
                args = args.concat(["--no-drop-late-frames", "--avcodec-skip-frame=1"])
            }

            return args
        }
//        onMediaError: root.tuningTimedOut = true
//        debug: true

        // don't stream audio from tuner if it is already coming from RCA jacks or iPod
        audioDevice: root.isIpodInput && !bluetoothAdapter.connectedHeadset ? "hw:" + audioDeviceNumber + ",0" : root.tvAlsaDevice
//        deinterlace: false
        muted: root.muted

        onPlaybackStarted: {
            if(options.autoChannelChangeInterval > 99) {
                tuneTimePopup.message = tuneTime/1000.0 + " seconds"
                tuneTimePopup.showWithTimeout(1)
            }
            console.log("Tune time:", tuneTime)
            tuneTimes.appendTuneTime(tuneTime)
            console.log(tuneTimes.count)
            var chan = root.getChannelObject()
            var freq = chan.freq
            console.log("TUNETIME", freq, tuneTime, tv.mrl);

//            if(root.firstTune && playing) {
//                // First tune or closed caption call on analog doesn't have sound, so retry
//                root.captionTrack = root.numCaptionTracks > 0 ? (root.captionTrack + 1) % root.numCaptionTracks : 0
//                console.log("retrying first tune, captionTrack: " + root.captionTrack + ", lastCaptionTrack: " + root.lastCaptionTrack)
//            }
        }
      onShowCloseCaption:
       {
           if(showclosecaption===true)
           {
           tv.captionTrack = tv.numCaptionTracks > 0 ? (tv.captionTrack + 1) % tv.numCaptionTracks : 0
           showclosecaption=false
              
           }
        }

       /* onFullscreenChanged: {
            if(tv.fullscreen===true){
            //if(videoPlayer.fullscreen) {
                //changeParent(main)
                console.log("*******************************************************")
                fullscreenVideoFrame.showRect()
                overlayFlag=true
               disableOverlay.start()

            } else {
                changeParent(root.viewParent)
                overlayFlag=false
                disableOverlay.stop()
            }
        }*/

//        onStarted: backgroundFill.visible = false
//        onStopped: backgroundFill.visible = true
        onTuningChanged: if(tv.tuning) backgroundFill.visible = true

        Rectangle {
            id: backgroundFill
            color: "black"
//            visible: tv.tuningTimedOut || !tv.playing
            visible: !tv.playing
//            visible: true
            anchors.fill: parent
            Component.onCompleted: {
                console.log("TV size " + backgroundFill.x + ", " + backgroundFill.y + ", " + backgroundFill.width + ", " + backgroundFill.height)
            }

            Text {
                anchors.centerIn: parent
                color: "white"
                visible: tv.tuningTimedOut && !tv.playing
                text: qsTr("The current channel may be temporarily unavailable.") + application.emptyString
            }
        }
    }

    MessagePopup {
        id: tuneTimePopup
    }

    Process { id: audioDeviceNumberDetect
        program: "scripts/detect_audioDevice.sh"
        onReadyReadStandardOutput: {
            var output = String(readAllStandardOutput())
            output = output.trim()
            var devices = output.split("\n")
            root.audioDeviceNumber = devices[0]
            root.analogDeviceNumber = devices[1]
            console.log("audioDeviceNumberDetect: audio number: " + root.audioDeviceNumber + ", analog number " + root.analogDeviceNumber + ", " + root.tvAlsaDevice)
        }
        onReadyReadStandardError: {
            var output = String(readAllStandardError())
            output = output.trim()
            console.log( "audioDeviceNumberDetect process (STDERR):" + output)
        }
        onStarted: console.debug("audioDeviceNumberDetect Started")
    }

    Process { id: tunerDetect
        program: root.scriptsdir + "/tunertype.sh"
        onReadyReadStandardOutput: {
            var output = String(readAllStandardOutput())
            output = output.trim()
            var tuners = output.split("\n")

            for (var i = 0; i < tuners.length; i++) {
                root.tunerType = tuners[i]
            }
//            channelList.setTunerType(root.tunerType)

            print("tunerDetect process: Tuner type: " + output)
        }
    }

    Process {
        id: bcasDetect
        program: "scripts/detect_bcas.sh"
        onReadyReadStandardOutput: {
            var output = String(readAllStandardOutput())
            output = output.trim()
            console.log( "bcasDetect process (STDOUT): BCAS card present = " + output)
            root.bcasCardPresent = (output === "yes")
            chanList.setBCAS(root.bcasCardPresent)

        }
    }

    Process {
        id: proIdiomDetect
        program: "scripts/detect_proIdiom.sh"
        onReadyReadStandardOutput: {
            var output = String(readAllStandardOutput())
            output = output.trim()
            console.log( "proIdiomDetect process (STDOUT): proIdiom detected = " + output)
            root.proIdiomPresent = (output === "yes")
            chanList.setProIdiom(root.proIdiomPresent)
        }
    }
}
