import QtQuick 2.12
import Components 1.0
import ".."

Item {
    id: root

    property int xOffset: 240
    property int yOffset: 225

    onVisibleChanged: {
        if(visible) {
            tvRecordingPopup.show()
        } else {
            tvRecordingPopup.hide()
        }
    }

    Timer {
        id: countTimer

        property int seconds: 0

        running: tvRecordingManager.recording
        repeat: true
        onTriggered: {
            countTimer.seconds++
        }
        onRunningChanged: {
            countTimer.seconds = 0
        }
    }

    ModalDialog {
        id: tvRecordingPopup
        blockKeys: true
        onTimedOut: hide() // hide the pop-up when timer expires
        visible: false

        property string message

        Item {
            z: tvRecordingPopup.z + 1
            anchors.fill: parent

            ScalableImage {
                id: recordIcon
                anchors.left: parent.left
                anchors.top: parent.top
                anchors.margins: 20 * main.vScaleFactor
                visible: tvRecordingManager.recording
                sourceName: "record_dot";
            }

            Text {
                id: recordText
                visible: tvRecordingManager.recording
                font.bold: false
                font.pixelSize: 24 * main.vScaleFactor
                color: main.colorFontLight
                anchors.verticalCenter: recordIcon.verticalCenter
                anchors.left: recordIcon.right
                text: qsTr("Recording TV") + "... " + Globals.secondsToTime(countTimer.seconds) + application.emptyString
            }

            Text {
                id: copyText
                visible: tvRecordingManager.copying
                anchors.fill: parent
                anchors.margins: 30 * main.vScaleFactor
                anchors.verticalCenter: parent.verticalCenter
                color: main.colorFontLight
                anchors.horizontalCenter: parent.horizontalCenter
                horizontalAlignment: Text.AlignHCenter
                verticalAlignment: Text.AlignVCenter
                wrapMode: Text.WordWrap
                font.bold: false
                font.pixelSize: 50 * main.vScaleFactor
                text: qsTr("Copying file to USB key...") + application.emptyString
            }

            MouseArea {
                anchors.fill: parent
                onClicked: {
                    if(tvRecordingPopup.dismissable) {
                        root.dismissed()
                    }
                }

                Rectangle {
                    anchors.fill: parent
                    color: main.colorGenericStimulusArea
                    opacity: 0.3
                    visible: main.showStimulusArea
                }
            }
        }
    }
}
