import WorkoutRunData 1.0
import WorkoutManager 1.0
import QtQuick 2.12
import "../string_format.js" as Format
import Components 1.0
import "../"
import ".."
import "../Keypad"
import QtQuick.Layouts 1.12

Item {
    id: root

    property int screenHeight: parent.height
    property int screenWidth: parent.width

    property bool isQuickSpeedKeysDisplayed: false
    property bool isLevelPressed:false
    property bool isInclinePressed:false
    property bool isSpeedPressed:false
    property bool isQuickStrideKeysDisplayed: false
    property int currentStride

    property string machineType: machineinfo.productTypeString
    property bool bikeWattsModeEnabled: false

    signal inclinePressed()
    signal levelPressed()
    signal speedPressed()
    signal stopPressed()
    signal strideSelected(int stride)

    height: screenHeight * 0.20
    width: screenWidth

    Component.onCompleted: reset();

    /**
     * Resets the toolbar to its initial state
     */
    function reset() {
        isQuickSpeedKeysDisplayed = false
        isLevelPressed=false
        isInclinePressed=false
        isSpeedPressed=false
        isQuickStrideKeysDisplayed = false
//        isHomeSelected = false
    }


    property string stringTargetSpeed:  {
        var tempSpeed;

        if (main.isStepmill){
            tempSpeed = workoutManager.treadSpeedGUI
            return tempSpeed
        } else if (workoutScreen.unitState === "ENGLISH") {
            tempSpeed = workoutManager.treadSpeedGUI / 10.0
            return tempSpeed.toFixed(1)
        } else {
            tempSpeed = workoutManager.treadSpeedMetricGUI / 10.0
            return tempSpeed.toFixed(1)
        }
    }

    property string stringTargetIncline: (workoutManager.treadInclineGUI / 10.0).toFixed(1)

    property string stringTargetHR: aWorkoutRunData.targetHeartRate.toString()

    function setTreadmillSpeed(speed) {
        if(workoutScreen.unitState === "ENGLISH") {
            workoutManager.treadSpeed = speed * 10
        } else {
            workoutManager.setTreadSpeedMetric(parseFloat(speed) * 10)
        }
    }

    function setStepmillSpeed(speed) {
        workoutManager.treadSpeed = speed
    }

    property string stringLevel: main.isStepmill ? workoutProgram.profile2.currentLevel : workoutManager.workloadLevel
    property string stringRPM: main.isStepmill ? stringTargetSpeed : aWorkoutRunData.rpm

    onIsQuickStrideKeysDisplayedChanged: {
        if (isQuickStrideKeysDisplayed) {
            // Show quick stride keys for 15 seconds
            hideQuickKeysTimer.restart()
        }
    }
    Timer {
        id:keypadTimer
        interval: 15000
        running: false
        repeat: false
        onTriggered:
        {
            isLevelPressed=false
            isInclinePressed=false
            isSpeedPressed=false
        }
    }

    Timer {
        id: hideQuickKeysTimer
        interval: 15000
        running: false
        repeat: false
        onTriggered: {
            if (isQuickStrideKeysDisplayed) {
                isQuickStrideKeysDisplayed = false
            }
        }
    }

    Rectangle {
        color: main.colorToolbarBackground
        anchors.fill: parent
    }

    Component {
        id: control

        Item {
            id: controlRoot
            property string stringLabel: "label"
            property string stringValue: "value"
            property string stringUnit: "unit"
            property string stringMiddleLabel: ""
            property bool controlEnabled: true
            property bool useStimulusArea: true

            signal toggleCalculator()
            signal controlUpClicked()
            signal controlDownClicked()
            signal controlUpReleased()
            signal controlUpFirstPress()

            Row {
                height: parent.height
                width: parent.width

                MouseArea {
                    onClicked: {
                        toggleCalculator()
                        buzzer.buttonPress()
                    }

                    width:  childrenRect.width
                    height: childrenRect.height

                    Rectangle {
                        height: parent.parent.height
                        width: parent.parent.width / 2
                        color: (main.showStimulusArea && useStimulusArea) ? main.colorGenericStimulusArea : main.colorButtonBackground

                        Column {
                            id: info
                            anchors.fill: parent

                            Item {
                                id: labelRectangle
                                height: (parent.height - valueRectangle.height) * 0.5
                                width: parent.width

                                TextLabel {
                                    id: label
                                    text: stringLabel
                                    anchors.fill: parent
                                    horizontalAlignment: Text.AlignHCenter
                                    verticalAlignment: Text.AlignBottom
                                    font.pixelSize: parent.height * 0.3
                                }
                            }

                            Item {
                                id: valueRectangle
                                height: parent.height * 0.4
                                width: parent.width

                                NumberLabel {
                                    id: value
                                    text: stringValue
                                    color: main.colorFontLight
                                    anchors.fill: parent
                                    horizontalAlignment: Text.AlignHCenter
                                    verticalAlignment: Text.AlignVCenter
                                    font.pixelSize: parent.height
                                }
                            }

                            Item {
                                id: unitRectangle
                                height: (parent.height - valueRectangle.height) * 0.5
                                width: parent.width

                                TextLabel {
                                    id: unit
                                    text: stringUnit
                                    anchors.fill: parent
                                    horizontalAlignment: Text.AlignHCenter
                                    verticalAlignment: Text.AlignTop
                                    font.pixelSize: parent.height * 0.3
                                }
                            }
                        }
                    }
                }

                Column {
                    height: parent.height
                    width: parent.width / 2
                    visible: controlRoot.controlEnabled

                    Item {
                        id: upControlItem
                        opacity: 1
                        height: (parent.height - middleLabel.height) / 2
                        width: parent.width

                        ImageButton {
                            id: upControl
                            width: 91 * main.hScaleFactor
                            height: 52 * main.vScaleFactor
                            anchors.centerIn: parent
                            useParentContainerSize: true
                            downimage: ""
                            upimage: ""
                            icon: "../graphics/ui3_0/LowerControlBar/Control_Up_blue.png"
//                            sourceName: "LowerControlBar/Control_Up_blue";
                            repeat: true
                            onClicked: controlUpClicked()
                            onIsDownChanged: {
                                if(isDown === false) {
                                    controlUpReleased()
                                } else {
                                    controlUpFirstPress()
                                }
                            }

                            mouseAreaScale: 1.25
                        }
                    }

                    TextLabel {
                        id: middleLabel
                        height: parent.height * 0.1
                        width: parent.width
                        text: stringMiddleLabel
                        horizontalAlignment: Text.AlignHCenter
                        verticalAlignment: Text.AlignVCenter
                        font.pixelSize: height
                    }


                    Item {
                        id: downControlItem
                        opacity: 1
                        height: (parent.height - middleLabel.height) / 2
                        width: parent.width

                        ImageButton {
                            id: downControl
                            width: 91 * main.hScaleFactor
                            height: 52 * main.vScaleFactor
                            anchors.centerIn: parent
                            useParentContainerSize: true
                            downimage: ""
                            upimage: ""
                            icon: "../graphics/ui3_0/LowerControlBar/Control_Down_blue.png"
//                            icon.sourceName: "LowerControlBar/Control_Down_blue";
                            repeat: true
                            onClicked: controlDownClicked()
                            mouseAreaScale: 1.25
                        }
                    }
                }
            }
        }
    }

    Row {
        anchors.fill: parent

        property real stopButtonWidthPercent: 0.22
        property real controlWidthPercent: 0.18
        property real quickKeyWidthPercent: 0.08
        property real spacerWidthPercent: 0.06
        property real spacerWidthPercent2: 0.10
        property real spacerWidthPercent3: 0.05
        property real speedGuagePercent: 0.075
        opacity: enabled ? 1.0 : 0.5

        Item {
            id: stopButtonItem
            height: parent.height
            width: parent.width * parent.stopButtonWidthPercent

            Rectangle {
                id: stopButton
                border.color: main.colorUIBorder
                border.width: main.widthBorder
                color: main.colorButtonBackground
                anchors {
                    verticalCenter: parent.verticalCenter
                    right: parent.right
                }
                width: 139 * main.hScaleFactor
                height: 113 * main.vScaleFactor
                radius: main.defaultRadius

                ScalableImage {
                    id: stopButtonImage
                    anchors.fill: parent
                    anchors.margins: 22 * main.scaleFactor
                    fillMode: Image.PreserveAspectFit
                    sourceName: "LowerControlBar/Stop_Pause_Icon";
                }

                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        root.stopPressed()
                        workoutScreen.stopButtonPressedHandler()
                        buzzer.buttonPress()
                    }

                    Rectangle {
                        anchors.fill: parent
                        color: main.colorGenericStimulusArea
                        opacity: 0.3
                        visible: main.showStimulusArea
                    }
                }
            }
        }

        Item {
            id: spacerItem
            height: parent.height
            width: parent.width * parent.spacerWidthPercent
        }

        Row {
            id: speedPresetsRow
            height: parent.height
            width: inclineControl.width + spacerItem2.width
            visible: isQuickSpeedKeysDisplayed === true && isLevelPressed===false && isInclinePressed===false && isSpeedPressed===false

            Item {
                id: spacerItemSpeed
                height: parent.height
                width: spacerItem2.width
            }

            Repeater {
                model: main.isStepmill ? stepSpeedsModel : (workoutScreen.unitState === "ENGLISH" ? speedsModel : km_speedsModel)
                delegate: speedDelegate
            }

            // To Do: Convert to steps per minute quick keys for stepmill

            ListModel {
                id: stepSpeedsModel
                ListElement { speed: 3 ; label: "3"; units: qsTr("LEVEL") }
                ListElement { speed: 6 ; label: "6"; units: qsTr("LEVEL") }
                ListElement { speed: 9 ; label: "9"; units: qsTr("LEVEL") }
            }

            ListModel {
                id: speedsModel
                ListElement { speed: 3.0 ; label: "3"; units: qsTr("MPH") }
                ListElement { speed: 5.0 ; label: "5"; units: qsTr("MPH") }
                ListElement { speed: 7.0 ; label: "7"; units: qsTr("MPH") }
            }

            ListModel {
                id: km_speedsModel
                ListElement { speed: 5.0  ; label: "5"  ; units: qsTr("KPH") }
                ListElement { speed: 8.0  ; label: "8"  ; units: qsTr("KPH") }
                ListElement { speed: 11.0 ; label: "11" ; units: qsTr("KPH") }
            }

            Component {
                id: speedDelegate
                Item {
                    height: speedPresetsRow.height
                    width: speedPresetsRow.width / 4
                    visible: model.label <= workoutManager.workoutProgram.maxSpeed

                    Rectangle {
                        border.color: main.colorUIBorder
                        border.width: main.widthBorder
                        color: main.colorButtonBackground
                        width: 90 * main.hScaleFactor
                        height: 113 * main.vScaleFactor
                        radius: main.defaultRadius
                        anchors.centerIn: parent

                        NumberLabel {
                            text: model.label
                            anchors.centerIn: parent
                            horizontalAlignment: Text.AlignHCenter
                            verticalAlignment: Text.AlignVCenter
                            font.pixelSize: parent.height * 0.4
                        }

                        TextLabel {
                            text: model.units
                            anchors.bottom: parent.bottom
                            anchors.bottomMargin: 7 * main.vScaleFactor
                            anchors.horizontalCenter: parent.horizontalCenter
                            font.pixelSize: parent.height * 0.15
                        }

                        MouseArea {
                            anchors.fill: parent
                            onClicked: {
                                workoutManager.stopHRC()
                                if(main.isStepmill){
                                    workoutProgram.profile2.setCurrentLevel(model.speed)
                                    workoutManager.speedLevel = workoutProgram.profile2.currentLevel
                                }else
                                    setTreadmillSpeed(model.speed)

                                buzzer.buttonPress()
                            }

                            Rectangle {
                                anchors.fill: parent
                                color: main.colorGenericStimulusArea
                                opacity: 0.3
                                visible: main.showStimulusArea
                            }
                        }
                    }
                }
            }
        }

        Row {
            id: stridePresetsRow
            height: parent.height
            width: levelControl.width + spacerItem2.width
            visible: isQuickStrideKeysDisplayed === true

            Item {
                id: spacerItemStride
                height: parent.height
                width: spacerItem2.width
            }

            Repeater {
                model: strideModel
                delegate: strideDelegate
            }

            ListModel {
                id: strideModel
                ListElement { stride: 13 ; label: "STEP"; icon: "AdjStride/AS_Step_Icon"; }
                ListElement { stride: 21 ; label: "ELLIPSE"; icon: "AdjStride/AS_Ellipse_Icon"; }
                ListElement { stride: 30 ; label: "RUN"; icon: "AdjStride/AS_Run_Icon"; }
            }

            Component {
                id: strideDelegate
                Item {
                    height: stridePresetsRow.height
                    width: stridePresetsRow.width / 4

                    Rectangle {
                        border.color: main.colorUIBorder
                        border.width: main.widthBorder
                        color: root.currentStride === model.stride ? main.colorHighlightBackground : main.colorButtonBackground
                        width: 90 * main.hScaleFactor
                        height: 113 * main.vScaleFactor
                        radius: main.defaultRadius
                        anchors.centerIn: parent

                        ScalableImage {
                            anchors.centerIn: parent
                            anchors.verticalCenterOffset: -10 * main.vScaleFactor
                            width: 0.9 * parent.width
                            height: 52 * main.vScaleFactor
                            fillMode: Image.PreserveAspectFit

                            sourceName: model.icon
                        }

                        Text {
                            color: main.colorFontLight
                            text: model.label
                            anchors.horizontalCenter: parent.horizontalCenter
                            anchors.bottom: parent.bottom
                            anchors.bottomMargin: 12*main.scaleFactor
                            horizontalAlignment: Text.AlignHCenter
                            verticalAlignment: Text.AlignBottom
                            font.bold: false
                            font.pixelSize: parent.height * 0.12
                            font.family: "Montserrat Semi Bold"
                        }

                        MouseArea {
                            anchors.fill: parent
                            onClicked: {
                                hideQuickKeysTimer.restart()
                                root.strideSelected(model.stride)
                                buzzer.buttonPress()
                            }

                            Rectangle {
                                anchors.fill: parent
                                color: main.colorGenericStimulusArea
                                opacity: 0.3
                                visible: main.showStimulusArea
                            }
                        }
                    }
                }
            }
        }

        Loader {
            id: inclineControl
            sourceComponent: control
            anchors.verticalCenter: parent.verticalCenter
            height: parent.height
            width: parent.width * parent.controlWidthPercent
            visible: isQuickSpeedKeysDisplayed === false && main.isTreadmill && isSpeedPressed===false  //&& isLevelPressed===false

            Binding {
                target: inclineControl.item
                property: "stringLabel"
                value: qsTr("INCLINE") + application.emptyString
            }

            Binding {
                target: inclineControl.item
                property: "stringValue"
                value: stringTargetIncline
            }

            Binding {
                target: inclineControl.item
                property: "stringUnit"
                value: "%"
            }

            Binding {
                target: inclineControl.item
                property: "useStimulusArea"
                value: true
            }

            Connections {
                target: inclineControl.item
                onToggleCalculator:
                {
                    isInclinePressed=!isInclinePressed
                    if(isInclinePressed)
                    keypadTimer.start()
                    else
                        keypadTimer.stop()
                }
                onControlUpClicked: {
                    workoutManager.stopHRC()
                    workoutManager.increaseIncline()
                    if(machineinfo.modelString === "ST1000")
                    centerpod.consoleInclinePressed()
                    diagnostics.logDiagnotsticEvent("XXXX","APP","Button","Incline UP","");
                }
                onControlDownClicked: {
                    workoutManager.stopHRC()
                    workoutManager.decreaseIncline()
                     if(machineinfo.modelString === "ST1000")
                    centerpod.consoleInclinePressed()
                    diagnostics.logDiagnotsticEvent("XXXX","APP","Button","Incline DOWN","");
                }
            }
        }

        Loader {
            id: levelControl
            sourceComponent: control
            anchors.verticalCenter: parent.verticalCenter
            height: parent.height
            width: parent.width * parent.controlWidthPercent
            visible: isQuickSpeedKeysDisplayed === false && !main.isTreadmill && isQuickStrideKeysDisplayed === false  && isSpeedPressed===false //&& isLevelPressed===false

            Binding {
                target: levelControl.item
                property: "stringLabel"
                value: {
                    if (main.isStepmill)
                        return application.emptyString
                    else if(root.bikeWattsModeEnabled)
                        return qsTr("WORKLOAD")
                    else
                        return qsTr("GEAR")
                }
            }

            Binding {
                target: levelControl.item
                property: "stringValue"
                value: qsTr(stringLevel)
            }

            Binding {
                target: levelControl.item
                property: "stringUnit"
                value: qsTr(root.bikeWattsModeEnabled || main.isStepmill ? "LEVEL" : "") + application.emptyString
            }

            Binding {
                target: levelControl.item
                property: "useStimulusArea"
                value: false
            }

            Connections {
                target: levelControl.item
                onToggleCalculator:
                {
                    isLevelPressed=!isLevelPressed
                    if(isLevelPressed)
                    keypadTimer.start()
                    else
                        keypadTimer.stop()
                    //levelPressed()
                }
                onControlUpClicked:{
                    keymapper.keyFunctionHandler(7)
                    diagnostics.logDiagnotsticEvent("XXXX","APP","Button","level UP","");
                }
                onControlDownClicked:{
                    keymapper.keyFunctionHandler(8)
                    diagnostics.logDiagnotsticEvent("XXXX","APP","Button","level DOWN","");
                }
            }
        }

        LowerKeypad {
            id:levelKeyPad

            allow_close: false
            clear_after_enter: false
            show_entry: true
            icon: "Speed_Keypad_Icon"
            onClose: root.resetState();
            width: spacerItem2.width +speedControl.width+paceControl.width+50
            height: parent.height
            visible: isLevelPressed
            onVisibleChanged: {
                if(visible) {
                    levelKeyPad.setValue(workoutManager.workloadLevel)

                }
            }

            Connections {
                target: workoutManager
                onSpeedLevelChanged:levelKeyPad.setValue(workoutManager.speedLevel)
                onWorkloadLevelChanged : levelKeyPad.setValue(workoutManager.workloadLevel)
            }

            onValueEntered: {
                if(main.isStepmill)
                {
                    if(val<=workoutManager.workoutProgram.maxSpeedLevel)
                    {
                        workoutManager.speedLevel=val
                    }else
                        levelKeyPad.setValue((workoutManager.speedLevel))
                }
                else if(val <= workoutManager.workoutProgram.maxWorkloadLevel) {
                    workoutManager.workloadLevel=val
                } else {
                    levelKeyPad.setValue(workoutManager.workloadLevel)
                }
                inclineKeyPad.visible = false;
                diagnostics.logDiagnotsticEvent("XXXX","APP","Button","Set level",val);
            }
        }

        LowerKeypad{
            id:inclineKeyPad

            units: "%"
            decimalPlaces: 1
            allow_close: false
            clear_after_enter: false
            show_entry: true
            icon: "Incline_Keypad_Icon"
            width: spacerItem2.width +speedControl.width+paceControl.width+50
            height: parent.height
            onClose: root.resetState();
            isColorInverted: true
            visible: isInclinePressed
            onVisibleChanged: {
                if(visible) {
                    inclineKeyPad.setValue(workoutManager.treadInclineGUI)
                }
            }

            Connections {
                target: workoutManager
                onTreadInclineGUIChanged: inclineKeyPad.setValue(workoutManager.treadInclineGUI)
            }

            onValueEntered: {
                if(val <= workoutManager.workoutProgram.maxIncline) {
                    var incline = workoutProgram.tableClosestValue(workoutProgram.inclineTable, val * 10)
                    console.log("WorkoutScreen: Incline set via on-screen keypad")
                    workoutManager.stopHRC()
                    workoutManager.treadIncline = incline
                } else {
                    inclineKeyPad.setValue(workoutManager.treadInclineGUI)
                }

                diagnostics.logDiagnotsticEvent("XXXX","APP","Button","Set incline",val);
            }
        }

        LowerKeypad {
            id:speedKeyPad

            units: main.isStepmill ? qsTr("SPM") : workoutScreen.unitState === "ENGLISH" ? qsTr("MPH") : qsTr("KPH")
            decimalPlaces: main.isStepmill ? 0 : 1
            allow_close: false
            clear_after_enter: false
            show_entry: true
            icon: "Speed_Keypad_Icon"
            width: (inclineControl.width+spacerItem2.width +quickSpeedToggleButtonItem.width+paceControl.width)-100
            height: parent.height
            onClose: root.resetState()
            isColorInverted: true
            visible:isSpeedPressed
            onVisibleChanged: {
                if(visible) {
                    speedKeyPad.units= main.isStepmill ? qsTr("SPM") : workoutScreen.unitState === "ENGLISH" ? qsTr("MPH") : qsTr("KPH")
                    speedKeyPad.setValue(convertedTreadSpeed)
                    //console.debug()
                }
            }

            property int convertedTreadSpeed: workoutScreen.unitState === "METRIC" && !main.isStepmill ? workoutManager.treadSpeedMetricGUI : workoutManager.treadSpeedGUI

            onConvertedTreadSpeedChanged:
            {
                speedKeyPad.units=main.isStepmill ? qsTr("SPM") : workoutScreen.unitState === "ENGLISH" ? qsTr("MPH") : qsTr("KPH")
                speedKeyPad.setValue(speedKeyPad.convertedTreadSpeed)
            }

            Connections {
                target: workoutManager
                onTreadSpeedGUIChanged: speedKeyPad.setValue(speedKeyPad.convertedTreadSpeed)
            }

            onValueEntered: {
                var myVal = val
                console.log("%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%")

                if (workoutScreen.unitState === "METRIC") {
                    myVal = Globals.kmToMile(parseFloat(val))
                }

                if((myVal >= workoutManager.workoutProgram.minSpeed) && myVal <= workoutManager.workoutProgram.maxSpeed) {
                    workoutManager.stopHRC()
                    console.log("WorkoutScreen: Speed set via on-screen keypad")

                    if (main.isStepmill)
                        workoutManager.treadSpeed = myVal
                    else if(workoutScreen.unitState === "ENGLISH") {
                        workoutManager.treadSpeed = myVal * 10
                    } else {
                        workoutManager.setTreadSpeedMetric(parseFloat(val) * 10)
                    }
                } else if(myVal < workoutManager.workoutProgram.minSpeed) {
                    console.log("WorkoutScreen: Speed set via on-screen keypad. Value entered less than minimum.")
                    workoutManager.stopHRC()
                    workoutManager.treadSpeed = main.isStepmill ? workoutManager.workoutProgram.minSpeed : workoutManager.workoutProgram.minSpeed*10
                    speedKeyPad.setValue(convertedTreadSpeed)
                } else {
                    speedKeyPad.setValue(convertedTreadSpeed)
                }
                diagnostics.logDiagnotsticEvent("XXXX","APP","Button","Set Speed",val);
                console.log("*******************************************************")
                //speedKeyPad.units=unitState

            }

            // re-translate the strings when the language changes
            Connections {
                target: application
                onLanguageChanged: {
                    speedKeyPad.units = main.isStepmill ? qsTr("SPM") : workoutScreen.unitState === "ENGLISH" ? qsTr("MPH") : qsTr("KPH")
                }
            }
        }

        Item {
            id: spacerItem2
            height: parent.height
            width: parent.width * parent.spacerWidthPercent2
            visible: isQuickSpeedKeysDisplayed === false && isQuickStrideKeysDisplayed === false && workoutProgram.isHRCProgram === false && isLevelPressed===false && isInclinePressed===false && isSpeedPressed===false
        }

        Loader {
            id: hrAdjustControl
            sourceComponent: control
            anchors.verticalCenter: parent.verticalCenter
            height: parent.height
            width: parent.width * parent.controlWidthPercent
            visible: options.enableProtoGraphs && isLevelPressed===false && isSpeedPressed===false && isInclinePressed===false && isQuickSpeedKeysDisplayed === false && isQuickStrideKeysDisplayed === false && (workoutProgram.isHRCProgram || workoutManager.cruiseControlEnabled)

            Binding {
                target: hrAdjustControl.item
                property: "stringLabel"
                value: qsTr("HR Target") + application.emptyString
            }

            Binding {
                target: hrAdjustControl.item
                property: "stringValue"
                value: stringTargetHR
            }

            Binding {
                target: hrAdjustControl.item
                property: "stringUnit"
                value: qsTr("BPM") + application.emptyString
            }

            Binding {
                target: hrAdjustControl.item
                property: "useStimulusArea"
                value: true
            }

            Connections {
                target: hrAdjustControl.item
                onControlUpClicked: workoutManager.increaseHRTarget()
                onControlDownClicked: workoutManager.decreaseHRTarget()
            }
        }

        Item {
            id: quickSpeedToggleButtonItem
            height: parent.height
            width: parent.width * parent.quickKeyWidthPercent

            visible: (main.isTreadmill || main.isStepmill) && !(workoutProgram.isFitnessTest && !workoutProgram.isMilitaryTest) && isLevelPressed===false && isSpeedPressed===false && isInclinePressed===false

            Rectangle {
                id: quickSpeedToggleButton
                border.color: isQuickSpeedKeysDisplayed ? main.colorUIBorder : "transparent"
                border.width: main.widthBorder
                radius: main.defaultRadius
                color: main.colorButtonBackground
                anchors.left: parent.horizontalCenter
                anchors.verticalCenter: parent.verticalCenter
                width: 76 * main.hScaleFactor
                height: 64 * main.vScaleFactor
                //visible:isLevelPressed===false && isSpeedPressed===false && isInclinePressed===false

                ScalableImage {
                    id: quickSpeedToggleButtonIcon
                    anchors.fill: parent
                    anchors.centerIn: parent
                    anchors.margins: 10 * main.scaleFactor
                    fillMode: Image.PreserveAspectFit

                    sourceName: main.isStepmill ? "LowerControlBar/Quick_Step_Icon" : "WF/WF_Button_Speed_Workout";
                }

                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        isQuickSpeedKeysDisplayed = !isQuickSpeedKeysDisplayed
                        if(isQuickSpeedKeysDisplayed)
                            //inclinePressed()  // hide calculator if quick keys showing
                            //isInclinePressed=false
                            buzzer.buttonPress()
                    }

                    Rectangle {
                        anchors.fill: parent
                        color: main.colorGenericStimulusArea
                        opacity: 0.3
                        visible: main.showStimulusArea
                    }
                }
            }
        }

        Item {
            id: quickStrideToggleButtonItem
            height: parent.height
            width: parent.width * parent.quickKeyWidthPercent
            visible: machineType === "Adjustable Stride Elliptical" && isLevelPressed===false && isInclinePressed===false && isSpeedPressed===false

            Rectangle {
                id: quickStrideToggleButton
                border.color: isQuickStrideKeysDisplayed ? main.colorUIBorder : "transparent"
                border.width: main.widthBorder
                radius: main.defaultRadius
                color: main.colorButtonBackground
                anchors.left: parent.horizontalCenter
                anchors.verticalCenter: parent.verticalCenter
                width: 76 * main.hScaleFactor
                height: 64 * main.vScaleFactor

                ScalableImage {
                    id: quickStrideToggleButtonIcon
                    anchors.fill: parent
                    anchors.centerIn: parent
                    anchors.margins: 10 * main.scaleFactor
                    fillMode: Image.PreserveAspectFit

                    sourceName: "AdjStride/AS_Run_Icon";
                }

                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        isQuickStrideKeysDisplayed = !isQuickStrideKeysDisplayed
                        buzzer.buttonPress()
                    }

                    Rectangle {
                        anchors.fill: parent
                        color: main.colorGenericStimulusArea
                        opacity: 0.3
                        visible: main.showStimulusArea
                    }
                }
            }
        }

        Item {
            id: intensifierToggleButtonItem
            height: parent.height
            width: parent.width * parent.quickKeyWidthPercent
            visible: main.isLateralTrainer && intensifierToggleButton.allowed && isLevelPressed===false && isInclinePressed===false && isSpeedPressed===false

            Rectangle {
                id: intensifierToggleButton
                border.color: intensifierActive ? main.colorUIBorder : "transparent"
                border.width: main.widthBorder
                radius: main.defaultRadius
                color: main.colorButtonBackground
                anchors.left: parent.horizontalCenter
                anchors.verticalCenter: parent.verticalCenter
                width: 60 * main.hScaleFactor
                height: 60 * main.vScaleFactor

                property bool allowed: !workoutProgram.isHRCProgram &&
                                       !workoutProgram.isFitnessTest &&
                                       !workoutManager.cruiseControlEnabled
                property bool intensifierActive: workoutManager.intensifierEnabled

                ScalableImage {
                    id: intensifierToggleButtonIcon
                    anchors.fill: parent
                    anchors.centerIn: parent
                    anchors.margins: 10 * main.scaleFactor
                    fillMode: Image.PreserveAspectFit

                    sourceName: "LowerControlBar/Intensifier_Icon";
                }

                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        workoutManager.intensifierEnabled = !workoutManager.intensifierEnabled
                        buzzer.buttonPress()
                    }

                    Rectangle {
                        anchors.fill: parent
                        color: main.colorGenericStimulusArea
                        opacity: 0.3
                        visible: main.showStimulusArea
                    }
                }
            }
        }

        Item {
            id: spacerItemSpeedGuage
            height: parent.height
            width: parent.width * parent.speedGuagePercent
            visible: root.bikeWattsModeEnabled && isLevelPressed===false && isInclinePressed===false && isSpeedPressed===false
        }

        ScalableImage {
            id: bikeModeMPHGauge
            visible: !root.bikeWattsModeEnabled && isLevelPressed===false
            height: parent.height
            width: parent.width * parent.speedGuagePercent
            sourceName: "BikeMode/SPEED_METER_bikemode";
            anchors.margins: 15 * main.scaleFactor
            anchors.verticalCenter: parent.verticalCenter
            fillMode: Image.PreserveAspectFit

            NumberLabel {
                id:value
                anchors.verticalCenter: parent.verticalCenter
                anchors.horizontalCenter: parent.horizontalCenter
                text: {
                    if (workoutScreen.unitState === "ENGLISH") {
                        aWorkoutRunData.bikeSpeedMph.toFixed(1)
                    } else {
                        Globals.mileToKm(aWorkoutRunData.bikeSpeedMph).toFixed(1)
                    }
                }
                font.pixelSize: 26 * main.vScaleFactor
            }

            TextLabel {
                id: label
                anchors.top: value.bottom
                anchors.topMargin: -2 * main.vScaleFactor
                anchors.horizontalCenter: parent.horizontalCenter
                text: workoutScreen.unitState === "ENGLISH" ? qsTr("MPH") : qsTr("KPH")
                font.pixelSize: 10 * main.vScaleFactor
            }
        }

        Loader {
            id: speedControl
            sourceComponent: control
            anchors.verticalCenter: parent.verticalCenter
            height: parent.height
            width: parent.width * parent.controlWidthPercent
            visible: main.isTreadmill && isLevelPressed===false && isInclinePressed===false

            Binding {
                target: speedControl.item
                property: "stringLabel"
                value: qsTr(main.isStepmill ? "":"SPEED")+ application.emptyString
            }

            Binding {
                target: speedControl.item
                property: "stringValue"
                value: stringTargetSpeed
            }

            Binding {
                target: speedControl.item
                property: "stringUnit"
                value: (workoutScreen.unitState === "ENGLISH" ? qsTr("MPH") : qsTr("KPH"))
            }

            Binding {
                target: speedControl.item
                property: "useStimulusArea"
                value: true
            }

            Connections {
                target: speedControl.item
                onToggleCalculator: {

                    isSpeedPressed=!isSpeedPressed
                    if(isSpeedPressed)
                    keypadTimer.start()
                    else
                        keypadTimer.stop()
                }
                onControlUpClicked: {
                    console.debug("level: "+ workoutProgram.level)
                    workoutManager.stopHRC()
                     if(machineinfo.modelString === "ST1000")
                    centerpod.consoleSpeedPressed()
                    if(workoutScreen.unitState === "ENGLISH" || main.isStepmill) {
                        workoutManager.increaseSpeed(workoutManager.withLimit);
                    } else {
                        workoutManager.increaseSpeedMetric(workoutManager.withLimit);
                    }
                    diagnostics.logDiagnotsticEvent("XXXX","APP","Button","Speed UP","");
                }
                onControlDownClicked: {
                    workoutManager.stopHRC()
                     if(machineinfo.modelString === "ST1000")
                    centerpod.consoleSpeedPressed()
                    if(workoutScreen.unitState === "ENGLISH" || main.isStepmill) {
                        workoutManager.decreaseSpeed(false);
                    } else {
                        workoutManager.decreaseSpeedMetric(false);
                    }
                    diagnostics.logDiagnotsticEvent("XXXX","APP","Button","Speed DOWN","");
                }
                onControlUpFirstPress: {
                    workoutManager.speedUpEnabled = true
                }
                onControlUpReleased: {
                    workoutManager.speedUpEnabled = false
                }
            }
        }

        Loader {
            id: paceControl
            sourceComponent: control
            anchors.verticalCenter: parent.verticalCenter
            height: parent.height
            width: parent.width * parent.controlWidthPercent + (paceControl.isPaceSetter ? 0.05 * main.screenWidth : 0)
            visible: !main.isTreadmill && isLevelPressed===false && isInclinePressed===false && isSpeedPressed===false

            property bool isPaceSetter: workoutProgram.displayDataVars.paceSetterAvailable

            Binding {
                target: paceControl.item
                property: "stringLabel"
                value: ( (root.bikeWattsModeEnabled || main.isStepmill) ? qsTr("PACE") : qsTr("CADENCE")) + application.emptyString
            }

            Binding {
                target: paceControl.item
                property: "stringValue"
                value: stringRPM
            }

            Binding {
                target: paceControl.item
                property: "stringUnit"
                value: main.isStepmill ? qsTr("SPM") : qsTr("RPM")
            }

            Binding {
                target: paceControl.item
                property: "stringMiddleLabel"
                value: paceControl.isPaceSetter ? "PACESETTER" : ""
            }

            Binding {
                target: paceControl.item
                property: "controlEnabled"
                value: paceControl.isPaceSetter
            }

            Binding {
                target: paceControl.item
                property: "useStimulusArea"
                value: false
            }

            Connections {
                target: paceControl.item
                onControlUpClicked: {
                    workoutManager.stopHRC()
                    workoutManager.increasePaceLevel()
                    diagnostics.logDiagnotsticEvent("XXXX","APP","Button","Pace UP","");
                }
                onControlDownClicked: {
                    workoutManager.stopHRC()
                    workoutManager.decreasePaceLevel()
                    diagnostics.logDiagnotsticEvent("XXXX","APP","Button","Pace DOWN","");
                }
            }
        }

        Item {
            id: paceLevelMeter

            property int rpmMax: 120
            property int rpmMin: 40

            property int paceTarget: workoutManager.paceTarget < rpmMin ? rpmMin : (workoutManager.paceTarget > rpmMax ? rpmMax : workoutManager.paceTarget)
            property int adjustedRPM: aWorkoutRunData.rpm < rpmMin ? rpmMin : (aWorkoutRunData.rpm  > rpmMax ? rpmMax : aWorkoutRunData.rpm )

            property real paceTargetPercent: 0.95*(paceTarget - rpmMin)/(rpmMax - rpmMin) + 0.05
            property real rpmPercent: 0.95*(adjustedRPM - rpmMin)/(rpmMax - rpmMin) + 0.05

            property real paceTargetHeight: paceTargetPercent * height
            property real rpmHeight: rpmPercent * height

            anchors.centerIn: paceControl
            height: 0.8*parent.height
            visible: paceControl.isPaceSetter && !options.enableProtoGraphs && isLevelPressed===false && isInclinePressed===false

            Rectangle {
                id: currentRPMFill

                width: levelHash.width
                height: paceLevelMeter.rpmHeight
                anchors.left: parent.horizontalCenter
                anchors.bottom: parent.bottom
                color: main.colorUIBorder
            }

            Column {
                id: levelHash

                property int lineHeight: Math.ceil(1*main.vScaleFactor)

                spacing: 3*lineHeight
                width: 15*main.hScaleFactor
                height: paceLevelMeter.height
                anchors.left: parent.horizontalCenter
                anchors.bottom: parent.bottom

                Repeater {
                    model: 20

                    Rectangle {
                        width: levelHash.width
                        height: levelHash.lineHeight
                        color: "#4D4B45"
                    }
                }
            }

            ScalableImage {
                id: goalLevelArrow

                anchors.right: parent.horizontalCenter
                anchors.rightMargin: 1
                anchors.bottom: parent.bottom
                anchors.bottomMargin: paceLevelMeter.paceTargetHeight - height/2

                width: 30 * main.hScaleFactor
                height: 20 * main.vScaleFactor

                sourceName: "LowerControlBar/PaceLevel_Arrow";

                NumberLabel {
                    id: goalLevelText
                    property string stringPaceLevel: "00"

                    text: stringPaceLevel
                    anchors.fill: parent
                    anchors.rightMargin: 10 * main.hScaleFactor

                    color: main.colorFontDark
                    font.pixelSize: height * 0.75
                    horizontalAlignment: Text.AlignHCenter
                    verticalAlignment: Text.AlignVCenter
                }

                Binding {
                    target: goalLevelText
                    property: "stringPaceLevel"
//                    value: workoutManager.paceLevel
                    value: workoutManager.paceTarget
                }
            }
        }

        Item {
            id: spacerItem3
            height: parent.height
            width: parent.width * parent.spacerWidthPercent3
        }
    }

    ListModel {
        id: keypadList

        ListElement {
            name: "1"
            label: qsTr("1")
            iconPath: ""
        }
        ListElement {
            name: "2"
            label: qsTr("2")
            iconPath: ""
        }
        ListElement {
            name: "3"
            label: qsTr("3")
            iconPath: ""
        }
        ListElement {
            name: "4"
            label: qsTr("4")
            iconPath: ""
        }
        ListElement {
            name: "5"
            label: qsTr("5")
            iconPath: ""
        }
        ListElement {
            name: "6"
            label: qsTr("6")
            iconPath: ""
        }
        ListElement {
            name: "7"
            label: qsTr("7")
            iconPath: ""
        }
        ListElement {
            name: "8"
            label: qsTr("8")
            iconPath: ""
        }
        ListElement {
            name: "9"
            label: qsTr("9")
            iconPath: ""
        }
        ListElement {
            name: "0"
            label: qsTr("0")
            iconPath: ""
        }
        ListElement {
            name: "BACK"
            label: qsTr("BACK")
            iconPath: ""
        }
        ListElement {
            name: "ENTER"
            label: qsTr("ENTER")
            iconPath: ""
        }
    }

    function keypadClicked(name)
    {
        switch(name) {
        case "0": nucleus.cabDigit(0); break;
        case "1": nucleus.cabDigit(1); break;
        case "2": nucleus.cabDigit(2); break;
        case "3": nucleus.cabDigit(3); break;
        case "4": nucleus.cabDigit(4); break;
        case "5": nucleus.cabDigit(5); break;
        case "6": nucleus.cabDigit(6); break;
        case "7": nucleus.cabDigit(7); break;
        case "8": nucleus.cabDigit(8); break;
        case "9": nucleus.cabDigit(9); break;
        case "CC": //nucleus.cabCloseCaption();
            nucleus.cabDigit(A)
            controlClicked("CloseCaptionByKeypad");
            break;
        }
    }
}

