import QtQuick 2.12
import ".."

Item {
    id: root
    property bool isEnabled
    property bool personPresent: machinecontrol.personPresent
    property bool timerTriggered: false

    signal releaseClick()

    state: "ppd_s0"

    //onStateChanged: console.debug("PPD STATE: "+ state)

    onPersonPresentChanged: {
        releaseClick() //releases control up click so press hold timer doesn't stick
        /////////////////in rare case of press hold during a person preset interrupt
        console.debug("Person Present Detection: Person Present = " + personPresent)
        if(personPresent) changeState("personpresent")
        else changeState("personnotpresent")
    }

    Connections{
        target: testwarning
        onVisibleChanged: {
            if(testwarning.visible === false && workoutScreen.workoutActive)
                changeState("workout")
        }
    }

    Connections{
        target: workoutScreen
        onWorkoutActiveChanged: {
            if(workoutScreen.workoutActive === false)
                changeState("notworkout")
        }
        onWorkoutPaused: changeState("workoutpaused")
        onWorkoutResumed: changeState("startpressed")
        onWorkoutStopped: changeState("notworkout")
    }

    Connections{
        target:keymapper
        onKeybeingpressedChanged:{
            if(keymapper.keybeingpressed === 0){
                changeState("keypressed")
            }
        }
    }
    Timer{
        id:changeTvState
        interval: 5
        repeat: false
        onTriggered:
        {
      if(workoutScreen.state==="DataExpanded" || workoutScreen.state==="ToolsVisible" || workoutScreen.stopPrompt.visible===true || appleWatchConnect_popup.visible===true)
        tv.on=false
       else
       tv.on=true
     changeTvState.stop()
        }
    }

    NoUserDetectedPrompt{
        id: noUserDetectedPrompt
        isTransparent: true
        onTimedOut: changeState("timeout")
        onResumeClicked: changeState("startpressed")
        Component.onCompleted: hide()
        x: 300 * main.hScaleFactor
        y: 200 * main.vScaleFactor

        onVisibleChanged: {
            console.debug("Person Present Detection: No User Detected Dialog = " + visible)
            if(noUserDetectedPrompt.visible===true)
            {
                if(workoutScreen.showingTV)
                {
                    tv.on=false
                }
            }else{
                if(workoutScreen.showingTV)
                changeTvState.start()
            }


        }
    }

    function restartPPDTimer(interval){
        if(interval){
            ppdTimer.stop()
            ppdTimer.interval = interval
            ppdTimer.start()
            console.debug("Person Present Detection: Starting " + interval / 1000 + " second timer")
        }
        else
        {
            ppdTimer.stop()
            console.debug("Person Present Detection: Stopping timer")
        }
    }

    function changeState(event){
        switch(state){
        case "ppd_s0":
            switch(event){
            case "workout":
                if(isEnabled){
                    if(!personPresent){
                        state = "ppd_s2"
                        restartPPDTimer(options.personPresentTimeout * 1000)
                    } else {
                        state = "ppd_s1"
                        restartPPDTimer(0)
                    }
                }
                break;
            }

            break;
        case "ppd_s1":
            switch(event){
            case "personnotpresent":
                state = "ppd_s2"
                restartPPDTimer(options.personPresentTimeout * 1000)
                break;
            case "notworkout":
                state = "ppd_s0"
                noUserDetectedPrompt.hide()
                restartPPDTimer(0)
                break;
            }
            break;
        case "ppd_s2":
            switch(event){
            case "personpresent":
                state = "ppd_s1"
                restartPPDTimer(0)
                break;
            case "timeout":
                if(options.noUserDetectedDialogTimeout){
                    state = "ppd_s3"
                    buzzer.warningBeep()
                    restartPPDTimer(0)
                    noUserDetectedPrompt.show()
                    noUserDetectedPrompt.startTimeout(options.noUserDetectedDialogTimeout)
                } else {
                    state = "ppd_s5"
                    buzzer.warningBeep()
                    noUserDetectedPrompt.hide()
                    console.log("Person Present Detection: Stopping workout")
                    workoutScreen.stopButtonPressedHandler()
                    restartPPDTimer(0)
                }

                break;
            case "notworkout":
                state = "ppd_s0"
                noUserDetectedPrompt.hide()
                restartPPDTimer(0)
                break;
            case "workoutpaused":
                state = "ppd_s5"
                restartPPDTimer(0)
                break;
            case "keypressed":
                state = "ppd_s2"
                restartPPDTimer(options.personPresentTimeout * 1000)
                break;
            }

            break;
        case "ppd_s3":
            switch(event){
            case "timeout":
                state = "ppd_s5"
                buzzer.warningBeep()
                noUserDetectedPrompt.hide()
                console.log("Person Present Detection: Stopping workout")
                workoutScreen.stopButtonPressedHandler()
                restartPPDTimer(0)
                break;
            case "startpressed":
            case "keypressed":
                // bug 644 - only START key should cancel popup on TFT. START key is handled in NoUserDetectedPrompt
                if ((event === "keypressed") || event === "startpressed") {
                    if(personPresent){
                        state = "ppd_s1"
                        noUserDetectedPrompt.hide()
                        restartPPDTimer(0)
                    } else {
                        state = "ppd_s2"
                        noUserDetectedPrompt.hide()
                        restartPPDTimer(options.personPresentTimeout * 1000)
                    }
                }

                break;
            case "notworkout":
                state = "ppd_s0"
                noUserDetectedPrompt.hide()
                restartPPDTimer(0)
                break;
            case "workoutpaused":
                state = "ppd_s5"
                noUserDetectedPrompt.hide()
                restartPPDTimer(0)
                break;
            }

            break;
        case "ppd_s5":
            switch(event){
            case "startpressed":
                if(personPresent){
                    state = "ppd_s1"
                    noUserDetectedPrompt.hide()
                    restartPPDTimer(0)
                } else {
                    state = "ppd_s2"
                    noUserDetectedPrompt.hide()
                    restartPPDTimer(options.personPresentTimeout * 1000)
                }
                break;
            case "notworkout":
                state = "ppd_s0"
                noUserDetectedPrompt.hide()
                restartPPDTimer(0)
                break;
            }

            break;

        }
    }

    Timer{
        id: ppdTimer
        interval: 10000
        repeat: false
        running: false
        onRunningChanged: {
            if(root.timerTriggered){
                root.timerTriggered = false
                changeState("timeout")
            }
        }
        onTriggered:{
            timerTriggered = true;
        }
    }

    function isSpeedAtTarget()
    {
        return Math.abs(machinecontrol.treadmillSpeedTarget - machinecontrol.treadmillSpeedActual) < 5
    }

    states: [
        State{
            name: "ppd_s0"
        },
        State{
            name: "ppd_s1"
        },
        State{
            name: "ppd_s2"
        },
        State{
            name: "ppd_s3"
        },
        State{
            name: "ppd_s4"
        },
        State{
            name: "ppd_s5"
        }
    ]
}
