import WorkoutRunData 1.0
import WorkoutManager 1.0
import TouchAppEnumerations 1.0
import QtQuick 2.12
import QtQuick.Layouts 1.12
import "../string_format.js" as Format
import Components 1.0
import ".."
import "../WorkoutSummary"

Item {
    id: root

    // REQUIRED property: for translation to work (via qsTranslate), it must know where the external model is stored.
    // Without this you will likely see blank strings in your data table.
    property string sourceFile: "DataSummaryTable"

    property int screenHeight: parent.height
    property int screenWidth: parent.width

    property int _expandedHeight: screenHeight * 854 / 1080
    property int _expandedWidth:  screenWidth * 1734 / 1920

    property int _collapsedHeight: screenHeight * 104 / 1080
    property int _collapsedWidth: screenWidth * 1397 / 1920//1417 / 1920

    property bool isExpanded: false
    property int expandTime: 500

    property alias dataDisplayModel: dataSelectionTable.dataDisplayModel

    state: ""

    property alias selectedCount: dataSelectionTable.selectedCount

    property string colorBackground: isExpanded ? main.colorDialogBackground : main.colorToolbarBackground

    width: _expandedWidth
    height: _collapsedHeight
    clip: true

    function updateDataDisplayItem(item) {
        var i;
        var obj;
        var menu = dataDisplayModel;

        for(i = 0; i < menu.count; i++) {
            obj = menu.get(i);

            if(obj.label === item.label && obj.listName === item.listName) {
                obj.value = item.value;
                return;
            }
        }
    }

    /**
     * Simply have two states: collapsed and expanded
     * Use the appropriate height for each state
     */
    states: [
        State {
            name: ""
            when: root.isExpanded === false
            PropertyChanges {
                target: root
                height: _collapsedHeight
            }
        },
        State {
            name: "expanded"
            when: root.isExpanded === true
            PropertyChanges {
                target: root
                height: _expandedHeight
            }
        }
    ]

    function reset() {
        dataSelectionTable.reset();
        isExpanded = false;
    }

    Rectangle {
        id: background
        opacity: 1
        color: colorBackground
        anchors.top: parent.top
        anchors.horizontalCenter: parent.horizontalCenter
        width: isExpanded ? _expandedWidth : _collapsedWidth
        height: isExpanded ? _expandedHeight : _collapsedHeight
        radius: isExpanded ? 0 : main.defaultRadius
        border.color: isExpanded ? main.colorUIBorder : "transparent"
        border.width: main.widthBorder
    }

    Item {
        id: dataDisplayArea
        width: _collapsedWidth
        height: _collapsedHeight
        anchors.top: parent.top
        anchors.horizontalCenter: parent.horizontalCenter

        Grid {
            id: dataGrid
            columns: selectedCount
            rows: 1
            anchors.fill: parent
            spacing: 5 * main.hScaleFactor

            Repeater {
                model: dataDisplayModel
                delegate: displayItem
            }
        }
    }

    Component {
        id: displayItem

        Item {
            visible: model.isSelected
            height: dataDisplayArea.height
            width: dataDisplayArea.width / dataGrid.columns - dataGrid.spacing

            Column {
                height: dataDisplayArea.height
                width: dataDisplayArea.width / dataGrid.columns - dataGrid.spacing
                spacing: parent.height * 0.05

                NumberLabel {
                    id: value
                    height: parent.height * 0.7
                    width: parent.width
                    visible: true
                    font.pixelSize: height
                    horizontalAlignment: Text.AlignHCenter
                    verticalAlignment: Text.AlignTop
                    text: model.value
                }

                TextLabel {
                    id: label
                    height: parent.height * 0.2
                    width: parent.width
                    font.pixelSize: height
                    horizontalAlignment: Text.AlignHCenter
                    verticalAlignment: Text.AlignBottom
                    text: qsTranslate(root.sourceFile, model.label) + application.emptyString
                    wrapMode: Text.NoWrap
                }
            }

            BeatingHeart {
                id: beatingHeartIcon
                anchors.verticalCenter: parent.verticalCenter
                anchors.right: parent.right
                visible: model.isSelected && model.isHR && heartRateManager.heartRateAvailable
            }
        }
    }

    Rectangle {
        height: _collapsedHeight
        width: 25 * main.hScaleFactor
        anchors {
            top: parent.top
            right: parent.right
            rightMargin: 30 * main.hScaleFactor
        }

        color: "transparent"

        ScalableImage {
            id: expandButton
            width: 25 * main.hScaleFactor
            height: 18 * main.vScaleFactor
            anchors {
                verticalCenter: parent.verticalCenter
                verticalCenterOffset: -10 * main.vScaleFactor
                right: parent.right
            }
            sourceName: root.isExpanded ? "UpperToolBar/collapse_icon" : "UpperToolBar/expand_icon";

            MouseArea {
                anchors.fill: parent
                onClicked: {
                    buzzer.buttonPress()
                    root.isExpanded = !root.isExpanded
                }

                Rectangle {
                    anchors.fill: parent
                    color: main.colorGenericStimulusArea
                    opacity: 0.3
                    visible: main.showStimulusArea
                }
            }
        }
    }

    MouseArea {
        width: root.isExpanded ? _expandedWidth : _collapsedWidth
        anchors {
            top: parent.top
            bottom: parent.bottom
            horizontalCenter: parent.horizontalCenter
        }
        onClicked: {
            buzzer.buttonPress()
            root.isExpanded = !root.isExpanded
        }

        Rectangle {
            anchors.fill: parent
            color: main.colorGenericStimulusArea
            opacity: 0.3
            visible: main.showStimulusArea
        }
    }

    Text {
        id: dataDisplayInstructionText
        width: parent.width
        height: 30 * main.vScaleFactor
        anchors.top: dataDisplayArea.bottom
        anchors.topMargin: 12 * main.vScaleFactor
        color: main.colorFontLight
        font.pixelSize: 14 * main.vScaleFactor
        font.bold: false
        font.letterSpacing: application.currentLanguage === "en" ? 2 : 0
        horizontalAlignment: Text.AlignHCenter
        text: qsTranslate("WorkoutDataDisplay", "Select or deselect data to customize your workout display") + application.emptyString
        wrapMode: Text.WordWrap
        visible: isExpanded
    }

    Item {
        id: dataSelectionArea
        width: 0.827 * parent.width
        anchors.top: dataDisplayInstructionText.bottom
        anchors.topMargin: 20 * main.vScaleFactor
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 20 * main.vScaleFactor

        DataSummaryTable {
            id: dataSelectionTable
            selectable: true
            tableWidth: width - 2*tableHMargin
            anchors.fill: parent
        }
    }
}
