import QtQuick 2.12
import Components 1.0
import ".."


// prompt user for ending the workout
ModalDialog {
    id: root
    width: 800 * main.hScaleFactor
    height: 350 * main.vScaleFactor
    opacity: 1

    signal resumeClicked()
    signal stopClicked()
    signal resetClicked()

    onNoTime: resetPauseButton.visible = false
    onHasTime: resetPauseButton.visible = true

    function convertSecondsToTimeString(cooldownTime) {
        var minutes = Math.floor(cooldownTime / 60);
        var seconds = cooldownTime % 60;

        if(minutes < 10) {
            minutes = "0" + minutes;
        }

        if(seconds < 10) {
            seconds = "0" + seconds;
        }

        return minutes + ":" + seconds;
    }
    Connections {
        target: centerpod

        onPausePressChanged:
        {
            if(root.visible) {
                //centerpod.setQuickStart(false)
                stopClicked()

            }
        }
        onStartPressChanged:
        {
            if (root.visible && machinecontrol.treadmillSpeedActual == 0) {
                resumeClicked()
            }
        }
    }

    Connections{
        target:keymapper

        onStopPausePressed: {
            if(root.visible) {
                stopClicked()
            }
        }
        onStartQuickStartPressed: {
            if(root.visible && machinecontrol.treadmillSpeedActual == 0) {
                resumeClicked()
            }
        }
        onStartPressed: {
            if (root.visible && machinecontrol.treadmillSpeedActual == 0) {
                resumeClicked()
            }
        }
    }

    Grid {
        columns: 2
        rowSpacing: 40 * main.hScaleFactor
        columnSpacing: 40 * main.vScaleFactor
        anchors.centerIn: parent
        z: parent.z + 1

        StandardButton {
            id: resumeButton

            property bool isInFault: false
            property bool isReady: {
                if(main.lowerSystem === "BRAINBOARD") {
                    return true
                } else if(main.lowerSystem === "NUCLEUS") {
                    return nucleus.systemReady
                } else {
                    return true
                }
            }

            buttonText: qsTr("RESUME WORKOUT") + application.emptyString
            onClicked: {
                resumeClicked()
                buzzer.buttonPress()
                diagnostics.logDiagnotsticEvent("XXXX","APP","Button","Resume Workout","");
            }
            enabled: machinecontrol.treadmillSpeedActual === 0 && isInFault === false && isReady === true

            icon.sourceName: "HomeScreen/QuickStartIcon"

            Connections {
                target: errorManager
                onNucleusNonRecoverableFaultTriggered: resumeButton.isInFault = true
                onNucleusRecoverableFaultTriggered: resumeButton.isInFault = true
                onNucleusFaultCleared: resumeButton.isInFault = false
            }
        }

        Rectangle {
            id: resetPauseButton
            color: "black"
            border.color: main.colorUIBorder
            border.width: main.widthBorder
            width: 188 * main.hScaleFactor
            height: 111 * main.vScaleFactor
            radius: main.defaultRadius

            property bool isInFault: false
            property bool isReady: {
                if(main.lowerSystem === "BRAINBOARD") {
                    return true
                } else if(main.lowerSystem === "NUCLEUS") {
                    return nucleus.systemReady
                } else {
                    return true
                }
            }

            enabled: ((machinecontrol.treadmillSpeedActual === 0) || (main.isStepmill && machinecontrol.stepmillSpeedActual === 0))
                     && isInFault === false && isReady === true
            opacity: enabled ? 1.0 : 0.5

            NumberLabel {
                anchors {
                    left: parent.left
                    leftMargin: 67 * main.hScaleFactor
                    top: parent.top
                    topMargin: 13 * main.vScaleFactor
                    right: parent.right
                    rightMargin: 67 * main.hScaleFactor
                    bottom: parent.bottom
                    bottomMargin: 40 * main.vScaleFactor
                }
                verticalAlignment: Text.AlignVCenter
                horizontalAlignment: Text.AlignHCenter
                text: ":" + ((countDown.toString().length < 2) ? "0" : "") + countDown
                font.pixelSize: parent.height * 0.5
            }

            TextLabel {
                anchors {
                    bottom: parent.bottom
                    bottomMargin: 18 * main.vScaleFactor
                    horizontalCenter: parent.horizontalCenter
                }
                font.pixelSize: 13 * main.vScaleFactor
                font.bold: false
                color: "white"
                text: qsTr("RESET PAUSE") + application.emptyString
            }

            MouseArea {
                anchors.fill: parent
                onClicked: {
                    if(resetPauseButton.enabled === true) {
                        resetClicked()
                        buzzer.buttonPress()
                    }
                }

                Rectangle {
                    anchors.fill: parent
                    color: main.colorGenericStimulusArea
                    opacity: 0.3
                    visible: main.showStimulusArea
                }
            }
        }

        Rectangle {
            id: coolDownButton
            color: "black"
            border.color: main.colorUIBorder
            border.width: main.widthBorder
            width: 188 * main.hScaleFactor
            height: 111 * main.vScaleFactor
            radius: main.defaultRadius

            property bool isInFault: false
            property bool isReady: {
                if(main.lowerSystem === "BRAINBOARD") {
                    return true
                } else if(main.lowerSystem === "NUCLEUS") {
                    return nucleus.systemReady
                } else {
                    return true
                }
            }

            enabled: machinecontrol.treadmillSpeedActual === 0 && isInFault === false && isReady === true
            opacity: enabled ? 1.0 : 0.5

            NumberLabel {
                anchors {
                    left: parent.left
                    leftMargin: 67 * main.hScaleFactor
                    top: parent.top
                    topMargin: 13 * main.vScaleFactor
                    right: parent.right
                    rightMargin: 67 * main.hScaleFactor
                    bottom: parent.bottom
                    bottomMargin: 40 * main.vScaleFactor
                }
                verticalAlignment: Text.AlignVCenter
                horizontalAlignment: Text.AlignHCenter
                text: convertSecondsToTimeString(options.cooldownTime);
                font.pixelSize: parent.height * 0.5
            }

            TextLabel {
                anchors {
                    bottom: parent.bottom
                    bottomMargin: 18 * main.vScaleFactor
                    horizontalCenter: parent.horizontalCenter
                }
                font.pixelSize: 13 * main.vScaleFactor
                font.bold: false
                color: "white"
                text: qsTr("COOL DOWN") + application.emptyString
            }

            MouseArea {
                anchors.fill: parent
                onClicked: {
                    if(coolDownButton.enabled === true) {
                        workoutManager.startCooldown()
                        resumeClicked()
                        buzzer.buttonPress()
                    }
                }

                Rectangle {
                    anchors.fill: parent
                    color: main.colorGenericStimulusArea
                    opacity: 0.3
                    visible: main.showStimulusArea
                }
            }
        }

        StandardButton {
            id: stopButton
            buttonText: qsTr("END WORKOUT") + application.emptyString
            onClicked:{
                diagnostics.logDiagnotsticEvent("XXXX","APP","Button","End Workout","");
                stopClicked()
            }
            icon.sourceName: "stop_button_icon"
        }
    }
}
