import QtQuick 2.12
import WorkoutRunData 1.0
import WorkoutManager 1.0
import StorageMgr 1.0
import Components 1.0
//import Centerpod 1.0
import TrueTouch 1.0
import "../MediaBrowser"
import "../views/views.js" as TheViews
import "../views"
import "../BlueTooth"
import ".."
import Process 0.1


FocusScope {
    id: root
    width: main.width
    height: main.height
    focus: main.state === "RunState"

    property alias container: workoutViewContainer
    property bool hrTargetVisibility: workoutProgram.isHRCProgram || workoutProgram.programIndex === WorkoutProgram.TREAD_GERKIN_TEST_PROG || workoutProgram.programIndex === WorkoutProgram.FITNESS_TEST_PROG
    property bool c360Available: workoutProgram.isC360Program
    property alias currentViewName: workoutViewContainer.currentViewName
    property bool showingTV: currentViewName === "TV_VIEW"
    property bool showingMirror:currentViewName=== "MIRROR_VIEW"
    property bool workoutActive:  (main.state === "RunState") || (aWorkoutRunData.mode == WorkoutRunData.WORKOUT_MODE) || (aWorkoutRunData.mode == WorkoutRunData.WARM_UP_MODE) || (aWorkoutRunData.mode == WorkoutRunData.COOL_DOWN_MODE)
    property bool bikeWattsModeRequired: machineinfo.productTypeString == "Bike" && (workoutProgram.profile1.segmentOption === WorkoutProfile.VARIED_LEVELS_SEG_OPTION || workoutProgram.profile1.segmentOption === WorkoutProfile.INTERVALS_SEG_OPTION || workoutProgram.profile1.segmentOption === WorkoutProfile.CUSTOM_SEG_OPTION || workoutProgram.profile1.segmentOption === WorkoutProfile.EGYM_SEG_OPTION)
    property bool bikeWattsModeEnabled: machineinfo.productTypeString == "Bike" && machinecontrol.machineMode === MachineControl.MODE_CONSTANT_POWER || bikeWattsModeRequired
    property string unitState
    property variant stopPrompt: _stopPrompt
    property bool browserFullscreen: false
    property bool tvMenuShowing: false
    property bool ipodVideoShown: false
    property bool isDataDisplayExpanded: dataDisplay.isExpanded
    property double stop_time
    property double ave_stop_time: 0
    property bool inclineVisible:false
    property bool speedVisible:false

    signal workoutStopped()
    signal workoutStarted()
    signal workoutPaused()
    signal workoutResumed()


    onVisibleChanged: reset();
    Component.onCompleted: reset();

    function resetState() {
        root.state = "";
    }

    function updateAdjustModel(){
        toolsMenu.updateAdjustModel()
    }

    states: [
        State { /* Default State */
            name: ""

            PropertyChanges { target: dataDisplay; isExpanded: false }
            PropertyChanges { target: toolsMenu; opacity: 0.0 }
           // PropertyChanges { target: speedKeyPad; opacity: 0.0 }
           // PropertyChanges { target: inclineKeyPad; opacity: 0.0 }
            PropertyChanges { target: workoutViewContainer; opacity: 1.0 }
            //PropertyChanges { target: levelKeyPad; opacity: 0.0 }
        },
        State { /* DataExpanded State */
            name: "DataExpanded"
            when: (dataDisplay.isExpanded === true);
            PropertyChanges { target: dataDisplay; isExpanded: true }
            PropertyChanges { target: toolsMenu; opacity: 0.0 }
            //PropertyChanges { target: speedKeyPad; opacity: 0.0 }
           // PropertyChanges { target: inclineKeyPad; opacity: 0.0 }
            PropertyChanges { target: workoutViewContainer; opacity: 1.0 }
           // PropertyChanges { target: levelKeyPad; opacity: 0.0 }
        },
        State { /* ToolsVisible State */
            name: "ToolsVisible"

            PropertyChanges { target: dataDisplay; isExpanded: false }
            PropertyChanges { target: toolsMenu; opacity: 1.0 }
            //PropertyChanges { target: speedKeyPad; opacity: 0.0 }
           // PropertyChanges { target: inclineKeyPad; opacity: 0.0 }
            PropertyChanges { target: workoutViewContainer; opacity: 0.0 }
           // PropertyChanges { target: levelKeyPad; opacity: 0.0 }
        }
       /* State { /* SpeedKPVisible State */
            /*name: "SpeedKPVisible"

            PropertyChanges { target: dataDisplay; isExpanded: false }
            PropertyChanges { target: toolsMenu; opacity: 0.0 }
            PropertyChanges { target: speedKeyPad; opacity: 1.0 }
            PropertyChanges { target: inclineKeyPad; opacity: inclineKeyPad.opacity }
            PropertyChanges { target: workoutViewContainer; opacity: 1.0 }
            PropertyChanges { target: levelKeyPad; opacity: 0.0 }
        },
        State { /* InclineKPVisible State */
            /*name: "InclineKPVisible"

            PropertyChanges { target: dataDisplay; isExpanded: false }
            PropertyChanges { target: toolsMenu; opacity: 0.0 }
            PropertyChanges { target: speedKeyPad; opacity: speedKeyPad.opacity }
            PropertyChanges { target: inclineKeyPad; opacity: 1.0 }
            PropertyChanges { target: workoutViewContainer; opacity: 1.0 }
            PropertyChanges { target: levelKeyPad; opacity: 0.0 }
        },
        State { /*ResetSpeedKP  State */
           /* name: "ResetSpeedKP"

            PropertyChanges { target: dataDisplay; isExpanded: false }
            PropertyChanges { target: toolsMenu; opacity: 0.0 }
            PropertyChanges { target: inclineKeyPad; opacity: inclineKeyPad.opacity }
            PropertyChanges { target: speedKeyPad; opacity: 0.0 }
            PropertyChanges { target: workoutViewContainer; opacity: 1.0 }
            PropertyChanges { target: levelKeyPad; opacity: 0.0 }
        },
        State { /* ResetInclineKP State */
          /*  name: "ResetInclineKP"

            PropertyChanges { target: dataDisplay; isExpanded: false }
            PropertyChanges { target: toolsMenu; opacity: 0.0 }
            PropertyChanges { target: inclineKeyPad; opacity: 0.0 }
            PropertyChanges { target: speedKeyPad; opacity: speedKeyPad.opacity }
            PropertyChanges { target: workoutViewContainer; opacity: 1.0 }
            PropertyChanges { target: levelKeyPad; opacity: 0.0 }
        },
        State { /* LevelKPVisible State */
          /*name: "LevelKPVisible"

            PropertyChanges { target: dataDisplay; isExpanded: false }
            PropertyChanges { target: toolsMenu; opacity: 0.0 }
            PropertyChanges { target: inclineKeyPad; opacity: 0.0 }
            PropertyChanges { target: speedKeyPad; opacity:0.0 }
            PropertyChanges { target: workoutViewContainer; opacity: 1.0 }
            PropertyChanges { target: levelKeyPad; opacity: 1.0 }
        },
        State { /* ResetLevelKP State */
           /* name: "ResetLevelKP"

            PropertyChanges { target: dataDisplay; isExpanded: false }
            PropertyChanges { target: toolsMenu; opacity: 0.0 }
            PropertyChanges { target: inclineKeyPad; opacity: 0.0 }
            PropertyChanges { target: speedKeyPad; opacity: 0.0 }
            PropertyChanges { target: workoutViewContainer; opacity: 1.0 }
            PropertyChanges { target: levelKeyPad; opacity: 0.0 }
        }*/
    ]
    
    /**
     * Resets the screen to its initial state
     */
    function reset() {
        root.resetState();
        upperToolBar.reset();
        lowerControlBar.reset();
        toolsMenu.reset();
        dataDisplay.reset();
        workoutViewContainer.reset();
    }

    function resetPause() {
        root.resetState();
        upperToolBar.reset();
        lowerControlBar.reset();
        toolsMenu.reset();
        workoutViewContainer.reset();
    }

    function showC360Message(message) {
        print("WorkoutScreen: C360 Message shown = " + message);
        viewContainerBanner.showMessage(message, 5);
    }

    function showMessage(message) {
        print("WorkoutScreen: Message shown = " + message);
        infoPopup.showMessage(message, 3);
    }

    function showBannerMessage(message) {
        print("WorkoutScreen: Message shown = " + message);
        infoBanner.showMessage(message, 3);
    }

    /* This should be placed after the background item but before all other UI
      elements */
    MouseArea {
        id: toolbarDisplayToggleArea
        anchors.fill: parent
        onClicked: workoutViewContainer.handleToolbarDisplay()
        enabled: stopPrompt.visible === false
    }

    function stopButtonPressedHandler() {
        // CSA Cardio 360 can be in "intro mode". Show popup anyway.
        if (workoutActive || (main.isCSA && workoutProgram.isC360Program)) {
            if(options.resumeWorkoutTimeout) {
                stopPrompt.show();

                if(main.lowerSystem === "BRAINBOARD") {
                    stopPrompt.startTimeout(options.resumeWorkoutTimeout);
                }

                workoutPaused();
            } else {
                stopPrompt.show();
                workoutPaused();
            }
            resetPause()
        }

        if(workoutProgram.isFitnessTest) {
            stopWorkout();
        }

        if(workoutProgram.isHRCProgram) {
            workoutManager.stopHRC();
        }
    }

    function resumeWorkout() {
        if (isTreadmill) {
            workoutManager.treadSpeed = 5;
        } else if (main.isStepmill) {
            console.debug("resume setting stepmill speed 20")
            workoutManager.treadSpeed = 20;
        }

        workoutManager.resume();
        aWorkoutRunData.resumeTime();
        workoutResumed();
    }

    function stepmillLevelUp() {
        if(workoutProgram.programIndex === WorkoutProgram.STEP_WFI_TEST_PROG ||
              workoutProgram.programIndex === WorkoutProgram.STEP_FIRE_FIGHTER_PROG){
            return
        }
        workoutManager.speedLevel = workoutProgram.profile2.currentLevel+1
    }
    function stepmillLevelDown() {
        if(workoutProgram.programIndex === WorkoutProgram.STEP_WFI_TEST_PROG ||
                workoutProgram.programIndex === WorkoutProgram.STEP_FIRE_FIGHTER_PROG){
            return
        }
        workoutManager.speedLevel = workoutProgram.profile2.currentLevel-1
    }


    Connections {

        target: nucleus
            onSafetyBeamTripped: {
                   stopButtonPressedHandler()
            }

    }
    Connections {
        target: workoutManager
        property int convertedTreadSpeed: root.unitState === "METRIC" && !main.isStepmill ? workoutManager.treadSpeedMetricGUI : workoutManager.treadSpeedGUI
        onTreadInclineGUIChanged:{
            if(machineinfo.modelString === "ST1000")
            centerpod.setTargetIncline((workoutManager.treadInclineGUI/10.0).toFixed(1))
        }//inclineKeyPad.setValue(workoutManager.treadInclineGUI)
        onTreadSpeedGUIChanged:
        {
           if(machineinfo.modelString === "ST1000")
            centerpod.setTargetSpeed((convertedTreadSpeed/10.0).toFixed(1))
        }
    }


    Connections {
        target:main.state=== "RunState" && machineinfo.modelString === "ST1000"? centerpod :null



        onTreadInclineChanged :{
            var val=centerpod.treadIncline
            if(val <= workoutManager.workoutProgram.maxIncline) {
                var incline = workoutProgram.tableClosestValue(workoutProgram.inclineTable, val * 10)
                console.log("WorkoutScreen: Incline set via on-screen keypad")
                workoutManager.stopHRC()
                workoutManager.treadIncline = incline
            //workoutManager.treadIncline=centerpod.treadIncline
        }

        }
        onTreadSpeedChanged:{
            var val=centerpod.treadSpeed
            var myVal = val
            if (workoutScreen.unitState === "METRIC") {
                myVal = Globals.kmToMile(parseFloat(val))
            }

            if((myVal >= workoutManager.workoutProgram.minSpeed) && myVal <= workoutManager.workoutProgram.maxSpeed) {
                workoutManager.stopHRC()
                console.log("WorkoutScreen: Speed set via on-screen keypad")

                if (main.isStepmill)
                    workoutManager.treadSpeed = myVal
                else if(workoutScreen.unitState === "ENGLISH") {
                    workoutManager.treadSpeed = myVal * 10
                } else {
                    workoutManager.setTreadSpeedMetric(parseFloat(val) * 10)
                }
            } else if(myVal < workoutManager.workoutProgram.minSpeed) {
                console.log("WorkoutScreen: Speed set via on-screen keypad. Value entered less than minimum.")
                workoutManager.stopHRC()
                workoutManager.treadSpeed = main.isStepmill ? workoutManager.workoutProgram.minSpeed : workoutManager.workoutProgram.minSpeed*10
            }
        }
        onPausePressChanged:{
            if(centerpod.pausePress)
            {
               stopButtonPressedHandler()
            }
        }
    }

    Connections {

        target: main.state === "RunState" ? keymapper : null
        onLevelUpPressed: {
            if(main.workoutKeysDisabled){
                return
            }

            if(workoutActive && !stopPrompt.visible) {
                workoutManager.stopHRC()
                workoutManager.stopFitnessTest()
                if(main.isStepmill){
                    stepmillLevelUp()
                }else{
                    workoutManager.increaseWorkloadLevel()
                }
            }
        }
        onLevelDownPressed: {
            if(main.workoutKeysDisabled){
                return
            }
            if(workoutActive && !stopPrompt.visible) {
                workoutManager.stopHRC()
                workoutManager.stopFitnessTest()
                if(main.isStepmill){
                    stepmillLevelDown()
                } else {
                        workoutManager.decreaseWorkloadLevel()
                }
            }
        }
        onInclineUpPressed: {
            if(workoutActive && !stopPrompt.visible) {
                workoutManager.stopHRC()
                workoutManager.increaseIncline()
            }
        }
        onInclineDownPressed: {
            if(workoutActive && !stopPrompt.visible) {
                workoutManager.stopHRC()
                workoutManager.decreaseIncline()
            }
        }
        onSpeedUpPressed: {
            if(main.workoutKeysDisabled){

                return
            }
            if(workoutActive && !stopPrompt.visible) {
                workoutManager.stopHRC()

                if(main.isStepmill){
                    stepmillLevelUp()
                    return
                }

                if(root.unitState === "ENGLISH" || main.isStepmill) {
                    workoutManager.increaseSpeed(workoutManager.withLimit)
                } else {
                    workoutManager.increaseSpeedMetric(workoutManager.withLimit)
                }
            }
        }
        onSpeedUpFirstPressed: {
            if(workoutActive && !stopPrompt.visible) {
                workoutManager.speedUpEnabled = true
            }
        }
        onSpeedUpReleased: {
            if(workoutActive && !stopPrompt.visible) {
                workoutManager.speedUpEnabled = false
            }
        }
        onSpeedDownPressed: {
            if(main.workoutKeysDisabled){
                return
            }
            if(workoutActive && !stopPrompt.visible ) {
                workoutManager.stopHRC()

                if(main.isStepmill){
                    stepmillLevelDown()
                    return
                }

                if(root.unitState === "ENGLISH") {
                    workoutManager.decreaseSpeed()
                } else {
                    workoutManager.decreaseSpeedMetric()
                }
            }
        }
        onStopPausePressed: stopButtonPressedHandler()
        onStrideUpPressed: workoutManager.increaseStrideLevel()
        onStrideDownPressed: workoutManager.decreaseStrideLevel()
    }

    Loader {
        source: workoutProgram.programIndex === WorkoutProgram.STRIDE_INTERVALS_PROG ? "../progs/stride_intervals.qml" : ""
    }

    ScalableImage {
        id: background
        anchors.fill: parent
        z: -5
        fillMode: Image.PreserveAspectCrop
        sourceName: "StandardPage/View_Background"
    }

    StrideChangePrompt{
        id:strideChangePrompt

        isTransparent: true
        onTimedOut: hide()
        onVisibleChanged: if(visible) {
                              buzzer.buttonPress()
                              startTimeout(3)
                          }
        Component.onCompleted: hide()
    }

    Timer {
        id: safetyKeyPollTimer
        repeat: true
        running: root.workoutActive && (isTreadmill || main.isStepmill) && main.lowerSystem === "BRAINBOARD"
        interval: 1000
        onTriggered: {
            // end workout if safety key found to be out
            if(!machinecontrol.estop) {
                stopWorkout()
            }
        }
    }

    function start() {
        print("Workout start.");

        // check safety key just before workout starts
        if(!machinecontrol.estop && (isTreadmill || main.isStepmill) ) {
            stopWorkout();
            return;
        }
        setUnitState(options.metricUnits)

        if(bikeWattsModeRequired && machineinfo.productTypeString == "Bike") {
            machinecontrol.machineMode = MachineControl.MODE_CONSTANT_POWER;
        }

        eGym.setStartTime();

        setViews();
//        videoOverlay.reset();
        workoutStarted();

        for(var i = 0; i < dataToggleModel.count; i++) {
            var item = dataToggleModel.get(i);
            item.thestate = "Enabled";
        }
        main.isNewWorkoutSelected = false
    }

    function stopWorkout() {

        var timeStart = new Date().getTime();
        console.debug("WorkoutScreen: Workout stopped");

        if(!main.isNewWorkoutSelected) // Don't turn off fan for change workout
            fan.fanSpeed = 0;

        container.currentIndex = 0;
        tv.fullscreen=false
        fullscreenVideoFrame.visible=false
//        tv_menu.menuOpen = false;
//        tv.endFullscreen();

        if(bikeWattsModeEnabled && machineinfo.productTypeString == "Bike") {
            machinecontrol.machineMode = MachineControl.MODE_CONSTANT_TORQUE;
        }
        nucleus.workoutStop();
        workoutStopped();
        workoutManager.cruiseControlEnabled = false

        stop_time =new Date().getTime() - timeStart
        ave_stop_time = (ave_stop_time + stop_time)/2
        console.debug("Stop Time: "+stop_time)
        console.debug("ave Stop Time: "+ave_stop_time)
    }

    function setViews() {
        var viewGroup = { views: [], defaultview: workoutViewContainer.defaultView };

        workoutViewContainer.defaultView = workoutProgram.defaultView;

        // only add facility view button if some slides exist
        var slides = storageMgr.listFiles("/data/facility", ["*.jpg", "*.png"]);
        var userSlides = storageMgr.listFiles("/data/facility/user", ["*.jpg", "*.png"]);

        if (slides.length > 0 || userSlides.length > 0) {
            viewGroup.views.push(TheViews.facilitiesViewDef);
            workoutViewContainer.defaultView = "FACILITIES_VIEW";
        }

        if(c360Available) {
            viewGroup.views.push(TheViews.c360ViewDef);
            workoutViewContainer.defaultView = "C360_VIEW";
        } else {
            viewGroup.views.push(TheViews.trackViewDef);
        }

        if(tv.channelList.channels.count) {
            viewGroup.views.push(TheViews.tvViewDef);
            if (options.autoChannelChangeInterval > 0)
                workoutViewContainer.defaultView =  "TV_VIEW" ;
        }
        viewGroup.views.push(TheViews.profileViewDef);

        dataExport.getNetworkAddresses();
        if(options.wifiMirroring===true)
        {
            viewGroup.views.push(TheViews.mirrorViewDef);
            //          workoutViewContainer.defaultView = "MIRROR_VIEW";
        }



        if(options.browserEnabled && dataExport.ipAddress) {
            viewGroup.views.push(TheViews.webViewDef);
        }

        if (workoutProgram.isMonumentWorkout) {
            viewGroup.views.push(TheViews.monumentViewDef);
            console.debug("set default to MONUMENT_VIEW")
            workoutViewContainer.defaultView = "MONUMENT_VIEW";
        } else {
            viewGroup.views.push(TheViews.sceneViewDef);
            if (options.autoVideoChangeInterval > 0)
                workoutViewContainer.defaultView =  "SCENE_VIEW";
        }

        workoutViewContainer.setViews(viewGroup);
        workoutViewContainer.defaultIndex = workoutViewContainer.findViewIndex(workoutViewContainer.defaultView);
    }

    function displayHRPrompt(index) {
        heartRatePrompt.setMsg(index);
        heartRatePrompt.show();
        heartRatePrompt.startTimeout(5);
    }

    /**
     * Sets the workout program's user weight in pounds
     */
    function setWeight(weight_lbs) {
        if(weight_lbs >= 40 && weight_lbs <= workoutProgram.userWeightMax) {
            workoutProgram.userWeight = weight_lbs;
            aWorkoutRunData.userWeight = weight_lbs;
            return true;
        } else {
            return false;
        }
    }

    function setUnitState(state) {
        if(state) {
            root.unitState = "METRIC"
        } else {
            root.unitState = "ENGLISH"
        }
//lowerControlBar.unitState=main.isStepmill ? qsTr("SPM") : root.unitState === "ENGLISH" ? qsTr("MPH") : qsTr("KPH")
        //speedKeyPad.units = main.isStepmill ? qsTr("SPM") : root.unitState === "ENGLISH" ? qsTr("MPH") : qsTr("KPH")
    }

    Item {
        id: dataToggleEnums

        property int timeEnum: 0
        property int timeRemainingEnum: 1
        property int paceEnum: 2
        property int paceSetterEnum: 3
        property int distanceEnum: 4
        property int distanceRemainingEnum: 5
        property int caloriesEnum: 6
        property int calsPerHourEnum: 7
        property int wattsEnum: 8
        property int metsEnum: 9
        property int heartRateEnum: 10
        property int targetHREnum: 11
        property int strideLengthEnum: 12
    }

    ListModel {
        id: dataToggleModel

        ListElement{thestate: "Enabled"}
        ListElement{thestate: "Enabled"}
        ListElement{thestate: "Enabled"}
        ListElement{thestate: "Enabled"}
        ListElement{thestate: "Enabled"}
        ListElement{thestate: "Enabled"}
        ListElement{thestate: "Enabled"}
        ListElement{thestate: "Enabled"}
        ListElement{thestate: "Enabled"}
        ListElement{thestate: "Enabled"}
        ListElement{thestate: "Enabled"}
        ListElement{thestate: "Enabled"}
        ListElement{thestate: "Enabled"}
        ListElement{thestate: "Enabled"}
        ListElement{thestate: "Enabled"}
    }

    WorkoutDataDisplay {
        id: dataDisplay
        anchors.horizontalCenter: root.horizontalCenter
        anchors.top: root.top
        anchors.topMargin: 0
        visible: upperToolBar.isMinimizedButtonPressed === false
        z: workoutViewContainer.z + 5

        onIsExpandedChanged: {
            if(dataDisplay.isExpanded) {
                if(showingTV || showingMirror) {
                    changeTvState.stop()
                    tv.on = false
                }
            } else if(showingTV) {
                changeTvState.start()
            }
        }

        Connections {
            target: root
            onWorkoutStarted: {
                dataDisplay.reset()
            }
        }

        enabled: stopPrompt.visible === false
        opacity: enabled ? 1.0 : 0.5
    }

    ViewContainer {
        id:workoutViewContainer
        width: parent.width
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.bottom: lowerControlBar.top
        anchors.top: upperToolBar.bottom
        anchors.topMargin: 10 * main.vScaleFactor
        visible: (upperToolBar.isMinimizedButtonPressed === false)
        workoutScreen: root

        enabled: stopPrompt.visible === false
        opacity: enabled ? 1.0 : 0.5
    }

    UpperToolBar {
        id: upperToolBar
        anchors.top: parent.top
        anchors.horizontalCenter: parent.horizontalCenter
        z: 3
        isToolsButtonPressed: toolsMenu.visible;
        onToolsButtonPressed: {
            if(isToolsButtonPressed) {
                root.resetState();
            } else {
                root.state = "ToolsVisible";
            }
        }

        enabled: stopPrompt.visible === false
        opacity: enabled ? 1.0 : 0.5
    }

    ToolsMenu {
        id: toolsMenu
        anchors.centerIn: parent
        opacity: 0.0
        visible: (opacity > 0.0) && (upperToolBar.isMinimizedButtonPressed === false)
        z: dataDisplay.z + 1
        fanEnabled: (fan.fanSpeed === 100)
        onVisibleChanged: {
            reset()
            if(toolsMenu.visible)
            {
            if(showingTV || showingMirror)
            {
                tv.on = false
            changeTvState.stop()
            }
            }
            else if(showingTV)
            {
             changeTvState.start()
            }


        }
        onClose: root.resetState()
        onWeightEntered: {
            var w = root.unitState === "METRIC" ? Globals.kgToPound(weight) : weight

            if(root.setWeight(w)) {
                reset()
            }
        }
        onFanButtonClicked: {
            fan.fanSpeed = (fan.fanSpeed === 100) ? 0 : 100
        }
        onCruiseControlButtonClicked: {
            if (workoutManager.cruiseControlEnabled) {
                workoutManager.cruiseControlEnabled = false
            } else {
                cruiseConfirmPrompt.show()
                cruiseConfirmPrompt.startTimeout(5)
            }
        }
        onAutoStrideButtonClicked: {
            machinecontrol.autoStrideEnabled = !machinecontrol.autoStrideEnabled
        }
        onBikeModeButtonClicked: {
            if(bikeWattsModeEnabled)
                machinecontrol.machineMode = MachineControl.MODE_CONSTANT_TORQUE
            else
                machinecontrol.machineMode = MachineControl.MODE_CONSTANT_POWER
        }

        enabled: stopPrompt.visible === false
    }

    ConfirmPrompt {
        id: cruiseConfirmPrompt

        iconSourceName: "ToolsMenu/cruiseControl_HR_icon"
        promptText: qsTr("HRC Cruise Control?") + application.emptyString
        promptDesc: qsTr("You will be entering a Heart Rate Controlled workout.") + application.emptyString

        anchors.horizontalCenter: root.horizontalCenter
        anchors.verticalCenter: root.verticalCenter

        onTimedOut: hide()
        Component.onCompleted: hide()
        onAcceptClicked: {
            if (main.state === "RunState") {
                workoutManager.cruiseControlEnabled = !workoutManager.cruiseControlEnabled
                console.debug("HR Cruise: " + workoutManager.cruiseControlEnabled + " at HR:" + aWorkoutRunData.heartRate)
            }
            hide()
        }
        onCancelClicked: hide()
    }
    Timer{
        id:changeTvState
        interval: 5
        repeat: false
        onTriggered:
        {
      if(workoutScreen.state==="DataExpanded" || workoutScreen.state==="ToolsVisible" || workoutScreen.stopPrompt.visible===true || appleWatchConnect_popup.visible===true)
        tv.on=false
       else
       tv.on=true
     changeTvState.stop()
        }
    }

    LowerControlBar {
        id: lowerControlBar
        visible: upperToolBar.isMinimizedButtonPressed === false
        anchors.left: parent.left
        anchors.bottom: parent.bottom
        z: workoutViewContainer.z + 1
        bikeWattsModeEnabled: root.bikeWattsModeEnabled || machineinfo.productTypeString != "Bike"
        enabled: stopPrompt.visible === false
        onStopPressed: {
            root.resetState()
        }
      /*  onSpeedPressed: {
            if(speedKeyPad.opacity > 0) {
                root.state = "ResetSpeedKP"
                speedVisible=false
                if(showingTV || showingMirror)
                {
                if (inclineKeyPad.opacity>0)
                {
                   tv.on=false
                    changeTvState.stop()
                }
                else
                    changeTvState.start()
                }
            } else {
                if(showingTV || showingMirror)
                {
                tv.on=false
                changeTvState.stop()
                }
                root.state = "SpeedKPVisible"
                speedVisible=true
            }
        }
        onLevelPressed: {
            if(levelKeyPad.opacity > 0) {
                root.state = "ResetLevelKP"
                if(showingTV || showingMirror)
                {
                changeTvState.start()
                }
            } else {
                root.state = "LevelKPVisible"
                if(showingTV || showingMirror)
                {
                tv.on=false
                changeTvState.stop()
                }
            }


        }

        onInclinePressed: {
            if(inclineKeyPad.opacity > 0 || isQuickSpeedKeysDisplayed || isLevelPressed) {
                root.state = "ResetInclineKP"
                inclineVisible=false
                if(showingTV || showingMirror)
                {
                if (speedKeyPad.opacity>0)
                {
                    tv.on=false
                    changeTvState.stop()
                }
                else
                    changeTvState.start()
                }
            } else {
                root.state = "InclineKPVisible"
                inclineVisible=true
                if(showingTV || showingMirror)
                {
                tv.on=false
                changeTvState.stop()
                }
            }
        }*/
        onStrideSelected: workoutManager.strideLevel = stride
        currentStride: workoutManager.strideLevel
    }

    Item {
        id: minimizedItem
        visible: upperToolBar.isMinimizedButtonPressed
        anchors.fill: parent

        Rectangle {
            id: minimizedBackground
            anchors.fill: parent
            z: workoutViewContainer.z + 1
            color: main.colorToolbarBackground
        }

        Item {
            id: upperMinimizedItem
            width: parent.width
            height: parent.height * 0.19
            anchors.top: parent.top
            z: workoutViewContainer.z + 2

            TextLabel {
                id: upperMinimizedText
                anchors.centerIn: parent
                text: qsTr("SCREEN MINIMIZED") + application.emptyString
                font.pixelSize: parent.height * 0.1
            }
        }

        Item {
            id: centerUpperTextItem
            width: parent.width
            height: parent.height * 0.37
            anchors.top: parent.top
            z: workoutViewContainer.z + 2

            TextLabel {
                id: centerUpperText
                anchors.fill: parent
                anchors.leftMargin: 20 * main.hScaleFactor
                color: "gray"
                text: qsTr("WORKOUT BECAUSE YOU LOVE YOUR BODY...") + application.emptyString
                horizontalAlignment: Text.AlignLeft
                verticalAlignment: Text.AlignBottom
                font.pixelSize: parent.height * 0.16
            }
        }

        Item {
            id: centerLowerTextItem
            width: parent.width
            height: parent.height * 0.37
            anchors.top: centerUpperTextItem.bottom
            z: workoutViewContainer.z + 2

            TextLabel {
                id: centerLowerText
                anchors.fill: parent
                anchors.rightMargin: 20 * main.hScaleFactor
                color: "gray"
                text: qsTr("NOT BECAUSE YOU HATE IT.") + application.emptyString
                horizontalAlignment: Text.AlignRight
                verticalAlignment: Text.AlignTop
                font.pixelSize: parent.height * 0.16
            }
        }

        Item {
            id: lowerMinimizedTextItem
            width: parent.width
            height: screenHeight * 0.19
            anchors.bottom: parent.bottom
            z: workoutViewContainer.z + 2

            TextLabel {
                id: lowerMinimizedText
                anchors.centerIn: parent
                text: qsTr("TOUCH TO RETURN") + application.emptyString
                font.pixelSize: parent.height * 0.1
            }
        }

        MouseArea {
            anchors.fill: parent
            onClicked: {
                upperToolBar.isMinimizedButtonPressed = !upperToolBar.isMinimizedButtonPressed
                buzzer.buttonPress()
            }

            Rectangle {
                anchors.fill: parent
                color: main.colorGenericStimulusArea
                opacity: 0.3
                visible: main.showStimulusArea
            }
        }
    }

    Connections {
        target: popupManager
        onEstopPopupPopped: {
            if(workoutActive && main.lowerSystem === "BRAINBOARD") {
                stopWorkout()
            }
        }
    }

    Connections {
        target: errorManager
        onPreventUseChanged: {
            if(main.lowerSystem === "BRAINBOARD" && workoutActive && errorManager.preventUse) {
                stopWorkout()
            }
        }
    }

    WorkoutEndPrompt {
        id: _stopPrompt
        anchors.centerIn: parent
        visible: false
        countDown: options.resumeWorkoutTimeout

        onVisibleChanged: {
            countDown = options.resumeWorkoutTimeout

            if(_stopPrompt.visible) {
                if(nucleus.systemReady === true) {
                    if(countDown !== 0) {
                        _stopPrompt.startTimeout(countDown)
                    }
                }
                 if(machineinfo.modelString === "ST1000")
                centerpod.consolePausepressed()
                /*if(showingMirror) {
                   // tv.on = false
                    mirror.stop()
                    changeTvState.stop()

                }*/

                if(showingTV ||showingMirror) {
                    tv.on = false
                    changeTvState.stop()

                }
            } else {
                if(showingTV || showingMirror ) {
                    //tv.on = true
                    changeTvState.start()
                }
                /*else if(showingMirror)
                {
                    mirror.play()
                }*/
            }

        }
        onTimedOut: {
            stopWorkout()
            hide()
        }
        onStopClicked: {
            if(showingTV||showingMirror) {
                tv.changeParent(tv.viewParent)
                tv.fullscreen=false
                //              fullscreenVideoFrame.visible=false
                if(machineinfo.modelString === "ST1000"){
                    centerpod.setQuickStart(false)
                    centerpod.setPausePress(true)
                }

            }

            stopWorkout()
            hide()


        }
        onResumeClicked: {
            if(nucleus.systemReady === true){
                root.resumeWorkout()
                hide()
                 if(machineinfo.modelString === "ST1000"){
                centerpod.setQuickStart(true)
                centerpod.setPausePress(false)
                 }
            }
        }
        onResetClicked: {
            countDown = options.resumeWorkoutTimeout
        }

        Connections {
            target: nucleus
            onSystemReadyChanged: {
                console.debug("Nucleus System Ready Changed: " + nucleus.systemReady)
                if(_stopPrompt.visible === true && nucleus.systemReady === true) {
                    _stopPrompt.countDown = options.resumeWorkoutTimeout
                    if(_stopPrompt.countDown !== 0) {
                        _stopPrompt.startTimeout(_stopPrompt.countDown)
                    }
                } else if(nucleus.systemReady === false) {
                    _stopPrompt.stopTimer()
                    _stopPrompt.countDown = options.resumeWorkoutTimeout
                }
            }
        }
    }

    Timer {
        id: rpmPauseTimer

        property bool wasTriggered: false

        interval: 10000
        running: !options.disableNoPedalStop && workoutActive && !isTreadmill && !main.isStepmill && !stopPrompt.visible && machinecontrol.pedalRPM == 0
        onTriggered: {
            if(!workoutActive) {
                return
            }

            rpmPauseTimer.wasTriggered = true

            if(options.resumeWorkoutTimeout){
                print("No pedal. Prompt end of workout.")
                stopPrompt.show()
                stopPrompt.startTimeout(options.resumeWorkoutTimeout)
                workoutPaused()
            } else {
                stopPrompt.show()
                workoutPaused()
            }

            resetPause()
        }
    }

    Connections {
        target: machinecontrol
        onPedalRPMChanged: {
            if(workoutActive && (pedalRPM > 0) && !options.disableNoPedalStop) {
                rpmPauseTimer.restart()

                if (stopPrompt.visible && rpmPauseTimer.wasTriggered) {
                    stopPrompt.hide()
                    rpmPauseTimer.wasTriggered = false
                    root.resumeWorkout()
                }
            }
        }
        onStrideLengthTargetChanged: {
            if (!main.isCSA) {
                return
            }

            if(!workoutActive) {
                return
            }

            strideChangePrompt.oldStride = strideChangePrompt.newStride
            strideChangePrompt.newStride = strideLengthTarget
            strideChangePrompt.show()
            strideChangePrompt.startTimeout(3)
        }
        onSafetyKeyPulled: {
            if(main.lowerSystem === "NUCLEUS" && workoutActive === true) {
                stopButtonPressedHandler()
            }
        }
        onSafetyKeyPulledDueToFault: {
            if(main.lowerSystem === "NUCLEUS" && workoutActive === true) {
                stopButtonPressedHandler()
            }
        }
    }

    HeartRatePrompts {
        id: heartRatePrompt

        x: 260
        y: 220
        visible: false
        onTimedOut: {
            hide();
        }
    }

  /*  Keypad{
        id:inclineKeyPad
        units: "%"
        length: 3
        decimalPlaces: 1
        allow_close: false
        clear_after_enter: false
        show_entry: true
        icon: "Incline_Keypad_Icon"
        anchors.left: lowerControlBar.left
        anchors.leftMargin: (lowerControlBar.width * 0.23) + (20 * main.hScaleFactor)
        anchors.bottom: lowerControlBar.top
        z:lowerControlBar.z
        onClose: root.resetState();
        opacity: 0.0
        isColorInverted: true
        visible: !upperToolBar.isMinimizedButtonPressed && (opacity > 0.0)
        onVisibleChanged: {
            if(visible) {
                inclineKeyPad.setValue(workoutManager.treadInclineGUI)
            }
        }

        Connections {
            target: workoutManager
            onTreadInclineGUIChanged: inclineKeyPad.setValue(workoutManager.treadInclineGUI)
        }

        onValueEntered: {
            if(val <= workoutManager.workoutProgram.maxIncline) {
                var incline = workoutProgram.tableClosestValue(workoutProgram.inclineTable, val * 10)
                console.log("WorkoutScreen: Incline set via on-screen keypad")
                workoutManager.stopHRC()
                workoutManager.treadIncline = incline
            } else {
                inclineKeyPad.setValue(workoutManager.treadInclineGUI)
            }

        diagnostics.logDiagnotsticEvent("XXXX","APP","Button","Set incline",val);
        }
    }
    Keypad{
        id:levelKeyPad
       // units: "%"
        length: 3
        //decimalPlaces: 1
        allow_close: false
        clear_after_enter: false
        show_entry: true
        icon: "Speed_Keypad_Icon"
        anchors.left: lowerControlBar.left
        anchors.leftMargin: (lowerControlBar.width * 0.23) + (20 * main.hScaleFactor)
        anchors.bottom: lowerControlBar.top
        z:lowerControlBar.z
        onClose: root.resetState();
        opacity: 0.0
        isColorInverted: true
        visible: !upperToolBar.isMinimizedButtonPressed && (opacity > 0.0)
        onVisibleChanged: {
            if(visible) {
                levelKeyPad.setValue(workoutManager.workloadLevel)

            }
        }

        Connections {
            target: workoutManager
            onSpeedLevelChanged:levelKeyPad.setValue(workoutManager.speedLevel)
            onWorkloadLevelChanged : levelKeyPad.setValue(workoutManager.workloadLevel)
                   }

        onValueEntered: {
            if(main.isStepmill)
            {
               if(val<=workoutManager.workoutProgram.maxSpeedLevel)
               {
                 workoutManager.speedLevel=val
                 }else
                  levelKeyPad.setValue((workoutManager.speedLevel))
                        }
            else if(val <= workoutManager.workoutProgram.maxWorkloadLevel) {
                           workoutManager.workloadLevel=val
            } else {
                levelKeyPad.setValue(workoutManager.workloadLevel)
            }
            inclineKeyPad.visible = false;
            diagnostics.logDiagnotsticEvent("XXXX","APP","Button","Set level",val);
        }
    }
    BluetoothDeviceSelectionDialog {
        id: btHRSelectionDialog
        isTop: true
        isTransparent: false
        isLowEnergy: false
        onClosed: btHRSelectionDialog.hide()
    }

    Keypad {
        id:speedKeyPad
        units: main.isStepmill ? qsTr("SPM") : root.unitState === "ENGLISH" ? qsTr("MPH") : qsTr("KPH")
        length: 3
        decimalPlaces: main.isStepmill ? 0 : 1
        allow_close: false
        clear_after_enter: false
        show_entry: true
        icon: "Speed_Keypad_Icon"
        anchors.left: lowerControlBar.left
        anchors.leftMargin: (lowerControlBar.width * 0.66) + (20 * main.hScaleFactor)
        anchors.bottom: lowerControlBar.top
        z:lowerControlBar.z
        onClose: root.resetState()
        opacity: 0.0
        isColorInverted: true
        visible: !upperToolBar.isMinimizedButtonPressed && (opacity > 0.0)
        onVisibleChanged: {
            if(visible) {
                speedKeyPad.units= main.isStepmill ? qsTr("SPM") : root.unitState === "ENGLISH" ? qsTr("MPH") : qsTr("KPH")
                speedKeyPad.setValue(convertedTreadSpeed)
                //console.debug()
            }
        }

        property int convertedTreadSpeed: root.unitState === "METRIC" && !main.isStepmill ? workoutManager.treadSpeedMetricGUI : workoutManager.treadSpeedGUI

        onConvertedTreadSpeedChanged: speedKeyPad.setValue(speedKeyPad.convertedTreadSpeed)

        Connections {
            target: workoutManager
            onTreadSpeedGUIChanged: speedKeyPad.setValue(speedKeyPad.convertedTreadSpeed)
        }

        onValueEntered: {
            var myVal = val

            if (root.unitState === "METRIC") {
                myVal = Globals.kmToMile(parseFloat(val))
            }

            if((myVal >= workoutManager.workoutProgram.minSpeed) && myVal <= workoutManager.workoutProgram.maxSpeed) {
                workoutManager.stopHRC()
                console.log("WorkoutScreen: Speed set via on-screen keypad")

                if (main.isStepmill)
                    workoutManager.treadSpeed = myVal
                else if(root.unitState === "ENGLISH") {
                    workoutManager.treadSpeed = myVal * 10
                } else {
                    workoutManager.setTreadSpeedMetric(parseFloat(val) * 10)
                }
            } else if(myVal < workoutManager.workoutProgram.minSpeed) {
                console.log("WorkoutScreen: Speed set via on-screen keypad. Value entered less than minimum.")
                workoutManager.stopHRC()
                workoutManager.treadSpeed = main.isStepmill ? workoutManager.workoutProgram.minSpeed : workoutManager.workoutProgram.minSpeed*10
                speedKeyPad.setValue(convertedTreadSpeed)
            } else {
                speedKeyPad.setValue(convertedTreadSpeed)
            }
            diagnostics.logDiagnotsticEvent("XXXX","APP","Button","Set Speed",val);
        }

        // re-translate the strings when the language changes
        Connections {
            target: application
            onLanguageChanged: {
                speedKeyPad.units = main.isStepmill ? qsTr("SPM") : root.unitState === "ENGLISH" ? qsTr("MPH") : qsTr("KPH")
            }
        }
   }*/
Process
    {
        id:stopMiracleScript
        program:  "scripts/stopMiracle.sh"
        onReadyReadStandardOutput: {
            var output = String(readAllStandardOutput())
            output = output.trim()
            console.log( "******************************* = " + output)
            tv.disconnectwifi=true
        }
        onReadyReadStandardError: {
            var output = String(readAllStandardError())
            output = output.trim()
            console.log( "audioDeviceNumberDetect process (STDERR):::::::::::::::::::::::::::::::::::::::::::::::::::::::" + output)
        }


    }

}
