import QtQuick 2.12
import WorkoutManager 1.0
import "../string_format.js" as Format
import Components 1.0
import QtQuick.Layouts 1.12
import "../views"
import ".."

import "program_setup.js" as Fields
import "setup_params.js" as SetupJS

Item {
    id: root

    property variant model1
    property variant model2
    property int currentIndex: 0
    property int workoutTime
    property int segmentTime
    property int maxSegs
    property int segmentIndex
    property bool valueEntered: false
    property var graphShow:"INCLINE"
    property var str:"INCLINE"
    property var segIndex:[]
    property var segValue:[]
    property var speedSegIndex:[]
    property var speedSegValue:[]
    property var totalSeg:0
    property var speedTotalSeg:0
    property var  model1Title
    property var model2Title


    property int paramTextSize: 15 * main.vScaleFactor
    property int numTextSize: 20 * main.vScaleFactor
    property var segmentNo
    property bool isIncline:true
    property bool isSpeed:false


//    property bool isTreadmill: machineinfo.productTypeString === "Treadmill"

    property variant model
    signal inclineDone()
    signal speedDone()

    onModelChanged: {
        if (root.model) {
            populateCustomModel();
            modelPostProcessing();
        }
    }

    function modelPostProcessing()
    {
        // get references to the time and distance model items for making the time/dist mutex for manual workout
        var timeItem = root.model.find("fieldType", WorkoutProgram.TIME_TYPE)
        if (timeItem) {
            root.model.setProperty(timeItem.fieldIndex - 1, "maxValue", options.workoutTimeMax)
            if (timeItem.dataValue > 0)
                SetupJS.setParameter(WorkoutProgram.TIME_TYPE, timeItem.dataValue) // re-set value in case it is now over max
        }

        for(var i = 0; i < myListView.model.count; i++)
        {
            var item = myListView.model.get(i)

            switch(item.fieldType)
            {
            case WorkoutProgram.SEGMENT_TYPE:
                mainProgItem.numSegs = item.dataValue;
                break;
            case WorkoutProgram.TIME_TYPE:
                mainProgItem.workTime = item.dataValue;
                break;
            }
        }
        mainProgItem.dataItemChanged()
    }

    function populateCustomModel() {
        customListModel.clear();
        var i;
        var item;
        for(i = 0; i < root.model.count; i++) {
            item = root.model.get(i);

            if(item.fieldType === WorkoutProgram.TIME_TYPE || item.fieldType === WorkoutProgram.SEGMENT_TYPE) {
                customListModel.append(item);
            }
        }
    }

    function calculateMaxSegmentsFromTime() {
        root.maxSegs = Math.max(2, Math.min(30, root.workoutTime))

        customListModel.setProperty(root.segmentIndex, "maxValue", root.maxSegs)
    }

    anchors.fill: parent

    state: (workoutProgram.programIndex === WorkoutProgram.TREAD_CUSTOM_SPEED_PROG || workoutProgram.programIndex == WorkoutProgram.CUSTOM_PACE_PROG) ? "Profile2" : "Profile1"

    //property bool isCustomIncline: (workoutProgram.programIndex == WorkoutProgram.TREAD_CUSTOM_HILLS_PROG || workoutProgram.programIndex == WorkoutProgram.CUSTOM_HILLS_PROG)
    //property bool isCustomSpeed: (workoutProgram.programIndex == WorkoutProgram.TREAD_CUSTOM_SPEED_PROG || workoutProgram.programIndex == WorkoutProgram.CUSTOM_PACE_PROG)
   // property variant newmodel:workoutProgram.profile2
    TextLabel {
        id: customProfileInstructLabel1
       // anchors.top: graphEditor.bottom
        anchors.top: traceRect.top
       anchors.topMargin: 10
        anchors.right: parent.right
        //anchors.left: graphEditor.left
        anchors.left: traceRect.left
        horizontalAlignment: Text.AlignHCenter
        wrapMode: Text.WordWrap
        text: {
            if(root.graphShow==="INCLINE")
            qsTr("DRAW YOUR WORKOUT FOR ") + model1Title +application.emptyString
            else if (root.graphShow==="SPEED")
                qsTr("DRAW YOUR WORKOUT FOR ") + model2Title +application.emptyString

        }
        font.pixelSize: 20 * main.vScaleFactor
        smooth: true
        visible:true
    }

    ModalDialog {
        id: wrongDrawNotice
        dismissable: true
        blockKeys: true
        visible: false


        Item {
            z: wrongDrawNotice.z + 1
            anchors.fill: parent

            TextLabel {
                id: warningText
                width: parent.width
                color: "white"
                text: qsTr("Please draw from left to right") + application.emptyString
                anchors.horizontalCenter: parent.horizontalCenter
                //anchors.top: parent.top
                anchors.centerIn: parent.Center
                anchors.verticalCenter: parent.verticalCenter
               // anchors.topMargin: 50 * main.vScaleFactor
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                font.pixelSize: 35 * main.vScaleFactor
            }
        }
        Component.onCompleted: hide()
        onTimedOut: hide()
    }
    ModalDialog {
        id: drawAgainNotice
        dismissable: true
        blockKeys: true
        visible: false


        Item {
            z: drawAgainNotice.z + 1
            anchors.fill: parent

            TextLabel {
                id: warningText2
                width: parent.width
                color: "white"
                text: qsTr("Please Clear the graph to draw again") + application.emptyString
                anchors.horizontalCenter: parent.horizontalCenter
               // anchors.top: parent.top
                anchors.centerIn: parent.Center
                anchors.verticalCenter: parent.verticalCenter
                //anchors.topMargin: 50 * main.vScaleFactor
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                font.pixelSize: 35 * main.vScaleFactor
            }
        }
        Component.onCompleted: hide()
        onTimedOut: hide()
    }
    Item {
           width: 250 * main.hScaleFactor
            height:155 * main.vScaleFactor
            anchors.top: traceRect.bottom
            anchors.topMargin: 0.10 * main.screenHeight
            anchors.left: parent.left
            anchors.leftMargin: 250*main.vScaleFactor
   ColumnLayout
{
    anchors.fill: parent
    visible:true
    Item {
       Layout.fillHeight: true
       Layout.fillWidth: true
    RowLayout
    {
        anchors.fill: parent
        visible:false
            StandardButton {
                Layout.fillWidth: true
                height: 90
                buttonText: qsTr("INCLINE") + application.emptyString
                selected: root.isIncline
                color: selected ? main.colorSelected : main.colorDialogBackground
                onClicked: {
                  //  traceRect.inlclinePressed()
                   // root.str="INCLINE"

                }
            }
            StandardButton {
                Layout.fillWidth: true
                height: 90
                buttonText: qsTr("speed") + application.emptyString
                selected: root.isSpeed && !graphEditor.visible
                color: selected ? main.colorSelected : main.colorDialogBackground
                onClicked: {
                  //  traceRect.speedPressed()
                   // root.str="SPEED"

                }
            }
    }
    }
            StandardButton {
                Layout.fillWidth: true
                height: 90
                visible:true //!graphEditor.visible
                buttonText: qsTr("Clear the graph") + application.emptyString
                color: selected ? main.colorSelected : main.colorDialogBackground
                onClicked: {
                    traceRect.clearGraph()
                }
            }
        }
        }

    ListModel {
        id: customListModel
    }

    ListView {
        id: myListView

        property real initialWidth: 270 * main.hScaleFactor
        property real initialHeight: 75 * main.vScaleFactor

        //anchors.right: graphEditor.right
        anchors.right: traceRect.right

        anchors.rightMargin: 200 * main.hScaleFactor
        anchors.top: parent.top
        anchors.topMargin: 0.75 * main.screenHeight
        anchors.bottom: parent.bottom

        width: initialWidth * 2 + spacing + 20 * main.hScaleFactor

        model: customListModel
        delegate: myDelegate
        spacing: 40 * main.vScaleFactor
        orientation: ListView.Horizontal
        interactive: false
        clip: true

        Component {
            id: myDelegate

            DualBox {
                id: dataElement

                clickToExpand: true

                property bool isCI: ListView.isCurrentItem
                onIsCIChanged: {
                    if(isCI) {
                        expand();
                        clickToExpand = false;
                    } else {
                        collapse();
                        clickToExpand = true;
                    }
                }

                onClicked: {
                    SetupJS.validateParam(myListView.currentIndex)
                    myListView.currentIndex = index;

                    buzzer.buttonPress()
                }

                Component.onCompleted: {
//                    myListView.positionViewAtIndex(2,ListView.End);
                    populateElement(model.fieldType);
                }

                function populateElement(fieldtype) {
                    switch(fieldtype) {
                    case WorkoutProgram.TIME_TYPE:
                        //collapsedLoader.sourceComponent=bottomcomp_button
                        collapsedLoader.sourceComponent = topcomp_time;
                        extensionLoader.sourceComponent = bottomcomp_slider;

                        break;
                    case WorkoutProgram.SEGMENT_TYPE:
                        //collapsedLoader.sourceComponent=bottomcomp_button
                        collapsedLoader.sourceComponent = topcomp;
                        extensionLoader.sourceComponent = bottomcomp_segment
                        //extensionLoader.sourceComponent =bottomcomp_button
                        root.segmentIndex = index;
                        break;
                    }
                }



                Component { // Top Component - Basic
                    id: topcomp

                    Item {
                        width: myListView.initialWidth
                        height: myListView.initialHeight

                        TextLabel {
                            id: itemName
                            text: qsTranslate("WorkoutSetup", SetupJS.getItemLabel(model)) + SetupJS.getItemAdditionalLabel(model) + application.emptyString

                            width: 0.7 * myListView.initialWidth
                            font.pixelSize: root.paramTextSize
                            anchors.left: parent.left
                            anchors.leftMargin: 20 * main.hScaleFactor
                            anchors.verticalCenter: parent.verticalCenter
                        }

                        NumberLabel {
                            id: itemValue

                            text: model.dataValue
                            font.pixelSize: root.numTextSize
                            anchors.right: parent.right
                            anchors.rightMargin: 10 * main.hScaleFactor
                            anchors.verticalCenter: parent.verticalCenter
                            color: main.colorFontLight
                        }
                    }
                }

                Component { // Top Component - Time
                    id: topcomp_time

                    Item {
                        width: myListView.initialWidth
                        height: myListView.initialHeight

                        TextLabel {
                            id: itemName
                            text: qsTranslate("WorkoutSetup", SetupJS.getItemLabel(model)) + SetupJS.getItemAdditionalLabel(model) + application.emptyString
                            font.pixelSize: root.paramTextSize
                            anchors.left: parent.left
                            anchors.leftMargin: 10 * main.hScaleFactor
                            anchors.verticalCenter: parent.verticalCenter
                            wrapMode: Text.Wrap
                            width: 0.9 * (parent.width - itemValue.width)
                        }

                        NumberLabel {
                            id: itemValue
                            text: Format.formatTimeString(root.workoutTime*60)
                            font.pixelSize: root.numTextSize
                            anchors.right: parent.right
                            anchors.rightMargin: 10 * main.hScaleFactor
                            anchors.verticalCenter: parent.verticalCenter
                            width: 70 * main.hScaleFactor
                            horizontalAlignment: Text.AlignRight
                        }
                    }
                }


                Component { // Bottom component - Slider
                    id: bottomcomp_slider



                    Item { // slider control box seen after expanding most simple items (age, weight, time, etc.)
                        id: details

                        height: myListView.initialHeight
                        width: myListView.initialWidth
                        anchors.top: topcomp_time.bottom
                        anchors.horizontalCenter: parent.horizontalCenter
                        anchors.verticalCenterOffset: 10 * main.vScaleFactor

                        property int value: sliderObject.value

                        SliderControl {
                            id: sliderObject
                            repeat: true
                            valueProxy: model.dataValue
                            Component.onCompleted: {
                                value = model.dataValue;
                            }
                            onValueChanged: {

                                SetupJS.sliderObjectValueChanged(model, value, valueProxyChange);

                                root.model.setProperty(model.selectedIndex, "dataValue", value)
                                if (model.fieldType === WorkoutProgram.TIME_TYPE) {
                                    root.workoutTime = value
                                    mainProgItem.workTime = value
                                    calculateMaxSegmentsFromTime();
                                }
                            }
                            showValue: false
                            maxValue: model.maxValue
                            onMaxValueChanged: {
                                if (model.fieldType === WorkoutProgram.SPEED_TYPE || model.fieldType === WorkoutProgram.INCLINE_TYPE) {
                                    sliderObject.valueChanged();
                                }
                            }
                            minValue: model.minValue
                            value: model.dataValue
                            precision: model.precision
                            stepValue: {
                                if (model.precision === 0) {
                                    return 1;
                                } else if (model.precision === 1) {
                                    return 0.1;
                                }
                            }

                            anchors.top: parent.top
                            anchors.topMargin: 10 * main.vScaleFactor
                            anchors.horizontalCenter: parent.horizontalCenter
                            width: 0.8 * myListView.initialWidth
                            height: 0.6* parent.height
                        }
                    }
                }

                Component { // Bottom component - Segment
                    id: bottomcomp_segment

                    ColumnLayout {

                        height: 97 * main.vScaleFactor
                        width: myListView.initialWidth

                        Item {
                            id: segmentDetails
                            width: myListView.initialWidth
                            height: calculatedSegTimeValue1.height
                            anchors.topMargin: 20 * main.vScaleFactor
                            LayoutMirroring.enabled: main.rightToLeft
                            LayoutMirroring.childrenInherit: true

                            TextLabel {
                                id: calculatedSegTime1
                                text: qsTr("SEGMENT TIME:") + application.emptyString
                                font.pixelSize: 13 * main.vScaleFactor
                                anchors.left: parent.left
                                anchors.leftMargin: 10 * main.hScaleFactor
                                anchors.bottom: parent.bottom
                            }

                            NumberLabel {
                                id: calculatedSegTimeValue1
                                text: Format.formatTimeString(mainProgItem.segTime) + application.emptyString
                                font.pixelSize: 18 * main.vScaleFactor
                                horizontalAlignment: Text.AlignRight
                                anchors.right: parent.right
                                anchors.rightMargin: 30 * main.hScaleFactor
                            }
                        }

                        Item { // slider control box seen after expanding most simple items (age, weight, time, etc.)
                            id: details_segment
                            height: 60 * main.vScaleFactor
                            width: myListView.initialWidth
                            anchors.top: segmentDetails.bottom
                            anchors.topMargin: 10 * main.vScaleFactor
                            anchors.horizontalCenter: parent.horizontalCenter

                            property int value: sliderObject3.value

                            SliderControl {
                                id: sliderObject3
                                onValueChanged: {
                                    SetupJS.sliderObject3ValueChanged(model, value);
                                    root.model.setProperty(model.selectedIndex, "dataValue", value)
                                    mainProgItem.setNumSegments(value)
                                    segmentNo=value
//                                    if(graphEditor.visible)
//                                    {
//                                        traceRect.resetcanvas()
//                                    }else
                                    traceRect.redraw(value)

                                    //redrawXSegment(value)
                                }
                                showValue: false

                                minValue: model.minValue
                                maxValue: root.maxSegs
                                value: model.dataValue
                                precision: model.precision
                                stepValue: {
                                    if (model.precision === 0) {
                                        return 1;
                                    } else if (model.precision === 1) {
                                        return 0.1;
                                    }
                                }

                                anchors.horizontalCenter: parent.horizontalCenter
                                width: 0.75 * parent.width
                                height: 0.7 * parent.height

                                Connections {
                                    target: root
                                    onMaxSegsChanged: {
                                        sliderObject3.maxValue= root.maxSegs
                                        if (sliderObject3.value > sliderObject3.maxValue)
                                            sliderObject3.value = sliderObject3.maxValue
                                    }
                                }
                            }
                        }

                        Component.onCompleted: root.maxSegs = model.maxValue
                    }
                }
            }
        }
    }
    Rectangle
    {
        id:traceRect
        property var segmentValue:0
        anchors.left: parent.left
        anchors.leftMargin:  0.03*main.screenWidth
        anchors.right: parent.right
        anchors.rightMargin: 0.05*main.screenWidth
        anchors.top: parent.top
        anchors.topMargin: 0.1*main.screenHeight
        color:"transparent"
        height: 0.55*main.screenHeight
        /* Incline Variables*/
        property var mousexarray:[]
        property var mouseyarray:[]
        property var xPoints:[]
        property var yPoints:[]
        property var calYPoints:[]
        property var realx:[]
        property var realy:[]
         property var drawLineX
        property var drawLineY
        property var xp:0
        property var x0
        property var xAxis:drawXY.x+30
        property var endYaxis:traceRect.height-30
        property var yvalue:-0.3
        property var endXasis:parent.width-20
        property var totalSeg:0
        property bool resetgraph:false
        property bool resetcan:false
        property var segValue:[]
        property var segIndex:[]
        property var s:0
        property bool isinclinePressed:true
        property bool isSpeedPressed : false

        /*speed variables*/
        property var speedMousexarray:[]
        property var speedMouseyarray:[]
        property var speedRealx:[]
        property var speedRealy:[]
        property var speedXPoints:[]
        property var speedYPoints:[]
        property var speedCalYPoints:[]
        property bool speedResetcan:false
         property var speedDrawLineX
        property var speedDrawLineY
        property var speedx0
        property var speedxp
        property var speedyvalue:-0.3
        property var speedTotalSeg:0
        property var speedSegValue:[]
        property var speedSsegIndex:[]
        property var speed:0
        property variant model: root.state == "Profile1" ? root.model1 : root.model2



 function clearGraph()
        {
     showGraph.stop()
     root.segIndex=[]
     root.segValue=[]
     root.speedSegIndex=[]
     root.speedSegValue=[]
     if(can.visible===true)
     {
         can.requestLine=true
         can.noLine=false
         can.lineDrawInc=false

         can1.resetCan=true
         can.lefttoright=false

         traceRect.mousexarray=[]
         traceRect.mouseyarray=[]
        traceRect.realx=[]
         traceRect.realy=[]
         traceRect.segValue=[]
         traceRect.segIndex=[]
         traceRect.s=0
         can.requestPaint()
        can1.requestPaint()

 }
     if(canSpeed.visible)
     {
         canSpeed.requestLineSpeed=true
         canSpeed.noLineSpeed=false
         canSpeed.lineDraw=false

         canSpeed1 .speedResetCan=true

         canSpeed.lefttorightspeed=false
         speedMousexarray=[]
         speedMouseyarray=[]
         speedRealx=[]
         speedRealy=[]
         speedSegValue=[]
         speedSsegIndex=[]
         traceRect.speed=0
         canSpeed.requestPaint()
          canSpeed1.requestPaint()

     }
        }
 function clearfromGraph()
        {
     showGraph.stop()
     root.segIndex=[]
     root.segValue=[]
     root.speedSegIndex=[]
     root.speedSegValue=[]
     if(can.visible===true)
     {
        // can.requestLine=true
         can.noLine=false
         can.lineDrawInc=false

        // can1.resetCan=true

         mousexarray=[]
         mouseyarray=[]
         realx=[]
         realy=[]
         segValue=[]
         segIndex=[]
         traceRect.s=0
         //can.requestPaint()
        //can1.requestPaint()

 }
     if(canSpeed.visible)
     {
        // canSpeed.requestLineSpeed=true
         canSpeed.noLineSpeed=false
         canSpeed.lineDraw=false
        // canSpeed.requestPaint()
        // canSpeed1 .speedResetCan=true
         //canSpeed1.requestPaint()
         speedMousexarray=[]
         speedMouseyarray=[]
         speedRealx=[]
         speedRealy=[]
         speedSegValue=[]
         speedSsegIndex=[]
         traceRect.speed=0
     }
        }


/* function inlclinePressed()
 {
    // console.log("HHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHHH")
     root.isIncline=true
     root.isSpeed=false
     isinclinePressed=true
     isSpeedPressed=false
     graphEditor.visible=false
     can.visible=true
     can1.visible=true
     canSpeed.visible=false
     canSpeed1.visible=false
     drawXYSpeed.visible=false
     console.log("taotal seg on incline:::::::::::::::::::::::::::::::::",traceRect.totalSeg)
     drawXY.redrawXSegment(traceRect.totalSeg)
     drawXY.visible=true
     clearGraphTimer.stop()
     inclinePress.start()
     //showGraph.start()
 }
 function speedPressed()
 {
    // preshowGraph.start()
     root.isIncline=false
     root.isSpeed=true
     inclinePress.stop()
     clearGraphTimer.start()
     isSpeedPressed=true
     isinclinePressed=false
     graphEditor.visible=false
     can.visible=false
     can1.visible=false
     canSpeed.visible=true
     canSpeed1.visible=true
     drawXY.visible=false
     console.log("taotal seg on speedddddd:::::::::::::::::::::::::::::::::",traceRect.speedTotalSeg)
     drawXYSpeed.speedredrawXSegment(traceRect.speedTotalSeg)
     drawXYSpeed.visible=true
    // drawXY.redrawXSegment(traceRect.totalSeg)

 }*/
 /*Timer
 {
     id:clearGraphTimer
     repeat: false
     interval: 5000
     onTriggered:
     {

          preshowGraph.start()

     }

 }
 /* Timer
  {
      id:preshowGraph
      repeat: false
      interval: 1000
      onTriggered:
      {

          traceRect.speed=0
          traceRect.resetgraph=true
          graphEditor.visible=true
          segNumberList.visible=true
          can.visible=false
          can1.visible=false
          canSpeed.visible=false
          canSpeed1.visible=false
          drawXY.visible=false
          drawXYSpeed.visible=false

      }
  }*/


function redraw(seg)
{
     var canWidth=0

    traceRect.xp=0
    traceRect.speedxp=0
    traceRect.totalSeg=seg
    traceRect.speedTotalSeg=seg
    root.speedTotalSeg=seg
    root.totalSeg=seg
    root.segIndex=[]
    root.segValue=[]
    root.speedSegIndex=[]
    root.speedSegValue=[]

    for (var x =0 ; x <=seg; x++)
    {


    if(canWidth>=traceRect.width)
    {
        canWidth=traceRect.width
    }
    else
        canWidth+=traceRect.xAxis+60
    }
    can.width=canWidth
    can.requestLine=true
    can.noLine=false
    can.requestPaint()
    drawXY.width=canWidth
    drawXYSpeed.width=canWidth
    can1.width=canWidth
    can1.resetCan=true
    can1.requestPaint()
    canSpeed .width=canWidth
    canSpeed.requestLineSpeed=true
    canSpeed.noLineSpeed=false
    canSpeed1.width=canWidth
    canSpeed1.speedResetCan=true
    canSpeed.requestPaint()
    canSpeed1.requestPaint()
    drawXY.redrawXSegment(seg)
    drawXYSpeed.speedredrawXSegment(seg)
}
function resetcanvas()
{
    if(traceRect.resetgraph)
    {
     drawXY.visible=false
        if(isinclinePressed)
        {
     can1.visible=false
     can.visible=false
        }
        if(isSpeedPressed)
        {
     canSpeed.visible=false
     canSpeed1.visible=false
        }
    traceRect.resetgraph=false
}
}
Timer
{
    id:hideMessage
    repeat: false
    interval: 2000
    onTriggered:
    {
        wrongDrawNotice.hide()
        drawAgainNotice.hide()

         //showGraph.start()

    }

}

       Timer
        {
            id:showGraph
            repeat: false
            interval: 10
            onTriggered:
            {

                if(graphShow==="INCLINE")
                {
                    inclineDone();
                }
                else if(graphShow==="SPEED")
                {
                    speedDone()
                }

               /*if(!root.isCustomIncline)
                {
                   if(canSpeed.noLineSpeed==true)
                   {
                    clearGraphTimer.start()
                   }
                   root.str="SPEED"
                   root.isIncline=false
                   root.isSpeed=true

                   drawXYSpeed.speedredrawXSegment(traceRect.speedTotalSeg)
                   drawXYSpeed.visible=true
                   canSpeed.visible=true
                   canSpeed1.visible=true
                   canSpeed1.speedResetCan=false

                   can.visible=false
                   can1.visible=false
                   drawXY.visible=false


                }
                else
                {
                   traceRect.s=0
                   traceRect.resetgraph=true
                   graphEditor.visible=true
                   segNumberList.visible=true
                   //drawXY.graphName="SPEED"
                }*/

            }
        }


/*******************************************************************INCLINE CANVAS******************************************************************/

        Canvas
        {
            id:drawXY
            width: parent.width
            height: parent.height
            anchors.topMargin: 20
            visible: root.graphShow==="INCLINE"
            property var yAxis:drawXY.y
            property var yp
            property var calYp
            property var xendpoint:0
            property var newYAxis
            property var seg
            property var graphName:"INCLINE"
            property var maxlength:traceRect.model.maxLevel
            property int countInc
            property var showValue
            property var showCount
            property bool redrawxy:false
            function redrawXSegment(segmentN)
            {
                seg=segmentN
                traceRect.xp=0
                drawXY.requestPaint()
            }

            onPaint:
            {
                var ctx=getContext('2d')
                ctx.reset()
                var count=20
                var county=20
                var countx=20
                 traceRect.xPoints=[]
                var l=0
                var m=0
                ctx.strokeStyle="white"
                ctx.lineWidth=3;
                ctx.beginPath();
                ctx.moveTo(traceRect.xAxis,yAxis)
                ctx.lineTo(traceRect.xAxis,traceRect.endYaxis)
                newYAxis=traceRect.endYaxis
                ctx.moveTo(traceRect.xAxis,traceRect.endYaxis)
                ctx.lineTo(traceRect.endXasis,traceRect.endYaxis)
                ctx.stroke()
                countInc=traceRect.endYaxis/maxlength
                for (var z=maxlength;z>=1;z--)
                {
                  calYp=yAxis+county
                  traceRect.calYPoints[z]=calYp
                 county=county+countInc
                }

                if (root.model1.segmentType === 3) {
                   showValue=Math.round( (machineinfo.inclineTable[maxlength - 1]/10.0).toFixed(1))
                }  else {
                    showValue=maxlength
                }
                showCount=Math.round(showValue/16)
                console.log("showcount:::::::::::::::::::::::::::",showCount,showValue)
                for (var y = 1; y <=showValue; )
                     {
                   // yp=yAxis+count
                    yp=traceRect.endYaxis-count
                    ctx.beginPath();
                    ctx.textBaseline = "bottom"
                    ctx.font = 'bold 20px "Montserrat Hairline"'
                   // if(y===0 && showCount>1)
                      // y=1
                    ctx.fillStyle = Qt.rgba(1.0, 1.0, 1.0, 1.0)
                    var  w = ctx.measureText(y).width
                    ctx.fillText(y, traceRect.xAxis - w -5, yp)
                    traceRect.yPoints[m]=yp
                    m=m+1
                    if(showValue===12)
                   count=count+45
                    else
                        count=count+30



                    y=y+showCount
                }
                countx=Math.round(drawXY.width/seg)
                var lessValue=40
                console.log("segggggggggggggggg::::::::::::::::::::::::::::::",seg,countx,drawXY.width)
               for (var x =1 ; x <=seg; x++)
               {
                   ctx.beginPath();
                  // traceRect.xp+=traceRect.xAxis+60
                   traceRect.xp+=traceRect.xAxis+countx-lessValue
                  // ctx.moveTo((traceRect.xp/2),traceRect.endYaxis)
                  // ctx.lineTo((traceRect.xp/2),traceRect.endYaxis)
                  // ctx.stroke();
                  // ctx.closePath();
//                   if(seg>20)
//                   {
//                       lessValue=60
//                   }

                   ctx.fillStyle = Qt.rgba(1.0, 1.0, 1.0, 1.0)
                   ctx.textBaseline = "bottom"
                   ctx.font = 'bold 20px "Montserrat Hairline"'

                   var p = ctx.measureText(x).width
                   var xpoint=traceRect.xp
                   ctx.fillText(x,xpoint,traceRect.endYaxis+10+p)
                   traceRect.xPoints[l]=traceRect.xp;
                   l=l+1
                   xendpoint=traceRect.xp
                   }
            }
        }


        Canvas
        {
            id:can1
            width: parent.width
            height: parent.height
            anchors.topMargin: 20
            visible: root.graphShow==="INCLINE"
            property bool resetCan:false
            onPaint:
            {
                var l=0
                var p=0
                var ctx=getContext('2d')
                var yAxisLength=traceRect.calYPoints.length
               for (var k=yAxisLength;k>=1;k--)
               {
                   if(traceRect.calYPoints[k]>=traceRect.realy[l])
                   {
                      traceRect.segValue[p]=k
                       root.segValue[p]=k
                       p=p+1
                       l=l+1
                       k=yAxisLength

                   }
               }

//               for (var j=0;j<traceRect.realx.length;j++)
//               {

//                   ctx.beginPath()
//                   ctx.fillStyle = "blue"//Qt.rgba(180/255,60/255,34/255, 0.5)
//                   ctx.fillRect(traceRect.realx[j], traceRect.realy[j],traceRect.xAxis-traceRect.realx[j],20)
//               }
                for(var i=0;i<traceRect.realx.length;i++)
                {
                    ctx.beginPath()
                    ctx.fillStyle = "blue"//Qt.rgba(180/255,60/255,34/255, 0.5)
                    ctx.fillRect(traceRect.realx[i], traceRect.realy[i], 40,traceRect.endYaxis-traceRect.realy[i])
                 }
                if(can1.resetCan===true)
                {
                    ctx.reset()
                    can1.resetCan=false
                }

            }
        }


       Canvas
       {
           id:can
           width: parent.width
           height: parent.height
           anchors.topMargin: 20
           visible: root.graphShow==="INCLINE"

           property int finishX:0;
           property int finishY:0;
           property int count:0
           property bool noLine:false

           property bool requestLine:false;
           property bool paintLine:false
           property bool lineDrawInc:false
           property bool lefttoright:false

           onPaint:
           {
               var ctx=getContext('2d')
               ctx.strokeStyle="white"
                ctx.lineWidth=5;
                ctx.beginPath();
                ctx.moveTo(finishX,finishY)
               if(area1.mouseX>finishX)
               {
                   finishX=area1.mouseX
                    finishY=area1.mouseY
                    ctx.lineTo(finishX,finishY)
                    ctx.stroke()
                   can.lineDrawInc=true

               }else
               {
                  // console.log("^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^")
                  // can.lefttoright=true
                  // wrongDrawNotice.show()
                  // hideMessage.start()
               }

               if(requestLine)
               {
                   ctx.reset()
                   requestLine=false
                  can.count=0
                   area1.i=0
                   can.lineDrawInc=false

               }


           }
           MouseArea
           {
               id:area1
               anchors.fill: parent
               property int i:0
               onPressed:
               {
                  if(can.count>=1)
                   {
                      //drawAgainNotice.show()
                     // hideMessage.start()
                       console.log("****")
                   }else
                   {

                  can.finishX=mouseX
                  can.finishY=mouseY
                  can.count=can.count+1;
                   }

               }
               onPositionChanged:
               {
                  if(can.noLine===false)
                  {
                   can.requestPaint()
                   traceRect.mousexarray[i]=mouseX
                   traceRect.mouseyarray[i]=mouseY
                   i++
                  }

               }
               onReleased:
               {
                   if(can.lineDrawInc===true)
                   {

                     can.lineDrawInc=false
                       can.count=can.count+1;
                      can.noLine=true
                       can.lefttoright=false

                   traceRect.isinclinePressed=true
                   var k=0
                   var i=0
                   var p=1
                   for (var m=0;m<traceRect.xPoints.length;m++)
                   {
                   if(traceRect.xPoints[m]<Math.round(traceRect.mousexarray[0]))
                   {
                     ///traceRect.segValue[traceRect.s]="-3.0%"
                    // traceRect.s=traceRect.s+1
                   }
                   else{
                       i=m;
                       break;
                   }
                   }

                   for(var j=0;j<traceRect.mousexarray.length;j++)
                  {
                       if(Math.round(traceRect.mousexarray[j])>traceRect.xPoints[i])
                       {
                           traceRect.drawLineY=traceRect.mouseyarray[j]
                           traceRect.drawLineX=traceRect.mousexarray[j]
                           traceRect.x0=traceRect.xPoints[i]
                           traceRect.segIndex[traceRect.s]=i
                           root.segIndex[traceRect.s]=i
                           traceRect.realx[k]=traceRect.xPoints[i]
                           traceRect.realy[k]=traceRect.drawLineY
                           i=i+1
                           k=k+1
                           traceRect.s=traceRect.s+1
                       }
                   }
                   can1.requestPaint()
                   showGraph.start()

               }else
                   {
                       if(can.noLine===true)
                       {
                           drawAgainNotice.show()
                           hideMessage.start()

                       }else{

                       if(can.lefttoright===true)
                       {
                           if(can.noLine===false)
                           {
                               wrongDrawNotice.show()
                               hideMessage.start()
                               can.count=0
                               area1.i=0
                               traceRect.clearfromGraph()
                           }

                       }else{

                       can.lefttoright=true
                       wrongDrawNotice.show()
                       hideMessage.start()
                           can.count=0
                           area1.i=0
                           traceRect.clearfromGraph()
                       }
                       }

                   }
               }
           }

       }



 /********************************************************** SPEED CANVAS *************************************************************************/
       Canvas
       {
           id:drawXYSpeed
           width: parent.width
           height: parent.height
           anchors.topMargin: 20
           visible: root.graphShow==="SPEED"
           property var speedyAxis:drawXY.y
           property var speedyp
           property var speedcalYp
           property var speedxendpoint:0
           property var speednewYAxis
           property var speedseg
           property var speedmaxlength:root.model2.maxLevel
           property int countervar
           property var showSpeed:0
           property var showSpeedValue:0
           property int showStartSpeed:1
           function speedredrawXSegment(segmentN)
           {
               speedseg=segmentN
               traceRect.speedxp=0
               drawXYSpeed.requestPaint()
           }

           onPaint:
           {
               var ctx1=getContext('2d')
               var speedcount=20
               var speedcounty=20
               var speedcountx=20
                traceRect.speedXPoints=[]
               var l=0
               var m=0
               ctx1.reset()
               ctx1.strokeStyle="white"
               ctx1.lineWidth=3;
               ctx1.beginPath();
               ctx1.moveTo(traceRect.xAxis,speedyAxis)
               ctx1.lineTo(traceRect.xAxis,traceRect.endYaxis)
               speednewYAxis=traceRect.endYaxis
               ctx1.moveTo(traceRect.xAxis,traceRect.endYaxis)
               ctx1.lineTo(traceRect.endXasis,traceRect.endYaxis)
               ctx1.stroke()
               countervar=Math.round(traceRect.endYaxis/speedmaxlength);
               for (var z=speedmaxlength;z>=1;z--)
               {
                  speedcalYp=speedyAxis+speedcounty
                   traceRect.speedCalYPoints[z]=speedcalYp
                   speedcounty=speedcounty+countervar

               }
               if (root.model2.segmentType === WorkoutProfile.SPEED_SEG_TYPE) {
                   showSpeed = Math.round((machineinfo.speedTable[speedmaxlength - 1]/10.0).toFixed(1))
                   showStartSpeed=1
               } else if (root.model2.segmentType === WorkoutProfile.PACE_SEG_TYPE) {
                          showSpeed=116
                          showStartSpeed=50
               }else
                   showSpeed=speedmaxlength

               showSpeedValue=Math.round((showSpeed-showStartSpeed)/16)
               console.log("showSpeedValue:::::::::::::::::::::::::::::::::::::::::::",showSpeedValue,showSpeed)
               for (var y = showStartSpeed; y <=showSpeed; )
                    {
                  //speedyp=speedyAxis+speedcount
                   speedyp=traceRect.endYaxis-speedcount
                  ctx1.beginPath();
                  ctx1.textBaseline = "bottom"
                  ctx1.font = 'bold 20px "Montserrat Hairline"'
                  ctx1.fillStyle = Qt.rgba(1.0, 1.0, 1.0, 1.0)
                  var  w = ctx1.measureText(y).width
                   ctx1.fillText(y, traceRect.xAxis - w -5, speedyp)
                  traceRect.speedYPoints[m]=speedyp
                  m=m+1
                  if(showSpeed===12)
                  {
                   speedcount=speedcount+45
                  }else
                  speedcount=speedcount+35

                  y=y+showSpeedValue

                       }
               speedcountx=drawXYSpeed.width/speedseg
              for (var x =1 ; x <=speedseg; x++)
                    {

                  ctx1.beginPath();
                  traceRect.speedxp+=traceRect.xAxis+speedcountx-40
                 // ctx1.moveTo((traceRect.speedxp/2),traceRect.endYaxis)
                 // ctx1.lineTo((traceRect.speedxp/2),traceRect.endYaxis)
                 // ctx1.stroke();
                  //ctx1.closePath();
                  ctx1.fillStyle = Qt.rgba(1.0, 1.0, 1.0, 1.0)
                  ctx1.textBaseline = "bottom"
                  ctx1.font = 'bold 20px "Montserrat Hairline"'

                  var z = ctx1.measureText(x).width
                  var xpoint=traceRect.speedxp
                  ctx1.fillText(x,xpoint,traceRect.endYaxis+10+z)
                  traceRect.speedXPoints[l]=traceRect.speedxp;
                  l=l+1
                  speedxendpoint=traceRect.speedxp
              }
           }
       }
       Canvas
       {
           id:canSpeed1
           visible: root.graphShow==="SPEED"
           width: parent.width
           height: parent.height
           anchors.topMargin: 20
           property bool speedResetCan:false
            onPaint:
           {
                var l=0
                var p=0
                var ctx=getContext('2d')
                var yAxisLength=traceRect.speedCalYPoints.length
              for (var k=yAxisLength;k>=1;k--)
              {
               if(traceRect.speedCalYPoints[k]>=traceRect.speedRealy[l])
                  {
                     traceRect.speedSegValue[p]=k
                      root.speedSegValue[p]=k
                      p=p+1
                      l=l+1
                      k=yAxisLength
               }
              }

//              for (var j=0;j<traceRect.speedRealy.length;j++)
//              {
////                  var value1=0
////                 value1= valueFromPosition(traceRect.speedRealy[j])
////                  console.log("!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!",value1)
////                  root.speedSegValue[l]=value1
////                  l=l+1

//                 // ctx.beginPath()
//                  //ctx.fillStyle = "blue"//Qt.rgba(180/255,60/255,34/255, 0.5)
//                  //ctx.fillRect(traceRect.realx[j], traceRect.realy[j],traceRect.xAxis-traceRect.realx[j],20)
//              }
               for(var i=0;i<traceRect.speedRealx.length;i++)
               {
                   ctx.beginPath()
                   ctx.fillStyle = "blue"//Qt.rgba(180/255,60/255,34/255, 0.5)
                   ctx.fillRect(traceRect.speedRealx[i], traceRect.speedRealy[i], 40,traceRect.endYaxis-traceRect.speedRealy[i])
                }
               if(canSpeed1.speedResetCan===true)
               {
                   ctx.reset()
                   canSpeed1.speedResetCan=false
               }
           }
       }


       Canvas
       {
           id:canSpeed
           width: parent.width
           height: parent.height
           anchors.topMargin: 20
           visible: root.graphShow==="SPEED"

           property int finishXSpeed:0;
           property int finishYSpeed:0;
           property int countSpeed:0
           property bool noLineSpeed:false

           property bool requestLineSpeed:false;
           property bool paintLineSpeed:false
           property bool lineDraw:false
           property bool lefttorightspeed:false

           onPaint:
           {
               var ctx1=getContext('2d')
               ctx1.strokeStyle="white"
                ctx1.lineWidth=5;
                ctx1.beginPath();
                ctx1.moveTo(finishXSpeed,finishYSpeed)
               if(areaSpeed.mouseX>finishXSpeed)
               {

                   finishXSpeed=areaSpeed.mouseX
                    finishYSpeed=areaSpeed.mouseY
                    ctx1.lineTo(finishXSpeed,finishYSpeed)
                    ctx1.stroke()
                   console.log("TTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT")
                   canSpeed.lineDraw=true
               }
               if(requestLineSpeed)
               {
                   ctx1.reset()
                   requestLineSpeed=false
                  canSpeed.countSpeed=0
                   areaSpeed.i=0
                   canSpeed.lineDraw=false

               }


           }
           MouseArea
           {
               id:areaSpeed
               anchors.fill: canSpeed
               property int i:0
               onPressed:
               {
                  if(canSpeed.countSpeed===1)
                   {
                       console.log("****")
                   }else
                   {

                  canSpeed.finishXSpeed=mouseX
                  canSpeed.finishYSpeed=mouseY
                  canSpeed.countSpeed=canSpeed.countSpeed+1;
                   }
                  // chart.requestPaint()
               }
               onPositionChanged:
               {

                  if(canSpeed.noLineSpeed===false)
                  {
                      console.log("YYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYY",i)
                   canSpeed.requestPaint()
                   traceRect.speedMousexarray[i]=mouseX
                   traceRect.speedMouseyarray[i]=mouseY
                   i++
                  }

               }
               onReleased:
               {
                   if(canSpeed.lineDraw===true)
                   {
                       canSpeed.countSpeed=canSpeed.countSpeed+1;
                     canSpeed.lineDraw=false
                   canSpeed.noLineSpeed=true
                   canSpeed.lefttorightspeed=false
                   traceRect.isSpeedPressed=true
                   var k=0
                   var i=0
                   var p=1
                   for (var m=0;m<traceRect.speedXPoints.length;m++)
                   {
                   if(traceRect.speedXPoints[m]<Math.round(traceRect.speedMousexarray[0]))
                   {
                     ///traceRect.segValue[traceRect.s]="-3.0%"
                    // traceRect.s=traceRect.s+1
                   }
                   else{
                       i=m;
                       break;
                   }
                   }

                  for(var j=0;j<traceRect.speedMouseyarray.length;j++)
                  {
                    if(Math.round(traceRect.speedMousexarray[j])>traceRect.speedXPoints[i])
                    {
                        traceRect.speedDrawLineY=traceRect.speedMouseyarray[j]
                        traceRect.speedDrawLineX=traceRect.speedMousexarray[j]
                        traceRect.speedx0=traceRect.speedXPoints[i]
                        traceRect.speedSsegIndex[traceRect.speed]=i
                        root.speedSegIndex[traceRect.speed]=i
                        traceRect.speedRealx[k]=traceRect.speedXPoints[i]
                        traceRect.speedRealy[k]=traceRect.speedDrawLineY
                        i=i+1
                        k=k+1
                        traceRect.speed=traceRect.speed+1
                    }
                   }
                  canSpeed1.requestPaint()
                  showGraph.start()
               }else
                   {
                       if(canSpeed.noLineSpeed===true)
                       {
                           drawAgainNotice.show()
                           hideMessage.start()

                       }else{

                       if(canSpeed.lefttorightspeed===true)
                       {
                           if(canSpeed.noLineSpeed===false)
                           {
                               wrongDrawNotice.show()
                               hideMessage.start()
                               canSpeed.countSpeed=0
                               areaSpeed.i=0
                               traceRect.clearfromGraph()
                           }

                       }else{

                       canSpeed.lefttorightspeed=true
                       wrongDrawNotice.show()
                       hideMessage.start()
                           canSpeed.countSpeed=0
                           areaSpeed.i=0
                           traceRect.clearfromGraph()
                       }
                       }

                   }
               }
       }
    }
}
}
