import QtQuick 2.12
import Components 1.0

Item {
    id: item1

    width: main.width
    height: main.height

    property int tableWidth: 1100 * main.hScaleFactor
    property int tableHMargin: 40 * main.hScaleFactor
    property int col1Width: 175 * hScaleFactor
    property int columnWidth: (tableWidth - col1Width)/3

    signal close()

    // mouse area masks other mouse areas underneath
    MouseArea {
        anchors.fill: parent
    }

    ScalableImage {
        id: background
        z: -2
        visible: true
        anchors.fill: parent
        sourceName: "StandardPage/View_Background"
    }

    BackButton {
        id: backButton
        z: homeScreenImage.z + 1
        backState: "SetupState";
        onClicked: {
            close()
        }
    }

    // build data set for heart rate chart
    Component.onCompleted: {
        var maxVals = [200, 195, 190, 185, 180, 175, 170, 165, 160, 155, 149, 143, 137 ]
        var age, i, max, min, cfc

        hrcWeightLossTable.append( { label: QT_TR_NOOP("60-75% MAX"), cellFillColor: "#00A0DF"} )
        hrcAerobicTable.append( { label: QT_TR_NOOP("75-85% MAX"), cellFillColor: "#00A0DF" } )
        hrcPerformanceTable.append( { label: QT_TR_NOOP("85%-100% MAX"), cellFillColor: "#00A0DF" } )
        ageModel.append( { label: "", cellFillColor: "#00A0DF" } )  // empty row in age column

        for (i=0, age=20 ; age< 85 ; i++, age+=5 ) {
            cfc = i % 2 == 1 ? "#333333" : "#000000"
            ageModel.append( { label: ""+age, cellFillColor: cfc } )

            min = maxVals[i] * 0.60
            max = maxVals[i] * 0.75
            hrcWeightLossTable.append( { label: min.toFixed(0) + "-" + max.toFixed(0), cellFillColor: cfc } )

            min = maxVals[i] * 0.75
            max = maxVals[i] * 0.85
            hrcAerobicTable.append( { label: min.toFixed(0) + "-" + max.toFixed(0), cellFillColor: cfc } )

            min = maxVals[i] * 0.85
            max = maxVals[i] * 1.0
            hrcPerformanceTable.append( { label: min.toFixed(0) + "-" + max.toFixed(0), cellFillColor: cfc } )
        }
    }

    ScalableImage {
        id: iconHRC
        anchors.left: parent.left
        anchors.leftMargin: 160 * main.hScaleFactor
        anchors.top: parent.top
        anchors.topMargin: 90 * main.vScaleFactor
        width: 80 * main.hScaleFactor
        height: 80 * main.vScaleFactor
        sourceName: "WF/WF_Button_HRC";
        fillMode: Image.PreserveAspectFit
    }

    Text {
        width: 500 * hScaleFactor
        color: main.colorFontLight
        text: qsTr("Use this Heart Rate Chart to determine the correct heart rate for your age and workout goal.") + application.emptyString
        anchors.left: guideTitle.right
        anchors.leftMargin: 50 * main.hScaleFactor
        anchors.verticalCenter: iconHRC.verticalCenter
        font.pointSize: 14 * vScaleFactor
        wrapMode: Text.WordWrap
    }

    ListModel {
        id: ageModel
        property int width: item1.col1Width
        property int hAlign: Text.AlignHCenter
        property string heading: qsTr("AGE") + application.emptyString
        property url bgimage: ""
        property bool showLines: false
        property bool showFill: true
    }

    ListModel {
        id: hrcWeightLossTable
        property int width: item1.columnWidth
        property string heading: qsTr("WEIGHT LOSS") + application.emptyString
        property bool showEdgeRule: true
        property int hAlign: Text.AlignHCenter
        property bool showLines: false
        property bool showFill: true
    }

    ListModel {
        id: hrcAerobicTable
        property int width: item1.columnWidth
        property string heading: qsTr("AEROBIC") + application.emptyString
        property bool showEdgeRule: true
        property int hAlign: Text.AlignHCenter
        property bool showLines: false
        property bool showFill: true
    }

    ListModel {
        id: hrcPerformanceTable
        property int width: item1.columnWidth
        property string heading: qsTr("PERFORMANCE") + application.emptyString
        property bool showEdgeRule: true
        property int hAlign: Text.AlignHCenter
        property bool showLines: false
        property bool showFill: true
    }

    Rectangle {
        id: tableWrap

        width: item1.tableWidth + 2*item1.tableHMargin
        height: 0.73*main.height
        radius: main.defaultRadius
        anchors.top: parent.top
        anchors.topMargin: 180 * main.vScaleFactor
        anchors.left: parent.left
        anchors.leftMargin: 120 * main.hScaleFactor
        color: main.colorDialogBackground
        border.color: main.colorUIBorder
        border.width: main.widthBorder

        DataTable {
            id: heartRateTable
            sourceFile: "HeartRateGuide"
            anchors.top: parent.top
            anchors.topMargin: 5 * main.vScaleFactor
            anchors.left: parent.left
            anchors.leftMargin: item1.tableHMargin
            height: tableWrap.height - 10*main.vScaleFactor
            models: [ ageModel, hrcWeightLossTable, hrcAerobicTable, hrcPerformanceTable ]
        }
    }

    TextLabel {
        id: guideTitle
        text: qsTr("HEART RATE CHART") + application.emptyString
        anchors.top: parent.top
        anchors.topMargin: 100 * vScaleFactor
        anchors.left: iconHRC.right
        anchors.leftMargin: 20 * hScaleFactor
        font.pixelSize: 24 * vScaleFactor
        font.letterSpacing: 5
    }
}
