import QtQuick 2.12
import Components 1.0
import StorageMgr 1.0
import "workout_menus.js" as TouchMenus
import ".."

Item {
    id: root

    signal saveProgram(string programFileName, int saveLocation)
    signal close()
    property int maxFiles: 5
    property string savedProgramPath: "/data/saved_programs/"
    property variant savedProgramFileList: savedFileList()
    property string programFileToSave: ""
    property int savingIndex: 0

    onVisibleChanged: {
        // populate the list of saved files when the dialog is shown
        if(visible) {
            root.savedProgramFileList = savedFileList()
            root.savingIndex=0
        }
    }

    Connections {
        target: main.state === "SetupState" && setupScreenManager.state === "LoadSavedWorkouts" ? workoutProgram : null
        onLoadSaveProgramComplete: {
            //            loadingText.visible = false
            nextButton.visible = true
        }
    }

    // populate the list of saved files from directory listing
    function savedFileList() {
        return TouchMenus.savedMenuList(true)
    }

    StorageMgr {
        id: storage
    }

    Text {
        id: instructValue
        anchors {
            top: parent.top
            topMargin: 100 * main.vScaleFactor
            left: parent.left
            leftMargin: 30 * main.hScaleFactor
            right: saveControls.left
            rightMargin: 30 * main.hScaleFactor
        }
        text: qsTr("Choose one of the 5 Saved Workout slots on the right to store your workout setup. Choosing a slot with an already saved workout will DELETE the existing saved workout and replace it with your workout.") + application.emptyString
        wrapMode: Text.WordWrap
        font.pixelSize: 20 * main.vScaleFactor
        font.bold: false
        color: main.colorFontLight
        visible: true
    }

    ListView {
        id: saveControls

        model: root.savedProgramFileList
        delegate: saveDelegate
        anchors {
            top: parent.top
            topMargin: 100 * main.vScaleFactor
            bottom: parent.bottom
            bottomMargin: 20 * main.vScaleFactor
            right: parent.right
            rightMargin: 15 * main.hScaleFactor
        }
        width: 434 * main.hScaleFactor
        interactive: true
        spacing: 12 * main.vScaleFactor
    }

    Component {
        id: saveDelegate

        WorkoutFinderOption {
            id: wfo

            isSaveWorkout: true
            initialWidth: parent.width
            initialHeight: 86 * main.vScaleFactor

            title: modelData.label
            description: modelData.desc
            icon_source: modelData.icon
            onClicked: {
                ListView.view.currentIndex = index
                buzzer.buttonPress()
            }
            onStateChanged: {
                enabled = false
                enabled = true
            }
            onButtonClicked: {
                root.savingIndex = index + 1
                saveProgram(root.programFileToSave,index+1)
                root.savedProgramFileList = root.savedFileList()
            }
            onTitleChanged: expanded = false

            property bool isCI: ListView.isCurrentItem
            onIsCIChanged: {
                if(!isCI) {
                    wfo.collapse()
                }
            }
        }
    }
}
