import QtQuick 2.12
import "../string_format.js" as Format
import "program_setup.js" as Fields
import Components 1.0
import QtQuick.Layouts 1.12
import ".."

Item {
    id: c360Content

    property alias model: myC360ListView.model
    property bool saveSelected: false

    signal itemOpened()

    function validate() {
        // if all entries are zero, issue a warning prompt to user and do not start workout
        for (var i = 0; i < c360Content.model.count; i++) {
            if (c360Content.model.get(i).dataValue !== 0) {
                return 0
            }
        }
        invalidEntryWarning.showWithTimeout(5)
        return 1
    }

    function getPhaseTitle(item) {
        if(main.isLateralTrainer) {
            return [qsTr("START UP, PUSH OUTWARD"),
                    qsTr("PUSH INWARD"),
                    qsTr("LEG PUMPS OUTWARD"),
                    qsTr("SQUAT INWARD"),
                    qsTr("PUSH OUTWARD"),
                    qsTr("LEG PUMPS INWARD"),
                    qsTr("STAND ON TOES, PUSH OUTWARD"),
                    qsTr("SQUAT OUTWARD"),
                    qsTr("STAND ON TOES, PUSH INWARD"),
                    qsTr("RECOVER, PUSH OUTWARD")
                    ][item.fieldIndex-1]
        } else {
            return [qsTr("STRIDE FORWARD"),
                    qsTr("STRIDE FORWARD & PUSH ARMS"),
                    qsTr("STAND ON SIDES, LEFT ARM ONLY"),
                    qsTr("STAND ON SIDES, RIGHT ARM ONLY"),
                    qsTr("REVERSE STRIDE & BEND KNEES"),
                    qsTr("STRIDE FORWARD & LIFT HEELS"),
                    qsTr("STRIDE FORWARD & PULL ARMS"),
                    qsTr("REVERSE STRIDE & LIFT TOES"),
                    qsTr("STAND ON SIDES, PUSH & PULL ARMS"),
                    qsTr("RECOVER - STRIDE FORWARD")
                    ][item.fieldIndex-1]
        }
    }

    // Reset saved flag when any data is changed
    Connections {
        target: c360Content.model ? c360Content.model : null
        ignoreUnknownSignals: true
        onDataChanged: {
            mainProgItem.saveHasHappened = false
        }
    }

    MessagePopup {
        id: invalidEntryWarning
        message: qsTr("Cannot Start Workout - All Phases are Set to 0:00") + application.emptyString
        Component.onCompleted: hide()
    }

    ListView {
        id: myC360ListView
        anchors.left: parent.left
        anchors.leftMargin: 30 * main.hScaleFactor
        anchors.top: prog_setup_desc_text.bottom
        anchors.topMargin: 10 * main.vScaleFactor
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 50 * main.vScaleFactor
        interactive: true
        clip: true
        delegate: myDelegate
        spacing: 20 * main.vScaleFactor
        currentIndex: -1;

        onCurrentIndexChanged: {
            keypad.clear()
            var item = model.get(currentIndex)

            if(!item) {
                return
            }

            mainProgItem.selectedIndex = item.selectedIndex
            mainProgItem.fieldIndex = item.fieldIndex
            keypad.units = item.units
        }

        Component {
            id: myDelegate

            DualBox {
                id: dataElement
                expandTime: 500

                property real initialWidth: 590 * main.hScaleFactor
                property real initialHeight: 75 * main.vScaleFactor
                property bool isCI: ListView.isCurrentItem

                onIsCIChanged: {
                    if(isCI) {
                        expand()
                        clickToExpand = false
                    } else {
                        collapse()
                        clickToExpand = true
                    }
                }

                onClicked: {
                    var item = ListView.view.model.get(mainProgItem.selectedIndex)

                    // Round out and save value of element being left just in case of leftover keypad input
                    if(keypad.value) {
                        var quarts = keypad.toQuarters(keypad.value).toFixed(0)

                        if(quarts > 8) {
                            quarts = 8
                        }

                        ListView.view.model.setProperty(mainProgItem.selectedIndex, "dataValue", quarts)
                    }

                    keypad.clear()
                    ListView.view.currentIndex = index
                    buzzer.buttonPress()
                }

                Component.onCompleted: {
                    populateElement(model.fieldType)
                }

                function populateElement(fieldtype) {
                    collapsedLoader.sourceComponent = topcomp_time
                    extensionLoader.sourceComponent = bottomcomp_slider
                }

                Component {
                    id: topcomp_time

                    RowLayout {
                        width: dataElement.initialWidth
                        height: dataElement.initialHeight

                        TextLabel {
                            id: c360ItemName
                            text: {
                                var txt = qsTr(c360Content.getPhaseTitle(model))
                                if (application.currentLanguage != "en")
                                    txt = txt.replace("\n", " ")
                                return txt + application.emptyString
                            }
                            font.pixelSize: 18 * main.vScaleFactor
                            anchors.left: parent.left
                            anchors.leftMargin: 10 * main.hScaleFactor
                            anchors.verticalCenter: parent.verticalCenter
                        }

                        NumberLabel {
                            id: itemValue
                            text: Format.formatTimeString(model.dataValue * 15)
                            font.pixelSize: 51 * main.vScaleFactor
                            anchors.right: parent.right
                            anchors.rightMargin: 10 * main.hScaleFactor
                            anchors.verticalCenter: parent.verticalCenter
                        }
                    }
                }

                Component { // Bottom component - Slider
                    id: bottomcomp_slider

                    Item { // slider control box seen after expanding most simple items (age, weight, time, etc.)
                        id: details
                        height: 55 * main.vScaleFactor
                        width: dataElement.initialWidth
                        anchors.centerIn: parent

                        property int value: c360SliderObject.value

                        SliderControl {
                            id: c360SliderObject
                            repeat: true
                            valueProxy: model.dataValue
                            Component.onCompleted: {
                                value = model.dataValue;
                            }
                            onValueChanged: {
                                if(!valueEntered) {
                                    model.dataValue= value                                }
                            }
                            onInput: keypad.clear() // Clear the keypad whenever there is an input
                            showValue: false
                            maxValue: model.maxValue
                            minValue: model.minValue
                            value: model.dataValue
                            precision: model.precision
                            stepValue: 1
                            anchors.verticalCenter: parent.verticalCenter
                            anchors.horizontalCenter: parent.horizontalCenter
                            width: 0.8*parent.width
                            height: parent.height
                        }
                    }
                }
            }
        }
    }

    Text {
        id: prog_setup_desc_text
        anchors.left: parent.left
        anchors.leftMargin: 30 * main.hScaleFactor
        anchors.top: parent.top
        anchors.topMargin: 85 * main.vScaleFactor
        anchors.right: parent.right
        anchors.rightMargin: 313 * main.hScaleFactor
        height: 75 * main.vScaleFactor
        text: qsTranslate("Setup", Fields.prog_setup_custom_c360_time_desc) + application.emptyString
        color: main.colorFontLight
        wrapMode: Text.WordWrap
        font.pixelSize: 16 * main.vScaleFactor
        font.bold: false
    }

    Keypad {
        id: keypad

        // convert a keypad entered 3-digit value to a quarter of minute value (1 = 0:15 ,etc.)
        function toQuarters(timestring) {
            timestring = timestring.toString()  // ensure it is a string and not a number
            var mins = 0
            if(timestring.length >2 )
                mins = parseInt(timestring[0])
            var secs = parseInt(timestring.slice(-2))
            var seconds = mins*60 + secs
            return seconds / 15
        }

        anchors.top: parent.top
        anchors.topMargin: 148 * main.vScaleFactor
        anchors.right: parent.right
        anchors.rightMargin: 30 * main.hScaleFactor
        show_entry: false
        allow_close: false
        keyWidth: 60 * main.hScaleFactor
        keyHeight: 63 * main.vScaleFactor
        clear_after_enter: true
        length: 3
        color: "transparent"
        onValueEntered: {
            if (keypad.value) {
                var quarts = toQuarters(keypad.value).toFixed(0)

                if(quarts > 8) {
                    quarts = 8
                }

                mainProgItem.valueEntered = true;
                model.setProperty(myC360ListView.currentIndex, "dataValue", quarts)
                mainProgItem.valueEntered = false
            }

            myC360ListView.incrementCurrentIndex()
        }
        onKeyPress: {
            if (key != ">") {
                // allow the display of invalid values (fractional quarts, etc.) as keypad value is entered
                // by not setting valueEntered, the slider is not quantizing or limiting input
                var quarts = toQuarters(keypad.value)
                model.setProperty(myC360ListView.currentIndex, "dataValue", quarts)
            }
        }
    }
}
