import QtQuick 2.12
import WorkoutManager 1.0
import "../string_format.js" as Format
import Components 1.0
import QtQuick.Layouts 1.12
import "../views"
import ".."

import "program_setup.js" as Fields
import "setup_params.js" as SetupJS

Item {
    id: root

    property variant model1
    property variant model2
    property int currentIndex: 0
    property int workoutTime
    property int segmentTime
    property int maxSegs
    property int segmentIndex
    property bool valueEntered: false


    property int paramTextSize: 15 * main.vScaleFactor
    property int numTextSize: 20 * main.vScaleFactor

//    property bool isTreadmill: machineinfo.productTypeString === "Treadmill"

    property variant model

    onModelChanged: {
        if (root.model) {
            populateCustomModel();
            modelPostProcessing();
        }
    }

    function modelPostProcessing() {
        // get references to the time and distance model items for making the time/dist mutex for manual workout
        var timeItem = root.model.find("fieldType", WorkoutProgram.TIME_TYPE)
        if (timeItem) {
            root.model.setProperty(timeItem.fieldIndex - 1, "maxValue", options.workoutTimeMax)
            if (timeItem.dataValue > 0)
                SetupJS.setParameter(WorkoutProgram.TIME_TYPE, timeItem.dataValue) // re-set value in case it is now over max
        }

        for(var i = 0; i < myListView.model.count; i++)
        {
            var item = myListView.model.get(i)

            switch(item.fieldType)
            {
            case WorkoutProgram.SEGMENT_TYPE:
                mainProgItem.numSegs = item.dataValue;
                break;
            case WorkoutProgram.TIME_TYPE:
                mainProgItem.workTime = item.dataValue;
                break;
            }
        }
        mainProgItem.dataItemChanged()
    }

    function populateCustomModel() {
        customListModel.clear();
        var i;
        var item;
        for(i = 0; i < root.model.count; i++) {
            item = root.model.get(i);

            if(item.fieldType === WorkoutProgram.TIME_TYPE || item.fieldType === WorkoutProgram.SEGMENT_TYPE) {
                customListModel.append(item);
            }
        }
    }

    function calculateMaxSegmentsFromTime() {
        root.maxSegs = Math.max(2, Math.min(30, root.workoutTime))

        customListModel.setProperty(root.segmentIndex, "maxValue", root.maxSegs)
    }

    anchors.fill: parent

    state: (workoutProgram.programIndex == WorkoutProgram.TREAD_CUSTOM_SPEED_PROG || workoutProgram.programIndex == WorkoutProgram.CUSTOM_PACE_PROG) ? "Profile2" : "Profile1"

    TextLabel {
        id: customProfileInstructLabel
        anchors.top: graphEditor.bottom
        anchors.topMargin: 0.05 * main.screenHeight
        anchors.right: parent.right
        anchors.left: graphEditor.left
        horizontalAlignment: Text.AlignHCenter
        wrapMode: Text.WordWrap
        text: qsTr("TOUCH ANY SEGMENT TO ADJUST") + application.emptyString
        font.pixelSize: 12 * main.vScaleFactor
        smooth: true
    }

    ListModel {
        id: customListModel
    }

    ListView {
        id: myListView

        property real initialWidth: 300 * main.hScaleFactor
        property real initialHeight: 75 * main.vScaleFactor

        anchors.right: graphEditor.right
        anchors.rightMargin: 200 * main.hScaleFactor
        anchors.top: parent.top
        anchors.topMargin: 0.75 * main.screenHeight
        anchors.bottom: parent.bottom

        width: initialWidth * 2 + spacing + 20 * main.hScaleFactor

        model: customListModel
        delegate: myDelegate
        spacing: 40 * main.vScaleFactor
        orientation: ListView.Horizontal
        interactive: false
        clip: true

        Component {
            id: myDelegate

            DualBox {
                id: dataElement

                clickToExpand: true

                property bool isCI: ListView.isCurrentItem
                onIsCIChanged: {
                    if(isCI) {
                        expand();
                        clickToExpand = false;
                    } else {
                        collapse();
                        clickToExpand = true;
                    }
                }

                onClicked: {
                    SetupJS.validateParam(myListView.currentIndex)
                    myListView.currentIndex = index;

                    buzzer.buttonPress()
                }

                Component.onCompleted: {
//                    myListView.positionViewAtIndex(2,ListView.End);
                    populateElement(model.fieldType);
                }

                function populateElement(fieldtype) {
                    switch(fieldtype) {
                    case WorkoutProgram.TIME_TYPE:
                        collapsedLoader.sourceComponent = topcomp_time;
                        extensionLoader.sourceComponent = bottomcomp_slider;
                        break;
                    case WorkoutProgram.SEGMENT_TYPE:
                        collapsedLoader.sourceComponent = topcomp;
                        extensionLoader.sourceComponent = bottomcomp_segment
                        root.segmentIndex = index;
                        break;
                    }
                }

                Component { // Top Component - Basic
                    id: topcomp

                    Item {
                        width: myListView.initialWidth
                        height: myListView.initialHeight

                        TextLabel {
                            id: itemName
                            text: qsTranslate("WorkoutSetup", SetupJS.getItemLabel(model)) + SetupJS.getItemAdditionalLabel(model) + application.emptyString

                            width: 0.7 * myListView.initialWidth
                            font.pixelSize: root.paramTextSize
                            anchors.left: parent.left
                            anchors.leftMargin: 20 * main.hScaleFactor
                            anchors.verticalCenter: parent.verticalCenter
                        }

                        NumberLabel {
                            id: itemValue

                            text: model.dataValue
                            font.pixelSize: root.numTextSize
                            anchors.right: parent.right
                            anchors.rightMargin: 10 * main.hScaleFactor
                            anchors.verticalCenter: parent.verticalCenter
                            color: main.colorFontLight
                        }
                    }
                }

                Component { // Top Component - Time
                    id: topcomp_time

                    Item {
                        width: myListView.initialWidth
                        height: myListView.initialHeight

                        TextLabel {
                            id: itemName
                            text: qsTranslate("WorkoutSetup", SetupJS.getItemLabel(model)) + SetupJS.getItemAdditionalLabel(model) + application.emptyString
                            font.pixelSize: root.paramTextSize
                            anchors.left: parent.left
                            anchors.leftMargin: 10 * main.hScaleFactor
                            anchors.verticalCenter: parent.verticalCenter
                            wrapMode: Text.Wrap
                            width: 0.9 * (parent.width - itemValue.width)
                        }

                        NumberLabel {
                            id: itemValue
                            text: Format.formatTimeString(root.workoutTime*60)
                            font.pixelSize: root.numTextSize
                            anchors.right: parent.right
                            anchors.rightMargin: 10 * main.hScaleFactor
                            anchors.verticalCenter: parent.verticalCenter
                            width: 70 * main.hScaleFactor
                            horizontalAlignment: Text.AlignRight
                        }
                    }
                }

                Component { // Bottom component - Slider
                    id: bottomcomp_slider

                    Item { // slider control box seen after expanding most simple items (age, weight, time, etc.)
                        id: details

                        height: myListView.initialHeight
                        width: myListView.initialWidth
                        anchors.top: topcomp_time.bottom
                        anchors.horizontalCenter: parent.horizontalCenter
                        anchors.verticalCenterOffset: 10 * main.vScaleFactor

                        property int value: sliderObject.value

                        SliderControl {
                            id: sliderObject
                            repeat: true
                            valueProxy: model.dataValue
                            Component.onCompleted: {
                                value = model.dataValue;
                            }
                            onValueChanged: {
                                SetupJS.sliderObjectValueChanged(model, value, valueProxyChange);

                                root.model.setProperty(model.selectedIndex, "dataValue", value)
                                if (model.fieldType === WorkoutProgram.TIME_TYPE) {
                                    root.workoutTime = value
                                    mainProgItem.workTime = value
                                    calculateMaxSegmentsFromTime();
                                }
                            }
                            showValue: false
                            maxValue: model.maxValue
                            onMaxValueChanged: {
                                if (model.fieldType === WorkoutProgram.SPEED_TYPE || model.fieldType === WorkoutProgram.INCLINE_TYPE) {
                                    sliderObject.valueChanged();
                                }
                            }
                            minValue: model.minValue
                            value: model.dataValue
                            precision: model.precision
                            stepValue: {
                                if (model.precision === 0) {
                                    return 1;
                                } else if (model.precision === 1) {
                                    return 0.1;
                                }
                            }

                            anchors.top: parent.top
                            anchors.topMargin: 10 * main.vScaleFactor
                            anchors.horizontalCenter: parent.horizontalCenter
                            width: 0.8 * myListView.initialWidth
                            height: 0.6* parent.height
                        }
                    }
                }

                Component { // Bottom component - Segment
                    id: bottomcomp_segment

                    ColumnLayout {

                        height: 97 * main.vScaleFactor
                        width: myListView.initialWidth

                        Item {
                            id: segmentDetails
                            width: myListView.initialWidth
                            height: calculatedSegTimeValue1.height
                            anchors.topMargin: 20 * main.vScaleFactor
                            LayoutMirroring.enabled: main.rightToLeft
                            LayoutMirroring.childrenInherit: true

                            TextLabel {
                                id: calculatedSegTime1
                                text: qsTr("SEGMENT TIME:") + application.emptyString
                                font.pixelSize: 13 * main.vScaleFactor
                                anchors.left: parent.left
                                anchors.leftMargin: 10 * main.hScaleFactor
                                anchors.bottom: parent.bottom
                            }

                            NumberLabel {
                                id: calculatedSegTimeValue1
                                text: Format.formatTimeString(mainProgItem.segTime) + application.emptyString
                                font.pixelSize: 18 * main.vScaleFactor
                                horizontalAlignment: Text.AlignRight
                                anchors.right: parent.right
                                anchors.rightMargin: 30 * main.hScaleFactor
                            }
                        }

                        Item { // slider control box seen after expanding most simple items (age, weight, time, etc.)
                            id: details_segment
                            height: 60 * main.vScaleFactor
                            width: myListView.initialWidth
                            anchors.top: segmentDetails.bottom
                            anchors.topMargin: 10 * main.vScaleFactor
                            anchors.horizontalCenter: parent.horizontalCenter

                            property int value: sliderObject3.value

                            SliderControl {
                                id: sliderObject3
                                onValueChanged: {
                                    SetupJS.sliderObject3ValueChanged(model, value);
                                    root.model.setProperty(model.selectedIndex, "dataValue", value)
                                    mainProgItem.setNumSegments(value)
                                }
                                showValue: false

                                minValue: model.minValue
                                maxValue: root.maxSegs
                                value: model.dataValue
                                precision: model.precision
                                stepValue: {
                                    if (model.precision === 0) {
                                        return 1;
                                    } else if (model.precision === 1) {
                                        return 0.1;
                                    }
                                }

                                anchors.horizontalCenter: parent.horizontalCenter
                                width: 0.75 * parent.width
                                height: 0.7 * parent.height

                                Connections {
                                    target: root
                                    onMaxSegsChanged: {
                                        sliderObject3.maxValue= root.maxSegs
                                        if (sliderObject3.value > sliderObject3.maxValue)
                                            sliderObject3.value = sliderObject3.maxValue
                                    }
                                }
                            }
                        }

                        Component.onCompleted: root.maxSegs = model.maxValue
                    }
                }
            }
        }
    }

    ListView {
        id: graphEditor

//        width: 0.55*main.screenWidth
        height: 0.55*main.screenHeight
        anchors.left: parent.left
        anchors.leftMargin:  0.10*main.screenWidth
        anchors.right: parent.right
        anchors.rightMargin: 0.05*main.screenWidth
        anchors.top: parent.top
        anchors.topMargin: 0.1*main.screenHeight
        orientation: ListView.Horizontal

        GraphView {
            id: profileWidget

            onEditSegmentChanged: {
                root.currentIndex = editSegment
                root.state = activeModel==1 ? "Profile1" : "Profile2"
            }
            onEditModelChanged: {
                root.currentIndex = editSegment
                root.state = activeModel==1 ? "Profile1" : "Profile2"
            }

            anchors {
                left: parent.left
                leftMargin: 10
                right: parent.right
                rightMargin: 10
                top: parent.top
                topMargin: 0
                bottom: parent.bottom
                bottomMargin: 0
            }

            model1: root.model1
            model2: root.model2
            columnWidth: 50 * main.hScaleFactor
            minBarHeight: 10 * main.vScaleFactor
            segmentFill: 100
            activeSegment: root.currentIndex
            active: false
            editable: true
            hasNegativeValues: machineinfo.treadmillInclineMinPercentGrade < 0.0
            numNegativeValues: hasNegativeValues ? machineinfo.inclineTable.indexOf(0.0) : 0
            z: profileSlider1.z -1
        }

        // Profile editor slider
        ProfileSliderControl {
            id: profileSlider1
            property int index: root.currentIndex
            property variant model: root.state == "Profile1" ? root.model1 : root.model2
            property int xOffset: root.state == "Profile1" ? 0 : 1.05*profileWidget.columnWidth

            x: profileWidget.x + profileWidget.currentSegmentX + xOffset
            z: 2

            width: profileWidget.columnWidth
            anchors.top: profileWidget.top
            anchors.topMargin: profileWidget.height - profileWidget.topYPosition
            anchors.bottom: profileWidget.bottom
            anchors.bottomMargin: profileWidget.yPosition

            Connections {
                target: profileSlider1.model
                onDataChanged: {
                    // reset saved flag whenever the user edits a profile segment
                    mainProgItem.saveHasHappened = false

                    var segValue = profileSlider1.model.getProperty(profileSlider1.index, "segmentLevel")
                    if (segValue)
                        profileSlider1.value = segValue
                }
            }

            onModelChanged: indexChanged(root.currentIndex)
            onIndexChanged: {
                if(model) {
                    var segValue = model.getProperty(index, "segmentLevel")
                    if(segValue)
                        value  = segValue
                }
            }

            onValueChanged: model.setSegmentLevel(root.currentIndex, value);
            showValue: false
            maxValue: model.maxLevel
            minValue: 1
            buttonOffsetX: 0
            buttonMargin: 0//-5
            orientation: Qt.Vertical
            baseOffset: profileWidget.yPosition
            baseIndex: minValue + profileWidget.numNegativeValues
            buttonAreaScale: 1.0
            dragAreaMargin: -30
        }

        // segment number displayed under each bar
        ListView {
            id: segNumberList

            height: 42 * main.vScaleFactor

            width:parent.width
            anchors {
                right: parent.right
                rightMargin: 0
                left: profileWidget.left
                top: profileWidget.bottom
                topMargin: 5 * main.vScaleFactor
            }
            interactive: false //root.editable
            orientation: ListView.Horizontal

            highlightRangeMode: ListView.ApplyRange
            highlightFollowsCurrentItem: true
            currentIndex: root.currentIndex
            preferredHighlightBegin: (width/2) - 60
            preferredHighlightEnd: (width/2) + 60
//            flickableDirection: Flickable.HorizontalFlick
//            boundsBehavior: Flickable.StopAtBounds
//            maximumFlickVelocity: 2*height

            clip: true
            model: profileWidget.model1.count
            z: 3
            delegate: NumberLabel {
                width: profileWidget.columnWidth*2.5
                text: index + 1
                color: main.colorFontLight
                horizontalAlignment: Text.AlignHCenter
                font.pixelSize: 14 * main.vScaleFactor
            }
        }
    }
}
