import QtQuick 2.12
import WorkoutManager 1.0
import Components 1.0
import "../string_format.js" as Format
import ".."

Item {
    id: root

    width: 0.68*main.width
    height: 0.4*main.height

    property string profile1Title
    property string profile2Title
    property int setupAge
    property int setupWeight
    property int totalTime
    property int numSegments
    property int segmentTime
    property int profile1Max
    property int profile2Max
    property int textWidth: 0.5*width
    property int textLineHeight: 17 * main.vScaleFactor
    property int fontSize: 18 * main.hScaleFactor
    property int fontSizeNum: 18 * main.hScaleFactor
    property int distanceFromTop: 0.6 * main.height
    property int distanceFromLeft: 230 * main.hScaleFactor + textWidth
    property int textMargin: 32 * main.hScaleFactor
    property int rectMargin: 17 * main.hScaleFactor
    property int lineHeight: 2 * main.hScaleFactor
    property int lineMargin: 0.20*textLineHeight
    property string profile1MaxComputed
    property string profile2MaxComputed

    function computeValueOfMax1(value) {
        var incline = workoutProgram.inclineTable[value - 1] / 10.0;
        return incline.toFixed(1);
    }

    function computeValueOfMax2(value) {
        var speed = workoutProgram.speedTable[value - 1] / 10.0;
        return speed.toFixed(1);
    }

    Rectangle {
        id: summaryBackground

        x: root.distanceFromLeft
        y: root.distanceFromTop
        width: 107 * main.vScaleFactor
        height: 15*root.textLineHeight
        color: Qt.rgba(0,0,0,0.5)
        border.color: main.colorUIBorder
    }

    NumberLabel {
        id: step3AgeText
        anchors.top: summaryBackground.top
        anchors.topMargin: textLineHeight
        anchors.horizontalCenter: summaryBackground.horizontalCenter
        text: setupAge
        font.pixelSize: fontSizeNum
        smooth: true
        color: main.colorFontLight
        z: 2
    }

    TextLabel {
        id: step3AgePromptText
        anchors.right: summaryBackground.left
        anchors.rightMargin: textMargin
        anchors.verticalCenter: step3AgeText.verticalCenter
        text: qsTr("AGE") + application.emptyString
        font.pixelSize: fontSize
        smooth: true
        z: 2
    }

    Rectangle {
        id: segementTextDivider1
        anchors.right: summaryBackground.right
        anchors.rightMargin: rectMargin
        anchors.top: step3AgeText.bottom
        anchors.topMargin: lineMargin
        width: root.textWidth+summaryBackground.width
        height: lineHeight
        color: main.colorUIBorder
    }

    NumberLabel {
        id: step3WeightText
        anchors.top: summaryBackground.top
        anchors.topMargin: textLineHeight*3
        anchors.horizontalCenter: summaryBackground.horizontalCenter
        text: setupWeight
        font.pixelSize: fontSizeNum
        smooth: true
        color: main.colorFontLight
        z: 2
    }

    TextLabel {
        id: step3WeightPromptText
        anchors.right: summaryBackground.left
        anchors.rightMargin: textMargin
        anchors.verticalCenter: step3WeightText.verticalCenter
        text: qsTr("WEIGHT") + application.emptyString
        font.pixelSize: fontSize
        smooth: true
        z: 2
    }

    Rectangle {
        id: segementTextDivider2
        anchors.right: summaryBackground.right
        anchors.rightMargin: rectMargin
        anchors.top: step3WeightText.bottom
        anchors.topMargin: lineMargin
        width: root.textWidth+summaryBackground.width
        height: lineHeight
        color: main.colorUIBorder
    }

    NumberLabel {
        id: step3TimeText
        anchors.top: summaryBackground.top
        anchors.topMargin: textLineHeight*5
        anchors.horizontalCenter: summaryBackground.horizontalCenter
        text: Format.formatTimeString(totalTime * 60);
        font.pixelSize: fontSizeNum
        smooth: true
        color: main.colorFontLight
        z: 2
    }

    TextLabel {
        id: step3TimePromptText
        anchors.right: summaryBackground.left
        anchors.rightMargin: textMargin
        anchors.verticalCenter: step3TimeText.verticalCenter
        text: qsTr("WORKOUT TIME") + application.emptyString
        font.pixelSize: fontSize
        smooth: true
        z: 2
    }

    NumberLabel {
        id: step3NumSegsText
        anchors.top: summaryBackground.top
        anchors.topMargin: textLineHeight*7
        anchors.horizontalCenter: summaryBackground.horizontalCenter
        text: numSegments
        font.pixelSize: fontSizeNum
        smooth: true
        color: main.colorFontLight
        z: 2
    }

    TextLabel {
        id: step3NumSegsPromptText
        anchors.right: summaryBackground.left
        anchors.rightMargin: textMargin
        anchors.verticalCenter: step3NumSegsText.verticalCenter
        text: qsTr("SEGMENTS") + application.emptyString
        font.pixelSize: fontSize
        smooth: true
        z: 2
    }

    NumberLabel {
        id: step3SegTimeText
        anchors.top: summaryBackground.top
        anchors.topMargin: textLineHeight*9
        anchors.horizontalCenter: summaryBackground.horizontalCenter
        text: Format.formatTimeString(segmentTime);
        font.pixelSize: fontSizeNum
        smooth: true
        color: main.colorFontLight
        z: 2
    }

    TextLabel {
        id: step3SegTimePromptText
        anchors.right: summaryBackground.left
        anchors.rightMargin: textMargin
        anchors.verticalCenter: step3SegTimeText.verticalCenter
        text: qsTr("SEGMENT TIME") + application.emptyString
        font.pixelSize: fontSize
        smooth: true
        z: 2
    }

    Rectangle {
        id: segementTextDivider3
        anchors.right: summaryBackground.right
        anchors.rightMargin: rectMargin
        anchors.top: step3SegTimePromptText.bottom
        anchors.topMargin: lineMargin
        width: root.textWidth+summaryBackground.width
        height: lineHeight
        color: main.colorUIBorder
    }

    NumberLabel {
        id: profile2MaxText
        anchors.top: summaryBackground.top
        anchors.topMargin: textLineHeight*11
        anchors.horizontalCenter: summaryBackground.horizontalCenter
        text: {
            if (main.isTreadmill || main.isStepmill) {
                var maxVal = computeValueOfMax2(profile2Max)
                return options.metricUnits ? Globals.mileToKm(maxVal).toFixed(1) : maxVal
            } else {
                return profile2Max
            }
        }
        font.pixelSize: fontSizeNum
        smooth: true
        color: main.colorFontLight
        z: 2
    }

    TextLabel {
        id: profile2MaxLabel
        anchors.right: summaryBackground.left
        anchors.rightMargin: textMargin
        anchors.verticalCenter: profile2MaxText.verticalCenter
        text: qsTr("MAX") + " " + root.profile2Title + application.emptyString
        font.pixelSize: fontSize
        smooth: true
        z: 2
    }

    Rectangle {
        id: segementTextDivider4
        anchors.right: summaryBackground.right
        anchors.rightMargin: rectMargin
        anchors.top: profile2MaxLabel.bottom
        anchors.topMargin: lineMargin
        width: root.textWidth+summaryBackground.width
        height: lineHeight
        color: main.colorUIBorder
    }

    NumberLabel {
        id: profile1MaxText
        anchors.top: summaryBackground.top
        anchors.topMargin: textLineHeight*13
        anchors.horizontalCenter: summaryBackground.horizontalCenter
        text: (main.isTreadmill || main.isStepmill)  ? computeValueOfMax1(profile1Max) : profile1Max
        font.pixelSize: fontSizeNum
        smooth: true
        color: main.colorFontLight
        z: 2
    }

    TextLabel {
        id: profile1MaxLabel
        anchors.right: summaryBackground.left
        anchors.rightMargin: textMargin
        anchors.verticalCenter: profile1MaxText.verticalCenter
        text: qsTr("MAX") + " " + root.profile1Title + application.emptyString
        font.pixelSize: fontSize
        smooth: true
        z: 2
    }
}
