import QtQuick 2.12
import Components 1.0
import "workout_menus.js" as TouchMenus
import WorkoutManager 1.0
import StorageMgr 1.0
import ".."

StandardPage {
    id: root
    title: qsTr("WORKOUT FINDER")  + application.emptyString
    
    no_bottom_margin: true

    property variant menu
    property string current_filter: "ALL"

    property bool isChangeWorkout: main.isNewWorkoutSelected

    signal workoutSelected(variant item, variant menu)
    signal menuSelected(variant menu)

    function selectWorkoutMenu() {
        console.debug("WorkoutFinder: Select menu for " + machineinfo.productTypeString)
        selectMenu("ALL")
    }

    function selectMenu(filter) {
        current_filter = filter
        var Menus = TouchMenus;

        switch(machineinfo.productType) {
            case WorkoutProgram.TREADMILL:
                changeMenu( main.isAlpineRunner ? Menus.menu_alpine_get_workouts(filter,isChangeWorkout) : Menus.menu_tread_get_workouts(filter,isChangeWorkout) );
                break;
            case WorkoutProgram.ELLIPTICAL:
                changeMenu( main.isCSA ? Menus.menu_csa_get_workouts(filter,isChangeWorkout) : Menus.menu_elliptical_get_workouts(filter,isChangeWorkout) );
                break;
            case WorkoutProgram.BIKE:
                changeMenu( Menus.menu_bike_get_workouts(filter,isChangeWorkout) );
                break;
            case WorkoutProgram.LATERAL_TRAINER:
                changeMenu( Menus.menu_lateral_get_workouts(filter,isChangeWorkout) );
                break;
            case WorkoutProgram.STEPMILL:
                changeMenu( Menus.menu_stepmill_get_workouts(filter,isChangeWorkout) );
                break;
            default:
                //changeMenu( Menus.menu_tread_get_workouts(filter,isChangeWorkout) );
        }
    }

    function changeMenu(menu) {
        contentItem.changeMenu(menu);
    }

    function reset() {
        contentItem.workoutFilter.resetDelegates();
        selectMenu("ALL");
        contentItem.workoutFilter.reloadModel();
    }

    Connections {
        target: contentItem
        ignoreUnknownSignals: true
        onWorkoutSelected: root.workoutSelected(item, menu)
        onMenuSelected: root.menuSelected(menu)
    }

    Text {
        id: welcomeBackLabel
        visible: userData.userName !== ""
        anchors {
            left: root.left
            leftMargin: page_spacing
            top: parent.top
            topMargin: 100 * main.vScaleFactor
        }
        width: 230 * main.hScaleFactor
        horizontalAlignment: Text.AlignHCenter
        color: main.colorFontGreen
        text: qsTr("Welcome Back ") + userData.userName + "!" + application.emptyString
        font.pixelSize: 18 * main.vScaleFactor
        font.bold: false
        wrapMode: Text.WordWrap
    }

    Component {
        id: workout_finder_content

        Item {
            id: workout_finder
            width: 845 * main.hScaleFactor
            height: parent.height
            anchors {
                horizontalCenter: parent.horizontalCenter
                top: parent.top
            }

            property variant menu
            property int currentIndex
            property bool isAllWorkouts: true
            property alias workoutFilter: workoutFilters

            onMenuChanged: workout_menu.resetDelegates()

            signal workoutSelected(variant item, variant menu)
            signal menuSelected(variant menu)

            function changeMenu(menu) {
                workout_menu_model.changeWorkoutFinderMenu(menu);
            }

            MenuModel {
                id: workout_menu_model
                onChangeMenuCallback: {
                    if(!options.saveWorkoutEnabled) {
                        var removeIndex = findItemIndex(function(item) { return item.program === "SAVED_WORKOUTS" })

                        if(removeIndex >= 0) {
                            remove(removeIndex)
                        }
                    }
                }
                onMenu_currentChanged: workout_finder.menu = menu_current
                Component.onCompleted: changeMenu(workout_finder.menu)
                onMenuSelected: workout_finder.menuSelected(workout_menu_model.menu_current)
                onOptionSelected: {
                    if(item.program) {
                        workoutSelected(item, workout_menu_model.menu_current)
                    }
                }
            }

            ListView {
                id: workoutFilters
                width: 280 * main.hScaleFactor
                anchors {
                    left: parent.left
                    leftMargin: page_spacing
                    top: parent.top
                    bottom: parent.bottom
                }
                spacing: 30 * main.hScaleFactor

                boundsBehavior: Flickable.StopAtBounds
                maximumFlickVelocity: 2 * height

                function resetDelegates() {
                    currentIndex = 0;
                    workoutFilters.positionViewAtBeginning();
                }

                function reloadModel() {
                    filterModel.clear();
//                    filterModel.append({"filter": "ALL","imgSrc": "WF/ArrowRightWhiteIcon","label":  "ALL WORKOUTS"});

                    if (!isChangeWorkout && eGym.enabled && eGym.connected){
                        filterModel.append({"filter": "EGYM","imgSrc": "WF/WF_Button_Saved_Workouts","label":  qsTr("EGYM WORKOUTS")});
                    }
                    if (main.isAlpineRunner || main.isStepmill) {
                        filterModel.append({"filter": "MONUMENTS", "imgSrc": "WF/WF_Button_Monuments", "label":  qsTr("MONUMENTS WORKOUTS")});
                    }

                    if (machineinfo.productType === WorkoutProgram.ELLIPTICAL || machineinfo.productTypeString === "Lateral Trainer") {
                       filterModel.append({"filter": "CARDIO360", "imgSrc": "WF/WF_Button_Cardio_360", "label":  qsTr("CARDIO360 WORKOUT")});
                    }

//                    if (main.isCSA || machineinfo.modelString === "TS1000") {
//                        filterModel.append({"filter": "ADJUSTABLESTRIDE", "imgSrc": "WF/WF_Button_Stride", "label":  qsTr("ADJUSTABLE STRIDE\n       WORKOUTS")});
//                    }

                    if (main.isTreadmill || main.isStepmill) {
                        filterModel.append({"filter": "HILL","imgSrc": "WF/WF_Button_Incline","label":  qsTr("HILL WORKOUTS")});
                    } else {
                        filterModel.append({"filter": "HILL","imgSrc": "WF/WF_Button_Incline","label":  qsTr("RESISTANCE WORKOUTS")});
                    }

                    if (!main.isAlpineRunner && !main.isStepmill) {
                        if (main.isTreadmill ) {
                            filterModel.append({"filter": "SPEED","imgSrc": "WF/WF_Button_Speed_Workout","label":  qsTr("SPEED WORKOUTS")});
                        } else {
                            filterModel.append({"filter": "SPEED","imgSrc": "WF/WF_Button_Speed_Workout","label":  qsTr("PACE WORKOUTS")});
                        }
                    }

                    if (!main.isLateralTrainer) {
                        if (main.isTreadmill) {
                            filterModel.append({"filter": "DISTANCE","imgSrc": "WF/WF_Button_Distance_Workouts","label":  qsTr("DISTANCE WORKOUTS")});
                        } else {
                            filterModel.append({"filter": "DISTANCE","imgSrc": "WF/WF_Button_Distance_Workouts","label":  qsTr("PERFORMANCE WORKOUTS")});
                        }
                    }

                    filterModel.append({"filter": "HRC","imgSrc": "WF/WF_Button_HRC","label":  qsTr("HRC WORKOUTS")});
//                    if (!isChangeWorkout)
//                        filterModel.append({"filter": "FITNESSTEST","imgSrc": "WF/WF_Button_Fitness_Test","label":  "FITNESS TESTS"});
//                    if (!isChangeWorkout){
//                        filterModel.append({"filter": "CUSTOM","imgSrc": "WF/WF_Button_Custom","label":  "CUSTOM WORKOUTS"});
//                    }
                    if (!isChangeWorkout && options.saveWorkoutEnabled){
                        filterModel.append({"filter": "SAVED","imgSrc": "WF/WF_Button_Saved_Workouts","label":  qsTr("SAVED WORKOUTS")});
                    }
                }

                ListModel {
                    id: filterModel
                }

                Component {
                    id: filterDelegate

                    StandardButton {
                        buttonText:  qsTr(model.label)
                        onClicked:   selected ? root.selectMenu("ALL") : root.selectMenu(model.filter)
                        selected:    current_filter === model.filter
                        width: 250 * main.hScaleFactor
                        height: 79 * main.vScaleFactor

                        icon.sourceName: model.imgSrc
                    }
                }

                delegate: filterDelegate
                model: filterModel
                footer: Component {
                    Item {
                        width: workoutFilters.width
                        height: 20 * main.vScaleFactor
                    }
                }
            }

            ListView {
                id: workout_menu
                width: 434 * main.hScaleFactor
                anchors {
                    top: parent.top
                    right: parent.right
                    rightMargin: page_spacing
                    bottom: parent.bottom
                }

                spacing: 12 * main.vScaleFactor
                currentIndex: -1;
                boundsBehavior: Flickable.StopAtBounds
                maximumFlickVelocity: 2 * height

                property int time: 300

                function resetDelegates() {
                    currentIndex = -1;
                    workout_menu.positionViewAtBeginning();
                }

                function workoutSelected(idx) {
                    workout_finder.workoutSelected(model.get(idx), model.menu_current);
                    if(eGym.enabled) {
                        var name = model.get(idx).label
                        var program = model.get(idx).program
                        if(current_filter === "EGYM" && !main.eGymCardioTest) {
                            eGym.selectWorkout(idx)
                        } else if (program.includes("eGym")) {
                            var eIdx = program.slice(20,21)
                            eGym.selectWorkout(eIdx)
                        } else {
                            eGym.selectedExerciseName = name.replace(/\ /g,'_')
                        }
                        console.log("EGym Selected Exercise Name " + eGym.selectedExerciseName)
                    }
                }

                footer: Component {
                    Item {
                        width: workout_menu.width
                        height: 150 * main.vScaleFactor
                    }
                }

                Component {
                    id: menuDelegate

                    WorkoutFinderOption {
                        id: wfo
                        initialWidth: _initialWidth
                        initialHeight: _initialHeight

                        isClickable: _isClickable
                        opacity: isClickable ? 1 : 0.5
                        title: _title
                        description: _description
                        icon_source: _icon_source
                        expanded: false
                        expandTime: _expandTime
                        onStateChanged: {
                            enabled = false
                            enabled = true

                            if(state === "expanded") {
                                _view.currentIndex = _index
                                buzzer.buttonPress()
                            }
                        }
                        onButtonClicked: {
                            if(_hasProgram) { // don't launch if program not implemented
                                _view.workoutSelected(_index)
                            }
                        }
                        onTitleChanged: expanded = false
                    }
                }

                displaced: Transition {
                    NumberAnimation {
                        properties: "x,y"
                        duration: workout_menu.time
                    }
                }
                delegate: Component {
                    Loader {
                        width: item.width
                        height: item.height
                        asynchronous: true

                        property real     _initialWidth:  ListView.view.width
                        property real     _initialHeight: 86 * main.vScaleFactor
                        property string   _title: qsTr(model.label) + application.emptyString
                        property string   _description: model ? qsTranslate("Menu", model.desc ? model.desc : "") + application.emptyString : ""
                        property string   _icon_source: (model.icon !== undefined) ? model.icon : ""
                        property int      _expandTime: ListView.view.time
                        property int      _index: index
                        property bool     _hasProgram: (model !== undefined) && (model.program !== undefined)
                        property ListView _view: ListView.view
                        property bool     isCI: ListView.isCurrentItem
                        property bool     _isClickable: model.program !== "SAVED_WORKOUTS"

                        onIsCIChanged: {
                            if(!isCI) {
                                item.collapse()
                            }
                        }

                        sourceComponent: menuDelegate
                    }
                }
                model: workout_menu_model
            }
        }
    }

    StorageMgr {
        id: storage
    }

    content: workout_finder_content
}
