import QtQuick 2.12
import QtQuick.Layouts 1.12
import Components 1.0
import ".."

ExpandableBox {
    id: wfo
    spacing: 0
    expandTime: 500

    property real initialWidth: 0
    property real initialHeight: 0
    property string title: ""
    property string description: ""
    property string icon_source: ""
    property bool isSaveWorkout: false

    clickToExpand: false
    
    signal buttonClicked()

    onClicked: buttonClicked()

    Component {
        id: topcomp

        RowLayout {
            width: initialWidth
            height: initialHeight + getTitleHeight(title)

            function getTitleHeight(title) {
                var len = title.length
                if (len > 21) {
                    return 10 * main.vScaleFactor
                }
                return 0
            }

            function updateIndicatorState(state) {
                wfo_indicator.state = state;
            }

            ScalableImage {
                id: wfo_indicator
                Layout.preferredWidth: 75 * main.hScaleFactor
                Layout.preferredHeight: 75 * main.vScaleFactor
                Layout.topMargin: 12 * main.vScaleFactor
                Layout.bottomMargin: 12 * main.vScaleFactor
                Layout.leftMargin: 12 * main.hScaleFactor
                Layout.alignment: Qt.AlignVCenter | Qt.AlignHCenter
                fillMode: Image.Pad
                sourceName: "Bullet_Triangle_Gray";
                /**
                 * Simply have two states: collapsed and expanded
                 * Use the appropriate height for each state
                 */
                states: [
                    State {
                        name: ""

                        PropertyChanges {
                            target: wfo_indicator
                            rotation: 0
                        }
                    },
                    State {
                        name: "expanded"

                        PropertyChanges {
                            target: wfo_indicator
                            rotation: 90
                        }
                    }
                ]
                /**
                 * Animations when changing states
                 */
                transitions: [
                    Transition {
                        ParallelAnimation {
                            PropertyAnimation {
                                target: wfo_indicator
                                property: "rotation"
                                duration: wfo.expandTime
                            }
                        }
                    }
                ]

                MouseArea {
                    anchors.fill: parent
                    onClicked: wfo.toggle()
                    Rectangle {
                        anchors.fill: parent
                        color: main.colorGenericStimulusArea
                        opacity: 0.3
                        visible: main.showStimulusArea
                    }
                }
            }

            ColumnLayout {
                Layout.fillWidth: true
                Layout.fillHeight: true
                Layout.topMargin: 12 * main.vScaleFactor
                Layout.bottomMargin: 12 * main.vScaleFactor
                Layout.alignment: Qt.AlignVCenter | Qt.AlignHCenter
                spacing: 12 * main.vScaleFactor

                ScalableImage {
                    id: wfo_icon
                    Layout.fillHeight: true
                    Layout.preferredHeight: 27 * main.vScaleFactor
                    Layout.maximumHeight: 27 * main.vScaleFactor
                    Layout.alignment: Qt.AlignTop | Qt.AlignHCenter
                    fillMode: Image.PreserveAspectFit
                    sourceName: icon_source
                }

                TextLabel {
                    id: wfo_title
                    wrapMode: Text.Wrap
                    text: title
                    horizontalAlignment: Text.AlignHCenter
                    verticalAlignment: Text.AlignTop
                    font.pixelSize: 15 * main.vScaleFactor
                    font.capitalization: Font.AllUppercase
                    Layout.fillWidth: true
                    Layout.fillHeight: true
                    Layout.alignment: Qt.AlignTop | Qt.AlignHCenter
                }
            }

            Rectangle {
                id: go_btn
                Layout.preferredWidth: (isSaveWorkout ? 76 : 60 )* main.hScaleFactor
                Layout.preferredHeight: 60 * main.vScaleFactor
                Layout.topMargin: 5 * main.vScaleFactor
                Layout.bottomMargin: 19 * main.vScaleFactor
                Layout.rightMargin: 12 * main.hScaleFactor
                Layout.alignment: Qt.AlignVCenter | Qt.AlignHCenter
                color: main.colorButtonBackground
                radius: main.defaultRadius
                border.color: isSaveWorkout ? main.colorUIBorder : "transparent"
                border.width: main.widthBorder

                ScalableImage {
                    visible: !isSaveWorkout
                    sourceName: "HomeScreen/QuickStartIcon"
                    anchors {
                        horizontalCenter: go_btn.horizontalCenter
                        verticalCenter: go_btn.verticalCenter
                    }
                }

                TextLabel {
                    visible: isSaveWorkout
                    text: "SAVE"
                    font.pixelSize: 16 * main.vScaleFactor
                    color: main.colorFontGreen
                    horizontalAlignment: Text.AlignHCenter
                    verticalAlignment: Text.AlignVCenter
                    anchors {
                        horizontalCenter: go_btn.horizontalCenter
                        verticalCenter: go_btn.verticalCenter
                    }
                }
            }
        }
    }

    Component {
        id: bottomcomp

        Item {
            width: initialWidth
            height: description.implicitHeight + 24*main.vScaleFactor
            Text {
                id: description
                anchors {
                    fill: parent
                    topMargin: 6
                    leftMargin: 24 * main.hScaleFactor
                    rightMargin: 24 * main.hScaleFactor
                    bottomMargin: 18 * main.vScaleFactor
                }
                wrapMode: Text.Wrap
                font.bold: false
                color: main.colorFontLight
                text: wfo.description
                font.pixelSize: 16 * main.vScaleFactor
            }
        }
    }

    collapsedLoader.sourceComponent: topcomp
    extensionLoader.sourceComponent: bottomcomp
    onStateChanged: {if (collapsedLoader.item) collapsedLoader.item.updateIndicatorState(state);}
}
