/* @file workout_menus.js
    @brief Definitions of the workout program menu for all machine types.
*
*   Each menu_xxx array definition is a menu.  Each entry may be
*    either another menu by defining the "nextmenu" property, or
*   a workout program by definining the "program" property to the corresponding xml filename.
*/

// ====== Top Level Menu Descriptions ======
var desc_menu_weightloss  = QT_TRANSLATE_NOOP("Menu", "If weight loss is your primary goal, this button will quickly get you to an ideal workout.")
var desc_menu_hrc         = QT_TRANSLATE_NOOP("Menu", "Let your heart guide you to your workout goal while the machine does all the adjusting for you.")
var desc_menu_performance = QT_TRANSLATE_NOOP("Menu", "Challenging workout options for those that are already cardio-fit." )
var desc_menu_custom      = QT_TRANSLATE_NOOP("Menu", "Allows you to set up your own interval workout or create a totally custom workout." )

// ====== Common Workout Descriptions ======
var desc_prog_manual    = QT_TRANSLATE_NOOP("Menu", "Set up your own workout to a TIME or DISTANCE limit.")
var desc_prog_distance  = QT_TRANSLATE_NOOP("Menu", "Choose any one of our 4 common distance workouts - 5k, 10k, 2 mile or 4 mile.")
var desc_prog_stride_5k = QT_TRANSLATE_NOOP("Menu", "Challenge yourself to a 5k distance workout! Choose your intensity level and the workout ends when you reach 5 kilometers (3.1 miles).")
var saved_workouts_desc = QT_TRANSLATE_NOOP("Menu", "Access to previously saved workouts.")

var prog_saved = { label: QT_TRANSLATE_NOOP("Menu", "SAVED WORKOUTS"), desc: saved_workouts_desc, program: "SAVED_WORKOUTS", icon: "WF/WF_Button_Saved_Workouts" }

// ====== Monument Workout Descriptions ======
var desc_mount_everest     = QT_TRANSLATE_NOOP("Menu", "This climb to 29,029 feet (8,848 meters) will put you on top of the world. Determine your own climbing pace by choosing INCLINE and SPEED. The Alpine Runner will automatically end the workout when the goal is reached.")
var desc_eiffel_tower      = QT_TRANSLATE_NOOP("Menu", "One of the most photographed objects in the world, climbing this Paris landmark ends at 1,063 feet (324 meters). Determine your own climbing pace by choosing INCLINE and SPEED. The Alpine Runner will automatically end the workout when the goal is reached.")
var desc_gateway_arch      = QT_TRANSLATE_NOOP("Menu", "Dominating the St. Louis, Missouri skyline, this gleaming monument will take you 630 feet (192 meters) to the top. Determine your own climbing pace by choosing INCLINE and SPEED. The Alpine Runner will automatically end the workout when the goal is reached.")
var desc_mount_kilimanjaro = QT_TRANSLATE_NOOP("Menu", "Climb the tallest mountain in Africa at 19,341 feet (5,895 meters). Determine your own climbing pace by choosing INCLINE and SPEED. The Alpine Runner will automatically end the workout when the goal is reached.")
var desc_mount_rainier     = QT_TRANSLATE_NOOP("Menu", "This majestic mountain in the state of Washington tops out at 14,409 feet (4392 meters). Determine your own climbing pace by choosing INCLINE and SPEED. The Alpine Runner will automatically end the workout when the goal is reached.")

// empty placeholder to allow positioning of items in a short menu
var prog_shim = { shim: true}

// ====== Treadmill Menus ======
// ----- Treadmill Fitness Tests -----
var tread_fitness_test_gerkin_desc   = QT_TRANSLATE_NOOP("Menu", "A fitness test used to estimate your VO2 max.  The test increases speed and incline gradually every minute and ends at the point where your heart rate reaches 85% of the maximum for your age.")
var tread_fitness_test_army_desc     = QT_TRANSLATE_NOOP("Menu", "A 2-mile running test measured against age and gender calculations.")
var tread_fitness_test_navy_desc     = QT_TRANSLATE_NOOP("Menu", "A 1.5-mile running test measured against age and gender calculations.")
var tread_fitness_test_airforce_desc = QT_TRANSLATE_NOOP("Menu", "A 1.5-mile running test measured against age and gender calculations.")
var tread_fitness_test_marines_desc  = QT_TRANSLATE_NOOP("Menu", "A 3-mile running test measured against age and gender calculations.")

var prog_tread_fitness_test_gerkin   = { label: QT_TRANSLATE_NOOP("Menu", "Gerkin Fitness Test"),    program: "Program_Files/Tread_Gerkin_Test.xml",                     desc: tread_fitness_test_gerkin_desc,   icon: "WF/WF_Button_Fitness_Test" }
var prog_tread_fitness_test_army     = { label: QT_TRANSLATE_NOOP("Menu", "Army Fitness Test"),      program: "Program_Files/Tread_Army_Military_Fitness_Test.xml",      desc: tread_fitness_test_army_desc,     icon: "WF/WF_Button_Army_Fitness" }
var prog_tread_fitness_test_navy     = { label: QT_TRANSLATE_NOOP("Menu", "Navy Fitness Test"),      program: "Program_Files/Tread_Navy_Military_Fitness_Test.xml",      desc: tread_fitness_test_navy_desc,     icon: "WF/WF_Button_Navy_Fitness" }
var prog_tread_fitness_test_airforce = { label: QT_TRANSLATE_NOOP("Menu", "Air Force Fitness Test"), program: "Program_Files/Tread_Air_Force_Military_Fitness_Test.xml", desc: tread_fitness_test_airforce_desc, icon: "WF/WF_Button_AirForce_Fitness" }
var prog_tread_fitness_test_marines  = { label: QT_TRANSLATE_NOOP("Menu", "Marines Fitness Test"),   program: "Program_Files/Tread_Marines_Military_Fitness_Test.xml",   desc: tread_fitness_test_marines_desc,  icon: "WF/WF_Button_Marines_Fitness" }

// ------ Treadmill Speed Workouts ------
var tread_walkrun_desc         = QT_TRANSLATE_NOOP("Menu", "Zero-incline WALKING or RUNNING intervals are in varying 1-minute segments.  Incline changes are permanent; speed changes affect the current 1-minute segment only.")
var tread_speed_ramp_desc      = QT_TRANSLATE_NOOP("Menu", "Speed increases to a maximum at the mid-point of the workout, then decreases to the finish.  Speed changes affect the current segment only.  Incline changes are permanent.")
var tread_speed_intervals_desc = QT_TRANSLATE_NOOP("Menu", "Zero-incline walking or running intervals are in 1-minute segments.  Incline changes are permanent; speed changes affect the current 1-minute segment only.")

var prog_tread_walkrun         = {label: QT_TRANSLATE_NOOP("Menu", "Walk & Run Intervals"), program: "Program_Files/Tread_Walk_And_Run.xml",    desc: tread_walkrun_desc,         icon: "WF/WF_Button_Walk_Run" }
var prog_tread_speed_ramp      = {label: QT_TRANSLATE_NOOP("Menu", "Speed Ramp"),           program: "Program_Files/Tread_Speed_Ramp.xml",      desc: tread_speed_ramp_desc,      icon: "WF/WF_Button_Speed_Ramp" }
var prog_tread_speed_intervals = {label: QT_TRANSLATE_NOOP("Menu", "Speed Intervals"),      program: "Program_Files/Tread_Speed_Intervals.xml", desc: tread_speed_intervals_desc, icon: "WF/WF_Button_Speed_Intervals" }

var desc_menu_tread_speed_workouts = QT_TRANSLATE_NOOP("Menu", "These workout choices use speed adjustments to add variety to your cardio fitness routine.");

// ------ Treadmill Weightloss ------
var tread_calorie_goal_desc     = QT_TRANSLATE_NOOP("Menu", "This workout allows you to choose a SPEED, INCLINE and WORKOUT TIME combination that will achieve your calorie goal.")
var tread_weightloss_hills_desc = QT_TRANSLATE_NOOP("Menu", "2-minute WALKING interval segments with incline alternating between hills and a nearly flat landscape. SPEED changes are permanent; INCLINE changes affect the current 2-minute segment only.")
var tread_glute_buster_desc     = QT_TRANSLATE_NOOP("Menu", "A changing incline profile focuses on intense glute muscle use.")
var tread_leg_shaper_desc       = QT_TRANSLATE_NOOP("Menu", "A workout with speed changes to work the leg muscles with added intensity.")
var tread_weightloss_hrc_desc   = QT_TRANSLATE_NOOP("Menu", "Based on age, this is a heart rate controlled workout at 65% of your maximum heart rate. This creates efficient fat burning without overtraining. The treadmill begins in MANUAL control - gradually increase your work level until heart rate is within 10 bpm of the target. At this point, the treadmill takes over to control speed and incline to maintain your HR within a few beats of the target.")

var prog_tread_calorie_goal     = {label: QT_TRANSLATE_NOOP("Menu", "Calorie Goal"),      desc: tread_calorie_goal_desc,     program: "Program_Files/Tread_Calorie_Goal.xml",      icon: "WF/WF_Button_Calorie_Goal" }
var prog_tread_weightloss_hills = {label: QT_TRANSLATE_NOOP("Menu", "Weight Loss Hills"), desc: tread_weightloss_hills_desc, program: "Program_Files/Tread_Weight_Loss_Hills.xml", icon: "WF/WF_Button_Weight_Loss_Hills" }
var prog_tread_glute_buster     = {label: QT_TRANSLATE_NOOP("Menu", "Glute Buster"),      desc: tread_glute_buster_desc,     program: "Program_Files/Tread_Glute_Buster.xml",      icon: "WF/WF_Button_Glute_Buster" }
var prog_tread_leg_shaper       = {label: QT_TRANSLATE_NOOP("Menu", "Leg Shaper"),        desc: tread_leg_shaper_desc,       program: "Program_Files/Tread_Leg_Shaper.xml",        icon: "WF/WF_Button_Leg_Shaper" }
var prog_tread_weightloss_hrc   = {label: QT_TRANSLATE_NOOP("Menu", "Weight Loss HRC"),   desc: tread_weightloss_hrc_desc,   program: "Program_Files/Tread_HRC_Weight_Loss.xml",   icon: "WF/WF_Button_HRC" }

// ----- Tread Hill Workouts -----
var tread_rolling_hills_desc  = QT_TRANSLATE_NOOP("Menu", "A series of gradual increasing and decreasing INCLINE changes that simulate rolling hills. Adjust your LEVEL at any time during the workout to increase or decrease intensity of the hills.")
var tread_single_hill_desc    = QT_TRANSLATE_NOOP("Menu", "INCLINE increases to a maximum at the midpoint of the workout, then decreases to the finish.  INCLINE changes affect the current segment only.  Speed changes are permanent.")
var tread_hill_intervals_desc = QT_TRANSLATE_NOOP("Menu", "Hill Intervals are in 2-minute segments with the speed remaining constant.  Speed changes are permanent; incline changes affect the current 2-minute segment only.")
var tread_random_hills_desc   = QT_TRANSLATE_NOOP("Menu", "A random profile of INCLINE changes that simulate random hills.  Adjust your LEVEL at any time during the workout to increase or decrease intensity of the hills.")

var prog_tread_rolling_hills  = {label: QT_TRANSLATE_NOOP("Menu", "Rolling Hills"),  desc: tread_rolling_hills_desc,  icon: "WF/WF_Button_Rolling_Hills", program: "Program_Files/Tread_Rolling_Hills.xml" }
var prog_tread_single_hill    = {label: QT_TRANSLATE_NOOP("Menu", "Single Hill"),    desc: tread_single_hill_desc,    icon: "WF/WF_Button_One_Big_Hill",  program: "Program_Files/Tread_Single_Hill.xml" }
var prog_tread_hill_intervals = {label: QT_TRANSLATE_NOOP("Menu", "Hill Intervals"), desc: tread_hill_intervals_desc, icon: "WF/WF_Button_Hill_Intervals",     program: "Program_Files/Tread_Hill_Intervals.xml" }
var prog_tread_random_hills   = {label: QT_TRANSLATE_NOOP("Menu", "Random Hills"),   desc: tread_random_hills_desc,   icon: "WF/WF_Button_Random_Hills",  program: "Program_Files/Tread_Random_Hills.xml" }

// ----- Tread PERFORMANCE Programs -----
var desc_prog_tread_cardio_challenge = QT_TRANSLATE_NOOP("Menu", "Speed and incline increase to a maximum at the mid-point of the workout, then decrease to the finish.  Incline and speed changes affect the current segment only.")

var prog_tread_cardio_challange = {label: QT_TRANSLATE_NOOP("Menu", "Cardio Challenge"), desc: desc_prog_tread_cardio_challenge, program: "Program_Files/Tread_Cardio_Challenge.xml", icon: "WF/WF_Button_Cardio_Challenge" }

var prog_tread_distance       = {label: QT_TRANSLATE_NOOP("Menu", "Distance"),        desc: desc_prog_distance, program: "Program_Files/Tread_Distance.xml", icon: "WF/WF_Button_Distance_Workouts" }
var prog_tread_distance_2mile = {label: QT_TRANSLATE_NOOP("Menu", "Distance 2 Mile"), desc: desc_prog_distance, program: "Program_Files/Tread_Distance2mi.xml", icon: "WF/WF_Button_2Mile_Distance" }
var prog_tread_distance_4mile = {label: QT_TRANSLATE_NOOP("Menu", "Distance 4 Mile"), desc: desc_prog_distance, program: "Program_Files/Tread_Distance4mi.xml", icon: "WF/WF_Button_4Mile_Distance" }
var prog_tread_distance_5k    = {label: QT_TRANSLATE_NOOP("Menu", "Distance 5K"),     desc: desc_prog_distance, program: "Program_Files/Tread_Distance5k.xml", icon: "WF/WF_Button_5k_Distance" }
var prog_tread_distance_10k   = {label: QT_TRANSLATE_NOOP("Menu", "Distance 10K"),    desc: desc_prog_distance, program: "Program_Files/Tread_Distance10k.xml", icon: "WF/WF_Button_10k_Distance" }

// ----- Tread CUSTOM Programs
var desc_prog_tread_custom_speed = QT_TRANSLATE_NOOP("Menu", "Set up your own speed intervals.  Up to 30 easy to adjust segments allow you to customize any speed profile.")
var desc_prog_tread_custom_hill  = QT_TRANSLATE_NOOP("Menu", "Build your own HILL profile using up to 30 segments.  User friendly setup screens allow you to create any hill or incline profile.")
var desc_prog_tread_custom_ultra = QT_TRANSLATE_NOOP("Menu", "Do you have trouble finding a workout that fits your specific needs?  Try setting up your own!  This completely customizable workout setup allows both SPEED and INCLINE control of up to 30 segments.")
var desc_prog_tread_custom_hrc   = QT_TRANSLATE_NOOP("Menu", "Set up your own heart rate intervals.  Specify WORK and REST targets and let the machine make all the adjustments." + "  " + "The workout begins in MANUAL control - gradually increase WORKLOAD until heart rate is within 10 bpm of the target. At this point, the machine takes control of WORKLOAD to maintain your HR within a few beats of your target.")

var prog_tread_custom_speed = {label: QT_TRANSLATE_NOOP("Menu", "Custom Speed"),         desc: desc_prog_tread_custom_speed, program: "Program_Files/Tread_Custom_Speed.xml",         icon: "WF/WF_Button_Custom" }
var prog_tread_custom_hill  = {label: QT_TRANSLATE_NOOP("Menu", "Custom Hill"),          desc: desc_prog_tread_custom_hill,  program: "Program_Files/Tread_Custom_Hills.xml",         icon: "WF/WF_Button_Custom" }
var prog_tread_custom_ultra = {label: QT_TRANSLATE_NOOP("Menu", "Custom Ultra"),         desc: desc_prog_tread_custom_ultra, program: "Program_Files/Tread_Custom_Ultra.xml",         icon: "WF/WF_Button_Custom" }
var prog_tread_custom_hrc   = {label: QT_TRANSLATE_NOOP("Menu", "Custom HRC Intervals"), desc: desc_prog_tread_custom_hrc,   program: "Program_Files/Tread_Custom_HRC_Intervals.xml", icon: "WF/WF_Button_HRC" }

var prog_tread_manual = {label: QT_TRANSLATE_NOOP("Menu", "Manual Workout"),   desc: desc_prog_manual, program: "Program_Files/Tread_Manual.xml", icon: "WF/WF_Button_Manual" }

// ----- Alpine Runner
var prog_mount_everest       = {label: QT_TRANSLATE_NOOP("Menu", "Mount Everest"), desc: desc_mount_everest,      program: "Program_Files/Mt_Everest.xml",          icon: "WF/WF_Button_Everest" }
var prog_eiffel_tower        = {label: QT_TRANSLATE_NOOP("Menu", "Eiffel Tower"),  desc: desc_eiffel_tower,       program: "Program_Files/Eiffel_Tower.xml",        icon: "WF/WF_Button_Eiffel" }
var prog_gateway_arch        = {label: QT_TRANSLATE_NOOP("Menu", "Gateway Arch"),  desc: desc_gateway_arch,       program: "Program_Files/Gateway_Arch.xml",        icon: "WF/WF_Button_Monuments" }
var prog_alpine_random_hills = {label: QT_TRANSLATE_NOOP("Menu", "Random Hills"),  desc: tread_random_hills_desc, program: "Program_Files/Alpine_Random_Hills.xml", icon: "WF/WF_Button_Random_Hills" }
var prog_mount_kilimanjaro   = {label: QT_TRANSLATE_NOOP("Menu", "Kilimanjaro"),   desc: desc_mount_kilimanjaro,  program: "Program_Files/Mt_Kilimanjaro.xml",      icon: "WF/WF_Button_Kilimanjaro" }
var prog_mount_rainier       = {label: QT_TRANSLATE_NOOP("Menu", "Mount Rainier"), desc: desc_mount_rainier,      program: "Program_Files/Mt_Rainier.xml",          icon: "WF/WF_Button_Rainier" }

// ----- Tread HRC Programs -----
var desc_prog_tread_hrc_target     = QT_TRANSLATE_NOOP("Menu", "Choose your target heart rate." + "  " + "The workout begins in MANUAL control - gradually increase work level until heart rate is within 10 bpm of the target. At this point, the machine takes control of work level to maintain your HR within a few beats of your target.")
var desc_prog_tread_hrc_weightloss = QT_TRANSLATE_NOOP("Menu", "Based on age, this is a heart rate controlled workout at 65% of your maximum heart rate.  This creates efficient fat burning without overtraining." + "  " + "The workout begins in MANUAL control - gradually increase work level until heart rate is within 10 bpm of the target. At this point, the machine takes control of work level to maintain your HR within a few beats of your target.")
var desc_prog_tread_hrc_aerobic    = QT_TRANSLATE_NOOP("Menu", "Based on age, this is a heart rate controlled workout at 80% of your maximum heart rate. This keeps you in the optimum aerobic training range to improve cardio fitness." + "  " + "The workout begins in MANUAL control - gradually increase work level until heart rate is within 10 bpm of the target. At this point, the machine takes control of work level to maintain your HR within a few beats of your target.")
var desc_prog_tread_hrc_distance   = QT_TRANSLATE_NOOP("Menu", "4 popular fixed distance workouts that puts the machine in control of maintaining your target heart rate." + "  " + "The workout begins in MANUAL control - gradually increase work level until heart rate is within 10 bpm of the target. At this point, the machine takes control of work level to maintain your HR within a few beats of your target.")

var desc_prog_tread_hrc_distance_5k    = QT_TRANSLATE_NOOP("Menu", "4 popular fixed distance workouts that puts the machine in control of maintaining your target heart rate." + "  " + "The workout begins in MANUAL control - gradually increase work level until heart rate is within 10 bpm of the target. At this point, the machine takes control of work level to maintain your HR within a few beats of your target.")
var desc_prog_tread_hrc_distance_10k   = QT_TRANSLATE_NOOP("Menu", "4 popular fixed distance workouts that puts the machine in control of maintaining your target heart rate." + "  " + "The workout begins in MANUAL control - gradually increase work level until heart rate is within 10 bpm of the target. At this point, the machine takes control of work level to maintain your HR within a few beats of your target.")
var desc_prog_tread_hrc_distance_2mile = QT_TRANSLATE_NOOP("Menu", "4 popular fixed distance workouts that puts the machine in control of maintaining your target heart rate." + "  " + "The workout begins in MANUAL control - gradually increase work level until heart rate is within 10 bpm of the target. At this point, the machine takes control of work level to maintain your HR within a few beats of your target.")
var desc_prog_tread_hrc_distance_4mile = QT_TRANSLATE_NOOP("Menu", "4 popular fixed distance workouts that puts the machine in control of maintaining your target heart rate." + "  " + "The workout begins in MANUAL control - gradually increase work level until heart rate is within 10 bpm of the target. At this point, the machine takes control of work level to maintain your HR within a few beats of your target.")

var desc_prog_tread_hrc_intervals = QT_TRANSLATE_NOOP("Menu", "Intervals of WORK and REST determined by target heart rate." + "  " + "The workout begins in MANUAL control - gradually increase work level until heart rate is within 10 bpm of the target. At this point, the machine takes control of work level to maintain your HR within a few beats of your target." + "  " + "The rest segment will reduce to 65% intensity of work segment.")
var desc_prog_tread_hrc_intervals_optimal = QT_TRANSLATE_NOOP("Menu", "Intervals of WORK and REST determined by target heart rate." + "  " + "The workout begins in MANUAL control - gradually increase work level until heart rate is within 10 bpm of the target. At this point, the machine takes control of work level to maintain your HR within a few beats of your target." + "  " + "The rest segment will reduce to 65% intensity of work segment.")

var prog_tread_hrc_target     = {label: QT_TRANSLATE_NOOP("Menu", "HRC Target"),      desc: desc_prog_tread_hrc_target,     program: "Program_Files/Tread_HRC_Target.xml",      icon: "WF/WF_Button_HRC" }
var prog_tread_hrc_weightloss = {label: QT_TRANSLATE_NOOP("Menu", "HRC Weight Loss"), desc: desc_prog_tread_hrc_weightloss, program: "Program_Files/Tread_HRC_Weight_Loss.xml", icon: "WF/WF_Button_HRC" }
var prog_tread_hrc_aerobic    = {label: QT_TRANSLATE_NOOP("Menu", "HRC Aerobic"),     desc: desc_prog_tread_hrc_aerobic,    program: "Program_Files/Tread_HRC_Aerobic.xml",     icon: "WF/WF_Button_HRC" }
var prog_tread_hrc_distance   = {label: QT_TRANSLATE_NOOP("Menu", "HRC Distance"),    desc: desc_prog_tread_hrc_distance,   program: "Program_Files/Tread_HRC_Distance.xml",    icon: "WF/WF_Button_HRC" }

var prog_tread_hrc_5k    = {label: QT_TRANSLATE_NOOP("Menu", "HRC 5k"),     desc: desc_prog_tread_hrc_distance_5k,    program: "Program_Files/Tread_HRC_Distance5k.xml",   icon: "WF/WF_Button_HRC" }
var prog_tread_hrc_10k   = {label: QT_TRANSLATE_NOOP("Menu", "HRC 10k"),    desc: desc_prog_tread_hrc_distance_10k,   program: "Program_Files/Tread_HRC_Distance10k.xml",  icon: "WF/WF_Button_HRC" }
var prog_tread_hrc_2mile = {label: QT_TRANSLATE_NOOP("Menu", "HRC 2 Mile"), desc: desc_prog_tread_hrc_distance_2mile, program: "Program_Files/Tread_HRC_Distance2mi.xml",  icon: "WF/WF_Button_HRC" }
var prog_tread_hrc_4mile = {label: QT_TRANSLATE_NOOP("Menu", "HRC 4 Mile"), desc: desc_prog_tread_hrc_distance_4mile, program: "Program_Files/Tread_HRC_Distance4mi.xml",  icon: "WF/WF_Button_HRC" }

var prog_tread_hrc_intervals = { label: QT_TRANSLATE_NOOP("Menu", "HRC Intervals"), desc: desc_prog_tread_hrc_intervals, program: "Program_Files/Tread_HRC_Intervals.xml", icon: "WF/WF_Button_HRC" }
var prog_tread_hrc_intervals_optimal = { label: QT_TRANSLATE_NOOP("Menu", "Optimal HRC Intervals"), desc: desc_prog_tread_hrc_intervals_optimal, program: "Program_Files/Tread_HRC_Intervals_Optimal.xml", icon: "WF/WF_Button_HRC" }

// ===== HILL Programs =====
var hill_workouts_desc  = QT_TRANSLATE_NOOP("Menu", "A choice of workouts that use WORKLOAD changes to simulate hills. A great way to change up your cardio workout.")

var hill_intervals_desc = QT_TRANSLATE_NOOP("Menu", "Hill intervals are in 2-minute segments with increased WORKLOAD to simulate hills.")
var single_hill_desc    = QT_TRANSLATE_NOOP("Menu", "WORKLOAD increases to a maximum at the midpoint of the workout, then decreases to the finish to simulate one big hill.")
var quad_burner_desc    = QT_TRANSLATE_NOOP("Menu", "This intense resistance workout is designed to burn calories!")
var rolling_hills_desc  = QT_TRANSLATE_NOOP("Menu", "A series of increasing and decreasing WORKLOAD changes that simulate rolling hills. Adjust your LEVEL at any time during the workout to increase or decrease intensity of the hills.")
var random_hills_desc   = QT_TRANSLATE_NOOP("Menu", "A random profile of WORKLOAD changes that simulate random hills.  Adjust your LEVEL at any time during the workout to increase or decrease intensity of the hills.")

var prog_hill_intervals = { label: QT_TRANSLATE_NOOP("Menu", "Hill Intervals"), desc: hill_intervals_desc, program: "Program_Files/Hill_Intervals.xml", icon: "WF/WF_Button_Hill_Intervals" }
var prog_single_hill    = { label: QT_TRANSLATE_NOOP("Menu", "Single Hill"),    desc: single_hill_desc,    program: "Program_Files/Single_Hill.xml",    icon: "WF/WF_Button_One_Big_Hill" }
var prog_rolling_hills  = { label: QT_TRANSLATE_NOOP("Menu", "Rolling Hills"),  desc: rolling_hills_desc,  program: "Program_Files/Rolling_Hills.xml",  icon: "WF/WF_Button_Rolling_Hills" }
var prog_random_hills   = { label: QT_TRANSLATE_NOOP("Menu", "Random Hills"),   desc: random_hills_desc,   program: "Program_Files/Random_Hills.xml",   icon: "WF/WF_Button_Random_Hills" }
var prog_quad_burner    = { label: QT_TRANSLATE_NOOP("Menu", "Quad Burner"),    desc: quad_burner_desc,    program: "Program_Files/Quad_Burner.xml",    icon: "WF/WF_Button_Leg_Shaper" }

// ===== PACE Programs =====
var pace_ramp_desc      = QT_TRANSLATE_NOOP("Menu", "This workout suggests PACE (RPM) increases to a maximum at the mid-point of the workout, then decreases to the finish. The PACE SETTER shows your target pace throughout the workout.")
var pace_intervals_desc = QT_TRANSLATE_NOOP("Menu", "This workout suggests PACE (RPM) intervals in 1-minute segments. The PACE SETTER shows the target pace along with your actual pace (RPM) throughout the workout.")
var walkrun_desc        = QT_TRANSLATE_NOOP("Menu", "This workout uses PACE SETTER to suggest walking then running intervals in 1-minute segments.  WORKLOAD can be adjusted throughout the workout.")

var prog_pace_ramp         = { label: QT_TRANSLATE_NOOP("Menu", "Pace Ramp"),          desc:pace_ramp_desc,       program: "Program_Files/Pace_Ramp.xml",      icon: "WF/WF_Button_Speed_Ramp" }
var prog_pace_intervals    = { label: QT_TRANSLATE_NOOP("Menu", "Pace Intervals"),     desc: pace_intervals_desc, program: "Program_Files/Pace_Intervals.xml", icon: "WF/WF_Button_Speed_Intervals" }
var prog_walkrun_intervals = { label: QT_TRANSLATE_NOOP("Menu", "Walk&Run Intervals"), desc:walkrun_desc,         program: "Program_Files/Walk_And_Run.xml",   icon: "WF/WF_Button_Walk_Run" }

// ====== PERFORMANCE Programs =======
var cardio_challenge_desc      = QT_TRANSLATE_NOOP("Menu", "WORKLOAD and suggested PACE (RPM) increase to a maximum at the mid-point of the workout, then decrease to the finish.")
var pace_workouts_desc         = QT_TRANSLATE_NOOP("Menu", "A choice of workouts that use PACE (RPM) suggestions to add variety to your cardio session.")
//var upper_body_desc          = QT_TRANSLATE_NOOP("Menu", "An intense 10 minute workout that focuses on the upper body.")
var fitness_test_desc          = QT_TRANSLATE_NOOP("Menu", "A fitness test used to estimate your VO2 max.")
var desc_prog_stride_intervals = QT_TRANSLATE_NOOP("Menu", "Set your own alternating WORK and REST stride length segments. Choose from short stepping to long striding motion, or anything in between. Intervals are 1 minute.")

var prog_cardio_challange = { label: QT_TRANSLATE_NOOP("Menu", "Cardio Challenge"), desc: cardio_challenge_desc,      program: "Program_Files/Cardio_Challenge.xml",  icon: "WF/WF_Button_Cardio_Challenge" }
//var prog_upper_body     = { label: QT_TRANSLATE_NOOP("Menu", "Upper Body"),       desc: upper_body_desc, icon: "WF/WF_Button_Performance" }
var prog_fitness_test     = { label: QT_TRANSLATE_NOOP("Menu", "Fitness Test"),     desc: fitness_test_desc,          program: "Program_Files/Fitness_Test.xml",      icon: "WF/WF_Button_Fitness_Test" }
var prog_stride_intervals = { label: QT_TRANSLATE_NOOP("Menu", "Stride Intervals"), desc: desc_prog_stride_intervals, program: "Program_Files/Stride_Intervals.xml",  icon: "WF/WF_Button_Walk_Run" }
var prog_distance_2mile   = { label: QT_TRANSLATE_NOOP("Menu", "Distance 2 Mile"),  desc: desc_prog_distance,         program: "Program_Files/Distance2mi.xml",       icon: "WF/WF_Button_2Mile_Distance" }
var prog_distance_4mile   = { label: QT_TRANSLATE_NOOP("Menu", "Distance 4 Mile"),  desc: desc_prog_distance,         program: "Program_Files/Distance4mi.xml",       icon: "WF/WF_Button_4Mile_Distance" }
var prog_distance_5k      = { label: QT_TRANSLATE_NOOP("Menu", "Distance 5K"),      desc: desc_prog_distance,         program: "Program_Files/Distance5k.xml",        icon: "WF/WF_Button_5k_Distance" }
var prog_distance_10k     = { label: QT_TRANSLATE_NOOP("Menu", "Distance 10K"),     desc: desc_prog_distance,         program: "Program_Files/Distance10k.xml",       icon: "WF/WF_Button_10k_Distance" }
var prog_stride_5k        = { label: QT_TRANSLATE_NOOP("Menu", "Distance 5K"),      desc: desc_prog_stride_5k,        program: "Program_Files/Stride_Distance5k.xml", icon: "WF/WF_Button_5k_Distance" }

// ====== HRC Programs ======
var hrc_target_desc     = QT_TRANSLATE_NOOP("Menu", "Choose your target heart rate." + "  " + "The workout begins in MANUAL control - gradually increase WORKLOAD until heart rate is within 10 bpm of the target. At this point, the machine takes control of WORKLOAD to maintain your HR within a few beats of your target.")
var hrc_weightloss_desc = QT_TRANSLATE_NOOP("Menu", "Based on age, this is a heart rate controlled workout at 65% of your maximum heart rate.  This creates efficient fat burning without overtraining." + "  " + "The workout begins in MANUAL control - gradually increase WORKLOAD until heart rate is within 10 bpm of the target. At this point, the machine takes control of WORKLOAD to maintain your HR within a few beats of your target.")
var hrc_aerobic_desc    = QT_TRANSLATE_NOOP("Menu", "Based on age, this is a heart rate controlled workout at 80% of your maximum heart rate. This keeps you in the optimum aerobic training range to improve cardio fitness." + "  " + "The workout begins in MANUAL control - gradually increase WORKLOAD until heart rate is within 10 bpm of the target. At this point, the machine takes control of WORKLOAD to maintain your HR within a few beats of your target.")
var hrc_distance_desc   = QT_TRANSLATE_NOOP("Menu","4 popular fixed distance workouts that puts the machine in control of maintaining your target heart rate." + "  " + "The workout begins in MANUAL control - gradually increase WORKLOAD until heart rate is within 10 bpm of the target. At this point, the machine takes control of WORKLOAD to maintain your HR within a few beats of your target.")

var hrc_distance_5k_desc    = QT_TRANSLATE_NOOP("Menu","4 popular fixed distance workouts that puts the machine in control of maintaining your target heart rate." + "  " + "The workout begins in MANUAL control - gradually increase WORKLOAD until heart rate is within 10 bpm of the target. At this point, the machine takes control of WORKLOAD to maintain your HR within a few beats of your target.")
var hrc_distance_10k_desc   = QT_TRANSLATE_NOOP("Menu","4 popular fixed distance workouts that puts the machine in control of maintaining your target heart rate." + "  " + "The workout begins in MANUAL control - gradually increase WORKLOAD until heart rate is within 10 bpm of the target. At this point, the machine takes control of WORKLOAD to maintain your HR within a few beats of your target.")
var hrc_distance_2mile_desc = QT_TRANSLATE_NOOP("Menu","4 popular fixed distance workouts that puts the machine in control of maintaining your target heart rate." + "  " + "The workout begins in MANUAL control - gradually increase WORKLOAD until heart rate is within 10 bpm of the target. At this point, the machine takes control of WORKLOAD to maintain your HR within a few beats of your target.")
var hrc_distance_4mile_desc = QT_TRANSLATE_NOOP("Menu","4 popular fixed distance workouts that puts the machine in control of maintaining your target heart rate." + "  " + "The workout begins in MANUAL control - gradually increase WORKLOAD until heart rate is within 10 bpm of the target. At this point, the machine takes control of WORKLOAD to maintain your HR within a few beats of your target.")

var hrc_intervals_desc = QT_TRANSLATE_NOOP("Menu","Intervals of WORK and REST determined by target heart rate." + "  " + "The workout begins in MANUAL control - gradually increase WORKLOAD until heart rate is within 10 bpm of the target. At this point, the machine takes control of WORKLOAD to maintain your HR within a few beats of your target." + "  " + "The rest segment will reduce to 65% intensity of work segment.")
var hrc_intervals_optimal_desc = QT_TRANSLATE_NOOP("Menu","Intervals of WORK and REST determined by target heart rate." + "  " + "The workout begins in MANUAL control - gradually increase WORKLOAD until heart rate is within 10 bpm of the target. At this point, the machine takes control of WORKLOAD to maintain your HR within a few beats of your target." + "  " + "The rest segment will reduce to 65% intensity of work segment.")

var prog_hrc_target     = { label: QT_TRANSLATE_NOOP("Menu", "HRC Target"),      desc: hrc_target_desc,     program: "Program_Files/HRC_Target.xml",      icon: "WF/WF_Button_HRC" }
var prog_hrc_weightloss = { label: QT_TRANSLATE_NOOP("Menu", "HRC Weight Loss"), desc: hrc_weightloss_desc, program: "Program_Files/HRC_Weight_Loss.xml", icon: "WF/WF_Button_HRC" }
var prog_hrc_aerobic    = { label: QT_TRANSLATE_NOOP("Menu", "HRC Aerobic"),     desc: hrc_aerobic_desc,    program: "Program_Files/HRC_Aerobic.xml",     icon: "WF/WF_Button_HRC" }
var prog_hrc_distance   = { label: QT_TRANSLATE_NOOP("Menu", "HRC Distance"),    desc: hrc_distance_desc,   program: "Program_Files/HRC_Distance.xml",    icon: "WF/WF_Button_HRC" }

var prog_hrc_5k    = {label: QT_TRANSLATE_NOOP("Menu", "HRC 5k"),     desc: hrc_distance_5k_desc,    program: "Program_Files/HRC_Distance5k.xml",  icon: "WF/WF_Button_HRC" }
var prog_hrc_10k   = {label: QT_TRANSLATE_NOOP("Menu", "HRC 10k"),    desc: hrc_distance_10k_desc,   program: "Program_Files/HRC_Distance10k.xml", icon: "WF/WF_Button_HRC" }
var prog_hrc_2mile = {label: QT_TRANSLATE_NOOP("Menu", "HRC 2 Mile"), desc: hrc_distance_2mile_desc, program: "Program_Files/HRC_Distance2mi.xml", icon: "WF/WF_Button_HRC" }
var prog_hrc_4mile = {label: QT_TRANSLATE_NOOP("Menu", "HRC 4 Mile"), desc: hrc_distance_4mile_desc, program: "Program_Files/HRC_Distance4mi.xml", icon: "WF/WF_Button_HRC" }

var prog_hrc_intervals = { label: QT_TRANSLATE_NOOP("Menu", "HRC Intervals"), desc: hrc_intervals_desc, program: "Program_Files/HRC_Intervals.xml", icon: "WF/WF_Button_HRC" }
var prog_hrc_intervals_optimal = { label: QT_TRANSLATE_NOOP("Menu", "Optimal HRC Intervals"), desc: hrc_intervals_optimal_desc, program: "Program_Files/HRC_Intervals_Optimal.xml", icon: "WF/WF_Button_HRC" }

// ====== WEIGHTLOSS Programs ======

var calgoal_desc     = QT_TRANSLATE_NOOP("Menu", "This workout allows you to choose the number of calories you wish to burn within a specified workout time.  The WORKLOAD will adjust automatically to attain this goal.")
var glutebuster_desc = QT_TRANSLATE_NOOP("Menu", "Changing workload focuses on intense glute muscle use.  For an added challenge, reverse the stride motion periodically.")
var legshaper_desc   = QT_TRANSLATE_NOOP("Menu", "A workout that suggests pace changes to work the leg muscles with added intensity.  Reverse stride occasionally for an added challenge.")

var prog_calorie_goal = {label: QT_TRANSLATE_NOOP("Menu", "Calorie Goal"), desc: calgoal_desc,     program: "Program_Files/Calorie_Goal.xml", icon: "WF/WF_Button_Calorie_Goal" }
var prog_glutebuster  = {label: QT_TRANSLATE_NOOP("Menu", "Glute Buster"), desc: glutebuster_desc, program: "Program_Files/Glute_Buster.xml", icon: "WF/WF_Button_Glute_Buster" }
var prog_legshaper    = {label: QT_TRANSLATE_NOOP("Menu", "Leg Shaper"),   desc: legshaper_desc,   program: "Program_Files/Leg_Shaper.xml",   icon: "WF/WF_Button_Leg_Shaper" }

// ====== Cardio360 Programs ======
var cardio360menu_desc   = QT_TRANSLATE_NOOP("Menu", "Cardio360 coaches you through a dynamic total-body workout!")
var cardio360_desc       = QT_TRANSLATE_NOOP("Menu", "If you're looking for variety to make your cardio workout fly, try this random cycle of Cardio360 exercises for a great total-body workout.")
var cardio360QS_desc     = QT_TRANSLATE_NOOP("Menu", "Get right into a pre-set 20-minute workout designed to shape and tone every major muscle group.")
var cardio360arms_desc   = QT_TRANSLATE_NOOP("Menu", "Challenge your upper body and core to this 10-minute, 3-motion program, following along at your own intensity.")
var cardio360legs_desc   = QT_TRANSLATE_NOOP("Menu", "Tighten and tone your legs and glutes, changing resistance on the fly.")
var cardio360custom_desc = QT_TRANSLATE_NOOP("Menu", "Modify and maximize your workout to its fullest potential.  Cardio360 Custom lets you build a personalized routine, choosing your favorite Cardio360 motions and lengths of time.  Then save your set-up for next time.")
var cardio360demo_desc   = QT_TRANSLATE_NOOP("Menu", "Try out Cardio360 and experience the dynamic total-body workout you have been looking for!")

var prog_cardio360QS     = {label: QT_TRANSLATE_NOOP("Menu", "Cardio360 QUICKSTART"),   desc: cardio360QS_desc,     program: "Program_Files/Cardio_360_Quick_Start.xml",   icon: "WF/WF_Button_Cardio_360" }
var prog_cardio360       = {label: QT_TRANSLATE_NOOP("Menu", "Cardio360"),              desc: cardio360_desc,       program: "Program_Files/Cardio_360.xml",               icon: "WF/WF_Button_Cardio_360" }
var prog_cardio360arms   = {label: QT_TRANSLATE_NOOP("Menu", "Cardio360 Arm Sculptor"), desc: cardio360arms_desc,   program: "Program_Files/Cardio_360_Arm_Sculptor.xml",  icon: "WF/WF_Button_Cardio_360" }
var prog_cardio360legs   = {label: QT_TRANSLATE_NOOP("Menu", "Cardio360 Leg Shaper"),   desc: cardio360legs_desc,   program: "Program_Files/Cardio_360_Leg_Shaper.xml",    icon: "WF/WF_Button_Cardio_360" }
var prog_cardio360custom = {label: QT_TRANSLATE_NOOP("Menu", "Cardio360 Custom"),       desc: cardio360custom_desc, program: "Program_Files/Cardio360_Custom_Workout.xml", icon: "WF/WF_Button_Cardio_360" }
var prog_cardio360demo   = {label: QT_TRANSLATE_NOOP("Menu", "Cardio360 Demo"),         desc: cardio360demo_desc,   program: "Program_Files/Cardio_360_Demo.xml",          icon: "WF/WF_Button_Cardio_360" }

var prog_LT_cardio360       = {label: QT_TRANSLATE_NOOP("Menu", "Cardio360"),        desc: cardio360_desc,       program: "Program_Files/Cardio_360_LateralTrainer.xml",               icon: "WF/WF_Button_Cardio_360" }
var prog_LT_cardio360custom = {label: QT_TRANSLATE_NOOP("Menu", "Cardio360 Custom"), desc: cardio360custom_desc, program: "Program_Files/Cardio360_Custom_Workout_LateralTrainer.xml", icon: "WF/WF_Button_Cardio_360" }

// ===== CUSTOM Programs ====
var custom_pace_desc  = QT_TRANSLATE_NOOP("Menu", "Set up your own speed intervals.  Easy to change setup screens allow you to customize any PACE SETTER (RPM) profile to add variation to your cardio session.")
var custom_hill_desc  = QT_TRANSLATE_NOOP("Menu", "Easy to change WORKLOAD interval workouts that simulate hills.  User friendly setup screens allow you to create any hill profile.")
var custom_ultra_desc = QT_TRANSLATE_NOOP("Menu", "Do you have trouble finding a workout that fits your specific needs?  Try setting up your own!  This completely customizable workout setup allows WORKLOAD and PACE SETTER interval control as well as the ability to control interval time.")
var custom_hrc_desc   = QT_TRANSLATE_NOOP("Menu", "Set up your own heart rate intervals.  Specify WORK and REST targets and let the machine make all the adjustments." + "  " + "The workout begins in MANUAL control - gradually increase WORKLOAD until heart rate is within 10 bpm of the target. At this point, the machine takes control of WORKLOAD to maintain your HR within a few beats of your target.")

var prog_custom_pace  = {label: QT_TRANSLATE_NOOP("Menu", "Custom Pace"),  desc: custom_pace_desc,  program: "Program_Files/Custom_Pace.xml",          dummy: QT_TRANSLATE_NOOP("Menu", "Custom Pace"),          icon: "WF/WF_Button_Custom" }
var prog_custom_hill  = {label: QT_TRANSLATE_NOOP("Menu", "Custom Hill"),  desc: custom_hill_desc,  program: "Program_Files/Custom_Hills.xml",         dummy: QT_TRANSLATE_NOOP("Menu", "Custom Hills"),         icon: "WF/WF_Button_Custom" }
var prog_custom_ultra = {label: QT_TRANSLATE_NOOP("Menu", "Custom Ultra"), desc: custom_ultra_desc, program: "Program_Files/Custom_Ultra.xml",         dummy: QT_TRANSLATE_NOOP("Menu", "Custom Ultra"),         icon: "WF/WF_Button_Custom" }
var prog_custom_hrc   = {label: QT_TRANSLATE_NOOP("Menu", "Custom HRC"),   desc: custom_hrc_desc,   program: "Program_Files/Custom_HRC_Intervals.xml", dummy: QT_TRANSLATE_NOOP("Menu", "Custom HRC Intervals"), icon: "WF/WF_Button_HRC" }

var prog_manual = { label: QT_TRANSLATE_NOOP("Menu", "Manual Workout"),   desc: desc_prog_manual, program: "Program_Files/Manual.xml", icon: "WF/WF_Button_Manual" }

// ===== Stepmill CUSTOM Programs =====
var step_fitness_test_wfi_desc   = QT_TRANSLATE_NOOP("Menu", "A fitness test used to estimate your VO2 max.  The test increases step rate gradually every minute and ends at the point where your heart rate reaches 85% of the maximum for your age.")
var step_fire_fighter_desc = QT_TRANSLATE_NOOP("Menu", "A 20 second warmup then 3 minute fitness test ")

var step_prog_manual_desc    = QT_TRANSLATE_NOOP("Menu", "Set up your own workout with a TIME limit.")
var step_rolling_hills_desc  = QT_TRANSLATE_NOOP("Menu", "A series of gradual increasing and decreasing step rate changes that simulate rolling hills. Adjust your SPEED at any time during the workout to increase or decrease intensity of the hills.")
var step_speed_intervals_desc = QT_TRANSLATE_NOOP("Menu", "Hill Intervals are in 2-minute segments.  Speed changes are permanent.")
var step_fat_burn_desc     = QT_TRANSLATE_NOOP("Menu", "A changing step rate profile focuses on intense glute muscle use.")
var step_cardio_challenge_desc = QT_TRANSLATE_NOOP("Menu", "Steps per minute increase to a maximum at the mid-point of the workout, then decrease to the finish.  Incline and speed changes affect the current segment only.")

var step_hrc_target_desc     = QT_TRANSLATE_NOOP("Menu", "Choose your target heart rate." + "  " + "The workout begins in MANUAL control - gradually increase WORKLOAD until heart rate is within 10 bpm of the target. At this point, the machine takes control of WORKLOAD to maintain your HR within a few beats of your target.")

var step_floors_desc = QT_TRANSLATE_NOOP("Menu", "Choose number of floors you want to climb.")

var desc_step_mount_everest     = QT_TRANSLATE_NOOP("Menu", "This climb to 29,029 feet (8,848 meters) will put you on top of the world. Determine your own climbing pace by choosing SPEED. The Stepmill will automatically end the workout when the goal is reached.")
var desc_step_eiffel_tower      = QT_TRANSLATE_NOOP("Menu", "One of the most photographed objects in the world, climbing this Paris landmark ends at 1,063 feet (324 meters). Determine your own climbing pace by choosing SPEED. The Stepmill automatically end the workout when the goal is reached.")
var desc_step_gateway_arch      = QT_TRANSLATE_NOOP("Menu", "Dominating the St. Louis, Missouri skyline, this gleaming monument will take you 630 feet (192 meters) to the top. Determine your own climbing pace by choosing SPEED. The Stepmill will automatically end the workout when the goal is reached.")
var desc_step_mount_kilimanjaro = QT_TRANSLATE_NOOP("Menu", "Climb the tallest mountain in Africa at 19,341 feet (5,895 meters). Determine your own climbing pace by choosing SPEED. The Stepmill will automatically end the workout when the goal is reached.")
var desc_step_mount_rainier     = QT_TRANSLATE_NOOP("Menu", "This majestic mountain in the state of Washington tops out at 14,409 feet (4392 meters). Determine your own climbing pace by choosing SPEED. The Stepmill will automatically end the workout when the goal is reached.")

var prog_step_fitness_test_wfi   = { label: QT_TRANSLATE_NOOP("Menu", "WFI Fitness Test"),    program: "Program_Files/Step_WFI_Test.xml", desc: step_fitness_test_wfi_desc, icon: "WF/WF_Button_Fitness_Test" }
var prog_step_fire_fighter_test        = { label: QT_TRANSLATE_NOOP("Menu", "Firefighter Fitness Test"),    program: "Program_Files/Step_Fire_Fighter.xml", desc: step_fire_fighter_desc, icon: "WF/WF_Button_Fitness_Test" }

var prog_step_manual = {label: QT_TRANSLATE_NOOP("Menu", "Manual Workout"),   desc: step_prog_manual_desc, program: "Program_Files/Step_Manual.xml", icon: "WF/WF_Button_Manual" }
var prog_step_rolling_hills  = {label: QT_TRANSLATE_NOOP("Menu", "Rolling Hills"),  desc: step_rolling_hills_desc,  icon: "WF/WF_Button_Rolling_Hills", program: "Program_Files/Step_Rolling_Hills.xml" }
var prog_step_speed_intervals = {label: QT_TRANSLATE_NOOP("Menu", "Speed Intervals"),   desc: step_speed_intervals_desc, program: "Program_Files/Step_Speed_Intervals.xml", icon: "WF/WF_Button_Rolling_Hills" }
var prog_step_fat_burn     = {label: QT_TRANSLATE_NOOP("Menu", "Fat Burn"),      desc: step_fat_burn_desc,     program: "Program_Files/Step_Fat_Burn.xml",      icon: "WF/WF_Button_Glute_Buster" }
var prog_step_cardio_challange = {label: QT_TRANSLATE_NOOP("Menu", "Cardio Challenge"), desc:  step_cardio_challenge_desc, program: "Program_Files/Step_Cardio_Challenge.xml", icon: "WF/WF_Button_Cardio_Challenge" }

var prog_step_hrc_target     = { label: QT_TRANSLATE_NOOP("Menu", "HRC Target"),      desc: step_hrc_target_desc,     program: "Program_Files/Step_HRC_Target.xml",      icon: "WF/WF_Button_HRC" }

var prog_step_floors = {label: QT_TRANSLATE_NOOP("Menu", "Floors"),  desc: step_floors_desc,  icon: "WF/WF_Button_Hill_Workout", program: "Program_Files/Step_Floors.xml" }

var prog_step_mount_everest       = {label: QT_TRANSLATE_NOOP("Menu", "Mount Everest"), desc: desc_step_mount_everest,      program: "Program_Files/Step_Mt_Everest.xml",          icon: "WF/WF_Button_Everest" }
var prog_step_eiffel_tower        = {label: QT_TRANSLATE_NOOP("Menu", "Eiffel Tower"),  desc: desc_step_eiffel_tower,       program: "Program_Files/Step_Eiffel_Tower.xml",        icon: "WF/WF_Button_Eiffel" }
var prog_step_gateway_arch        = {label: QT_TRANSLATE_NOOP("Menu", "Gateway Arch"),  desc: desc_step_gateway_arch,       program: "Program_Files/Step_Gateway_Arch.xml",        icon: "WF/WF_Button_Monuments" }
var prog_step_mount_kilimanjaro   = {label: QT_TRANSLATE_NOOP("Menu", "Kilimanjaro"),   desc: desc_step_mount_kilimanjaro,  program: "Program_Files/Step_Mt_Kilimanjaro.xml",      icon: "WF/WF_Button_Kilimanjaro" }
var prog_step_mount_rainier       = {label: QT_TRANSLATE_NOOP("Menu", "Mount Rainier"), desc: desc_step_mount_rainier,      program: "Program_Files/Step_Mt_Rainier.xml",          icon: "WF/WF_Button_Rainier" }

// ===== eGym Workouts =====
var egym_icon = ""
var egym_workouts_desc = QT_TRANSLATE_NOOP("Menu", "Access to eGym Trainer workouts.")
var egym_cardio_test_desc = QT_TRANSLATE_NOOP("Menu", "Cardio Test for eGym.")
var prog_egym_cardio_test = {label: QT_TRANSLATE_NOOP("Menu", "Cardio Test"), desc: egym_cardio_test_desc, program: "Program_Files/eGymCardioTest.xml", icon: "WF/WF_Button_Cardio_Challenge" }
var prog_tread_egym_cardio_test = {label: QT_TRANSLATE_NOOP("Menu", "Cardio Test"), desc: egym_cardio_test_desc, program: "Program_Files/Tread_eGymCardioTest.xml", icon: "WF/WF_Button_Cardio_Challenge" }
var prog_step_egym_cardio_test = {label: QT_TRANSLATE_NOOP("Menu", "Cardio Test"), desc: egym_cardio_test_desc, program: "Program_Files/Step_eGymCardioTest.xml", icon: "WF/WF_Button_Cardio_Challenge" }

// ===== Tread Menus =====
function menu_tread_get_workouts(filter, isChangeWorkout) {
    switch(filter) {
    case "BASIC":
        return [prog_tread_manual];
    case "HILL":
        if (isChangeWorkout)
            return [prog_tread_hill_intervals,
                    prog_tread_rolling_hills,
                    prog_tread_single_hill,
                    prog_tread_weightloss_hills,
                    prog_tread_glute_buster,
                    prog_tread_cardio_challange];
        else
            return [prog_tread_hill_intervals,
                    prog_tread_rolling_hills,
                    prog_tread_single_hill,
                    prog_tread_weightloss_hills,
                    prog_tread_glute_buster,
                    prog_tread_calorie_goal,
                    prog_tread_cardio_challange];
    case "SPEED":
        return [prog_tread_walkrun,
                prog_tread_speed_intervals,
                prog_tread_speed_ramp,
                prog_tread_leg_shaper];
    case "DISTANCE":
        return [prog_tread_distance_5k,
                prog_tread_distance_10k,
                prog_tread_distance_2mile,
                prog_tread_distance_4mile];
    case "SAVED":
        if (isChangeWorkout)
            return [];
        else
            return savedMenuList();
    case "EGYM":
        if (isChangeWorkout)
            return [];
        else
            return egymMenuList(prog_tread_egym_cardio_test);
    case "CUSTOM":
        if (isChangeWorkout)
            return [];
        else
            return [prog_tread_custom_speed,
                    prog_tread_custom_hill,
                    prog_tread_custom_ultra];
    case "HRC":
        if (isChangeWorkout)
            return [prog_tread_hrc_target,
                    prog_tread_hrc_weightloss,
                    prog_tread_hrc_aerobic,
                    prog_tread_hrc_intervals,
                    prog_tread_hrc_5k,
                    prog_tread_hrc_10k,
                    prog_tread_hrc_2mile,
                    prog_tread_hrc_4mile];
        else if (options.enableProtoGraphs)
            return [prog_tread_hrc_target,
                    prog_tread_hrc_weightloss,
                    prog_tread_hrc_aerobic,
                    prog_tread_hrc_intervals,
                    prog_tread_hrc_intervals_optimal,
                    prog_tread_custom_hrc,
                    prog_tread_hrc_5k,
                    prog_tread_hrc_10k,
                    prog_tread_hrc_2mile,
                    prog_tread_hrc_4mile];
        else
            return [prog_tread_hrc_target,
                    prog_tread_hrc_weightloss,
                    prog_tread_hrc_aerobic,
                    prog_tread_hrc_intervals,
                    prog_tread_custom_hrc,
                    prog_tread_hrc_5k,
                    prog_tread_hrc_10k,
                    prog_tread_hrc_2mile,
                    prog_tread_hrc_4mile];
    case "FITNESSTEST":
        if (isChangeWorkout)
            return [];
        else
            return [prog_tread_fitness_test_gerkin,
                    prog_tread_fitness_test_airforce,
                    prog_tread_fitness_test_navy,
                    prog_tread_fitness_test_army,
                    prog_tread_fitness_test_marines];
    case "CARDIO360":
        return [];
    case "ADJUSTABLESTRIDE":
        return [];
    case "MONUMENTS":
        return [];
    case "ALL":
        return menu_tread_get_workouts("BASIC").concat( menu_tread_get_workouts("HILL", isChangeWorkout),
                                                       menu_tread_get_workouts("SPEED", isChangeWorkout),
                                                       menu_tread_get_workouts("DISTANCE", isChangeWorkout),
                                                       menu_tread_get_workouts("HRC", isChangeWorkout),
                                                       menu_tread_get_workouts("FITNESSTEST", isChangeWorkout),
                                                       menu_tread_get_workouts("CARDIO360", isChangeWorkout),
                                                       menu_tread_get_workouts("ADJUSTABLESTRIDE", isChangeWorkout),
                                                       menu_tread_get_workouts("MONUMENTS", isChangeWorkout),
                                                       menu_tread_get_workouts("CUSTOM", isChangeWorkout),
                                                       menu_tread_get_workouts("EGYM", isChangeWorkout),
                                                       menu_tread_get_workouts("SAVED", isChangeWorkout))
    }
}

// ===== Elliptical Menus =====
var menu_elliptical_get_workouts = function(filter, isChangeWorkout) {
    switch(filter) {
    case "BASIC":
        return [prog_manual,
                prog_cardio360QS];
    case "HILL":
        if (isChangeWorkout)
            return [prog_hill_intervals,
                    prog_rolling_hills,
                    prog_single_hill,
                    prog_random_hills,
                    prog_glutebuster,
                    prog_cardio_challange];
        else
            return [prog_hill_intervals,
                    prog_rolling_hills,
                    prog_single_hill,
                    prog_random_hills,
                    prog_glutebuster,
                    prog_calorie_goal,
                    prog_cardio_challange];
    case "SPEED":
        return [prog_walkrun_intervals,
                prog_pace_intervals,
                prog_pace_ramp,
                prog_legshaper];
    case "DISTANCE":
        return [prog_distance_5k,
                prog_distance_10k,
                prog_distance_2mile,
                prog_distance_4mile];
    case "SAVED":
        if (isChangeWorkout)
            return [];
        else
            return savedMenuList(false);
    case "EGYM":
        if (isChangeWorkout)
            return [];
        else
            return egymMenuList(prog_egym_cardio_test);
    case "CUSTOM":
        if (isChangeWorkout)
            return [];
        else
            return [prog_custom_pace,
                    prog_custom_hill,
                    prog_custom_ultra];
    case "HRC":
        if (isChangeWorkout)
            return [prog_hrc_target,
                    prog_hrc_weightloss,
                    prog_hrc_aerobic,
                    prog_hrc_intervals,
                    prog_hrc_5k,
                    prog_hrc_10k,
                    prog_hrc_2mile,
                    prog_hrc_4mile];
        else if (options.enableProtoGraphs)
            return [prog_hrc_target,
                    prog_hrc_weightloss,
                    prog_hrc_aerobic,
                    prog_hrc_intervals,
                    prog_hrc_intervals_optimal,
                    prog_custom_hrc,
                    prog_hrc_5k,
                    prog_hrc_10k,
                    prog_hrc_2mile,
                    prog_hrc_4mile];
        else
            return [prog_hrc_target,
                    prog_hrc_weightloss,
                    prog_hrc_aerobic,
                    prog_hrc_intervals,
                    prog_custom_hrc,
                    prog_hrc_5k,
                    prog_hrc_10k,
                    prog_hrc_2mile,
                    prog_hrc_4mile];
    case "FITNESSTEST":
        if (isChangeWorkout)
            return [];
        else
            return [prog_fitness_test];
    case "CARDIO360":
        if (isChangeWorkout)
            return [prog_cardio360,
                    prog_cardio360arms,
                    prog_cardio360legs,
                    prog_cardio360demo];
        else
            return [prog_cardio360,
                    prog_cardio360arms,
                    prog_cardio360legs,
                    prog_cardio360custom,
                    prog_cardio360demo];
    case "ADJUSTABLESTRIDE":
        return [];
    case "MONUMENTS":
        return [];
    case "ALL":
        return menu_elliptical_get_workouts("CARDIO360").concat( menu_elliptical_get_workouts("BASIC", isChangeWorkout),
                                                                menu_elliptical_get_workouts("HILL", isChangeWorkout),
                                                                menu_elliptical_get_workouts("SPEED", isChangeWorkout),
                                                                menu_elliptical_get_workouts("DISTANCE", isChangeWorkout),
                                                                menu_elliptical_get_workouts("HRC", isChangeWorkout),
                                                                menu_elliptical_get_workouts("FITNESSTEST", isChangeWorkout),
                                                                menu_elliptical_get_workouts("ADJUSTABLESTRIDE", isChangeWorkout),
                                                                menu_elliptical_get_workouts("MONUMENTS", isChangeWorkout),
                                                                menu_elliptical_get_workouts("CUSTOM", isChangeWorkout),
                                                                menu_elliptical_get_workouts("EGYM", isChangeWorkout),
                                                                menu_elliptical_get_workouts("SAVED", isChangeWorkout))
    }
}

// ===== Adjustable Stride elliptical Menus =====
var menu_csa_get_workouts = function(filter, isChangeWorkout) {
    switch(filter) {
    case "BASIC":
        return [prog_manual,
                prog_cardio360QS];
    case "HILL":
        if (isChangeWorkout)
            return [prog_hill_intervals,
                    prog_random_hills,
                    prog_glutebuster,
                    prog_cardio_challange]; //?
        else
            return [prog_hill_intervals,
                    prog_random_hills,
                    prog_glutebuster,
                    prog_calorie_goal,
                    prog_cardio_challange]; //?
    case "SPEED":
        return [prog_pace_intervals,
                prog_legshaper];
    case "DISTANCE":
        return [prog_distance_5k];
    case "SAVED":
        if (isChangeWorkout)
            return [];
        else
            return savedMenuList(false);
    case "EGYM":
        if (isChangeWorkout)
            return [];
        else
            return egymMenuList(prog_egym_cardio_test);
    case "CUSTOM":
        if (isChangeWorkout)
            return [];
        else
            return [prog_custom_ultra];
    case "HRC":
        if (isChangeWorkout)
            return [prog_hrc_target,
                    prog_hrc_weightloss];
        else if (options.enableProtoGraphs)
            return [prog_hrc_target,
                    prog_hrc_weightloss,
                    prog_hrc_intervals_optimal,
                    prog_custom_hrc];
        else
            return [prog_hrc_target,
                    prog_hrc_weightloss,
                    prog_custom_hrc];
    case "FITNESSTEST":
        if (isChangeWorkout)
            return [];
        else
            return [prog_fitness_test];
    case "CARDIO360":
        if (isChangeWorkout)
            return [prog_cardio360,
                    prog_cardio360demo];
        else
            return [prog_cardio360,
                    prog_cardio360custom,
                    prog_cardio360demo];
    case "ADJUSTABLESTRIDE":
        return [prog_stride_5k,
                prog_stride_intervals];
    case "MONUMENTS":
        return [];
    case "ALL":
        return menu_csa_get_workouts("CARDIO360").concat( menu_csa_get_workouts("BASIC", isChangeWorkout),
                                                         menu_csa_get_workouts("HILL", isChangeWorkout),
                                                         menu_csa_get_workouts("SPEED", isChangeWorkout),
                                                         menu_csa_get_workouts("DISTANCE", isChangeWorkout),
                                                         menu_csa_get_workouts("HRC", isChangeWorkout),
                                                         menu_csa_get_workouts("FITNESSTEST", isChangeWorkout),
                                                         menu_csa_get_workouts("ADJUSTABLESTRIDE", isChangeWorkout),
                                                         menu_csa_get_workouts("MONUMENTS", isChangeWorkout),
                                                         menu_csa_get_workouts("CUSTOM", isChangeWorkout),
                                                         menu_csa_get_workouts("EGYM", isChangeWorkout),
                                                         menu_csa_get_workouts("SAVED", isChangeWorkout))
    }
}

// ===== Bike Menus =====
var menu_bike_get_workouts = function(filter, isChangeWorkout) {
    switch(filter) {
    case "BASIC":
        return [prog_manual];
    case "HILL":
        if (isChangeWorkout)
            return [prog_hill_intervals,
                    prog_rolling_hills,
                    prog_single_hill,
                    prog_random_hills,
                    prog_glutebuster,
                    prog_cardio_challange];
        else
            return [prog_hill_intervals,
                    prog_rolling_hills,
                    prog_single_hill,
                    prog_random_hills,
                    prog_glutebuster,
                    prog_calorie_goal,
                    prog_cardio_challange];
    case "SPEED":
        return [prog_pace_intervals,
                prog_pace_ramp,
                prog_legshaper];
    case "DISTANCE":
        return [prog_distance_5k,
                prog_distance_10k,
                prog_distance_2mile,
                prog_distance_4mile];
    case "SAVED":
        if (isChangeWorkout)
            return [];
        else
            return savedMenuList(false);
    case "EGYM":
        if (isChangeWorkout)
            return [];
        else
            return egymMenuList(prog_egym_cardio_test);
    case "CUSTOM":
        if (isChangeWorkout)
            return [];
        else
            return [prog_custom_pace,
                    prog_custom_hill,
                    prog_custom_ultra];
    case "HRC":
        if (isChangeWorkout)
            return [prog_hrc_target,
                    prog_hrc_weightloss,
                    prog_hrc_aerobic,
                    prog_hrc_intervals,
                    prog_hrc_5k,
                    prog_hrc_10k,
                    prog_hrc_2mile,
                    prog_hrc_4mile];
        else if (options.enableProtoGraphs)
            return [prog_hrc_target,
                    prog_hrc_weightloss,
                    prog_hrc_aerobic,
                    prog_hrc_intervals,
                    prog_hrc_intervals_optimal,
                    prog_hrc_5k,
                    prog_hrc_10k,
                    prog_hrc_2mile,
                    prog_hrc_4mile];
        else
            return [prog_hrc_target,
                    prog_hrc_weightloss,
                    prog_hrc_aerobic,
                    prog_hrc_intervals,
                    prog_hrc_5k,
                    prog_hrc_10k,
                    prog_hrc_2mile,
                    prog_hrc_4mile];
    case "FITNESSTEST":
        if (isChangeWorkout)
            return [];
        else
            return [prog_fitness_test];
    case "CARDIO360":
        return [];
    case "ADJUSTABLESTRIDE":
        return [];
    case "MONUMENTS":
        return [];
    case "ALL":
        return menu_bike_get_workouts("BASIC").concat( menu_bike_get_workouts("HILL", isChangeWorkout),
                                                      menu_bike_get_workouts("SPEED", isChangeWorkout),
                                                      menu_bike_get_workouts("DISTANCE", isChangeWorkout),
                                                      menu_bike_get_workouts("HRC", isChangeWorkout),
                                                      menu_bike_get_workouts("FITNESSTEST", isChangeWorkout),
                                                      menu_bike_get_workouts("CARDIO360", isChangeWorkout),
                                                      menu_bike_get_workouts("ADJUSTABLESTRIDE", isChangeWorkout),
                                                      menu_bike_get_workouts("MONUMENTS", isChangeWorkout),
                                                      menu_bike_get_workouts("CUSTOM", isChangeWorkout),
                                                      menu_bike_get_workouts("EGYM", isChangeWorkout),
                                                      menu_bike_get_workouts("SAVED", isChangeWorkout))
    }
}

// ===== Alpine Menus =====
var menu_alpine_get_workouts = function(filter, isChangeWorkout) {
    switch(filter) {
    case "BASIC":
        return [prog_tread_manual];
    case "HILL":
        if (isChangeWorkout)
            return [prog_tread_hill_intervals,
                    prog_tread_rolling_hills,
                    prog_tread_single_hill,
                    prog_tread_random_hills,
                    prog_tread_glute_buster,
                    prog_tread_cardio_challange];
        else
            return [prog_tread_hill_intervals,
                    prog_tread_rolling_hills,
                    prog_tread_single_hill,
                    prog_tread_random_hills,
                    prog_tread_glute_buster,
                    prog_tread_calorie_goal,
                    prog_tread_cardio_challange];
    case "SPEED":
        return [];
    case "DISTANCE":
        return [prog_tread_distance_5k,
                prog_tread_distance_10k,
                prog_tread_distance_2mile,
                prog_tread_distance_4mile];
    case "SAVED":
        if (isChangeWorkout)
            return [];
        else
            return savedMenuList(false);
    case "EGYM":
        if (isChangeWorkout)
            return [];
        else
            return egymMenuList(prog_tread_egym_cardio_test);
    case "CUSTOM":
        if (isChangeWorkout)
            return [];
        else
            return [prog_tread_custom_hill,
                    prog_tread_custom_ultra];
    case "HRC":
        if (isChangeWorkout)
            return [prog_tread_hrc_target,
                    prog_tread_hrc_weightloss,
                    prog_tread_hrc_aerobic,
                    prog_tread_hrc_intervals];
        else if(options.enableProtoGraphs)
            return [prog_tread_hrc_target,
                    prog_tread_hrc_weightloss,
                    prog_tread_hrc_aerobic,
                    prog_tread_hrc_intervals,
                    prog_tread_hrc_intervals_optimal,
                    prog_tread_custom_hrc];
        else
            return [prog_tread_hrc_target,
                    prog_tread_hrc_weightloss,
                    prog_tread_hrc_aerobic,
                    prog_tread_hrc_intervals,
                    prog_tread_custom_hrc];
    case "FITNESSTEST":
        if (isChangeWorkout)
            return [];
        else
            return [prog_tread_fitness_test_gerkin];
    case "CARDIO360":
        return [];
    case "ADJUSTABLESTRIDE":
        return [];
    case "MONUMENTS":
        return [prog_gateway_arch,
                prog_eiffel_tower,
                prog_mount_everest,
                prog_mount_rainier,
                prog_mount_kilimanjaro];
    case "ALL":
        return menu_alpine_get_workouts("BASIC").concat( menu_alpine_get_workouts("MONUMENTS", isChangeWorkout),
                                                        menu_alpine_get_workouts("HILL", isChangeWorkout),
                                                        menu_alpine_get_workouts("DISTANCE", isChangeWorkout),
                                                        menu_alpine_get_workouts("HRC", isChangeWorkout),
                                                        menu_alpine_get_workouts("FITNESSTEST", isChangeWorkout),
                                                        menu_alpine_get_workouts("CUSTOM", isChangeWorkout),
                                                        menu_alpine_get_workouts("EGYM", isChangeWorkout),
                                                        menu_alpine_get_workouts("SAVED", isChangeWorkout) )
    }
}

// ===== Lateral Menus =====
var menu_lateral_get_workouts = function(filter, isChangeWorkout) {
    switch(filter) {
    case "BASIC":
        return [prog_manual];
    case "HILL":
        if (isChangeWorkout)
            return [prog_hill_intervals,
                    prog_random_hills,
                    prog_quad_burner,
                    prog_glutebuster,
                    prog_cardio_challange];
        else
            return [prog_hill_intervals,
                    prog_random_hills,
                    prog_quad_burner,
                    prog_glutebuster,
                    prog_calorie_goal,
                    prog_cardio_challange];
    case "SPEED":
        return [prog_pace_intervals];
    case "DISTANCE":
        return [];
    case "SAVED":
        if (isChangeWorkout)
            return [];
        else
            return savedMenuList(false);
    case "EGYM":
        if (isChangeWorkout)
            return [];
        else
            return egymMenuList(prog_egym_cardio_test);
    case "CUSTOM":
        return [];
    case "HRC":
        return [prog_hrc_target]; //cruise control?
    case "FITNESSTEST":
        if (isChangeWorkout)
            return [];
        else
        return [prog_fitness_test];
    case "CARDIO360":
        return [prog_LT_cardio360, prog_LT_cardio360custom];
    case "ADJUSTABLESTRIDE":
        return [];
    case "MONUMENTS":
        return [];
    case "ALL":
        return menu_lateral_get_workouts("CARDIO360").concat( menu_lateral_get_workouts("BASIC", isChangeWorkout),
                                                             menu_lateral_get_workouts("HILL", isChangeWorkout),
                                                             menu_lateral_get_workouts("SPEED", isChangeWorkout),
                                                             menu_lateral_get_workouts("DISTANCE", isChangeWorkout),
                                                             menu_lateral_get_workouts("HRC", isChangeWorkout),
                                                             menu_lateral_get_workouts("FITNESSTEST", isChangeWorkout),
                                                             menu_lateral_get_workouts("ADJUSTABLESTRIDE", isChangeWorkout),
                                                             menu_lateral_get_workouts("MONUMENTS", isChangeWorkout),
                                                             menu_lateral_get_workouts("CUSTOM", isChangeWorkout),
                                                             menu_lateral_get_workouts("EGYM", isChangeWorkout),
                                                             menu_lateral_get_workouts("SAVED", isChangeWorkout))
    }
}

// ===== Stepmill Menus =====
function menu_stepmill_get_workouts(filter, isChangeWorkout) {
    switch(filter) {
    case "BASIC":
        return [
                prog_step_manual
                ];

    case "HILL":
        return [
                prog_step_rolling_hills,
                prog_step_fat_burn,
                prog_step_cardio_challange,
                prog_step_speed_intervals
                ];

    case "SPEED":
        return [
               ];

    case "DISTANCE":
        return [
               prog_step_floors,
               ];

    case "SAVED":
        if (isChangeWorkout)
            return [];
        else
            return savedMenuList(false);
    case "EGYM":
        if (isChangeWorkout)
            return [];
        else
            return egymMenuList(prog_step_egym_cardio_test);
    case "CUSTOM": //Tentative
        return [];
//        if (isChangeWorkout)
//            return [];
//        else
//            return [prog_step_custom_speed];
    case "HRC":
            return [
                    prog_step_hrc_target
                    ];
    case "FITNESSTEST":
            return [
                    prog_step_fitness_test_wfi,
                    prog_step_fire_fighter_test
                    ];
    case "CARDIO360":
        return [];
    case "ADJUSTABLESTRIDE":
        return [];
    case "MONUMENTS":
        return [prog_step_eiffel_tower,
                prog_step_mount_everest,
                prog_step_mount_kilimanjaro,
                prog_step_mount_rainier,
                prog_step_gateway_arch
                ];
    case "ALL":
        return menu_stepmill_get_workouts("BASIC").concat(
                                                       menu_stepmill_get_workouts("MONUMENTS", isChangeWorkout),
                                                       menu_stepmill_get_workouts("HILL", isChangeWorkout),
                                                       menu_stepmill_get_workouts("SPEED", isChangeWorkout),
                                                       menu_stepmill_get_workouts("DISTANCE", isChangeWorkout),
                                                       menu_stepmill_get_workouts("HRC", isChangeWorkout),
                                                       menu_stepmill_get_workouts("FITNESSTEST", isChangeWorkout),
//                                                     menu_stepmill_get_workouts("CUSTOM", isChangeWorkout),
                                                       menu_stepmill_get_workouts("EGYM", isChangeWorkout),
                                                       menu_stepmill_get_workouts("SAVED", isChangeWorkout))
    }
}

// populate the list of saved files from directory listing
function savedMenuList(doSave) {
    var savedProgramPath = "/data/saved_programs/"
    var maxFiles = 5
    var storedFiles = storage.listFiles(savedProgramPath, "*.xml")
    var newList = [];
    var idx=0
    for(var i=0 ; i < maxFiles ; i++) {
        // files are prefixed with 1_, 2_, etc.  Assume list is sorted.
        if(storedFiles[idx] && (storedFiles[idx][0] == (i+1).toString()) ) {
            var progName = storedFiles[idx].split(".");
            var tempStr = progName[0];
            tempStr  = tempStr.substr(2);
            var item = findMatchingProgs(tempStr)
            var j = doSave ? i : idx  // Filter out empty list items if displaying menu items
            newList[j] = { label: qsTr("Saved: ") + application.translateText("Menu", item.label),
                desc: item.desc,
                program: savedProgramPath + storedFiles[idx],
                icon: item.icon };
            idx++
        }
        else if(doSave)
            newList[i] = prog_saved
    }
    return newList
}

function egymMenuList(cardio_test_desc) {
    var programPath = "/data/eGym_programs/"
    var storedFiles = storage.listFiles(programPath, "*.xml")
    var newList = [];
    var idx=0
    while(storedFiles[idx]) {
        // files are prefixed with 1_, 2_, etc.  Assume list is sorted.
        var progName = storedFiles[idx].split(".");
        var tempStr = progName[0];
        tempStr  = tempStr.slice(2);
        newList[idx] = { label: qsTr("eGym: ") + application.translateText("Menu", tempStr),
            desc: egym_workouts_desc,
            program: programPath + storedFiles[idx],
            icon: egym_icon };
        idx++
    }

    // Cardio Test will be implemented later
//    newList[idx] = cardio_test_desc
    return newList
}

// Find icon and description
var allDesc = [prog_tread_fitness_test_gerkin,
               prog_tread_fitness_test_army,
               prog_tread_fitness_test_navy,
               prog_tread_fitness_test_airforce,
               prog_tread_fitness_test_marines,
               prog_tread_walkrun,
               prog_tread_speed_ramp,
               prog_tread_speed_intervals,
               prog_tread_calorie_goal,
               prog_tread_weightloss_hills,
               prog_tread_glute_buster,
               prog_tread_leg_shaper,
               prog_tread_weightloss_hrc,
               prog_tread_rolling_hills,
               prog_tread_single_hill,
               prog_tread_hill_intervals,
               prog_tread_random_hills,
               prog_tread_cardio_challange,
               prog_tread_distance,
               prog_tread_distance_2mile,
               prog_tread_distance_4mile,
               prog_tread_distance_5k,
               prog_tread_distance_10k,
               prog_tread_custom_speed,
               prog_tread_custom_hill,
               prog_tread_custom_ultra,
               prog_tread_custom_hrc,
               prog_tread_manual,
               prog_mount_everest,
               prog_eiffel_tower,
               prog_gateway_arch,
               prog_alpine_random_hills,
               prog_mount_kilimanjaro,
               prog_mount_rainier,
               prog_tread_hrc_target,
               prog_tread_hrc_weightloss,
               prog_tread_hrc_aerobic,
               prog_tread_hrc_distance,
               prog_tread_hrc_5k,
               prog_tread_hrc_10k,
               prog_tread_hrc_2mile,
               prog_tread_hrc_4mile,
               prog_tread_hrc_intervals,
               prog_tread_hrc_intervals_optimal,
               prog_hill_intervals,
               prog_single_hill,
               prog_rolling_hills,
               prog_random_hills,
               prog_quad_burner,
               prog_pace_ramp,
               prog_pace_intervals,
               prog_walkrun_intervals,
               prog_cardio_challange,
               prog_fitness_test,
               prog_stride_intervals,
               prog_distance_2mile,
               prog_distance_4mile,
               prog_distance_5k,
               prog_distance_10k,
               prog_stride_5k,
               prog_hrc_target,
               prog_hrc_weightloss,
               prog_hrc_aerobic,
               prog_hrc_distance,
               prog_hrc_5k,
               prog_hrc_10k,
               prog_hrc_2mile,
               prog_hrc_4mile,
               prog_hrc_intervals,
               prog_hrc_intervals_optimal,
               prog_calorie_goal,
               prog_glutebuster,
               prog_legshaper,
               prog_cardio360QS,
               prog_cardio360,
               prog_cardio360arms,
               prog_cardio360legs,
               prog_cardio360custom,
               prog_cardio360demo,
               prog_LT_cardio360,
               prog_LT_cardio360custom,
               prog_custom_pace,
               prog_custom_hill,
               prog_custom_ultra,
               prog_custom_hrc,
               prog_manual,
               prog_step_manual
        ]

function findMatchingProgs(progName) {
    var progFile = "Program_Files/" + progName + ".xml"
    for (var i=0; i < allDesc.length; i++) {
        if(allDesc[i].program === progFile) {
            return allDesc[i]
        }
    }
    return prog_saved
}

//var menu_EXAMPLE_get_workouts = function(filter) {
//    switch(filter) {
//    case "BASIC":
//        return [];
//    case "HILL":
//        return [];
//    case "SPEED":
//        return [];
//    case "DISTANCE":
//        return [];
//    case "SAVED":
//        return [];
//    case "CUSTOM":
//        return [];
//    case "HRC":
//        return [];
//    case "FITNESSTEST":
//        return [];
//    case "CARDIO360":
//        return [];
//    case "ADJUSTABLESTRIDE":
//        return [];
//    case "MONUMENTS":
//        return [];
//    case "ALL":
//        return menu_EXAMPLE_get_workouts("BASIC").concat( menu_EXAMPLE_get_workouts("HILL"), menu_EXAMPLE_get_workouts("SPEED"), menu_EXAMPLE_get_workouts("DISTANCE"), menu_EXAMPLE_get_workouts("CUSTOM"), menu_EXAMPLE_get_workouts("HRC"), menu_EXAMPLE_get_workouts("FITNESSTEST"), menu_EXAMPLE_get_workouts("CARDIO360"), menu_EXAMPLE_get_workouts("ADJUSTABLESTRIDE"), menu_EXAMPLE_get_workouts("MONUMENTS"))
//    }
//}

