import QtQuick 2.12
import Components 1.0
import WorkoutRunData 1.0
import WorkoutManager 1.0
import "../string_format.js" as StrFormat
import ".."

Item {
    id: root

    property int tableWidth: 1000 * main.hScaleFactor
    property int tableHMargin: 40 * main.hScaleFactor
    property int numColumns: 5 // dataTable.models.length
    property int columnWidth: (tableWidth)/numColumns
    property alias selectable: dataTable.selectable
    property alias dataDisplayModel: dataTable.dataDisplayModel
    property alias selectedCount: dataTable.selectedCount

    property alias dataIdxEnum: dataTable.dataIdxEnum

    // build data set for chart
    Component.onCompleted: {
        reset();
        updateDataValues();
    }

    function convertUnits(speedMiles) {
        return workoutScreen.unitState === "METRIC" ? Globals.mileToKm(speedMiles) : speedMiles;
    }

    function convertMeters(feet) {
        return workoutScreen.unitState === "METRIC" ? Globals.feetToMeters(feet) : feet;
    }

    function convertPaceTime(pace) {
        return workoutScreen.unitState === "METRIC" ? pace/1.61 : pace;
    }

    function updateDataValues() {
        dataDisplayModel.setProperty(dataIdxEnum.distance, "value", convertUnits(aWorkoutRunData.totalDistance).toFixed(2));
        dataDisplayModel.setProperty(dataIdxEnum.distanceRemaining, "value", convertUnits(aWorkoutRunData.distanceRemaining).toFixed(2));
        dataDisplayModel.setProperty(dataIdxEnum.distanceClimbed, "value", workoutScreen.unitState === "METRIC" ? convertMeters(aWorkoutRunData.totalFeetClimbed).toFixed(1) : aWorkoutRunData.totalFeetClimbed.toFixed(0));
        dataDisplayModel.setProperty(dataIdxEnum.avgIncline, "value", aWorkoutRunData.avgIncline.toFixed(1));
        dataDisplayModel.setProperty(dataIdxEnum.strideCount, "value", machineinfo.productType === WorkoutProgram.ELLIPTICAL || machineinfo.productType === WorkoutProgram.LATERAL_TRAINER
                                     ? Math.floor(aWorkoutRunData.strideCount).toFixed(0)
                                     : "0");
        dataDisplayModel.setProperty(dataIdxEnum.stepsClimbed, "value", aWorkoutRunData.totalStepsClimbed.toFixed(0));
        dataDisplayModel.setProperty(dataIdxEnum.floorsClimbed, "value", Math.floor(aWorkoutRunData.totalFloorsClimbed).toFixed(0));
        dataDisplayModel.setProperty(dataIdxEnum.floorsRemaining, "value", convertUnits(aWorkoutRunData.floorsRemaining).toFixed(0));

        dataDisplayModel.setProperty(dataIdxEnum.timeElapsed, "value", StrFormat.formatTimeStringMinAndSec(aWorkoutRunData.totalTime));
        dataDisplayModel.setProperty(dataIdxEnum.timeRemaining, "value", workoutProgram.isMonumentWorkout && aWorkoutRunData.mode === WorkoutRunData.WORKOUT_MODE
                                     ? (main.isTreadmill && workoutManager.treadIncline <= 0) ? "--:--" : StrFormat.formatTimeStringMinAndSec(aWorkoutRunData.climbTimeRemaining)
                                     : StrFormat.formatTimeStringMinAndSec(aWorkoutRunData.timeRemaining))
        dataDisplayModel.setProperty(dataIdxEnum.segmentTimeRemaining, "value", StrFormat.formatTimeStringMinAndSec(aWorkoutRunData.segmentTimeRemaining))
        dataDisplayModel.setProperty(dataIdxEnum.pace, "value", main.isTreadmill
                                     ? StrFormat.formatTimeStringMinAndSec(convertPaceTime(aWorkoutRunData.treadPace))
                                     : aWorkoutRunData.rpm.toFixed(0));
        dataDisplayModel.setProperty(dataIdxEnum.avgPace, "value", main.isTreadmill
                                     ? StrFormat.formatTimeStringMinAndSec(convertPaceTime(aWorkoutRunData.avgTreadPace))
                                     : aWorkoutRunData.totalAveragePace.toFixed(0)); // Avg RPM
        dataDisplayModel.setProperty(dataIdxEnum.avgSpeed, "value", main.isTreadmill || main.isStepmill
                                     ? convertUnits(aWorkoutRunData.totalAverageSpeed).toFixed(1)
                                     : "0");
        dataDisplayModel.setProperty(dataIdxEnum.maxSpeed, "value", main.isTreadmill || main.isStepmill
                                     ? convertUnits(aWorkoutRunData.totalMaximumSpeed).toFixed(1)
                                     : aWorkoutRunData.totalMaximumPace.toFixed(0)); // max RPM

        dataDisplayModel.setProperty(dataIdxEnum.calories, "value", aWorkoutRunData.totalCalories.toFixed(0));
        dataDisplayModel.setProperty(dataIdxEnum.calPerHr, "value", aWorkoutRunData.calsPerHour.toFixed(0));
        dataDisplayModel.setProperty(dataIdxEnum.activeCalories, "value", gem.gemActiveCalories.toFixed(0));
        dataDisplayModel.setProperty(dataIdxEnum.totalCalories, "value", gem.gemTotalCalories.toFixed(0));

        dataDisplayModel.setProperty(dataIdxEnum.mets, "value", aWorkoutRunData.mets.toFixed(0));
        dataDisplayModel.setProperty(dataIdxEnum.watts, "value", aWorkoutRunData.watts.toFixed(0));
        dataDisplayModel.setProperty(dataIdxEnum.avgWatts, "value", aWorkoutRunData.avgWatts.toFixed(0));

        dataDisplayModel.setProperty(dataIdxEnum.bpm, "value", heartRateManager.heartRate.toFixed(0));
        dataDisplayModel.setProperty(dataIdxEnum.maxBPM, "value", aWorkoutRunData.totalMaximumHeartRate > 0
                                     ? aWorkoutRunData.totalMaximumHeartRate.toString()
                                     : "--");
        dataDisplayModel.setProperty(dataIdxEnum.avgBPM, "value", aWorkoutRunData.totalAverageHeartRate > 0
                                     ? aWorkoutRunData.totalAverageHeartRate.toString()
                                     : "--");
        dataDisplayModel.setProperty(dataIdxEnum.targetBPM, "value", workoutProgram.displayDataVars.targetHRAvailable
                                     ? aWorkoutRunData.targetHeartRate.toString()
                                     : "--");
    }

    function reset() {
        if(!selectable){
            dataDisplayModel.setProperty(dataIdxEnum.distance, "isDisplayed", workoutProgram.displayDataVars.distanceAvailable);
            dataDisplayModel.setProperty(dataIdxEnum.distanceRemaining, "isDisplayed", false);
            dataDisplayModel.setProperty(dataIdxEnum.distanceClimbed, "isDisplayed", workoutProgram.displayDataVars.feetClimbedAvailable);

            dataDisplayModel.setProperty(dataIdxEnum.avgIncline, "isDisplayed", main.isTreadmill);
            dataDisplayModel.setProperty(dataIdxEnum.strideCount, "isDisplayed", machineinfo.productType === WorkoutProgram.ELLIPTICAL || machineinfo.productType === WorkoutProgram.LATERAL_TRAINER);

            dataDisplayModel.setProperty(dataIdxEnum.stepsClimbed, "isDisplayed", main.isStepmill);
            dataDisplayModel.setProperty(dataIdxEnum.floorsClimbed, "isDisplayed", main.isStepmill);
            dataDisplayModel.setProperty(dataIdxEnum.floorsRemaining, "isDisplayed", false);

            dataDisplayModel.setProperty(dataIdxEnum.timeElapsed, "isDisplayed", true);
            dataDisplayModel.setProperty(dataIdxEnum.timeRemaining, "isDisplayed", false);
            dataDisplayModel.setProperty(dataIdxEnum.segmentTimeRemaining, "isDisplayed", false);
            dataDisplayModel.setProperty(dataIdxEnum.pace, "isDisplayed", false);
            dataDisplayModel.setProperty(dataIdxEnum.avgPace, "isDisplayed", !main.isStepmill);
            dataDisplayModel.setProperty(dataIdxEnum.avgSpeed, "isDisplayed", (main.isTreadmill || main.isStepmill) && workoutProgram.displayDataVars.paceAvailable);
            dataDisplayModel.setProperty(dataIdxEnum.maxSpeed, "isDisplayed", true);

            dataDisplayModel.setProperty(dataIdxEnum.calories, "isDisplayed", !gem.appleWatchConnected);
            dataDisplayModel.setProperty(dataIdxEnum.calPerHr, "isDisplayed", workoutProgram.displayDataVars.calsPerHourAvailable);
            dataDisplayModel.setProperty(dataIdxEnum.activeCalories, "isDisplayed", gem.appleWatchConnected);
            dataDisplayModel.setProperty(dataIdxEnum.totalCalories, "isDisplayed", gem.appleWatchConnected);

            dataDisplayModel.setProperty(dataIdxEnum.mets, "isDisplayed", workoutProgram.displayDataVars.metsAvailable);
            dataDisplayModel.setProperty(dataIdxEnum.watts, "isDisplayed", false);
            dataDisplayModel.setProperty(dataIdxEnum.avgWatts, "isDisplayed", workoutProgram.displayDataVars.wattsAvailable);

            dataDisplayModel.setProperty(dataIdxEnum.bpm, "isDisplayed", false);
            dataDisplayModel.setProperty(dataIdxEnum.maxBPM, "isDisplayed", true);
            dataDisplayModel.setProperty(dataIdxEnum.avgBPM, "isDisplayed", true);
            dataDisplayModel.setProperty(dataIdxEnum.targetBPM, "isDisplayed", workoutProgram.isHRCProgram);

            return;
        }

        dataDisplayModel.setProperty(dataIdxEnum.distance, "isDisplayed", workoutProgram.displayDataVars.distanceAvailable);
        dataDisplayModel.setProperty(dataIdxEnum.distanceRemaining, "isDisplayed", workoutProgram.displayDataVars.distanceRemainingAvailable);
        dataDisplayModel.setProperty(dataIdxEnum.distanceClimbed, "isDisplayed", workoutProgram.displayDataVars.feetClimbedAvailable);
        dataDisplayModel.setProperty(dataIdxEnum.stepsClimbed, "isDisplayed", main.isStepmill);
        dataDisplayModel.setProperty(dataIdxEnum.floorsClimbed, "isDisplayed", main.isStepmill);
        dataDisplayModel.setProperty(dataIdxEnum.floorsRemaining, "isDisplayed", workoutProgram.isFloorsWorkout);

        dataDisplayModel.setProperty(dataIdxEnum.avgIncline, "isDisplayed", main.isTreadmill);
        dataDisplayModel.setProperty(dataIdxEnum.strideCount, "isDisplayed", machineinfo.productType === WorkoutProgram.ELLIPTICAL || machineinfo.productType === WorkoutProgram.LATERAL_TRAINER);

        dataDisplayModel.setProperty(dataIdxEnum.timeElapsed, "isDisplayed", workoutProgram.displayDataVars.timeAvailable);
        dataDisplayModel.setProperty(dataIdxEnum.timeRemaining, "isDisplayed", workoutProgram.displayDataVars.timeRemainingAvailable);
        dataDisplayModel.setProperty(dataIdxEnum.segmentTimeRemaining, "isDisplayed", workoutProgram.isHRCIntervalsProgram);
        dataDisplayModel.setProperty(dataIdxEnum.pace, "isDisplayed", main.isTreadmill && workoutProgram.displayDataVars.paceAvailable);
        dataDisplayModel.setProperty(dataIdxEnum.avgPace, "isDisplayed", !main.isStepmill);
        dataDisplayModel.setProperty(dataIdxEnum.avgSpeed, "isDisplayed", (main.isTreadmill || main.isStepmill) && workoutProgram.displayDataVars.paceAvailable);
        dataDisplayModel.setProperty(dataIdxEnum.maxSpeed, "isDisplayed", false);

        dataDisplayModel.setProperty(dataIdxEnum.calories, "isDisplayed", workoutProgram.displayDataVars.caloriesAvailable && !gem.appleWatchConnected);
        dataDisplayModel.setProperty(dataIdxEnum.calPerHr, "isDisplayed", workoutProgram.displayDataVars.calsPerHourAvailable);
        dataDisplayModel.setProperty(dataIdxEnum.activeCalories, "isDisplayed", workoutProgram.displayDataVars.caloriesAvailable && gem.appleWatchConnected && gem.connected === 1);
        dataDisplayModel.setProperty(dataIdxEnum.totalCalories, "isDisplayed", workoutProgram.displayDataVars.caloriesAvailable && gem.appleWatchConnected && gem.connected === 1);

        dataDisplayModel.setProperty(dataIdxEnum.mets, "isDisplayed", workoutProgram.displayDataVars.metsAvailable);
        dataDisplayModel.setProperty(dataIdxEnum.watts, "isDisplayed", workoutProgram.displayDataVars.wattsAvailable);
        dataDisplayModel.setProperty(dataIdxEnum.avgWatts, "isDisplayed", workoutProgram.displayDataVars.wattsAvailable);

        dataDisplayModel.setProperty(dataIdxEnum.bpm, "isDisplayed", workoutProgram.displayDataVars.heartRateAvailable);
        dataDisplayModel.setProperty(dataIdxEnum.maxBPM, "isDisplayed", workoutProgram.displayDataVars.heartRateAvailable);
        dataDisplayModel.setProperty(dataIdxEnum.avgBPM, "isDisplayed", workoutProgram.displayDataVars.heartRateAvailable);
        dataDisplayModel.setProperty(dataIdxEnum.targetBPM, "isDisplayed", workoutProgram.isHRCProgram);

        dataTable.reset();
    }

    Connections {
        target: workoutManager
        onWorkoutDataChanged: {
            updateDataValues();
        }
    }

    Connections {
        target: aWorkoutRunData
        onWorkoutDataReset: {
            updateDataValues();
        }
    }

    Connections {
        target: gem
        onAppleWatchConnectedChanged: {
            reset()
        }
        onConnectedChanged: {
            reset()
        }
    }

    Rectangle {
        id: tableWrap

        width: root.tableWidth + 2*root.tableHMargin
        height: root.height
        anchors.top: parent.top
        anchors.left: parent.left
        color: root.selectable ? main.colorToolbarBackground : "transparent"
        border.color: root.selectable ? "transparent" : main.colorUIBorder
        border.width: main.widthBorder

        SelectableDataTable {
            id: dataTable
            sourceFile: "DataSummaryTable"
            anchors.top: parent.top
            anchors.left: parent.left
            anchors.leftMargin: root.tableHMargin
            width: root.tableWidth
            height: tableWrap.height
        }
    }
}
