import QtQuick 2.12
import Components 1.0

Item {
    id: root
    visible: main.eGymCardioTest
    property bool isSync: summaryArea.numResults > 0

    Rectangle {
        id: syncing
        visible: root.isSync

        width: 1080 * main.hScaleFactor
        height: root.height
        anchors.top: parent.top
        anchors.left: parent.left
        color: "transparent"
        border.color: main.colorUIBorder
        border.width: main.widthBorder

        TextLabel {
            anchors.centerIn: parent
            text: qsTr("SENDING DATA TO EGYM") + application.emptyString
            font.pixelSize: 24 * main.vScaleFactor
        }
    }

    Rectangle {
        id: summaryArea
        visible: !root.isSync

        width: 1080 * main.hScaleFactor
        height: root.height
        anchors.top: parent.top
        anchors.left: parent.left
        color: "transparent"
        border.color: main.colorUIBorder
        border.width: main.widthBorder

        property var vo2Array: []
        property var ageArray: []
        property var wattsArray: []
        property var dateArray: []
        property int maxAge: 0
        property int maxVo2: 0
        property int maxWatts: 0
        property var numResults: eGym.pastCardioResults.length

        property int barWidth: parent.width/numResults

        onNumResultsChanged: convertResults()

        function convertResults() {
            var i
            ageArray = []
            vo2Array = []
            wattsArray = []
            dateArray = []

            for (i=0; i<numResults; i++) {
                var age = eGym.pastCardioResults["cardioAge"].toInt()
                var vo2 = eGym.pastCardioResults["vo2max"].toDouble()
                var watts = eGym.pastCardioResults["maxWatts"].toDouble()
                maxAge = Math.max(age, maxAge)
                maxVo2 = Math.max(vo2, maxVo2)
                maxWatts = Math.max(watts, maxWatts)

                var timestamp = eGym.pastCardioResults["timestamp"].toDouble()
                var d =  new Date(timestamp)
                var mmdd = d.toUTCString().slice(4,10)

                ageArray.push(age)
                vo2Array.push(vo2)
                wattsArray.push(watts)
                dateArray.push(mmdd)
            }

            maxAge = maxAge*1.2
            maxVo2 = maxVo2*1.2
            maxWatts = maxWatts*1.2
        }

        Rectangle {
            anchors {
                top: parent.top
                topMargin: 20 * main.vScaleFactor
                right: parent.right
                rightMargin: 20 * main.hScaleFactor
            }
            width: parent.width * 0.2
            height: parent.height * 0.3

            color: main.colorHighlightBackground
            border.color: main.colorUIBorder
            border.width: main.widthBorder
            radius: main.widthBorder

            Column {
                spacing: 10 * main.vScaleFactor

                TextLabel {
                    text: qsTr("CARDIO AGE") + application.emptyString
                    font.pixelSize: 24 * main.vScaleFactor
                }

                NumberLabel {
                    text: summaryArea.numResults>0 ? summaryArea.ageArray[summaryArea.numResults-1] : 0
                    font.pixelSize: 36 * main.vScaleFactor
                }

                TextLabel {
                    text: qsTr("YEARS") + application.emptyString
                    font.pixelSize: 24 * main.vScaleFactor
                }
            }
        }

        Rectangle {
            anchors {
                bottom: parent.bottom
                bottomMargin: 20 * main.vScaleFactor
                right: parent.right
                rightMargin: 20 * main.hScaleFactor
            }
            width: parent.width * 0.2
            height: parent.height * 0.3

            color: main.colorHighlightBackground
            border.color: main.colorUIBorder
            border.width: main.widthBorder
            radius: main.widthBorder

            Column {
                spacing: 10 * main.vScaleFactor

                TextLabel {
                    text: qsTr("MAXIMUM WATTS") + application.emptyString
                    font.pixelSize: 24 * main.vScaleFactor
                }

                NumberLabel {
                    text: summaryArea.numResults>0 ? summaryArea.wattsArray[summaryArea.numResults-1] : 0
                    font.pixelSize: 36 * main.vScaleFactor
                }

                TextLabel {
                    text: qsTr("WATTS") + application.emptyString
                    font.pixelSize: 24 * main.vScaleFactor
                }
            }
        }

        Column {
            anchors {
                top: parent.top
                topMargin: 20 * main.vScaleFactor
                left: parent.left
                leftMargin: 20 * main.hScaleFactor
                bottom: parent.bottom
                bottomMargin: 20 * main.vScaleFactor
            }
            width: parent.width * 0.75
            spacing: 20 * main.vScaleFactor

            property int barH: (parent.height - 2*spacing)/(!(main.isStepmill || main.isTreadmill) ? 2 : 3)

            function computeHeight(target, maxH) {
                var percent = target/maxH
                return percent * barH
            }

            Row {
                id: ageHistory

                height: parent.barH
                width: parent.width

                TextLabel {
                    rotation: 270
                    text: qsTr("AGE") + application.emptyString
                    font.pixelSize: 20 * main.hScaleFactor
                }

                Repeater {
                    model: summaryArea.numPts
                    delegate: Component {
                        Column {
                            spacing: 0

                            TextLabel {
                                text: summaryArea.ageArray[index]
                                font.pixelSize: 20 * main.vScaleFactor
                            }

                            Rectangle {
                                color: main.colorSelected
                                border.color: main.colorUIBorder
                                border.width: main.widthBorder
                                radius: main.defaultRadius
                                width: summaryArea.barWidth
                                height: computeHeight(summaryArea.ageArray[index], summaryArea.maxAge)
                            }

                            TextLabel {
                                text: dateArray[index]
                                font.pixelSize: 20 * main.vScaleFactor
                            }
                        }
                    }
                }
            }

            Row {
                id: vo2History

                height: parent.barH
                width: parent.width

                TextLabel {
                    rotation: 270
                    text: qsTr("VO2") + application.emptyString
                    font.pixelSize: 20 * main.hScaleFactor
                }

                Repeater {
                    model: summaryArea.numPts
                    delegate: Component {
                        Column {
                            spacing: 0

                            TextLabel {
                                text: summaryArea.vo2Array[index]
                                font.pixelSize: 20 * main.vScaleFactor
                            }

                            Rectangle {
                                color: main.colorSelected
                                border.color: main.colorUIBorder
                                border.width: main.widthBorder
                                radius: main.defaultRadius
                                width: summaryArea.barWidth
                                height: computeHeight(summaryArea.vo2Array[index], summaryArea.maxVo2)
                            }

                            TextLabel {
                                text: dateArray[index]
                                font.pixelSize: 20 * main.vScaleFactor
                            }
                        }
                    }
                }
            }

            Row {
                id: wattsHistory

                height: parent.barH
                width: parent.width
                visible: !(main.isStepmill || main.isTreadmill)

                TextLabel {
                    rotation: 270
                    text: qsTr("WATTS") + application.emptyString
                    font.pixelSize: 20 * main.hScaleFactor
                }

                Repeater {
                    model: summaryArea.numPts
                    delegate: Component {
                        Column {
                            spacing: 0

                            TextLabel {
                                text: summaryArea.wattsArray[index]
                                font.pixelSize: 20 * main.vScaleFactor
                            }

                            Rectangle {
                                color: main.colorSelected
                                border.color: main.colorUIBorder
                                border.width: main.widthBorder
                                radius: main.defaultRadius
                                width: summaryArea.barWidth
                                height: computeHeight(summaryArea.wattsArray[index], summaryArea.maxWatts)
                            }

                            TextLabel {
                                text: dateArray[index]
                                font.pixelSize: 20 * main.vScaleFactor
                            }
                        }
                    }
                }
            }
        }
    }
}
