import QtQuick 2.12
import QtQuick.Layouts 1.12
//import QtAV 1.6
import QtMultimedia 5.7
import Components 1.0
import Process 0.1
import "../Diagnostics"

Item {
    id: root
    anchors.fill: parent

    property bool muted: false
    property bool playing: videoView.playbackState === MediaPlayer.PlayingState
    property string videosPresent : "va"
    property bool isMenuDisplayed: false
    property alias isMenuMoving: sceneMenu.moving
    property int currentIndex: -1
    property variant videoModel
    property real defaultPlaybackRate
    property bool pendingPlay: false

    signal action()

    function reset() {
        sceneMenu.currentIndex = -1;
    }

    function stopVideo() {
        state = "MenuState";
        videoView.source = ""
        print("Stop Video");
        //videoView.stop()
        root.reset();
    }

    function startVideo() {
        if(!root.videoModel) {
            root.pendingPlay = true
            return
        }

        root.pendingPlay = false
        var currVideo = root.videoModel.get(root.currentIndex)
        sceneMenu.currentIndex = root.currentIndex
        videoView.source = currVideo.file
        defaultPlaybackRate = parseFloat(currVideo.speed)
        root.state = "PlayingState"
        print("Play Video " + currVideo.file + "(" + currVideo.name + ")" + " at speed (" + currVideo.speed + ")")
//        videoView.startPosition = 0
        videoView.play()
        miscStats.incrementVideoUsage(currVideo.file)
        buzzer.buttonPress()
        root.action()
    }

    function pickRandomVideo() {
        if(options.autoVideoChangeInterval > 0)
            root.currentIndex = 0
        else
            root.currentIndex = Math.floor(Math.random() * root.videoModel.count);
        console.log("Random Course Selected: " + root.currentIndex + " of " + root.videoModel.count);

        if(root.pendingPlay)
            startVideo()
    }

    function playNextVideo() {
        root.currentIndex = (root.currentIndex+1) % root.videoModel.count;
        videoView.stop()
        startVideo()
        oiTestHud.count++
        console.log("Next Course Selected: " + root.currentIndex + " of " + root.videoModel.count);
    }

    function pause() {
        videoView.pause()
    }

    // start out showing a menu of video thumbnails
    Component.onCompleted: {
        console.log("Starting oiDetect");
        oiDetect.start()
        state = "MenuState"
    }

    Process {
        id: oiDetect
        program: "scripts/detect_outsideInteractive.sh"
        onReadyReadStandardOutput: {
            var output = String(readAllStandardOutput())
            output = output.trim()
            console.log( "Outside Interactive Videos installed " + output)
            root.videosPresent = output
            videoModel = getVideoModel()
            pickRandomVideo()
            console.log("oiDetect root.videosPresent = " + root.videosPresent)
        }
        onReadyReadStandardError: {
            var output = String(readAllStandardError())
            output = output.trim()
            console.log( "oiDetect Error " + output)
        }
    }

    // List Model of videos - name displayed as title, file is video file, thumbnail shows in menu
    //Outdoor Interactive Videos
    ListModel {
        id: oiVideos
        ListElement { speed: "1.7"; ls: 0.5; lpb: 0.5; us: 12.0; upb: 2.5; bls: 10; bus: 180; name: QT_TR_NOOP("Hills of Bali");        file: "/data/video/OI/BaliTrueFitA_V_Compressed_Cut.mp4";                thumbnail: "/data/video/OI/Bali_Screenshot.JPG"}
        ListElement { speed: "1.4"; ls: 0.5; lpb: 0.5; us: 12.0; upb: 2.5; bls: 10; bus: 180; name: QT_TR_NOOP("Australian Outback");   file: "/data/video/OI/AustralianOutbackTrueFitA_V_Compressed_Cut_1.mp4"; thumbnail: "/data/video/OI/Australian-Outback_Screenshot.JPG"}
        ListElement { speed: "1.0"; ls: 0.5; lpb: 0.5; us: 12.0; upb: 2.5; bls: 10; bus: 180; name: QT_TR_NOOP("Central Park");         file: "/data/video/OI/CentralParkTrueA_V_Compressed_Cut.mp4";            thumbnail: "/data/video/OI/Central_Park_Screenshot.JPG"}
        ListElement { speed: "1.4"; ls: 0.5; lpb: 0.5; us: 12.0; upb: 2.5; bls: 10; bus: 180; name: QT_TR_NOOP("Falmouth Road Race");   file: "/data/video/OI/New_Balance_Falmouth_Road_Race_Compressed.mp4";    thumbnail: "/data/video/OI/New_Balance_Falmouth_Road_Race_Screenshot.JPG"}
        ListElement { speed: "1.5"; ls: 0.5; lpb: 0.5; us: 12.0; upb: 2.5; bls: 10; bus: 180; name: QT_TR_NOOP("Niagara Falls");        file: "/data/video/OI/NiagaraTrueFitA_V_Compressed.mp4";                 thumbnail: "/data/video/OI/Niagara_Falls_Screen_Shot.JPG"}
        ListElement { speed: "1.45"; ls: 0.5; lpb: 0.5; us: 12.0; upb: 2.5; bls: 10; bus: 180; name: QT_TR_NOOP("Washington Mall");     file: "/data/video/OI/WashMallTrueFitA_V_Compressed.mp4";                thumbnail: "/data/video/OI/Washington_Mall_Screenshot.JPG"}
        ListElement { speed: "1.0"; ls: 0.5; lpb: 0.5; us: 12.0; upb: 2.5; bls: 10; bus: 180; name: QT_TR_NOOP("Alpine Mountains");     file: "/data/video/OI/Alpine-Mountains_1.0.mp4";                         thumbnail: "/data/video/OI/Alpine-Mountains-Screenshot.JPG"}
        ListElement { speed: "1.0"; ls: 0.5; lpb: 0.5; us: 12.0; upb: 2.5; bls: 10; bus: 180; name: QT_TR_NOOP("Mediterranean Beach");  file: "/data/video/OI/Mediterranean-Beach_1.0.mp4";                      thumbnail: "/data/video/OI/Mediterranean-Beach-Screenshot.JPG"}
    }

    //Outdoor Interactive Videos
    ListModel {
        id: oiVideosModest
        ListElement { speed: "1.7"; ls: 0.5; lpb: 0.5; us: 12.0; upb: 2.5; bls: 10; bus: 180; name: QT_TR_NOOP("Hills of Bali");        file: "/data/video/OI/BaliTrueFitA_V_Compressed_Cut.mp4";                thumbnail: "/data/video/OI/Bali_Screenshot.JPG"}
        ListElement { speed: "1.4"; ls: 0.5; lpb: 0.5; us: 12.0; upb: 2.5; bls: 10; bus: 180; name: QT_TR_NOOP("Australian Outback");   file: "/data/video/OI/AustralianOutbackTrueFitA_V_Compressed_Cut_1.mp4"; thumbnail: "/data/video/OI/Australian-Outback_Screenshot.JPG"}
        ListElement { speed: "1.0"; ls: 0.5; lpb: 0.5; us: 12.0; upb: 2.5; bls: 10; bus: 180; name: QT_TR_NOOP("Alpine Mountains");     file: "/data/video/OI/Alpine-Mountains_1.0.mp4";                         thumbnail: "/data/video/OI/Alpine-Mountains-Screenshot.JPG"}
        ListElement { speed: "1.0"; ls: 0.5; lpb: 0.5; us: 12.0; upb: 2.5; bls: 10; bus: 180; name: QT_TR_NOOP("Mediterranean Beach");  file: "/data/video/OI/Mediterranean-Beach_1.0.mp4";                      thumbnail: "/data/video/OI/Mediterranean-Beach-Screenshot.JPG"}
    }

    // Virtual Active Videos
    ListModel {
        id: vaVideos
        ListElement { speed: "1.0"; ls: 0.5; lpb: 0.5; us: 12.0; upb: 2.5; bls: 10; bus: 180; name: QT_TR_NOOP("Wild California Run") ; file: "/data/video/TFRN0104_tfe01.mp4"; thumbnail: "/data/video/TFRN0104.png"}
        ListElement { speed: "1.0"; ls: 0.5; lpb: 0.5; us: 12.0; upb: 2.5; bls: 10; bus: 180; name: QT_TR_NOOP("Germany Run") ; file: "/data/video/TFRN0103_tfe01.mp4"; thumbnail: "/data/video/TFRN0103.png"}
        ListElement { speed: "1.0"; ls: 0.5; lpb: 0.5; us: 12.0; upb: 2.5; bls: 10; bus: 180; name: QT_TR_NOOP("Chicago Run") ; file: "/data/video/TFRN0102_tfe01.mp4"; thumbnail: "/data/video/TFRN0102.png"}
        ListElement { speed: "1.0"; ls: 0.5; lpb: 0.5; us: 12.0; upb: 2.5; bls: 10; bus: 180; name: QT_TR_NOOP("American Southwest II") ; file: "/data/video/TFRN0101_tfe01.mp4"; thumbnail: "/data/video/TFRN0101.png"}
        ListElement { speed: "1.0"; ls: 0.5; lpb: 0.5; us: 12.0; upb: 2.5; bls: 10; bus: 180; name: QT_TR_NOOP("Trinity Mountains") ; file: "/data/video/TFHK0101_tfe01.mp4"; thumbnail: "/data/video/TFHK0101.png"}
        ListElement { speed: "1.0"; ls: 0.5; lpb: 0.5; us: 12.0; upb: 2.5; bls: 10; bus: 180; name: QT_TR_NOOP("Northern Italy") ; file: "/data/video/TFBK0101_tfe01.mp4"; thumbnail: "/data/video/TFBK0101.png"}
    }

    /*
     * This function takes the speed in units of 1.0 mph and returns the desired
     * playback rate. The list model that defines the videos should contain 4
     * members. (See oiVideos, ioVideosModest and vaVideos as an example) The 4
     * members are:
     * - ls (LowerSpeed)
     * - lpb (LowerPlayBack)
     * - us (UpperSpeed)
     * - upb (UpperPlayBack)
     *
     * This function uses the 4 members to describe the line equation used to
     * compute the desired playback, where Speed is on the X-axis and PlayBack
     * is on the Y-axis. Point A would then be (ls, lpb). Point B would be
     * (us, upb). Point C would be our desired PlayBack rate at a certain speed
     * along the line between A and B. So the equation would be:
     *
     *  upb - lpb     pb - lpb
     * ----------- = ----------
     *   us - ls       s - ls
     *
     * Solving for pb:
     *
     *       ( upb - lpb ) ( s - ls )
     * pb = -------------------------- + lpb
     *               us - ls
     *
     * To calibrate the line equation, one should adjust the values of ls, lpb,
     * us and upb. Right now this is purely subjective and the values are obtained
     * using trial and error. To get the values for ls, lpb, us and upb, one can
     * think of it as follows:
     *
     * At a certain pb(PlayBack), the video looks like it is running at s(Speed)
     *
     */
    function getVideoSpeed(speed) {
        if(root.currentIndex < 0) {
            return 1.0
        }

        var currVideo = root.videoModel.get(root.currentIndex)
        if(options.virtualVideoSpeedControlledPlaybackRate === true) {
            var pbspeed = ((currVideo.upb - currVideo.lpb) * (speed - currVideo.ls) / (currVideo.us - currVideo.ls)) + currVideo.lpb

            if(pbspeed < 0.5) {
                pbspeed = 0.5
            }

            return pbspeed
        } else {
            return currVideo.speed
        }
    }

    function getVideoSpeedBike(rpm) {
        if (root.currentIndex < 0 ){
            return 1.0
        }
        var currVideo = root.videoModel.get(root.currentIndex)
        if(options.virtualVideoSpeedControlledPlaybackRate === true) {
            var pbspeed = ((currVideo.upb - currVideo.lpb) * (rpm - currVideo.bls) / (currVideo.bus - currVideo.bls)) + currVideo.lpb

            if(pbspeed < 0.5) {
                pbspeed = 0.5
            }

            return pbspeed
        } else {
            return currVideo.speed
        }
    }

    function getVideoModel() {
        switch(root.videosPresent) {
            case "oi":
                console.log("case oi, returning oiVideos, root.vidsPresent=" + root.videosPresent);
                if (options.modestyMode) {
                    return oiVideosModest
                }
                else {
                    return oiVideos
                }

             case "va":
                 console.log("case va, returning vaVideos, root.vidsPresent=" + root.videosPresent);
                 console.log("case va");
                 return vaVideos;
             default:
                 console.log("case default");
                 return null;
        }
    }

    Rectangle {
        id: videoViewBackground
        anchors.fill: parent
        color: main.colorDialogBackground
        border.color: main.colorUIBorder
        border.width: main.widthBorder

        RowLayout {
            anchors.fill: parent
            anchors.margins: 1.5*main.widthBorder
            spacing: 0

            Item {
                id: listArea
                Layout.fillHeight: isMenuDisplayed ? true : false
                width: isMenuDisplayed ? root.width * 0.17 : 0
                visible: isMenuDisplayed

                ListView {
                    id: sceneMenu
                    anchors.top: parent.top
                    anchors.left: parent.left
                    anchors.right: parent.right
                    anchors.bottom: parent.bottom
                    anchors.margins: 8 * main.vScaleFactor
                    currentIndex: root.currentIndex
                    model: root.videoModel
                    delegate: menuButtonDelegate
                    spacing: 8 * main.vScaleFactor
                    clip: true
                }
            }

            // Video window to play video
            Video {
                id: videoView

                property int sideBandOffset: 60
                property int seekValue: 0

                visible: true
                fillMode: VideoOutput.PreserveAspectFit
                state: "not-fullscreen"
                anchors.verticalCenter: parent.verticalCenter
                playbackRate: main.isTreadmill  || main.isStepmill ? getVideoSpeed(machinecontrol.treadmillSpeedActual / 10.0) : getVideoSpeedBike(machinecontrol.pedalRPM)
                muted: true

                loops: MediaPlayer.Infinite

                Connections{
                    target: bluetoothAdapter
                    onConnectedHeadsetChanged: {
                        if(bluetoothAdapter.connectedHeadset) {
                            /* Workaround for OI audio not switching to bluetooth headset */
                            resumeTimer.interval = 3000
                            resumeTimer.start()
                        }
                    }

                    onDisconnectingHeadset: {
                        /* Workaround for video going into "fast forward" mode after a disconnection from a bluetooth headset */
                        resumeTimer.interval = 1000
                        resumeTimer.start()
                    }
                }

                Timer {
                    id: resumeTimer
                    interval: 1000
                    onTriggered: {
                        if(root.playing === true) {
                            videoView.seekValue = videoView.position
                            videoView.stop()
                            videoView.startPosition = videoView.seekValue
                            videoView.play()
                        }
                    }
                }
                Timer {
                    id: changeTestTimer
                    interval: options.autoVideoChangeInterval
                    repeat: true
                    running: root.visible && options.autoVideoChangeInterval > 0
                    onTriggered: {
                        playNextVideo()
                    }
                }

//                Connections {
//                    target: machinecontrol
//                    onTreadmillSpeedActualChanged: {
//                        if(videoView.source != "") {
//                            if(main.isTreadmill === true) {
//                                if(machinecontrol.treadmillSpeedActual / 10.0 < 0.5) {
//                                    videoView.pause()
//                                } else {
//                                    videoView.play()
//                                }
//                            }
//                        }
//                    }

//                    onPedalRPMChanged: {
//                        if(videoView.source != "") {
//                            if(main.isTreadmill === false) {
//                                if(machinecontrol.pedalRPM < 20) {
//                                    videoView.pause()
//                                } else {
//                                    videoView.play()
//                                }
//                            }
//                        }
//                    }
//                }

                function toggleState() {
                    if(videoView.state === "not-fullscreen") {
                        videoView.state = "fullscreen"
                    } else {
                        videoView.state = "not-fullscreen"
                    }
                }

//                 This was taken from main.qml, where the full screen video frame was
//                   handled. The original implementation used a separate VLCSurface to
//                   display the full screen video, which was not ideal. So fullscreen
//                   video vs non-fullscreen is handled here and the corresponding data
//                   overlay was also implemented here.
//
                VideoDataOverlay {
                    id: videoOverlay
                    visible: (main.state === "RunState" && videoView.state === "fullscreen")
                    isTreadmill: main.isTreadmill
                    //showHR: heartRateManager.heartRateAvailable
                    //heartRate: heartRateManager.heartRate
                    incline: workoutManager.treadInclineGUI
                    speed: workoutScreen.unitState === "ENGLISH" || main.isStepmill ? workoutManager.treadSpeedGUI : workoutManager.treadSpeedMetricGUI.toFixed(1)
                    speedUnits: main.isStepmill ? qsTr("SPM") : (workoutScreen.unitState === "ENGLISH" ? qsTr("MPH") : qsTr("KPH") ) + application.emptyString
                    rpm: machinecontrol.pedalRPM
                    level: main.isStepmill ? workoutProgram.profile2.currentLevel : workoutManager.workloadLevel
                    opacity: 0.6
                    enabled: (visible && opacity > 0.0)
                    anchors.fill: parent
                    showData: (main.state === "RunState")
                }

                Column {
                    id: controls
                    spacing: 10 * main.vScaleFactor
                    anchors {
                        left: parent.left
                        leftMargin: 0 * main.hScaleFactor + videoView.sideBandOffset
                        bottom: parent.bottom
                        bottomMargin: 0
                    }
                    visible: videoView.visible
                    z: videoView.z + 1

//                    Item {
//                        id: stopButton
//                        width: 53 * main.hScaleFactor
//                        height: 45 * main.vScaleFactor

//                        ScalableImage {
//                            anchors.fill: parent
//                            anchors.margins: 12 * main.scaleFactor
//                            fillMode: Image.PreserveAspectFit
//                            sourceName: "Stop_icon_WHITE";
//                        }

//                        MouseArea {
//                            anchors.fill: parent
//                            onClicked: {
//                                root.stopVideo()
//                                root.action()
//                                buzzer.buttonPress()
//                            }

//                            Rectangle {
//                                anchors.fill: parent
//                                color: main.colorGenericStimulusArea
//                                opacity: 0.3
//                                visible: main.showStimulusArea
//                            }
//                        }
//                    }

                    Item {
                        id: sizeButton
                        width: 150 * main.hScaleFactor
                        height: 150 * main.vScaleFactor

                        ScalableImage {
                            width: 40 * main.hScaleFactor
                            height: 32 * main.vScaleFactor
                            anchors.horizontalCenter: parent.horizontalCenter
                            anchors.verticalCenter: parent.verticalCenter
                            sourceName: videoView.state === "fullscreen" ? "UpperToolBar/collapse_icon" : "UpperToolBar/expand_icon";
                        }

                        MouseArea {
                            anchors.fill: parent
                            onClicked: {
                                videoView.toggleState()
                                buzzer.buttonPress()
                                root.action()
                            }

                            Rectangle {
                                anchors.fill: parent
                                color: main.colorGenericStimulusArea
                                opacity: 0.3
                                visible: main.showStimulusArea
                            }
                        }
                    }
                }

                states: [
                    State {
                        name: "not-fullscreen"
                        PropertyChanges {
                            target: videoView
                            parent: root
                            height: root.height - (1.5 * main.widthBorder * 2)
                            width: root.width * 0.83
                            anchors.left: root.left
                            anchors.leftMargin: listArea.width - sideBandOffset
                        }
                    },
                    State {
                        name: "fullscreen"
                        PropertyChanges {
                            target: videoView
                            parent: main
                            height: main.height
                            width: main.width
                            anchors.left: main.left
                            anchors.leftMargin: 0
                        }
                    }
                ]

            }
        }
    }

    states: [
        State {
            name: "MenuState"
            PropertyChanges { target: videoView; visible: false }
        },
        State {
            name: "PlayingState"
            PropertyChanges { target: videoView; visible: true }
        }
    ]

    Component {
        id: menuButtonDelegate

        Item {
            id: menuButtonItem
            height: ListView.view.height * 0.15
            width: ListView.view.width

            property bool isCurrentItem: menuButtonItem.ListView.isCurrentItem
            property int _index: index

            Rectangle {
                color: menuButtonItem.isCurrentItem ? main.colorSelected : main.colorDialogBackground
                height: parent.height
                width: parent.width * 0.95
                border.color: main.colorUIBorder
                border.width: main.widthBorder
                radius: main.defaultRadius
                anchors.horizontalCenter: parent.horizontalCenter

                Connections {
                    target: menuButtonMouseArea
                    ignoreUnknownSignals: true
                    onClicked: {
                        menuButtonItem.ListView.view.currentIndex = menuButtonItem._index
                        root.action()
                    }
                }

                TextLabel {
                    anchors.fill: parent
                    anchors.margins: 12 * main.scaleFactor
                    horizontalAlignment: Text.AlignHCenter
                    verticalAlignment: Text.AlignVCenter
                    text: qsTr(name) + application.emptyString
                    wrapMode: Text.WordWrap
                    font.pixelSize: 14 * main.vScaleFactor
                    clip: true
                }

                MouseArea {
                    id: menuButtonMouseArea
                    anchors.fill: parent
                    enabled: isMenuDisplayed
                    onClicked: {
                        root.currentIndex = index
                        videoView.stop()
                        startVideo()
                    }

                    Rectangle {
                        anchors.fill: parent
                        color: main.colorGenericStimulusArea
                        opacity: 0.3
                        visible: main.showStimulusArea
                    }
                }
            }
        }
    }
}
