import QtQuick 2.12
import QtQuick.Layouts 1.12
//import VLCVideo 1.0
import ".."
import Components 1.0

Item {
    id:root

    property bool viewShowing: false
    property string channelID: ""
    property alias channelIndex: channelMenu.currentIndex
    property alias channelCount: channelMenu.count
    property bool isSelected: currentViewName === "TV_VIEW"
    //    property bool tunedToCabChannel: tv.tunedToCab()

    property bool isMenuDisplayed: true
    property alias isMenuMoving: channelMenu.moving
    property var counter :0
    property bool ccpresed:false
    property string ccName
    property var channelId

    objectName: "TV_VIEW_CONTAINER"

    signal stopped()
    signal menuButtonPressed()
    signal action()
    // signal channelChange()

    function viewdestruct() {
        tv.stop()
        tv.firstTune = false
    }

    Connections {
        target: tv
        onTuningChanged: {
            if(tv.tuning === false) {
                if(root.viewShowing === false) {
                    vlcMute.setMute(1)
                }
            }
        }
    }

    Timer {
        interval: tvTestHud.channelChangeTime
        repeat: true
        running: !channelChangeTimeSlider.off
        onTriggered: {

            root.channelIndex = (root.channelIndex + 1) % channelCount
            console.log("Automatically Changing Channel to " + root.channelIndex)
            tv.channelUp()
            tvTestHud.count++
        }
    }
    Timer{
        id:startTv
        interval:30
        repeat: false
        onTriggered:
        {
            // tv.firstTune = true
            tv.viewParent = videoViewBackground
            tv.changeParent(videoViewBackground)
            if (tv.isIpodInput) {
                tv.restoreChannel();
            } else {
                if(channelMenu.currentIndex < 0) {
                    tv.channelUp()
                    channelMenu.currentIndex = 0
                } else {
                    tv.tuneLastChannel()
                    // tv.restoreChannel();
                }
            }

            tv.muted = !audioManager.tvAllowed;
            audioManager.tvRequest();
            startTv.stop()


        }
    }


    function reset() {
        channelMenu.currentIndex = -1;
    }

    function shown() {
        root.viewShowing = true;
        workoutViewContainer.persistMenu = true;
        workoutScreen.state=""
        startTv.start()
        console.log("**********************************************",options.cabEnabled)
        if(options.cabEnabled)
        {
            cabArea.visible=true
            listArea.visible=false
            cabControlArea.visible=true
            controlArea.visible=false

        }
        else
        {
            cabArea.visible=false
            listArea.visible=true
            cabControlArea.visible=false
            controlArea.visible=true
        }

        // request to play audio when switching to this view
      /* if (tv.isIpodInput) {
            tv.restoreChannel();
        } else {
            if(channelMenu.currentIndex < 0) {
                tv.channelUp()
                channelMenu.currentIndex = 0
            } else {
                tv.tuneLastChannel()
               // tv.restoreChannel();
            }
        }

        tv.muted = !audioManager.tvAllowed;
        audioManager.tvRequest();*/
    }

    function hidden() {
        tv.on = false
        root.viewShowing = false;
        workoutViewContainer.persistMenu = false;
        startTv.stop()
    }

    function stop() {
        root.stopped();
        tv.stop();
        root.reset();
    }

    Component.onCompleted: {
        tv.playerOnly = false

        if (tv.currentChannel >= 0) {
            var chanid = tv.channelList.channels.get(tv.currentChannel).id

            channelSelected(chanid)
        }
    }


    Connections{
        target: workoutScreen
        onWorkoutStopped: root.stop()
    }

    Rectangle {
        color: main.colorDialogBackground
        anchors.fill: parent
        border.color: main.colorUIBorder
        border.width: main.widthBorder
    }

    RowLayout {
        anchors.fill: parent
        anchors.margins: 1.5 * main.widthBorder
        spacing: 0

        Item {
            Layout.preferredWidth: root.width*0.15
            Layout.fillHeight: true
            Layout.margins: 10 * main.scaleFactor
            Layout.alignment: Qt.AlignHCenter | Qt.AlignVCenter
            visible: !root.fullscreen && isMenuDisplayed

            ColumnLayout {
                anchors.fill: parent
                spacing: 5 * main.vScaleFactor
                Rectangle { // channel list area
                    id: cabArea
                    Layout.fillWidth: true
                    Layout.fillHeight: true
                    Layout.alignment: Qt.AlignHCenter | Qt.AlignTop
                    //border.color: main.colorUIBorder
                    // border.width: main.widthBorder
                    color: "black"
                    visible: options.cabEnabled ? true :false
                    // radius: main.defaultRadius
                    GridLayout {
                        id: keypadGrid
                        anchors.fill: parent
                        rows: 4
                        rowSpacing: 7 * main.hScaleFactor
                        columns: 3
                        columnSpacing:7*main.vScaleFactor

                        property real delegateWidth: (width-columnSpacing)/(columns)
                        property real delegateHeight: (height-rowSpacing)/(rows+0.5)

                        Repeater {
                            model:keypadList
                            delegate: keypadButtonDelegate
                        }

                        Component {
                            id: keypadButtonDelegate

                            Item {
                                Layout.preferredWidth: keypadGrid.delegateWidth
                                Layout.preferredHeight: keypadGrid.delegateHeight

                                StandardButton {
                                    anchors.fill: parent
                                    //sourceName: model.iconPath
                                    buttonText: qsTr(model.label) + application.emptyString
                                    //                                    buttonText: model.name ===  "CloseCaption" ? qsTr("Track #") + tv.captionTrack  : qsTr(model.label)
                                    label.font.pixelSize: 20 * main.vScaleFactor
                                    //                                    wideImage: true
                                    selected: (tv.captionTrack>0 && model.name ===  "CC")
                                    color: selected ? main.colorSelected : main.colorDialogBackground
                                    onClicked: {
                                        keypadClicked(model.name)
                                        root.action()
                                    }
                                }
                            }
                        }
                    }
                }

                Item { // channel list area
                    id: listArea
                    Layout.fillWidth: true
                    Layout.fillHeight: true
                    Layout.alignment: Qt.AlignHCenter | Qt.AlignTop
                    visible: (options.cabEnabled)? false : true

                    ListView {
                        id: channelMenu
                        anchors.fill: parent
                        anchors.horizontalCenter: parent.horizontalCenter
                        anchors.verticalCenter: parent.verticalCenter
                        currentIndex: -1
                        model: tv.channelList.channels
                        delegate: menuButtonDelegate
                        spacing: 8 * main.vScaleFactor
                        clip: true
                    }
                }
                Item { // media buttons
                    id: cabControlArea
                    Layout.fillWidth: true
                    Layout.preferredHeight: 0.8*parent.width / 2 * cabControlGrid.rows
                    Layout.alignment: Qt.AlignHCenter | Qt.AlignBottom
                    visible: (options.cabEnabled)?true:false

                    GridLayout {
                        id: cabControlGrid
                        anchors.fill: parent
                        rows: 3
                        rowSpacing: 7 * main.hScaleFactor
                        columns: 2
                        columnSpacing: 7 * main.vScaleFactor

                        property real delegateWidth: (width-columnSpacing)/columns
                        property real delegateHeight: (height-rowSpacing)/rows

                        Repeater {
                            model:controlsListCab
                            delegate: cabControlButtonDelegate
                        }

                        Component {
                            id: cabControlButtonDelegate

                            Item {
                                Layout.preferredWidth: cabControlGrid.delegateWidth
                                Layout.preferredHeight: cabControlGrid.delegateHeight

                                StandardButton {
                                    anchors.fill: parent
                                    sourceName: model.iconPath
                                    buttonText: qsTr(model.label) + application.emptyString
//                                    buttonText: model.name ===  "CloseCaption" ? qsTr("Track #") + tv.captionTrack  : qsTr(model.label)
//                                    label.font.pixelSize: 10 * main.vScaleFactor
//                                    wideImage: true
                                    selected: (volume_controls.muted && model.name === "VolumeMute") || (tv.captionTrack>0 && model.name ===  "CloseCaption")
                                    color: selected ? main.colorSelected : main.colorDialogBackground
                                    onClicked: {
                                        controlClicked(model.name)
                                        root.action()
                                    }
                                }
                            }
                        }
                    } // end GridLayout
                }

                Item { // media buttons
                    id: controlArea
                    Layout.fillWidth: true
                    Layout.preferredHeight: 0.8*parent.width / 2 * controlGrid.rows
                    Layout.alignment: Qt.AlignHCenter | Qt.AlignBottom
                    visible: (options.cabEnabled)?false:true

                    GridLayout {
                        id: controlGrid
                        anchors.fill: parent
                        rows:  2
                        rowSpacing: 7 * main.hScaleFactor
                        columns: 2
                        columnSpacing: 7 * main.vScaleFactor

                        property real delegateWidth: (width-columnSpacing)/columns
                        property real delegateHeight: (height-rowSpacing)/rows

                        Repeater {
                            model: controlsList
                            delegate: controlButtonDelegate
                        }

                        Component {
                            id: controlButtonDelegate

                            Item {
                                Layout.preferredWidth: controlGrid.delegateWidth
                                Layout.preferredHeight: controlGrid.delegateHeight

                                StandardButton {
                                    anchors.fill: parent
                                    sourceName: model.iconPath
                                    buttonText: qsTr(model.label) + application.emptyString
//                                    buttonText: model.name ===  "CloseCaption" ? qsTr("Track #") + tv.captionTrack  : qsTr(model.label)
//                                    label.font.pixelSize: 10 * main.vScaleFactor
//                                    wideImage: true
                                    selected: (volume_controls.muted && model.name === "VolumeMute") || (tv.captionTrack>0 && model.name ===  "CloseCaption")
                                    color: selected ? main.colorSelected : main.colorDialogBackground
                                    onClicked: {
                                        controlClicked(model.name)
                                        root.action()
                                    }
                                }
                            }
                        }
                    } // end GridLayout
                } // end Item

                StandardButton
                {
                    id:tvFullScreenButton
                    Layout.fillWidth: true
                    Layout.preferredHeight: 0.8*parent.width/3
                    //buttonText: qsTr("FULL SCreen")+application.emptyString
                    icon.sourceName: "Media/expand_icon_720"
                    enabled:true
                    visible: (!options.cabEnabled)?true:false
                    onClicked:
                    {
                        tv.showScreen()
                    }
                }


            } // end ColumnLayout
        } // end Item

        Item { // TV area
            id: videoViewBackground
            Layout.fillWidth: true
            Layout.fillHeight: true
            Rectangle
            {
                id:tvNotPlaying
                anchors.fill: parent
                color: "black"
                visible: true

                Text {
                    anchors.centerIn: parent
                    color: "white"
                    visible: false
                    text: qsTr("The current channel may be temporarily unavailable.") + application.emptyString
                }
            }
        }
    }

    function channelSelected(id) {
        channelId=id
     /* if(workoutScreen.state==="SpeedKPVisible" || workoutScreen.state==="InclineKPVisible" || workoutScreen.state==="LevelKPVisible" )
        {
         showRect.start()
         workoutScreen.state=""

        }else
        {
            showRect.stop()*/

        //workoutScreen.state=""
        tv.on = true;
        print("TV channel selected id:" + id);

        if(id) {
            audioManager.tvRequest();
            root.channelID = id;
            tv.tuneChannelID(id);
            //}
        }
    }
    Timer
    {
        id:showRect
        interval: 1
        repeat: false
        onTriggered:
        {
            tv.on = true;
            print("TV channel selected id:" + channelId);

            if(channelId) {
                audioManager.tvRequest();
                root.channelID = channelId;
                tv.tuneChannelID(channelId);
                showRect.stop()
            }
        }
    }

    Component {
        id: menuButtonDelegate

        Item {
            id: menuButtonItem
            height: ListView.view.height * 0.2
            width: ListView.view.width

            property bool isCurrentItem: menuButtonItem.ListView.isCurrentItem
            property int _index: index

            function getChannelDesc()  {
                if (name || (number && name && number != name)) {
                    return name
                } else if (number) {
                    return number
                } else {
                    return ""
                }
            }

            Rectangle {
                color: menuButtonItem.isCurrentItem ? main.colorSelected : main.colorDialogBackground
                height: parent.height
                width: parent.width
                border.color: main.colorUIBorder
                border.width: main.widthBorder
                radius: main.defaultRadius
                anchors.horizontalCenter: parent.horizontalCenter

                Connections {
                    target: menuButtonMouseArea
                    ignoreUnknownSignals: true
                    onClicked: {
                        menuButtonItem.ListView.view.currentIndex = menuButtonItem._index;
                        root.action()
                    }
                }

                TextLabel {
                    anchors.fill: parent
                    anchors.margins: 12 * main.scaleFactor
                    horizontalAlignment: Text.AlignJustify
                    verticalAlignment: Text.AlignVCenter
                    text: getChannelDesc()
                    wrapMode: Text.WordWrap
                    font.pixelSize: 14 * main.vScaleFactor
                    clip: true
                }

                MouseArea {
                    id: menuButtonMouseArea
                    anchors.fill: parent
                    onClicked: {

                        channelSelected(id)
                        root.action()


                    }




                    Rectangle {
                        anchors.fill: parent
                        color: main.colorGenericStimulusArea
                        opacity: 0.3
                        visible: main.showStimulusArea
                    }
                }
            }
        }
    }

    ListModel {
        id: controlsList

        ListElement {
            name: "VolumeDown"
            label: QT_TR_NOOP("VOL")
            iconPath: "Media/Media_Volume_Minus"
        }
        ListElement {
            name: "VolumeUp"
            label: QT_TR_NOOP("VOL")
            iconPath: "Media/Media_Volume_Plus"
        }
        ListElement {
            name: "CloseCaption"
            label: QT_TR_NOOP("")
            iconPath: "Media/CC_icon"
        }
        ListElement {
            name: "VolumeMute"
            label: ""
            iconPath: "Media/Media_Mute_Up"
        }
    }


    function controlClicked(name) {
        if(name === "VolumeDown") {
            volume_controls.volumeDown();
        } else if(name === "VolumeUp") {
            volume_controls.volumeUp();
        } else if(name === "CloseCaption") {
            if(tv.on)
            {
                tv.captionTrack = tv.numCaptionTracks > 0 ? (tv.captionTrack + 1) % tv.numCaptionTracks : 0
                if(tv.captionTrack===0)
                    ccName=""
                else
                    ccName="TRACK "+tv.captionTrack
                //  controlsList.setProperty(2,"label",ccName)
            }
        }else if(name === "CloseCaptionByKeypad") {

            ccpresed=true
            tv.showclosecaption=true
            tv.on=true
            channelKeypad.opacity = 0
        }
        else if(name === "VolumeMute") {
            volume_controls.toggleMute();
        } else if(name === "ChannelDown") {
            if(options.cabEnabled)
                nucleus.cabChannelDown()
        } else if(name === "ChannelUp") {
            if(options.cabEnabled)
                nucleus.cabChannelUp()
        }else if(name === "FullScreen") {
            tv.showScreen()
        }
        /* else if(name === "Keypad") {
            if(options.cabEnabled) {
                /* Show keypad */
        //channelKeypad.opacity = 1.0
        //}
        // }
    }

    ListModel {
        id: keypadList


        ListElement {
            name: "1"
            label: qsTr("1")
            iconPath: ""
        }
        ListElement {
            name: "2"
            label: qsTr("2")
            iconPath: ""
        }
        ListElement {
            name: "3"
            label: qsTr("3")
            iconPath: ""
        }
        ListElement {
            name: "4"
            label: qsTr("4")
            iconPath: ""
        }
        ListElement {
            name: "5"
            label: qsTr("5")
            iconPath: ""
        }
        ListElement {
            name: "6"
            label: qsTr("6")
            iconPath: ""
        }
        ListElement {
            name: "7"
            label: qsTr("7")
            iconPath: ""
        }
        ListElement {
            name: "8"
            label: qsTr("8")
            iconPath: ""
        }
        ListElement {
            name: "9"
            label: qsTr("9")
            iconPath: ""
        }
        ListElement {
            name: "CC"
            label: qsTr("CC")
            iconPath: ""
        }
        ListElement {
            name: "0"
            label: qsTr("0")
            iconPath: ""
        }
    }

    function keypadClicked(name)
    {

        switch(name) {
        case "0": nucleus.cabDigit(0); break;
        case "1": nucleus.cabDigit(1); break;
        case "2": nucleus.cabDigit(2); break;
        case "3": nucleus.cabDigit(3); break;
        case "4": nucleus.cabDigit(4); break;
        case "5": nucleus.cabDigit(5); break;
        case "6": nucleus.cabDigit(6); break;
        case "7": nucleus.cabDigit(7); break;
        case "8": nucleus.cabDigit(8); break;
        case "9": nucleus.cabDigit(9); break;
        case "CC": nucleus.cabCloseCaption();
            //nucleus.cabDigit(A)
            controlClicked("CloseCaptionByKeypad");
            break;

        }
    }

    ListModel {
        id: controlsListCab

        ListElement {
            name: "ChannelDown"
            label: qsTr("CHAN")
            iconPath: "Media/Media_Volume_Minus"
        }
        ListElement {
            name: "ChannelUp"
            label: qsTr("CHAN")
            iconPath: "Media/Media_Volume_Plus"
        }
        ListElement {
            name: "VolumeDown"
            label: qsTr("VOL")
            iconPath: "Media/Media_Volume_Minus"
        }
        ListElement {
            name: "VolumeUp"
            label: qsTr("VOL")
            iconPath: "Media/Media_Volume_Plus"
        }
        ListElement {
            name: "VolumeMute"
            label: ""
            iconPath: "Media/Media_Mute_Up"
        }
        //        ListElement {
        //            name: "CloseCaption"
        //            label: ""
        //            iconPath: "Media/CC_icon"
        //        }
        /*ListElement {
            name: "Keypad"
            label: ""
            iconPath: "Media/Remote_icon"
        }*/
        ListElement {
            name: "FullScreen"
            label: ""
            iconPath: "Media/expand_icon_480"
        }

    }
    /*function controlClicked(name) {
        if(name === "VolumeDown") {
            volume_controls.volumeDown();
        } else if(name === "VolumeUp") {
            volume_controls.volumeUp();
        } else if(name === "CloseCaption") {

            tv.captionTrack = tv.numCaptionTracks > 0 ? (tv.captionTrack + 1) % tv.numCaptionTracks : 0
            console.log("tv caption trackkkkkkkkkkkkkkkkkkkkkkkkkkk::::::::::::::::::::::::::::::",tv.captionTrack)
                if(tv.captionTrack===0)
                    ccName=""
                else
             ccName="TRACK "+tv.captionTrack
          //  controlsList.setProperty(2,"label",ccName)

        }else if(name === "CloseCaptionByKeypad") {

             ccpresed=true
            tv.showclosecaption=true
            //tv.on=true
            tvON()
            //channelKeypad.opacity = 0
         }
        else if(name === "VolumeMute") {
            volume_controls.toggleMute();
        } else if(name === "ChannelDown") {
            if(options.cabEnabled)
                nucleus.cabChannelDown()
        } else if(name === "ChannelUp") {
            if(options.cabEnabled)
                nucleus.cabChannelUp()
        } else if(name === "Keypad") {
            if(options.cabEnabled) {
                // Show keypad
                //channelKeypad.opacity = 1.0
            }
        }

        else if(name === "FullScreen") {
                    //if(root.tunedToCabChannel && options.cabEnabled)
                    //nucleus.cabChannelUp()
             tv.showScreen()
                }
    }

    Keypad{
        id:channelKeypad
        units: ""
        length: 3
        decimalPlaces: 1
        allow_close: false
        clear_after_enter: false
        show_entry: false
        icon: ""
        anchors.left: parent.left
        anchors.leftMargin: root.width * 0.20
        anchors.bottom: parent.bottom
        z: root.z + 1
        opacity: 0.0
        isColorInverted: true
        visible: (opacity > 0.0)
        labelForLeftArrow: "CC"

        onOpacityChanged: {
            if(opacity === 1.0) {
                if(ccpresed)
                {
                    ccName="TRACK"+" "+tv.captionTrack +"\n" +"\n"+"CC"
                    console.log("ccName::::::::::::::::::::::::::::::::::::::::::::::",ccName)
                   // channelKeypad.labelForLeftArrow=ccName
                    ccpresed=false
                }

                timer.start()
                tv.on = false
            }
        }

        onKeyPress: {
            if(visible === false) {
                return;
            }

            timer.restart()

            switch(key) {
            case "0": nucleus.cabDigit(0); break;
            case "1": nucleus.cabDigit(1); break;
            case "2": nucleus.cabDigit(2); break;
            case "3": nucleus.cabDigit(3); break;
            case "4": nucleus.cabDigit(4); break;
            case "5": nucleus.cabDigit(5); break;
            case "6": nucleus.cabDigit(6); break;
            case "7": nucleus.cabDigit(7); break;
            case "8": nucleus.cabDigit(8); break;
            case "9": nucleus.cabDigit(9); break;
            case "<": nucleus.cabCloseCaption(); controlClicked("CloseCaptionByKeypad"); break;
            case ">":

                timer.stop()
                tv.on = true
                nucleus.cabEnter();
                channelKeypad.opacity = 0
                break;
            }
        }

        Timer {
            id: timer
            interval: 5000
            onTriggered: {
                tv.on = true
                parent.opacity = 0
            }
        }
    }*/
}
